
## Multi-tree objects
Toytree also supports the use of `multitree` objects to store lists of linked trees, such as bootstrap replicates or trees sampled from a posterior distribution. `multitree` objects can be generated by parsing a file or string of newick trees separated by newlines. 


```python
import toytree
import toyplot
import numpy as np
```

An example multi-tree newick file represented as a string:


```python
string = """\
(((a:1,b:1):1,(d:1.5,e:1.5):0.5):1,c:3);
(((a:1,d:1):1,(b:1,e:1):1):1,c:3);
(((a:1.5,b:1.5):0.5,(d:1,e:1):1):1,c:3);
(((a:1.25,b:1.25):0.75,(d:1,e:1):1):1,c:3);
(((a:1,b:1):1,(d:1.5,e:1.5):0.5):1,c:3);
(((a:1,b:1):1,(d:1.5,e:1.5):0.5):1,c:3);
(((a:1.5,b:1.5):0.5,(d:1,e:1):1):1,c:3);
(((b:1.5,d:1.5):0.5,(a:1,e:1):1):1,c:3);
"""
```

Parse the multi-tree newick string as a `multitree` object:


```python
trees = toytree.multitree(string)
```

You can access each individual tree from the `multitree` object's `treelist` attribute. Unlike regular Toytree objects these trees will have *their tip order fixed* so that discordance between trees is apparent. This is important for creating cloudtrees, further below. 


```python
trees.treelist
```




    [<toytree.tree.Toytree at 0x7f0410627d90>,
     <toytree.tree.Toytree at 0x7f0410627ed0>,
     <toytree.tree.Toytree at 0x7f0410635110>,
     <toytree.tree.Toytree at 0x7f0410635450>,
     <toytree.tree.Toytree at 0x7f0410635650>,
     <toytree.tree.Toytree at 0x7f0410635b10>,
     <toytree.tree.Toytree at 0x7f0410635d90>,
     <toytree.tree.Toytree at 0x7f0410635dd0>]




```python
for tre in trees.treelist:
    tre.draw(tree_style='c')
```


<div class="toyplot" id="td8a30e1fb5714342bb8bbb9ccf82ef5f" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="t64ce12677b5c4999a3f1382452103233" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t87e9fd8a0be64037845cb9f15af2bba7"><clipPath id="t2ab3ffe2caf341ae821e6c3d29d7ec1c"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#t2ab3ffe2caf341ae821e6c3d29d7ec1c)"><g class="toyplot-mark-Text" id="t681fb946fc5d4a52955f3cc3ca537412"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(56.652587117212249,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">c</text></g><g class="toyplot-Datum" transform="translate(97.076293558606125,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(137.5,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(177.92370644139388,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(218.34741288278775,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">d</text></g></g></g><g class="toyplot-mark-Graph" id="tf06e82fb309e4f10b52d8f20c5215c2b"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 121.020144722 L 137.5 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 121.020144722 L 97.0762935586 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 117.288146779 121.020144722" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 103.265108542 L 218.347412883 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 103.265108542 L 177.923706441 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 198.135559662 103.265108542" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 85.510072361" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.34741288278775, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.076293558606125, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.652587117212249, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.13555966209083, 103.26510854150759)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.28814677930306, 121.02014472201012)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 85.510072361005058)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "td8a30e1fb5714342bb8bbb9ccf82ef5f";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t64ce12677b5c4999a3f1382452103233";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf06e82fb309e4f10b52d8f20c5215c2b","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -1.5, -2.0, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf06e82fb309e4f10b52d8f20c5215c2b","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
})();</script></div></div>



<div class="toyplot" id="t849c4fdb750d4cf79bc77f57c7d5a012" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="t45229dda2ea841b9a3def52e36b8502b" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t2c457977e1f54d77a461d85eb3c18f37"><clipPath id="tc2546d6eb3fe480a8a157493ff4d7f4e"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#tc2546d6eb3fe480a8a157493ff4d7f4e)"><g class="toyplot-mark-Text" id="t09fd9e0c36f24f8993e63c37c13e20de"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(56.652587117212249,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">c</text></g><g class="toyplot-Datum" transform="translate(97.076293558606125,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(137.5,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(177.92370644139388,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(218.34741288278775,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">d</text></g></g></g><g class="toyplot-mark-Graph" id="t47113cb84d044c039ffe0c295a297254"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.923706441 121.020144722 L 137.5 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.923706441 121.020144722 L 218.347412883 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 177.923706441 121.020144722" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.5 121.020144722 L 97.0762935586 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.5 121.020144722 L 177.923706441 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 137.5 121.020144722" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 85.510072361" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.076293558606125, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.34741288278775, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.652587117212249, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 121.02014472201012)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 121.02014472201012)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 85.510072361005058)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t849c4fdb750d4cf79bc77f57c7d5a012";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t45229dda2ea841b9a3def52e36b8502b";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t47113cb84d044c039ffe0c295a297254","vertex_data","graph vertex data",["x", "y"],[[3.0, 1.0, 4.0, 2.0, 0.0, 2.0, 3.0, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -2.0, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t47113cb84d044c039ffe0c295a297254","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
})();</script></div></div>



<div class="toyplot" id="t845c337da14447028ec2c17c4714551e" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="ta87cacd740aa49dbac26b7a440cb4ec6" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t032caf0d7cd94deca45511fd414081dc"><clipPath id="t9b83f267fe294014b4490a05b3ebaab7"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#t9b83f267fe294014b4490a05b3ebaab7)"><g class="toyplot-mark-Text" id="t5a4e6965a84c4b3bad438d404c85a087"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(56.652587117212249,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">c</text></g><g class="toyplot-Datum" transform="translate(97.076293558606125,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(137.5,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(177.92370644139388,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(218.34741288278775,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">d</text></g></g></g><g class="toyplot-mark-Graph" id="tbff8aa78d9234c40bb9efe8b8d3e0751"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 103.265108542 L 137.5 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 103.265108542 L 97.0762935586 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 117.288146779 103.265108542" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 121.020144722 L 218.347412883 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 121.020144722 L 177.923706441 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 198.135559662 121.020144722" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 85.510072361" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.34741288278775, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.076293558606125, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.652587117212249, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.13555966209083, 121.02014472201012)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.28814677930306, 103.26510854150759)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 85.510072361005058)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t845c337da14447028ec2c17c4714551e";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "ta87cacd740aa49dbac26b7a440cb4ec6";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbff8aa78d9234c40bb9efe8b8d3e0751","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -1.5, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbff8aa78d9234c40bb9efe8b8d3e0751","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
})();</script></div></div>



<div class="toyplot" id="t61160f0157c2499a9fefa0d2ffe2e1ee" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="t0fd24be8c0c244c9a6ca13d5ce4b0e48" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t86e08e2ee38547d5ade096b0eec1a0e0"><clipPath id="tb0adfd539d44466cac64ef64c6ce1f57"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#tb0adfd539d44466cac64ef64c6ce1f57)"><g class="toyplot-mark-Text" id="t666b1a1849bc4edfa340f5443a011fd1"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(56.652587117212249,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">c</text></g><g class="toyplot-Datum" transform="translate(97.076293558606125,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(137.5,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(177.92370644139388,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(218.34741288278775,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">d</text></g></g></g><g class="toyplot-mark-Graph" id="t65a78639289d4824acc1b4f06b02360c"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 112.142626632 L 137.5 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 112.142626632 L 97.0762935586 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 117.288146779 112.142626632" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 121.020144722 L 218.347412883 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 121.020144722 L 177.923706441 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 198.135559662 121.020144722" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 85.510072361" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.34741288278775, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.076293558606125, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.652587117212249, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.13555966209083, 121.02014472201012)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.28814677930306, 112.14262663175884)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 85.510072361005058)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t61160f0157c2499a9fefa0d2ffe2e1ee";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t0fd24be8c0c244c9a6ca13d5ce4b0e48";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t65a78639289d4824acc1b4f06b02360c","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -1.75, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t65a78639289d4824acc1b4f06b02360c","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
})();</script></div></div>



<div class="toyplot" id="t022081c306fa44168e8a98ac64bc2210" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="tb8e6011a2066479aa6ce51126fbff607" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="tc84ea85947e2414c947d563ec368448e"><clipPath id="t0c607faf8fad4cdfbc961ac4edbc3c17"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#t0c607faf8fad4cdfbc961ac4edbc3c17)"><g class="toyplot-mark-Text" id="tfec3ac3693a94630a6af98559bd7cbc9"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(56.652587117212249,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">c</text></g><g class="toyplot-Datum" transform="translate(97.076293558606125,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(137.5,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(177.92370644139388,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(218.34741288278775,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">d</text></g></g></g><g class="toyplot-mark-Graph" id="t4379ae911b534d44bf22b59b86f1a460"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 121.020144722 L 137.5 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 121.020144722 L 97.0762935586 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 117.288146779 121.020144722" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 103.265108542 L 218.347412883 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 103.265108542 L 177.923706441 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 198.135559662 103.265108542" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 85.510072361" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.34741288278775, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.076293558606125, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.652587117212249, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.13555966209083, 103.26510854150759)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.28814677930306, 121.02014472201012)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 85.510072361005058)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t022081c306fa44168e8a98ac64bc2210";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "tb8e6011a2066479aa6ce51126fbff607";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4379ae911b534d44bf22b59b86f1a460","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -1.5, -2.0, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4379ae911b534d44bf22b59b86f1a460","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
})();</script></div></div>



<div class="toyplot" id="te5f2a241ff2d49c2b4c5cda7d0d8d3cd" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="t67c2f7150b1540dc98bd6ed24eb39739" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t076fae28bc3e400a95c11c188a1ac0e8"><clipPath id="t303d7cd347e046d9a7fe9569697871c3"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#t303d7cd347e046d9a7fe9569697871c3)"><g class="toyplot-mark-Text" id="t5f1a47ef1b804a118ac5a093b87ae1f1"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(56.652587117212249,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">c</text></g><g class="toyplot-Datum" transform="translate(97.076293558606125,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(137.5,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(177.92370644139388,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(218.34741288278775,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">d</text></g></g></g><g class="toyplot-mark-Graph" id="t870883564118491e9da6d770e96047e3"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 121.020144722 L 137.5 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 121.020144722 L 97.0762935586 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 117.288146779 121.020144722" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 103.265108542 L 218.347412883 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 103.265108542 L 177.923706441 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 198.135559662 103.265108542" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 85.510072361" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.34741288278775, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.076293558606125, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.652587117212249, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.13555966209083, 103.26510854150759)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.28814677930306, 121.02014472201012)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 85.510072361005058)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "te5f2a241ff2d49c2b4c5cda7d0d8d3cd";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t67c2f7150b1540dc98bd6ed24eb39739";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t870883564118491e9da6d770e96047e3","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -1.5, -2.0, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t870883564118491e9da6d770e96047e3","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
})();</script></div></div>



<div class="toyplot" id="t8fcd52d3742346a48127a58f738ad48e" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="t518b94b345ef495db4ce2db51070c5c7" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t9b77becc02b74896964bb3c5cc9abfd2"><clipPath id="t7671024c64ee4d5c849814c403be27bb"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#t7671024c64ee4d5c849814c403be27bb)"><g class="toyplot-mark-Text" id="td16fda6774ac4f27a1bc8ad056ce99aa"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(56.652587117212249,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">c</text></g><g class="toyplot-Datum" transform="translate(97.076293558606125,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(137.5,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(177.92370644139388,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(218.34741288278775,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">d</text></g></g></g><g class="toyplot-mark-Graph" id="ta9219e33a6754bdfb0e44a840c36c2a7"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 103.265108542 L 137.5 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 103.265108542 L 97.0762935586 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 117.288146779 103.265108542" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 121.020144722 L 218.347412883 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 121.020144722 L 177.923706441 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 198.135559662 121.020144722" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 85.510072361" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.34741288278775, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.076293558606125, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.652587117212249, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.13555966209083, 121.02014472201012)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.28814677930306, 103.26510854150759)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 85.510072361005058)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t8fcd52d3742346a48127a58f738ad48e";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t518b94b345ef495db4ce2db51070c5c7";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta9219e33a6754bdfb0e44a840c36c2a7","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -1.5, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta9219e33a6754bdfb0e44a840c36c2a7","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
})();</script></div></div>



<div class="toyplot" id="t6996c2783e63415888248718910655d3" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="tbeb1671fad8843978b2c3613fb48f615" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t59d3499fea474c5db5f034c472d99d71"><clipPath id="t8948935381c445639a4689242eda8364"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#t8948935381c445639a4689242eda8364)"><g class="toyplot-mark-Text" id="tbacf3f10bca14cf2b2e83d3d58284c5c"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(56.652587117212249,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">c</text></g><g class="toyplot-Datum" transform="translate(97.076293558606125,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(137.5,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(177.92370644139388,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(218.34741288278775,156.53021708301517)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">d</text></g></g></g><g class="toyplot-mark-Graph" id="tdd7a0b30842748c9b03f33dd524a440c"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 103.265108542 L 97.0762935586 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 103.265108542 L 218.347412883 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 157.711853221 103.265108542" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 121.020144722 L 137.5 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 121.020144722 L 177.923706441 156.530217083" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 85.510072361 L 157.711853221 121.020144722" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 85.510072361" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.34741288278775, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.076293558606125, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.652587117212249, 156.53021708301517)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 121.02014472201012)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 103.26510854150759)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 85.510072361005058)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t6996c2783e63415888248718910655d3";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "tbeb1671fad8843978b2c3613fb48f615";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd7a0b30842748c9b03f33dd524a440c","vertex_data","graph vertex data",["x", "y"],[[3.0, 2.0, 4.0, 1.0, 0.0, 2.5, 2.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -1.5, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd7a0b30842748c9b03f33dd524a440c","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
})();</script></div></div>


### Consensus tree

A `multitree` object can return an unrooted consensus tree as a `toytree` object. 



```python
## returns the majority 50% tree 
constree = trees.get_consensus_tree(cutoff=0.50)

## returns the extended majority-rule consensus tree
constree = trees.get_consensus_tree()
```


```python
## it is unrooted so I shift the node labels to the edges
constree.draw(
    node_labels=constree.get_node_values("support"), 
    node_size=0,
    node_labels_style={
        'font-size': '12px',
        '-toyplot-anchor-shift': '-15px',
        'baseline-shift': '10px'
        }
    );
```


<div class="toyplot" id="te3cf58ad35a740a5b484c8148bfce675" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="275.0px" id="t29f8ea8b8b674030886c8ef14738e78b" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 225.0 275.0" width="225.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t30bc8af82b404238ae786f669b645103"><clipPath id="tc210267a3e74406b8318340122cf381b"><rect height="275.0" width="225.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#tc210267a3e74406b8318340122cf381b)"><g class="toyplot-mark-Text" id="td7ea5421744d40df938dd7a058e1ea74"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(156.53021708301517,218.34741288278775)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(156.53021708301517,177.9237064413939)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">d</text></g><g class="toyplot-Datum" transform="translate(156.53021708301517,137.50000000000003)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(156.53021708301517,97.076293558606153)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(88.738260757460054,56.652587117212242)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">c</text></g></g></g><g class="toyplot-mark-Graph" id="tf86c97cde04243cea65433c474b87675"><g class="toyplot-Edges"><path d="M 50.0 107.182220169 L 50.0 56.6525871172" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 56.6525871172 L 88.7382607575 56.6525871172" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 107.182220169 L 50.0 157.711853221" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 157.711853221 L 88.7382607575 157.711853221" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.7382607575 157.711853221 L 88.7382607575 117.288146779" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.7382607575 117.288146779 L 117.791956326 117.288146779" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.7382607575 157.711853221 L 88.7382607575 198.135559662" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.7382607575 198.135559662 L 117.791956326 198.135559662" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.791956326 117.288146779 L 117.791956326 97.0762935586" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.791956326 97.0762935586 L 156.530217083 97.0762935586" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.791956326 117.288146779 L 117.791956326 137.5" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.791956326 137.5 L 156.530217083 137.5" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.791956326 198.135559662 L 117.791956326 177.923706441" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.791956326 177.923706441 L 156.530217083 177.923706441" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.791956326 198.135559662 L 117.791956326 218.347412883" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.791956326 218.347412883 L 156.530217083 218.347412883" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(50.0, 107.1822201689546)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(50.0, 56.652587117212242)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(88.738260757460054, 56.652587117212242)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(50.0, 157.71185322069692)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(88.738260757460054, 157.71185322069692)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(88.738260757460054, 157.71185322069692)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(88.738260757460054, 117.28814677930308)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.79195632555509, 117.28814677930308)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(88.738260757460054, 198.13555966209083)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.79195632555509, 198.13555966209083)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.79195632555509, 117.28814677930308)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.79195632555509, 97.076293558606153)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(156.53021708301517, 97.076293558606153)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.79195632555509, 137.50000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(156.53021708301517, 137.50000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.79195632555509, 198.13555966209083)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.79195632555509, 177.9237064413939)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(156.53021708301517, 177.9237064413939)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.79195632555509, 218.34741288278775)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(156.53021708301517, 218.34741288278775)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Scatterplot" id="t84126558f0914adcb3bcacf606d32cf9"><g class="toyplot-Series"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(117.79195632555509, 198.13555966209083)"><title>idx: 5
name: i5
dist: 75
support: 75
height: 100</title><circle r="0.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-21.672" y="-6.934">75</text></g></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(117.79195632555509, 117.28814677930308)"><title>idx: 6
name: i6
dist: 75
support: 75
height: 100</title><circle r="0.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-21.672" y="-6.934">75</text></g></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(88.738260757460054, 157.71185322069692)"><title>idx: 7
name: i7
dist: 100
support: 100
height: 175</title><circle r="0.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-25.008" y="-6.934">100</text></g></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "te3cf58ad35a740a5b484c8148bfce675";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t29f8ea8b8b674030886c8ef14738e78b";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf86c97cde04243cea65433c474b87675","vertex_data","graph vertex data",["x", "y"],[[-275.0, -275.0, -175.0, -275.0, -175.0, -175.0, -175.0, -100.0, -175.0, -100.0, -100.0, -100.0, 0.0, -100.0, 0.0, -100.0, -100.0, 0.0, -100.0, 0.0], [2.75, 4.0, 4.0, 1.5, 1.5, 1.5, 2.5, 2.5, 0.5, 0.5, 2.5, 3.0, 3.0, 2.0, 2.0, 0.5, 1.0, 1.0, 0.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf86c97cde04243cea65433c474b87675","edge_data","graph edge data",["source", "target"],[[0, 1, 0, 3, 5, 6, 5, 8, 10, 11, 10, 13, 15, 16, 15, 18], [1, 2, 3, 4, 6, 7, 8, 9, 11, 12, 13, 14, 16, 17, 18, 19]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t84126558f0914adcb3bcacf606d32cf9","data","scatterplot",["x", "y0"],[[0.0, 0.0, 0.0, 0.0, -175.0, -100.0, -100.0, -175.0, -275.0], [0.0, 1.0, 2.0, 3.0, 4.0, 0.5, 2.5, 1.5, 2.75]],"toyplot");
})();</script></div></div>


### Draw a cloud-tree
Cloud trees are useful for representing discordance or variation among a set of trees. You can draw a cloudtree from a multitree object using the `draw_cloudtree()` function, which has similar arguments as the standard `draw()` function. 


```python
trees.draw_cloudtree(
    edge_style={"opacity": 0.25}
    );
```


<div class="toyplot" id="t50c4ceb44e0c4fe58fed00cea5c013e2" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="t40a1ab03bd9e4983af3f825796bf712e" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t1a597ae95a784303b876061bd1a8ccdd"><clipPath id="te60f256a2d924bbcac6646a8bb3d46d5"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#te60f256a2d924bbcac6646a8bb3d46d5)"><g class="toyplot-mark-Text" id="t3e8a9cd3ccd34250a18c7366a8d74028"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t45da611c129f477ca5e2f303a55f555f"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 122.503108933 L 137.5 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 122.503108933 L 97.0762935586 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 117.288146779 122.503108933" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 104.3773317 L 218.347412883 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 104.3773317 L 177.923706441 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 198.135559662 104.3773317" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 86.2515544667" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.92370644139388, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.34741288278775, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.076293558606125, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.5, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.652587117212249, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.13555966209083, 104.3773316999833)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(117.28814677930306, 122.50310893331108)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.71185322069695, 86.251554466655534)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5a0f42ef728a490d92f9bbf64635aa4b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t652953978c984fd68c429b2dae7a98d7"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.923706441 122.503108933 L 137.5 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.923706441 122.503108933 L 218.347412883 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 177.923706441 122.503108933" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.5 122.503108933 L 97.0762935586 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.5 122.503108933 L 177.923706441 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 137.5 122.503108933" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 86.2515544667" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.92370644139388, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(97.076293558606125, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(218.34741288278775, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(137.5, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(56.652587117212249, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(137.5, 122.50310893331108)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.92370644139388, 122.50310893331108)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(157.71185322069695, 86.251554466655534)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t803fe535f22f44c0b243d13d253c095d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t125ed37ef9ec4a0aab4bb73f8bb4b490"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 104.3773317 L 137.5 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 104.3773317 L 97.0762935586 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 117.288146779 104.3773317" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 122.503108933 L 218.347412883 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 122.503108933 L 177.923706441 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 198.135559662 122.503108933" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 86.2515544667" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.92370644139388, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(218.34741288278775, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(97.076293558606125, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.5, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(56.652587117212249, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.13555966209083, 122.50310893331108)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(117.28814677930306, 104.3773316999833)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(157.71185322069695, 86.251554466655534)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4749258f40d94b60ae6327024ec53898"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t808e9d718cdc481bb81409194388dc9d"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 113.440220317 L 137.5 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 113.440220317 L 97.0762935586 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 117.288146779 113.440220317" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 122.503108933 L 218.347412883 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 122.503108933 L 177.923706441 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 198.135559662 122.503108933" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 86.2515544667" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(177.92370644139388, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(218.34741288278775, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(97.076293558606125, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.5, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(56.652587117212249, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.13555966209083, 122.50310893331108)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(117.28814677930306, 113.44022031664718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(157.71185322069695, 86.251554466655534)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t48bd60356fdd49ea82e785018c0bdec0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf6e3425115b541bc9405dcb5d1457f7a"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 122.503108933 L 137.5 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 122.503108933 L 97.0762935586 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 117.288146779 122.503108933" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 104.3773317 L 218.347412883 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 104.3773317 L 177.923706441 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 198.135559662 104.3773317" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 86.2515544667" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(177.92370644139388, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(218.34741288278775, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(97.076293558606125, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(137.5, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(56.652587117212249, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.13555966209083, 104.3773316999833)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(117.28814677930306, 122.50310893331108)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(157.71185322069695, 86.251554466655534)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t280f3c5eec1c430d8f4d8f09df31060f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9788e2323b2e4a959b99343b0e2415e5"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 122.503108933 L 137.5 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 122.503108933 L 97.0762935586 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 117.288146779 122.503108933" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 104.3773317 L 218.347412883 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 104.3773317 L 177.923706441 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 198.135559662 104.3773317" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 86.2515544667" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(177.92370644139388, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(218.34741288278775, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(97.076293558606125, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(137.5, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(56.652587117212249, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.13555966209083, 104.3773316999833)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(117.28814677930306, 122.50310893331108)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(157.71185322069695, 86.251554466655534)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta263ec1a87a4470c93728e1dbd5387ff"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2b77a39306cc4b80b0765713c72d511d"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 104.3773317 L 137.5 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.288146779 104.3773317 L 97.0762935586 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 117.288146779 104.3773317" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 122.503108933 L 218.347412883 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.135559662 122.503108933 L 177.923706441 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 198.135559662 122.503108933" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 86.2515544667" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(177.92370644139388, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(218.34741288278775, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(97.076293558606125, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(137.5, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(56.652587117212249, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.13555966209083, 122.50310893331108)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(117.28814677930306, 104.3773316999833)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(157.71185322069695, 86.251554466655534)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6be66492d9e84810871b191585d2f834"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t484c9161f6d34f1b81547cdfbfa11e7c"><g class="toyplot-Edges"><path d="M 107.182220169 50.0 L 56.6525871172 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 104.3773317 L 97.0762935586 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 104.3773317 L 218.347412883 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 157.711853221 104.3773317" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 122.503108933 L 137.5 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 122.503108933 L 177.923706441 158.7546634" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.711853221 86.2515544667 L 157.711853221 122.503108933" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 107.182220169 50.0 L 157.711853221 86.2515544667" style="fill:none;opacity:0.25;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.92370644139388, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(137.5, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(218.34741288278775, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(97.076293558606125, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(56.652587117212249, 158.7546633999666)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(157.71185322069695, 122.50310893331108)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(157.71185322069695, 104.3773316999833)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(157.71185322069695, 86.251554466655534)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(107.18222016895459, 50.0)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb730eeec901a4184801bf3b2fa2413a0"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(177.92370644139388,158.7546633999666)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">d</text></g><g class="toyplot-Datum" transform="translate(137.5,158.7546633999666)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">e</text></g><g class="toyplot-Datum" transform="translate(218.34741288278775,158.7546633999666)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">a</text></g><g class="toyplot-Datum" transform="translate(97.076293558606125,158.7546633999666)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">b</text></g><g class="toyplot-Datum" transform="translate(56.652587117212249,158.7546633999666)rotate(90.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">c</text></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t50c4ceb44e0c4fe58fed00cea5c013e2";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t40a1ab03bd9e4983af3f825796bf712e";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t45da611c129f477ca5e2f303a55f555f","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -1.5, -2.0, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t45da611c129f477ca5e2f303a55f555f","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t652953978c984fd68c429b2dae7a98d7","vertex_data","graph vertex data",["x", "y"],[[3.0, 1.0, 4.0, 2.0, 0.0, 2.0, 3.0, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -2.0, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t652953978c984fd68c429b2dae7a98d7","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t125ed37ef9ec4a0aab4bb73f8bb4b490","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -1.5, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t125ed37ef9ec4a0aab4bb73f8bb4b490","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t808e9d718cdc481bb81409194388dc9d","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -1.75, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t808e9d718cdc481bb81409194388dc9d","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf6e3425115b541bc9405dcb5d1457f7a","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -1.5, -2.0, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf6e3425115b541bc9405dcb5d1457f7a","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9788e2323b2e4a959b99343b0e2415e5","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -1.5, -2.0, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9788e2323b2e4a959b99343b0e2415e5","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2b77a39306cc4b80b0765713c72d511d","vertex_data","graph vertex data",["x", "y"],[[3.0, 4.0, 1.0, 2.0, 0.0, 3.5, 1.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -1.5, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2b77a39306cc4b80b0765713c72d511d","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t484c9161f6d34f1b81547cdfbfa11e7c","vertex_data","graph vertex data",["x", "y"],[[3.0, 2.0, 4.0, 1.0, 0.0, 2.5, 2.5, 2.5, 1.25], [-3.0, -3.0, -3.0, -3.0, -3.0, -2.0, -1.5, -1.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t484c9161f6d34f1b81547cdfbfa11e7c","edge_data","graph edge data",["source", "target"],[[8, 6, 6, 7, 5, 5, 7, 8], [4, 3, 2, 6, 1, 0, 5, 7]],"toyplot");
})();</script></div></div>


### Empirical example

In this example we'll load an mcmc file from a species tree analysis in the program BPP which includes a sample of species trees sampled from a posterior distribution. 


```python
## btw, your input newick files can be a weblink
mcmcfile = "http://eaton-lab.org/pdsb/full-r0.mcmc.txt"
trees = toytree.multitree(mcmcfile)
print("{} trees".format(len(trees)))
```

    2001 trees


First you can examine a consensus tree. 


```python
## get consens tree
ctre = trees.get_consensus_tree()

## draw with supports (this consensus method does not currently return edge lengths)
ctre.draw(node_labels=ctre.get_node_values("support"), use_edge_lengths=False);
```


<div class="toyplot" id="t900a4172aeac4e44b90737561a81ed23" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="275.0px" id="tcf7bc9a79487465382b57e6e6f4c848d" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 225.0 275.0" width="225.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t5624d630a283453e94dced66200f91a5"><clipPath id="t509d003f4acf4743a112bad3ae308517"><rect height="275.0" width="225.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#t509d003f4acf4743a112bad3ae308517)"><g class="toyplot-mark-Text" id="tdd2fd2f210e34761b0bb2150a7867217"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(148.05828898483784,218.34741288278775)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">lip</text></g><g class="toyplot-Datum" transform="translate(148.05828898483784,198.13555966209083)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">rex</text></g><g class="toyplot-Datum" transform="translate(148.05828898483784,177.9237064413939)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">rck</text></g><g class="toyplot-Datum" transform="translate(148.05828898483784,157.71185322069692)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">tha</text></g><g class="toyplot-Datum" transform="translate(148.05828898483784,137.50000000000003)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">cup</text></g><g class="toyplot-Datum" transform="translate(148.05828898483784,117.28814677930308)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">sup</text></g><g class="toyplot-Datum" transform="translate(148.05828898483784,97.076293558606153)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">cya</text></g><g class="toyplot-Datum" transform="translate(148.05828898483784,76.864440337909201)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">cys</text></g><g class="toyplot-Datum" transform="translate(148.05828898483784,56.652587117212242)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="15.0" y="3.066">prz</text></g></g></g><g class="toyplot-mark-Graph" id="t223f106b8fbd4ffdb67a0082c9a84143"><g class="toyplot-Edges"><path d="M 50.0 90.4442792206 L 50.0 56.6525871172" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 56.6525871172 L 148.058288985 56.6525871172" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 90.4442792206 L 50.0 124.235971324" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 124.235971324 L 66.3430481641 124.235971324" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.3430481641 124.235971324 L 66.3430481641 92.0233302534" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.3430481641 92.0233302534 L 115.372192657 92.0233302534" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.3430481641 124.235971324 L 66.3430481641 156.448612394" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.3430481641 156.448612394 L 82.6860963283 156.448612394" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.372192657 92.0233302534 L 115.372192657 76.8644403379" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.372192657 76.8644403379 L 148.058288985 76.8644403379" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.372192657 92.0233302534 L 115.372192657 107.182220169" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.372192657 107.182220169 L 131.715240821 107.182220169" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.6860963283 156.448612394 L 82.6860963283 137.5" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.6860963283 137.5 L 148.058288985 137.5" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.6860963283 156.448612394 L 82.6860963283 175.397224789" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.6860963283 175.397224789 L 99.0291444924 175.397224789" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.715240821 107.182220169 L 131.715240821 97.0762935586" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.715240821 97.0762935586 L 148.058288985 97.0762935586" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.715240821 107.182220169 L 131.715240821 117.288146779" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.715240821 117.288146779 L 148.058288985 117.288146779" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 99.0291444924 175.397224789 L 99.0291444924 157.711853221" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 99.0291444924 157.711853221 L 148.058288985 157.711853221" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 99.0291444924 175.397224789 L 99.0291444924 193.082596357" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 99.0291444924 193.082596357 L 115.372192657 193.082596357" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.372192657 193.082596357 L 115.372192657 177.923706441" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.372192657 177.923706441 L 148.058288985 177.923706441" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.372192657 193.082596357 L 115.372192657 208.241486272" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.372192657 208.241486272 L 131.715240821 208.241486272" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.715240821 208.241486272 L 131.715240821 198.135559662" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.715240821 198.135559662 L 148.058288985 198.135559662" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.715240821 208.241486272 L 131.715240821 218.347412883" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.715240821 218.347412883 L 148.058288985 218.347412883" style="fill:none;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(50.0, 90.444279220564965)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(50.0, 56.652587117212242)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(148.05828898483784, 56.652587117212242)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(50.0, 124.23597132391765)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(66.343048164139645, 124.23597132391765)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(66.343048164139645, 124.23597132391765)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(66.343048164139645, 92.023330253431908)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(115.37219265655857, 92.023330253431908)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(66.343048164139645, 156.44861239440337)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(82.686096328279291, 156.44861239440337)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(115.37219265655857, 92.023330253431908)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(115.37219265655857, 76.864440337909201)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(148.05828898483784, 76.864440337909201)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(115.37219265655857, 107.1822201689546)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(131.7152408206982, 107.1822201689546)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(82.686096328279291, 156.44861239440337)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(82.686096328279291, 137.50000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(148.05828898483784, 137.50000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(82.686096328279291, 175.39722478880677)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(99.029144492418908, 175.39722478880677)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(131.7152408206982, 107.1822201689546)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(131.7152408206982, 97.076293558606153)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(148.05828898483784, 97.076293558606153)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(131.7152408206982, 117.28814677930308)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(148.05828898483784, 117.28814677930308)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(99.029144492418908, 175.39722478880677)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(99.029144492418908, 157.71185322069692)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(148.05828898483784, 157.71185322069692)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(99.029144492418908, 193.08259635691658)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(115.37219265655857, 193.08259635691658)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(115.37219265655857, 193.08259635691658)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(115.37219265655857, 177.9237064413939)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(148.05828898483784, 177.9237064413939)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(115.37219265655857, 208.24148627243929)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(131.7152408206982, 208.24148627243929)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(131.7152408206982, 208.24148627243929)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(131.7152408206982, 198.13555966209083)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(148.05828898483784, 198.13555966209083)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(131.7152408206982, 218.34741288278775)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(148.05828898483784, 218.34741288278775)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Scatterplot" id="t0df90ee5b0964c46bae0d639ad8cd541"><g class="toyplot-Series"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(131.7152408206982, 208.24148627243929)"><title>idx: 9
name: i9
dist: 56
support: 56
height: 100</title><circle r="11.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:9.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-5.004" y="2.2995">56</text></g></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(115.37219265655857, 193.08259635691658)"><title>idx: 10
name: i10
dist: 60
support: 60
height: 156</title><circle r="11.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:9.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-5.004" y="2.2995">60</text></g></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(99.029144492418908, 175.39722478880677)"><title>idx: 11
name: i11
dist: 98
support: 98
height: 216</title><circle r="11.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:9.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-5.004" y="2.2995">98</text></g></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(131.7152408206982, 107.1822201689546)"><title>idx: 13
name: i13
dist: 100
support: 100
height: 314</title><circle r="11.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:9.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-7.506" y="2.2995">100</text></g></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(82.686096328279291, 156.44861239440337)"><title>idx: 12
name: i12
dist: 100
support: 100
height: 214</title><circle r="11.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:9.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-7.506" y="2.2995">100</text></g></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(115.37219265655857, 92.023330253431908)"><title>idx: 14
name: i14
dist: 100
support: 100
height: 314</title><circle r="11.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:9.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-7.506" y="2.2995">100</text></g></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:none" transform="translate(66.343048164139645, 124.23597132391765)"><title>idx: 15
name: i15
dist: 100
support: 100
height: 414</title><circle r="11.0"></circle><g><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:9.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-7.506" y="2.2995">100</text></g></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t900a4172aeac4e44b90737561a81ed23";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "tcf7bc9a79487465382b57e6e6f4c848d";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t223f106b8fbd4ffdb67a0082c9a84143","vertex_data","graph vertex data",["x", "y"],[[-6.0, -6.0, 0.0, -6.0, -5.0, -5.0, -5.0, -2.0, -5.0, -4.0, -2.0, -2.0, 0.0, -2.0, -1.0, -4.0, -4.0, 0.0, -4.0, -3.0, -1.0, -1.0, 0.0, -1.0, 0.0, -3.0, -3.0, 0.0, -3.0, -2.0, -2.0, -2.0, 0.0, -2.0, -1.0, -1.0, -1.0, 0.0, -1.0, 0.0], [6.328125, 8.0, 8.0, 4.65625, 4.65625, 4.65625, 6.25, 6.25, 3.0625, 3.0625, 6.25, 7.0, 7.0, 5.5, 5.5, 3.0625, 4.0, 4.0, 2.125, 2.125, 5.5, 6.0, 6.0, 5.0, 5.0, 2.125, 3.0, 3.0, 1.25, 1.25, 1.25, 2.0, 2.0, 0.5, 0.5, 0.5, 1.0, 1.0, 0.0, 0.0]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t223f106b8fbd4ffdb67a0082c9a84143","edge_data","graph edge data",["source", "target"],[[0, 1, 0, 3, 5, 6, 5, 8, 10, 11, 10, 13, 15, 16, 15, 18, 20, 21, 20, 23, 25, 26, 25, 28, 30, 31, 30, 33, 35, 36, 35, 38], [1, 2, 3, 4, 6, 7, 8, 9, 11, 12, 13, 14, 16, 17, 18, 19, 21, 22, 23, 24, 26, 27, 28, 29, 31, 32, 33, 34, 36, 37, 38, 39]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0df90ee5b0964c46bae0d639ad8cd541","data","scatterplot",["x", "y0"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0, -2.0, -3.0, -1.0, -4.0, -2.0, -5.0, -6.0], [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 0.5, 1.25, 2.125, 5.5, 3.0625, 6.25, 4.65625, 6.328125]],"toyplot");
})();</script></div></div>


Again we'll load the data from the mcmc file from a species tree analysis in the program BPP. For plotting cloud-trees often such a file will contain too many trees to display clearly, and so we can use the `treeslice` argument to subsample them. In the example below we sample every 10th tree between 10-4000. 


```python
mcmcfile = "http://eaton-lab.org/pdsb/full-r0.mcmc.txt"
trees = toytree.multitree(mcmcfile, treeslice=(10, 4000, 10))
print("{} trees".format(len(trees)))
```

    200 trees


With default options the cloud tree doesn't look too bad. 


```python
trees.draw_cloudtree(
    orient='right',
    height=300,
    );
```


<div class="toyplot" id="t0f708f8e46e64bca8d7b944b6f7ea1d1" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="300.0px" id="t6b834ee6651a47939e163eecf930d4c6" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 300.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="ta291265b388b44cf830da85cff9bc461"><clipPath id="t5238c435328547cf94bbc20d73141ae0"><rect height="300.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#t5238c435328547cf94bbc20d73141ae0)"><g class="toyplot-mark-Text" id="t358abee8425d4957b222e363798336bc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te5e5508097d34c2badd26aa75e7370b3"><g class="toyplot-Edges"><path d="M 149.466963667 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.326657552 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.04481709 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.04481709 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.326657552 202.472014925 L 188.04481709 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.909608206 162.389225746 L 168.326657552 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.794965518 122.306436567 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.839216325 117.933768657 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.991238476 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.247961391 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.247961391 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.991238476 85.8675373134 L 182.247961391 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.839216325 117.933768657 L 180.991238476 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.794965518 122.306436567 L 157.839216325 117.933768657" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.909608206 162.389225746 L 157.794965518 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.466963667 202.836403918 L 151.909608206 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(182.24796139097523, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.99123847606398, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.83921632530505, 117.93376865671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(188.04481709003758, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.79496551844198, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.32665755185297, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(151.90960820565348, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(149.46696366681192, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4f1ac10ab2364ba49d2ac4deb1069426"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t42d5a45fe8ec4f1f89e250c9f6167070"><g class="toyplot-Edges"><path d="M 151.281246748 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.512169765 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.620214049 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.620214049 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.512169765 202.472014925 L 190.620214049 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.900894514 162.389225746 L 163.512169765 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 159.255242145 122.306436567 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 159.35259392 117.933768657 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.053326076 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.053326076 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 85.8675373134 L 183.053326076 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 159.35259392 117.933768657 L 182.601967846 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 159.255242145 122.306436567 L 159.35259392 117.933768657" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.900894514 162.389225746 L 159.255242145 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.281246748 202.836403918 L 153.900894514 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.05332607588312, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.60196784587981, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(159.35259392002209, 117.93376865671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.62021404946836, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(159.25524214492333, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(163.51216976515079, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(153.90089451449171, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(151.28124674819787, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8fd6714aeafc42579ab4bfc67d2d1ad1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t86bd757d33d34e8d9635dbe72c9aba31"><g class="toyplot-Edges"><path d="M 146.953517837 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.007847037 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.575895007 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.575895007 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.007847037 202.472014925 L 189.575895007 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.776719315 162.389225746 L 165.007847037 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.520474046 122.306436567 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.582425175 117.933768657 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.185942026 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.309844285 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.309844285 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.185942026 85.8675373134 L 181.309844285 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.582425175 117.933768657 L 181.185942026 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.520474046 122.306436567 L 155.582425175 117.933768657" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.776719315 162.389225746 L 155.520474046 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.953517837 202.836403918 L 149.776719315 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.30984428547811, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.1859420262615, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(155.58242517528839, 117.93376865671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(189.57589500749987, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(155.52047404568012, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(165.00784703712262, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(149.77671931485344, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(146.95351783698948, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcdff238fca65425782d9edf7ee73536d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta81ff826e7ca41e6a55c0b69449eee1b"><g class="toyplot-Edges"><path d="M 146.121602668 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.423941092 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.423941092 202.472014925 L 191.91233761 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.272260117 162.389225746 L 167.423941092 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.148767268 122.306436567 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.35232098 117.933768657 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.920437185 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.194792188 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.194792188 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.920437185 85.8675373134 L 181.194792188 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.35232098 117.933768657 L 180.920437185 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.148767268 122.306436567 L 155.35232098 117.933768657" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.272260117 162.389225746 L 155.148767268 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.121602668 202.836403918 L 149.272260117 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.19479218763414, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(180.9204371850831, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(155.35232097960042, 117.93376865671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.91233760987006, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(155.1487672680303, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(167.4239410918463, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(149.2722601166144, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(146.12160266796371, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t622f94ab9666450a8aeb62376ebe4b8c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t48ea4f9650844ae5b02016c7895dddb5"><g class="toyplot-Edges"><path d="M 146.749964125 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.468055428 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.664601327 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.664601327 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.468055428 202.472014925 L 192.664601327 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.803269799 165.304337687 L 165.468055428 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.865630339 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.25503744 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.407196061 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.557648804 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.557648804 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.407196061 85.8675373134 L 181.557648804 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.25503744 106.273320896 L 181.407196061 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.865630339 128.136660448 L 156.25503744 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.803269799 165.304337687 L 155.865630339 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.749964125 204.293959888 L 149.803269799 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.55764880391132, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.40719606057689, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(156.25503743960709, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.66460132654225, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(155.86563033921206, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(165.46805542849856, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(149.80326979897126, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(146.74996412541935, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taeeeaf6576434faa8b9d038b03144a01"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf2b77caa85d7496fbec041eb1e01da75"><g class="toyplot-Edges"><path d="M 143.634707322 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.910563497 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.682301649 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.682301649 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.910563497 202.472014925 L 192.682301649 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.97121816 165.304337687 L 165.910563497 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.184031443 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.343334348 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.256675082 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.442528471 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.442528471 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.256675082 85.8675373134 L 180.442528471 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.343334348 106.273320896 L 180.256675082 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.184031443 128.136660448 L 153.343334348 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.97121816 165.304337687 L 153.184031443 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.634707322 204.293959888 L 146.97121816 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.44252847096192, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.25667508213701, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(153.34333434801698, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.68230164928747, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(153.18403144330992, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(165.91056349712926, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(146.97121815973469, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(143.63470732225912, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc4bb02e6f5b0415fae1b859210773712"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5e17b4df7cbf4ef8b9ee56bc50a16882"><g class="toyplot-Edges"><path d="M 141.625720691 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.981501258 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.876936964 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.876936964 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.981501258 202.472014925 L 191.876936964 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.245368457 165.304337687 L 167.981501258 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.307797232 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.608702719 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.477860881 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.946919434 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.946919434 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.477860881 85.8675373134 L 179.946919434 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.608702719 106.273320896 L 179.477860881 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.307797232 128.136660448 L 151.608702719 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.245368457 165.304337687 L 151.307797232 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.625720691 204.293959888 L 144.245368457 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.94691943409555, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.47786088134697, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(151.6087027189846, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.87693696437958, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(151.30779723231569, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.981501258321, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(144.24536845696952, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(141.62572069067568, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4a760359c7fa45f9a77f381480b37c9c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td414dd31b5bc408497c623c68b041dfe"><g class="toyplot-Edges"><path d="M 143.838261034 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.928673231 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 184.981343284 L 198.399505896 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 184.981343284 L 198.399505896 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.928673231 202.472014925 L 191.91233761 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.511009768 165.304337687 L 171.928673231 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.776992255 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.87434403 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.619531698 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.858486055 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.858486055 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.619531698 85.8675373134 L 180.858486055 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.87434403 106.273320896 L 180.619531698 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.776992255 128.136660448 L 153.87434403 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.511009768 165.304337687 L 153.776992255 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.838261034 204.293959888 L 146.511009768 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599633, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599633, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(180.85848605547477, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(180.61953169841422, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(153.87434403037383, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.91233760987006, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(153.7769922552751, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(171.928673230507, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(146.51100976835878, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(143.83826103382927, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taf2acb0964a5416b915276a6eb65f774"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tff7880ac8ff246dc93cef7625b36aad0"><g class="toyplot-Edges"><path d="M 144.944531205 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.203232938 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.664601327 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.664601327 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.203232938 202.472014925 L 192.664601327 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 147.493377681 165.304337687 L 175.203232938 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.086816138 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.22841872 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.070889928 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.194792188 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.194792188 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.070889928 85.8675373134 L 181.194792188 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.22841872 106.273320896 L 181.070889928 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.086816138 128.136660448 L 155.22841872 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 147.493377681 165.304337687 L 155.086816138 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.944531205 204.293959888 L 147.493377681 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.19479218763414, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.07088992841753, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(155.22841872038384, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.66460132654225, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(155.08681613842197, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(175.20323293837424, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(147.49337768071894, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(144.94453120540604, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t418c97da1b064e9cbda12ec2ae9d2a7e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6b581d573fcc4a369db205bb83d605cf"><g class="toyplot-Edges"><path d="M 148.528846561 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.707692137 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.707692137 202.472014925 L 192.080490676 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 150.599784323 165.304337687 L 175.707692137 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.423326976 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.635730849 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.37186365 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.469215425 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.469215425 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.37186365 85.8675373134 L 182.469215425 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.635730849 106.273320896 L 182.37186365 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.423326976 128.136660448 L 158.635730849 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 150.599784323 165.304337687 L 158.423326976 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 148.528846561 204.293959888 L 150.599784323 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.4692154252906, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.37186365019187, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(158.63573084884035, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.0804906759497, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(158.4233269758976, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(175.7076921366133, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(150.59978432250657, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(148.52884656131482, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t40b129563f054fff9756ff268ccfe779"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t968a2b82d63543b399c4183330df5bf4"><g class="toyplot-Edges"><path d="M 143.333801836 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 202.472014925 L 192.381396163 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.802996859 165.304337687 L 177.442323766 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.467304842 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.104516461 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.752284119 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.796534926 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.796534926 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.752284119 85.8675373134 L 180.796534926 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.104516461 106.273320896 L 180.752284119 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.467304842 128.136660448 L 155.104516461 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.802996859 165.304337687 L 154.467304842 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.333801836 204.293959888 L 145.802996859 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.7965349258665, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.75228411900343, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(155.10451646116724, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.38139616261856, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(154.46730484233902, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.44232376564568, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(145.80299685854962, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(143.33380183559024, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t60e4180c389846578338a53505302806"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3c31a181fd9a4e9cb34b00bfcd81afce"><g class="toyplot-Edges"><path d="M 144.758677817 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.778561663 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.778561663 202.472014925 L 192.505298422 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 147.210172517 165.304337687 L 176.778561663 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.139985342 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.865698574 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.221342672 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.265593479 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.265593479 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.221342672 85.8675373134 L 181.265593479 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.865698574 106.273320896 L 181.221342672 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.139985342 128.136660448 L 156.865698574 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 147.210172517 165.304337687 L 156.139985342 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.758677817 204.293959888 L 147.210172517 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.26559347861505, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.22134267175196, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(156.86569857431749, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.50529842183516, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(156.13998534176309, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(176.77856166269962, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(147.2101725167953, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(144.75867781658113, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb2231ee11f9347b3ae8f6c2b4eee5938"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t419723cab929472da934cf154e7f7eb3"><g class="toyplot-Edges"><path d="M 141.43101714 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.229783422 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.806067438 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.806067438 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.229783422 202.472014925 L 190.806067438 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.103765875 165.304337687 L 175.229783422 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.830093224 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.467304842 106.273320896 L 198.399505896 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.132772823 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.168173468 68.3768656716 L 198.399505896 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.168173468 68.3768656716 L 198.399505896 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.132772823 85.8675373134 L 180.168173468 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.467304842 106.273320896 L 180.132772823 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.830093224 128.136660448 L 154.467304842 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.103765875 165.304337687 L 153.830093224 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.43101714 204.293959888 L 144.103765875 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.16817346841088, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.1327728229204, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(154.46730484233902, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(190.80606743829327, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(153.83009322351077, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(175.22978342249212, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(144.1037658750077, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.43101714047816, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4d250f4f8ccc4c05a96ffae99ea195ca"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7bdf31a2b1fa4152b34b7dad33e1c69a"><g class="toyplot-Edges"><path d="M 142.209831341 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.18505497 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.416728573 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.416728573 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.18505497 202.472014925 L 191.416728573 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.289687499 165.304337687 L 168.18505497 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.732809684 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.458522916 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.495629439 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.56643073 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.56643073 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.495629439 85.8675373134 L 180.56643073 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.458522916 106.273320896 L 180.495629439 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.732809684 128.136660448 L 155.458522916 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.289687499 165.304337687 L 154.732809684 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.209831341 204.293959888 L 145.289687499 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.56643073017852, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.49562943919759, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(155.45852291607179, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.41672857300364, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(154.73280968351742, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.18505496989113, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(145.28968749893798, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(142.2098313412682, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb9d5078b9b804657a221e093adf72c8d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8689baeab9a1482ca058c49834b9d080"><g class="toyplot-Edges"><path d="M 143.705508613 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.884422424 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.328295194 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.328295194 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.884422424 202.472014925 L 192.328295194 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.095052184 165.304337687 L 171.884422424 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.13113518 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.715245831 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.01778896 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.053189606 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.053189606 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.01778896 85.8675373134 L 181.053189606 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.715245831 106.273320896 L 181.01778896 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.13113518 128.136660448 L 156.715245831 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.095052184 165.304337687 L 156.13113518 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.705508613 204.293959888 L 146.095052184 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.05318960567232, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.01778896018186, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(156.71524583098301, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.32829519438289, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(156.13113518039049, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.88442242364394, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(146.09505218384587, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(143.70550861324003, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9b2d4949acbb4d96a7d7ac1f5351cb7a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tea8c9f86b6f4427a9e19e77267bb9f2c"><g class="toyplot-Edges"><path d="M 139.864538578 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.476973825 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.476973825 202.472014925 L 191.761884867 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.528437151 165.304337687 L 166.476973825 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.299083541 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.830093224 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.743365723 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.85841782 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.85841782 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.743365723 85.8675373134 L 179.85841782 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.830093224 106.273320896 L 179.743365723 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.299083541 128.136660448 L 153.830093224 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.528437151 165.304337687 L 153.299083541 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.864538578 204.293959888 L 142.528437151 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(179.85841782036937, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(179.7433657225254, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(153.83009322351077, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.76188486653561, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(153.29908354115392, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(166.47697382497657, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(142.52843715068232, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(139.86453857752542, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td46ff5754a65481b9f99c712f63a030b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2f1cb1f88c3a495dbfab83c82e3b11cc"><g class="toyplot-Edges"><path d="M 140.953108426 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.760315459 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.760315459 202.472014925 L 192.62035052 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.572756193 165.304337687 L 168.760315459 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.423054035 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.945213556 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.168173468 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.601831376 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.601831376 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.168173468 85.8675373134 L 180.601831376 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.945213556 106.273320896 L 180.168173468 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.423054035 128.136660448 L 154.945213556 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.572756193 165.304337687 L 154.423054035 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.953108426 204.293959888 L 143.572756193 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.60183137566901, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.16817346841088, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(154.94521355646017, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.62035051967919, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(154.42305403547593, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.76031545911107, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(143.57275619265084, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(140.95310842635701, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tae63bbc536cb4c328284b9000814288c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td889acaf26cf4162849c0691edb0c81c"><g class="toyplot-Edges"><path d="M 143.324951674 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.92812735 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.620418755 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.620418755 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.92812735 202.472014925 L 193.620418755 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.997700409 165.304337687 L 163.92812735 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.679845185 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.317056804 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.07974009 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.21249251 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.21249251 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.07974009 85.8675373134 L 181.21249251 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.317056804 106.273320896 L 181.07974009 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.679845185 128.136660448 L 157.317056804 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.997700409 165.304337687 L 156.679845185 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.324951674 204.293959888 L 145.997700409 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.21249251037938, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.07974008979016, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(157.31705680432083, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.62041875478459, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(156.67984518549258, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(163.92812734966367, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(145.99770040874714, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(143.32495167421763, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tddcab6dd72f4419bb98f89acbcae705f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t068684e8906a4db4bc3f96b1f7ae8ea3"><g class="toyplot-Edges"><path d="M 142.554987635 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.883944778 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.000975694 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.000975694 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.883944778 202.472014925 L 194.000975694 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.705645083 165.304337687 L 164.883944778 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.184236149 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.768346799 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.752284119 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.008938799 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.008938799 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.752284119 85.8675373134 L 181.008938799 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.768346799 106.273320896 L 180.752284119 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.184236149 128.136660448 L 156.768346799 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.705645083 165.304337687 L 156.184236149 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.554987635 204.293959888 L 145.705645083 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.00893879880925, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.75228411900343, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(156.76834679921873, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(194.00097569380699, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(156.18423614862616, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(164.88394477790601, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(145.70564508345086, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(142.55498763480017, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4932c4f8809a41b282f20a63eed9f958"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t542cf0fa38e548dd93dafc1bcab1e0a2"><g class="toyplot-Edges"><path d="M 142.793941992 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.627426568 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.089409072 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.089409072 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.627426568 202.472014925 L 193.089409072 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.643693954 165.304337687 L 166.627426568 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.70639567 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.48520987 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.893886701 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.646150418 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.646150418 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.893886701 85.8675373134 L 181.646150418 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.48520987 106.273320896 L 180.893886701 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.70639567 128.136660448 L 157.48520987 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.643693954 165.304337687 L 156.70639567 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.793941992 204.293959888 L 145.643693954 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.64615041763744, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(180.89388670096525, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(157.48520987040047, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(193.08940907242774, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(156.7063956696104, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(166.62742656831102, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(145.64369395384256, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(142.79394199186075, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t514ab1fa54ff473db8228be870c91096"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0be0d6e7d0834d1abcaf25bf30ed4efb"><g class="toyplot-Edges"><path d="M 141.077010686 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.600876084 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.089477308 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.089477308 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.600876084 202.472014925 L 194.089477308 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.378120878 165.304337687 L 166.600876084 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.104584696 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.09580277 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.061971532 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.637232021 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.637232021 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.061971532 85.8675373134 L 180.637232021 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.09580277 106.273320896 L 180.061971532 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.104584696 128.136660448 L 157.09580277 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.378120878 165.304337687 L 156.104584696 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.077010686 204.293959888 L 144.378120878 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.63723202115943, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.06197153193949, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(157.09580277000546, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(194.08947730753314, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(156.10458469627264, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(166.60087608419315, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(144.37812087755873, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.07701068557361, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf5865af1dfea484598fef5504bfa3477"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2a41fbbac8c04cbaa5c84a8b4848497d"><g class="toyplot-Edges"><path d="M 138.891020827 204.293959888 L 198.399505896 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.901986276 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.257562139 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.257562139 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.901986276 202.472014925 L 193.257562139 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.554987635 165.304337687 L 169.901986276 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.467441313 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.741932785 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.168105233 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.973469918 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.973469918 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.168105233 85.8675373134 L 179.973469918 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.741932785 106.273320896 L 179.168105233 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.467441313 128.136660448 L 158.741932785 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.554987635 165.304337687 L 156.467441313 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.891020827 204.293959888 L 142.554987635 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(179.97346991821337, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(179.16810523330548, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(158.74193278531172, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.25756213850741, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(156.46744131254982, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.90198627617832, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(142.55498763480017, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.89102082653787, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t05c2671fb23f42ceb1a25f31a4940d5b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0d1754155b89404ab0ed41f4a00c1801"><g class="toyplot-Edges"><path d="M 136.775832258 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.521292867 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.521292867 202.472014925 L 193.248711977 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.855756651 165.304337687 L 167.521292867 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 161.697886684 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.512169765 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.433610074 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.575212656 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.575212656 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.433610074 85.8675373134 L 179.575212656 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.512169765 106.273320896 L 179.433610074 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 161.697886684 128.136660448 L 163.512169765 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.855756651 165.304337687 L 161.697886684 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.775832258 204.293959888 L 140.855756651 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.57521265644573, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.43361007448391, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(163.51216976515079, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.2487119771348, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(161.69788668376489, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.52129286694506, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.85575665125822, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(136.77583225848304, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t55d5988432274a1eb608a760228dea03"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcb7ad009f4d541d998e6e19b43bff03b"><g class="toyplot-Edges"><path d="M 133.660575455 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.476700885 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.476700885 202.472014925 L 193.045158266 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.846701785 165.304337687 L 162.476700885 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.804156855 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.848544132 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.247688451 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.345040226 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.345040226 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.247688451 85.8675373134 L 178.345040226 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.848544132 106.273320896 L 178.247688451 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.804156855 128.136660448 L 164.848544132 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.846701785 165.304337687 L 162.804156855 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.660575455 204.293959888 L 137.846701785 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.34504022565235, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.24768845055357, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(164.84854413241555, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.04515826556465, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(162.80415685534163, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(162.47670088455493, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(137.84670178456938, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(133.66057545532283, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t982b6d5899be4adebf28ead90d770f2b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3501b96537ad40789187b483244804d6"><g class="toyplot-Edges"><path d="M 132.926012061 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.167013472 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.167013472 202.472014925 L 193.248711977 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.112138391 165.304337687 L 163.167013472 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.618508172 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.423872857 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.11493603 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.185737321 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.185737321 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.11493603 85.8675373134 L 178.185737321 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.423872857 106.273320896 L 178.11493603 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.618508172 128.136660448 L 166.423872857 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.112138391 165.304337687 L 165.618508172 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.926012061 204.293959888 L 137.112138391 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.18573732094529, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.11493602996435, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.4238728567409, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.2487119771348, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(165.61850817183301, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(163.16701347161884, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.11213839064237, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(132.92601206139582, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcfb83b2599874c01bf4a2e5020134342"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3157de9e8e364e54acf3d41c027f2feb"><g class="toyplot-Edges"><path d="M 131.271031885 203.929570896 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.361989962 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.841604554 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.841604554 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.361989962 202.472014925 L 192.841604554 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.88196596 164.575559701 L 167.361989962 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.680459301 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.742478666 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.849431189 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.875981673 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.875981673 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.849431189 80.0373134328 L 177.875981673 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.742478666 103.358208955 L 177.849431189 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.680459301 126.679104478 L 166.742478666 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.88196596 164.575559701 L 165.680459301 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.271031885 203.929570896 L 135.88196596 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.87598167290378, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.84943118878596, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(166.74247866615502, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.84160455399456, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(165.68045930144129, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(167.36198996223803, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(135.88196595984903, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(131.27103188471696, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0b6e8323a63f4d9c86f37423a7606109"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t604447fa951948eda59ba41528487ed9"><g class="toyplot-Edges"><path d="M 128.846087669 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.28233851 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.611500358 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.611500358 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.28233851 202.472014925 L 192.611500358 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.669425617 163.846781716 L 167.28233851 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.804293326 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.06101624 100.443097015 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.15026844 74.2070895522 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.176818924 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.176818924 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.15026844 74.2070895522 L 177.176818924 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.06101624 100.443097015 L 177.15026844 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.804293326 125.221548507 L 166.06101624 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.669425617 163.846781716 L 164.804293326 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.846087669 203.565181903 L 133.669425617 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.17681892446726, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.15026844034944, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.06101624046372, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.61150035830656, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(164.80429332555252, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(167.28233850988448, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(133.66942561669543, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(128.84608766862064, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8aefdf1df87643f88f693578402bf183"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tae4730938b614482bf72b3e39fdbb58a"><g class="toyplot-Edges"><path d="M 128.421279923 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.945964143 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.133591644 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.133591644 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.945964143 202.472014925 L 192.133591644 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.483572228 163.846781716 L 165.945964143 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.777811077 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.839830441 100.443097015 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.309571345 74.2070895522 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.344971991 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.344971991 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.309571345 74.2070895522 L 177.344971991 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.839830441 100.443097015 L 177.309571345 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.777811077 125.221548507 L 166.839830441 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.483572228 163.846781716 L 165.777811077 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.421279923 203.565181903 L 133.483572228 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(177.34497199054692, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(177.30957134505647, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(166.83983044125378, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.13359164418537, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(165.77781107654008, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(165.94596414261974, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(133.48357222787052, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(128.42127992273518, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t077db52c2f844391b494d7dd41f765ac"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8b01a3b1b1234a59ab881022536627ea"><g class="toyplot-Edges"><path d="M 128.554032343 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.919277188 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.593800036 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.593800036 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.919277188 202.472014925 L 192.593800036 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.333051249 165.304337687 L 163.919277188 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.822130119 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.972651097 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.557375863 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.592776509 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.592776509 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.557375863 85.8675373134 L 177.592776509 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.972651097 106.273320896 L 177.557375863 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.822130119 128.136660448 L 167.972651097 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.333051249 165.304337687 L 166.822130119 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.554032343 204.293959888 L 132.333051249 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(177.59277650898011, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(177.55737586348968, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.9726510969484, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.59380003556137, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(166.82213011850854, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(163.91927718829109, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(132.33305124943067, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(128.55403234332437, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t15b537daa3c0430c9030feae1fd322fb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tad6306f9d1ca49ea8c7a86a54eefdbb7"><g class="toyplot-Edges"><path d="M 128.279677341 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.777674606 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.777674606 202.472014925 L 192.142441806 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.36852013 165.304337687 L 163.777674606 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.131954002 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.18519144 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.433473604 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.46887425 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.46887425 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.433473604 85.8675373134 L 177.46887425 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.18519144 106.273320896 L 177.433473604 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.131954002 128.136660448 L 170.18519144 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.36852013 165.304337687 L 168.131954002 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.279677341 204.293959888 L 133.36852013 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(177.4688742497635, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(177.43347360427305, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(170.18519144010196, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.14244180555801, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.13195400165546, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(163.77767460632921, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(133.36852013002652, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(128.27967734077333, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbabd339836524d56894b995d6eab03ea"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta755c08b7ff2477d8896e265d08ef2c4"><g class="toyplot-Edges"><path d="M 127.279609106 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.467577783 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.912405845 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.912405845 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.467577783 202.472014925 L 192.912405845 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.598624326 165.304337687 L 158.467577783 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.981501258 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.831389691 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.937864567 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.672427961 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.672427961 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.937864567 85.8675373134 L 177.672427961 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.831389691 106.273320896 L 176.937864567 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.981501258 128.136660448 L 172.831389691 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.598624326 165.304337687 L 167.981501258 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 127.279609106 204.293959888 L 133.598624326 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(177.67242796133365, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(176.93786456740668, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(172.83138969051365, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.91240584497544, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.981501258321, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(158.46757778276066, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(133.59862432571452, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(127.27960910566793, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2392c10f997c43029be5495089a4f00b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta6f00b606bc1475985ab540257d12547"><g class="toyplot-Edges"><path d="M 124.73076263 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.715859947 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.195474539 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.195474539 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.715859947 202.472014925 L 191.195474539 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.156048022 165.304337687 L 165.715859947 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.83125322 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.619122288 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.336121829 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.336121829 85.8675373134 L 177.442323766 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.619122288 106.273320896 L 177.336121829 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.83125322 128.136660448 L 174.619122288 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.156048022 165.304337687 L 170.83125322 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 124.73076263 204.293959888 L 132.156048022 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.44232376564568, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.33612182917435, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(174.61912228778172, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.1954745386883, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(170.83125322030284, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(165.71585994693174, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(132.15604802197839, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(124.73076263035502, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t109b09a0f6574ab3bca435cff48057ad"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t284137fba7e5474bbc54325ec83c58f9"><g class="toyplot-Edges"><path d="M 124.359055853 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.892931409 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.892931409 202.472014925 L 192.080490676 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.085314966 165.304337687 L 166.892931409 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.424350502 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.858213115 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.424623443 85.8675373134 L 198.399505896 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.477724411 68.3768656716 L 198.399505896 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.477724411 68.3768656716 L 198.399505896 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.424623443 85.8675373134 L 177.477724411 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.858213115 106.273320896 L 177.424623443 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.424350502 128.136660448 L 176.858213115 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.085314966 165.304337687 L 173.424350502 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 124.359055853 204.293959888 L 133.085314966 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.47772441113614, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.42462344290047, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(176.85821311505313, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.0804906759497, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(173.4243505024788, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.89293140948945, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(133.08531496610289, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(124.35905585270521, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t632e66f6016545be83fff497996d48a4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfa00a92beacf426897360b8c08613052"><g class="toyplot-Edges"><path d="M 120.066727587 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.636208495 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.142305335 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.142305335 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.636208495 202.472014925 L 190.142305335 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.17368011 165.304337687 L 165.636208495 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.866858571 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.822675999 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.689991814 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.265252303 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.265252303 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.689991814 85.8675373134 L 176.265252303 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.822675999 106.273320896 L 175.689991814 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.866858571 128.136660448 L 174.822675999 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.17368011 165.304337687 L 173.866858571 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 120.066727587 204.293959888 L 131.17368011 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(176.265252303088, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(175.68999181386803, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(174.82267599935187, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.14230533534717, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(173.8668585711095, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(165.63620849457823, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(131.1736801096182, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(120.0667275869873, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t474a8b9f90544329a454ec79e4653552"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2fc2fcb85bc34218bad4318d0556022b"><g class="toyplot-Edges"><path d="M 116.579764006 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.795579634 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.514080348 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.514080348 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.795579634 202.472014925 L 191.514080348 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.306637236 165.304337687 L 166.795579634 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.893272585 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.300516478 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.01737955 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.999747462 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.999747462 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.01737955 85.8675373134 L 175.999747462 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.300516478 106.273320896 L 175.01737955 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.893272585 128.136660448 L 174.300516478 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.306637236 165.304337687 L 171.893272585 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 116.579764006 204.293959888 L 134.306637236 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(175.99974746190955, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(175.01737954954936, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(174.30051647836763, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.51408034810237, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(171.89327258501652, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.79557963439072, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(134.30663723552368, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(116.57976400617724, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te0614726805744e6b55ea4c2d64a6a3c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4d6d8de9ad6a41b78f81e0ecf4caf72f"><g class="toyplot-Edges"><path d="M 121.234948888 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.424077562 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.868086803 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.868086803 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.424077562 202.472014925 L 191.868086803 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.501681961 165.304337687 L 169.424077562 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.229510482 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.583789877 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.911245848 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.132568118 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.132568118 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.911245848 85.8675373134 L 177.132568118 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.583789877 106.273320896 L 175.911245848 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.229510482 128.136660448 L 175.583789877 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.501681961 165.304337687 L 171.229510482 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 121.234948888 204.293959888 L 139.501681961 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(177.13256811760422, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(175.91124584818343, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(175.5837898773967, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.86808680300697, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(171.22951048207048, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.42407756205714, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(139.50168196124827, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(121.23494888817238, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tad6329c092ac4eb18b4a567aaaf77a1a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t241b036311cd4dd4b33485f3fd55b935"><g class="toyplot-Edges"><path d="M 116.199207067 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.73383321 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.73383321 202.472014925 L 191.797285512 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.297650604 165.304337687 L 169.73383321 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.50393372 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.265115833 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.610272126 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.008529388 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.008529388 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.610272126 85.8675373134 L 175.008529388 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.265115833 106.273320896 L 174.610272126 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.50393372 128.136660448 L 174.265115833 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.297650604 165.304337687 L 172.50393372 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 116.199207067 204.293959888 L 132.297650604 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(175.00852938817678, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(174.61027212640914, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(174.26511583287717, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.79728551202606, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(172.50393371972692, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(169.73383321009865, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(132.29765060394024, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(116.19920706715484, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2726c3d5802349b2972f62769abac93c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7c4d222715d343b7a8ec88580fd3e10d"><g class="toyplot-Edges"><path d="M 112.075031868 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.423941092 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.423941092 202.472014925 L 191.65568293 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.589910635 165.304337687 L 167.423941092 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.132158707 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.999610992 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.397868253 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.645672772 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.645672772 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.397868253 85.8675373134 L 174.645672772 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.999610992 106.273320896 L 174.397868253 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.132158707 128.136660448 L 173.999610992 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.589910635 165.304337687 L 171.132158707 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 112.075031868 204.293959888 L 135.589910635 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(174.64567277189954, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(174.39786825346633, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(173.99961099169872, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.65568293006422, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(171.13215870697169, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(167.4239410918463, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(135.58991063455272, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(112.07503186751657, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1f775b7b9d15450ab367f5ee6104bcc9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfb6b356741be4294b833a41344a1919c"><g class="toyplot-Edges"><path d="M 112.066181706 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.840444557 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.230943419 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.230943419 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.840444557 202.472014925 L 192.230943419 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.085792612 165.304337687 L 175.840444557 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.433064194 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.619190523 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.85814488 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.070548753 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.070548753 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.85814488 85.8675373134 L 176.070548753 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.619190523 106.273320896 L 175.85814488 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.433064194 128.136660448 L 175.619190523 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.085792612 165.304337687 L 171.433064194 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 112.066181706 204.293959888 L 140.085792612 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(176.07054875289049, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(175.85814487994773, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(175.61919052288712, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.23094341928419, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.4330641936406, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(175.84044455720252, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.08579261184082, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(112.06618170614396, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t258a6500a63b4983a1b98f413b973076"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t611f1c79bf1e4e2f8909b5e94aaa4ac1"><g class="toyplot-Edges"><path d="M 113.668060915 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.858622526 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.629200681 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.629200681 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.858622526 202.472014925 L 192.629200681 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.448239817 165.304337687 L 182.858622526 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.521702278 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.566226025 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.610476832 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.11493603 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.11493603 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.610476832 85.8675373134 L 178.11493603 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.566226025 106.273320896 L 177.610476832 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.521702278 128.136660448 L 177.566226025 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.448239817 165.304337687 L 173.521702278 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 113.668060915 204.293959888 L 134.448239817 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.11493602996438, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.61047683172535, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.56622602486229, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.62920068105177, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(173.52170227757756, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.85862252568563, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(134.4482398174855, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(113.66806091458717, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfe1ad32d6c8748d68b888dd358b3c2a3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf7a4e13ce9694782bd7c80afe82c3f59"><g class="toyplot-Edges"><path d="M 112.924647359 204.293959888 L 198.399505896 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.159323307 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.416796808 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.416796808 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.159323307 202.472014925 L 192.416796808 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.262386429 165.304337687 L 180.159323307 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.300516478 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.645877477 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.831730866 85.8675373134 L 198.399505896 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.937932803 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.937932803 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.831730866 85.8675373134 L 177.937932803 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.645877477 106.273320896 L 177.831730866 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.300516478 128.136660448 L 177.645877477 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.262386429 165.304337687 L 174.300516478 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 112.924647359 204.293959888 L 134.262386429 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.93793280251211, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.83173086604074, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.64587747721583, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.41679680810904, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(174.30051647836763, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.15932330703828, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(134.26238642866062, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(112.92464735928758, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0720fdc772374967ad0dcc5a84035d4c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t682cd8c2c11240e9a4d455a6d0eae071"><g class="toyplot-Edges"><path d="M 112.676842841 203.929570896 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.655068814 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.761953102 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.761953102 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.655068814 202.472014925 L 192.761953102 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.058764482 164.575559701 L 182.655068814 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.220796791 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.167968763 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.814030543 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.814030543 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 80.0373134328 L 177.814030543 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.167968763 103.358208955 L 177.442323766 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.220796791 126.679104478 L 177.167968763 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.058764482 164.575559701 L 173.220796791 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 112.676842841 203.929570896 L 133.058764482 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.8140305432955, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.44232376564568, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.16796876309465, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.76195310164101, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(173.22079679090865, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.65506881411548, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(133.05876448198507, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(112.67684284085436, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t698d7c958b194078afe7a47b31a571f1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t08d6790eb26c411693dff29e7579e631"><g class="toyplot-Edges"><path d="M 113.030849296 203.929570896 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.37186365 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.868155038 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.868155038 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.37186365 202.472014925 L 192.868155038 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.740226908 164.575559701 L 182.37186365 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.105744693 126.679104478 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.645877477 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.982183609 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.0529849 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.0529849 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.982183609 80.0373134328 L 178.0529849 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.645877477 103.358208955 L 177.982183609 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.105744693 126.679104478 L 177.645877477 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.740226908 164.575559701 L 173.105744693 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 113.030849296 203.929570896 L 133.740226908 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(178.05298490035608, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.98218360937517, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.64587747721581, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.86815503811235, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(173.10574469306468, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(182.37186365019184, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(133.74022690767634, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(113.03084929575893, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2887dd7bcde84dea98ee5db339cf96d0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc02170a7cf3c44fda9a2a1395df32a89"><g class="toyplot-Edges"><path d="M 114.960184475 203.929570896 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.17729657 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.098259234 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.098259234 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.17729657 202.472014925 L 193.098259234 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.802450978 164.575559701 L 184.17729657 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.070480518 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.495561204 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.814167014 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.902668627 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.902668627 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.814167014 80.0373134328 L 179.902668627 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.495561204 103.358208955 L 179.814167014 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.070480518 126.679104478 L 179.495561204 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.802450978 164.575559701 L 175.070480518 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 114.960184475 203.929570896 L 137.802450978 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(179.90266862723243, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(179.81416701350631, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(179.49556120409218, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(193.09825923380035, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(175.07048051778503, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.17729657020513, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.80245097770631, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(114.96018447498884, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t56c2f1704bc34647abccf3cc1c75031b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1819d6cf222e4a47b0de79b5c3ad97bc"><g class="toyplot-Edges"><path d="M 110.322699916 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.23911123 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.903487448 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.903487448 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.23911123 202.472014925 L 191.903487448 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.881897725 165.304337687 L 182.23911123 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.672018551 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.902600392 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.115004265 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.123854426 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.123854426 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.115004265 85.8675373134 L 179.123854426 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.902600392 106.273320896 L 179.115004265 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.672018551 128.136660448 L 178.902600392 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.881897725 165.304337687 L 171.672018551 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 110.322699916 204.293959888 L 134.881897725 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(179.12385442644239, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(179.11500426506979, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(178.90260039212706, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.90348744849743, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(171.67201855070118, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.23911122960263, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(134.8818977247436, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(110.32269991573898, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t971b39bceae14785a9f7f035df40d296"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1aec3dcaa6a04617be80d3001223a6aa"><g class="toyplot-Edges"><path d="M 102.773512265 203.929570896 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.575485597 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.575485597 202.472014925 L 191.788435351 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.067614643 164.575559701 L 183.575485597 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.698705505 126.679104478 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.37159071 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.486642808 80.0373134328 L 198.399505896 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.486642808 80.0373134328 L 198.399505896 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.486642808 80.0373134328 L 198.399505896 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.486642808 80.0373134328 L 178.486642808 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.37159071 103.358208955 L 178.486642808 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.698705505 126.679104478 L 178.37159071 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.067614643 164.575559701 L 173.698705505 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 102.773512265 203.929570896 L 133.067614643 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(178.48664280761417, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(178.48664280761417, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(178.37159070977017, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.78843535065346, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(173.69870550502984, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.57548559686737, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(133.06761464335764, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(102.77351226489897, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t085c8581aba24ba19850b1575b64adbe"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t32c3ae6d24114f6b917262d26b950e2e"><g class="toyplot-Edges"><path d="M 102.313303874 203.929570896 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.805589793 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.55839939 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.55839939 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.805589793 202.472014925 L 192.55839939 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.11186545 164.575559701 L 183.805589793 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.884627129 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.468942485 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.575144421 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.575144421 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.575144421 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.575144421 80.0373134328 L 178.575144421 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.468942485 103.358208955 L 178.575144421 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.884627129 126.679104478 L 178.468942485 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.11186545 164.575559701 L 174.884627129 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 102.313303874 203.929570896 L 133.11186545 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.5751444213403, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.5751444213403, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.46894248486896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.55839939007086, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(174.88462712896015, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(183.80558979255537, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(133.11186545022073, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(102.31330387352303, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t93a271e824204dcf8538a9b8154f2696"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td4b26fce5f3743cb846f3af13f922599"><g class="toyplot-Edges"><path d="M 100.472470308 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.43381478 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.885718891 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.885718891 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.43381478 202.472014925 L 190.885718891 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.925943826 163.846781716 L 182.43381478 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.698841975 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.194587482 100.443097015 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.380440871 74.2070895522 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.406991355 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.406991355 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.380440871 74.2070895522 L 178.406991355 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.194587482 100.443097015 L 178.380440871 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.698841975 125.221548507 L 178.194587482 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.925943826 163.846781716 L 175.698841975 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 100.472470308 203.565181903 L 131.925943826 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.40699135526063, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.38044087114281, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.1945874823179, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.88571889064676, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(175.69884197524067, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.43381477980012, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(131.92594382629042, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(100.47247030801927, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td8c3eb75638841f88676c884a882f8d1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9dc1fc2853d24c4ca941c56b278fb38a"><g class="toyplot-Edges"><path d="M 97.8528225417 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.106495279 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.469761306 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.469761306 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.106495279 202.472014925 L 190.469761306 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.483708698 163.846781716 L 184.106495279 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.50407019 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.707896842 100.443097015 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.796398456 74.2070895522 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.858349585 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.858349585 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.796398456 74.2070895522 L 178.858349585 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.707896842 100.443097015 L 178.796398456 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.50407019 125.221548507 L 178.707896842 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.483708698 163.846781716 L 174.50407019 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 97.8528225417 203.565181903 L 135.483708698 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.85834958526397, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.79639845565566, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.70789684192954, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.4697613061339, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(174.50407018993775, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.10649527922425, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(135.48370869808136, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.852822541725459, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdbdfbb2b45224352859942069abe13c3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb1fe2b6e9fc14986b3e2fda866b5ccfa"><g class="toyplot-Edges"><path d="M 95.8084352647 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.637436726 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.637436726 202.472014925 L 191.390178089 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.855415476 163.846781716 L 183.637436726 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.79592081 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.415909752 100.443097015 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.495561204 74.2070895522 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.690264754 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.690264754 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.495561204 74.2070895522 L 179.690264754 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.415909752 100.443097015 L 179.495561204 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.79592081 125.221548507 L 179.415909752 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.855415476 163.846781716 L 171.79592081 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 95.8084352647 203.565181903 L 135.855415476 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(179.6902647542897, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(179.49556120409218, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(179.4159097517387, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.39017808888582, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(171.79592080991779, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.6374367264757, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(135.85541547573118, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(95.808435264651536, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf24152c4bc984c008991cd6a580acdfa"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4373ae0c7bb146468ee49a51cb055d30"><g class="toyplot-Edges"><path d="M 96.5429986586 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.832208512 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.098190999 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.098190999 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.832208512 202.472014925 L 192.098190999 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.386629863 163.846781716 L 184.832208512 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.592025923 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.62838186 100.443097015 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.699183151 74.2070895522 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.805385087 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.805385087 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.699183151 74.2070895522 L 180.805385087 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.62838186 100.443097015 L 180.699183151 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.592025923 125.221548507 L 180.62838186 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.386629863 163.846781716 L 166.592025923 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 96.5429986586 203.565181903 L 139.386629863 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.8053850872391, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.69918315076771, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.62838185978683, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.09819099869495, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.59202592282057, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(184.83220851177859, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(139.38662986340424, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(96.542998658578512, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3cff7d3d2999446e85636bceba505772"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfb001b56dd424c288e55a8ab84f417da"><g class="toyplot-Edges"><path d="M 97.2156109229 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.186556142 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.637982607 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.637982607 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.186556142 202.472014925 L 191.637982607 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.944121795 163.846781716 L 190.186556142 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.017174844 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.009007034 100.443097015 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.088658486 74.2070895522 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.124059132 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.124059132 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.088658486 74.2070895522 L 182.124059132 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.009007034 100.443097015 L 182.088658486 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.017174844 125.221548507 L 182.009007034 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.944121795 163.846781716 L 172.017174844 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 97.2156109229 203.565181903 L 138.944121795 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.1240591317586, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.08865848626817, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.00900703391463, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.63798260731897, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(172.01717484423312, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.18655614221026, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(138.94412179477354, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(97.215610922897199, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6f6631b65270477f9d7509d877a0a7d5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t95f9e38607ea49149a160511ff7a7036"><g class="toyplot-Edges"><path d="M 94.0561033129 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.036308104 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.036308104 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 202.472014925 L 193.036308104 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.342379057 165.304337687 L 187.708510958 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.079194209 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.991306711 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.026707357 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.088658486 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.088658486 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.026707357 85.8675373134 L 182.088658486 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.991306711 106.273320896 L 182.026707357 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.079194209 128.136660448 L 181.991306711 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.342379057 165.304337687 L 173.079194209 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 94.0561033129 204.293959888 L 139.342379057 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.0886584862682, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.02670735665987, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.99130671116941, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.03630810419205, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(173.07919420894683, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.70851095787827, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.34237905654118, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(94.056103312873915, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbfa45089b7384e97aba4edc24d7e5689"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="taeb39256f30b4421bcdf3443b37a772d"><g class="toyplot-Edges"><path d="M 88.976110685 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.575622067 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.779653424 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.779653424 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.575622067 202.472014925 L 192.779653424 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.280496162 163.846781716 L 185.575622067 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.946237083 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.27444364 100.443097015 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.300994124 74.2070895522 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.584199288 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.584199288 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.300994124 74.2070895522 L 181.584199288 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.27444364 100.443097015 L 181.300994124 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.946237083 125.221548507 L 181.27444364 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.280496162 163.846781716 L 169.946237083 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.976110685 203.565181903 L 140.280496162 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.58419928802917, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.3009941241055, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.27444363998768, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.77965342438623, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.94623708304138, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(185.57562206707823, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(140.2804961620383, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(88.976110684993301, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taccf3a68015548f48a2280fedc6a7b53"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tae084ad4ce79473b8098d26b79335d3f"><g class="toyplot-Edges"><path d="M 96.5429986586 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.248302567 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.142510041 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.142510041 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.248302567 202.472014925 L 193.142510041 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.793737287 163.846781716 L 187.248302567 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.547979821 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.840922203 100.443097015 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.849772364 74.2070895522 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.973674624 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.973674624 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.849772364 74.2070895522 L 182.973674624 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.840922203 100.443097015 L 182.849772364 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.547979821 125.221548507 L 182.840922203 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.793737287 163.846781716 L 169.547979821 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 96.5429986586 203.565181903 L 139.793737287 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.9736746235296, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.849772364313, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.84092220294036, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.14251004066344, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(169.54797982127371, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.2483025665023, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(139.79373728654451, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(96.542998658578512, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t857442803cde46bc85d23c3e8fa06754"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5d6cbe3bea944000ae99127dc9d31768"><g class="toyplot-Edges"><path d="M 89.3478174626 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.053462546 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.584949874 184.981343284 L 198.399505896 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.584949874 184.981343284 L 198.399505896 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.053462546 202.472014925 L 192.584949874 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.581333414 161.660447761 L 185.053462546 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.415363871 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.044407679 91.697761194 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.044407679 91.697761194 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.035557518 91.697761194 L 182.044407679 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.212560745 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.212560745 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.035557518 91.697761194 L 182.212560745 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.415363871 120.848880597 L 182.035557518 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.581333414 161.660447761 L 171.415363871 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 89.3478174626 202.472014925 L 139.581333414 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.21256074548478, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.04440767940511, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.03555751803248, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.58494987418874, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(171.41536387089536, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.05346254609398, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(139.58133341360175, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(89.347817462643107, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta5451e8660f14520bd466d95e3f23f16"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc9090f04f84d436b90ea594daa3447fc"><g class="toyplot-Edges"><path d="M 78.7984251065 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.540630832 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.540630832 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 202.472014925 L 191.540630832 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.005868219 161.660447761 L 186.04468062 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.751670003 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.938137508 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.938137508 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.699183151 91.697761194 L 180.938137508 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.76113428 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.76113428 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.699183151 91.697761194 L 180.76113428 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.751670003 120.848880597 L 180.699183151 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.005868219 161.660447761 L 171.751670003 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.7984251065 202.472014925 L 136.005868219 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.76113428037604, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.93813750782832, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.69918315076771, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.54063083222024, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(171.7516700030547, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.04468061982678, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(136.00586821906563, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(78.798425106486889, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta617f7f3d7f743b291a0f01aa835ea52"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t96575ddb160e44be92b07a4c0ec09f76"><g class="toyplot-Edges"><path d="M 79.1258810773 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 202.472014925 L 191.930037933 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.572346782 161.660447761 L 187.363354664 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.627767744 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.009007034 91.697761194 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.009007034 91.697761194 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.477997352 91.697761194 L 182.009007034 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.575349127 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.575349127 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.477997352 91.697761194 L 181.575349127 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.627767744 120.848880597 L 181.477997352 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.572346782 161.660447761 L 171.627767744 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.1258810773 202.472014925 L 137.572346782 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.57534912665656, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.00900703391466, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.47799735155778, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.93003793261528, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(171.62776774383812, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.36335466434628, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(137.57234678201834, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(79.125881077273618, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2e07d0992c4c48f3b32a073d69073e9c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t208c16a624944996aa9b1454c23b9583"><g class="toyplot-Edges"><path d="M 78.763024461 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.283771447 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.55839939 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.55839939 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.283771447 202.472014925 L 192.55839939 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.164966418 161.660447761 L 188.283771447 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.167422882 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.354095092 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.354095092 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.265593479 91.697761194 L 181.354095092 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.309844285 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.309844285 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.265593479 91.697761194 L 181.309844285 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.167422882 120.848880597 L 181.265593479 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.164966418 161.660447761 L 169.167422882 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.763024461 202.472014925 L 133.164966418 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.30984428547811, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.35409509234117, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.26559347861505, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.55839939007086, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.16742288225132, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.28377144709819, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(133.1649664184564, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(78.763024460996419, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t09d5325c8a0a4fa6a2e73b765498f071"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t708427411a01426e8ec2d95645233c7a"><g class="toyplot-Edges"><path d="M 80.2941023785 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.672905607 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.841604554 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.841604554 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.672905607 202.472014925 L 192.841604554 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.04147357 161.660447761 L 184.672905607 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.512579176 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.566498965 91.697761194 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.566498965 91.697761194 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.53109832 91.697761194 L 181.566498965 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.584199288 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.584199288 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.53109832 91.697761194 L 181.584199288 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.512579176 120.848880597 L 181.53109832 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.04147357 161.660447761 L 169.512579176 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.2941023785 202.472014925 L 139.04147357 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.58419928802917, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.56649896528396, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.5310983197935, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.84160455399456, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.51257917578329, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.67290560707156, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(139.0414735698723, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(80.294102378458703, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taf512121461d47e8b8e09e2ee682cf02"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t411b3673f72c44d6a3962a6c93b8165d"><g class="toyplot-Edges"><path d="M 74.5326473249 202.836403918 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.124400307 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.921256006 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.921256006 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.124400307 202.472014925 L 192.921256006 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.590047105 162.389225746 L 187.124400307 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.512579176 122.306436567 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.044339444 94.6128731343 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.070889928 85.8675373134 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.097440413 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.097440413 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.070889928 85.8675373134 L 181.097440413 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.044339444 94.6128731343 L 181.070889928 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.512579176 122.306436567 L 181.044339444 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.590047105 162.389225746 L 169.512579176 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.5326473249 202.836403918 L 137.590047105 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.09744041253538, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.07088992841753, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.04433944429971, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.92125600634807, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(169.51257917578329, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.1244003072857, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(137.59004710476356, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(74.532647324886796, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td0e0d2b9186a4739af933d5c0e53247c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t094a9688c0db46bea819a9e996a70ba0"><g class="toyplot-Edges"><path d="M 73.6653315104 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.752761765 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.673519723 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.673519723 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.752761765 202.472014925 L 193.673519723 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.333870071 162.389225746 L 187.752761765 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.184850265 122.306436567 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.964756227 94.6128731343 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.98245655 85.8675373134 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.044407679 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.044407679 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.98245655 85.8675373134 L 182.044407679 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.964756227 94.6128731343 L 181.98245655 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.184850265 122.306436567 L 181.964756227 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.333870071 162.389225746 L 165.184850265 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.6653315104 202.836403918 L 144.333870071 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(182.04440767940508, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.98245654979681, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.96475622705159, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.67351972302026, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(165.18485026457489, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.75276176474134, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(144.33387007069567, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(73.665331510370592, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t136a98fe92be4458b4bc830cdfdbca05"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1091585a5a6c46a8af3094ff17e8bd43"><g class="toyplot-Edges"><path d="M 72.160804077 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.04495356 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.708920369 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.708920369 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.04495356 202.472014925 L 193.708920369 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.634297912 161.660447761 L 190.04495356 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.875231087 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.407264296 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.407264296 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.389563973 91.697761194 L 182.407264296 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.495765909 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.495765909 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.389563973 91.697761194 L 182.495765909 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.875231087 120.848880597 L 182.389563973 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.634297912 161.660447761 L 166.875231087 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.160804077 202.472014925 L 137.634297912 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.49576590940845, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.40726429568227, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.38956397293708, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.70892036851072, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(166.87523108674421, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.04495356024839, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(137.63429791162665, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(72.160804077026157, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t293fd6d97bf84ef4b2de9ee3c02945aa"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfa12e1a5049b45e9b5f1e299fc0547ee"><g class="toyplot-Edges"><path d="M 72.9396182778 202.107625933 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.159869188 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.160210363 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.160210363 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.159869188 202.472014925 L 193.160210363 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.997154528 160.931669776 L 188.159869188 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.724914814 119.391324627 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.92050542 88.7826492537 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.947055904 97.5279850746 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.000156873 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.000156873 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.947055904 97.5279850746 L 182.000156873 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.92050542 88.7826492537 L 181.947055904 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.724914814 119.391324627 L 181.92050542 88.7826492537" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.997154528 160.931669776 L 168.724914814 119.391324627" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.9396182778 202.107625933 L 137.997154528 160.931669776" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.00015687254205, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.94705590430635, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.92050542018848, 88.782649253731364)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.16021036340868, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(168.72491481362061, 119.39132462686571)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(188.15986918788158, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(137.99715452790383, 160.93166977611943)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(72.939618277816237, 202.10762593283584)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t39215b00660840e8915988dd9302fa41"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t16b2c81fad2440d6baf2d23caf4552b9"><g class="toyplot-Edges"><path d="M 78.1789138104 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.319240328 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.124809718 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.124809718 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.319240328 202.472014925 L 193.124809718 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.62558422 161.660447761 L 189.319240328 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.769302091 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.62851833 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.62851833 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.619668169 91.697761194 L 182.62851833 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.876322848 91.697761194 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.876322848 91.697761194 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.619668169 91.697761194 L 182.876322848 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.769302091 120.848880597 L 182.619668169 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.62558422 161.660447761 L 170.769302091 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.1789138104 202.472014925 L 139.62558422 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(182.87632284843087, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(182.62851832999766, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(182.61966816862503, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.1248097179182, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.76930209069451, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(189.31924032769405, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(139.62558422046484, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(78.17891381040387, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t98142f6f0f9a420ea3277d11a9150205"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3b73898cbeea4087a2a04e0b7d0f509b"><g class="toyplot-Edges"><path d="M 76.8956404114 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.94780649 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.94780649 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 202.472014925 L 192.94780649 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.510600358 161.660447761 L 187.381054987 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.601149025 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.256811552 91.697761194 L 182.601967846 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.274511875 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.274511875 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.256811552 91.697761194 L 182.274511875 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.601149025 120.848880597 L 182.256811552 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.510600358 161.660447761 L 170.601149025 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.8956404114 202.472014925 L 140.510600358 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.27451187509308, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.60196784587981, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.25681155234784, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.94780649046589, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.60114902461484, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.38105498709152, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(140.51060035772628, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(76.895640411374814, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t26cdebe9980d4165bce0a8035da7394b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8d7efe6dab8041bb94fb60d00e2c198c"><g class="toyplot-Edges"><path d="M 74.2405919996 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.867882098 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.2664123 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.2664123 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.867882098 202.472014925 L 193.2664123 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.227190488 162.389225746 L 188.867882098 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.724914814 122.306436567 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.814303484 94.6128731343 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.858554291 85.8675373134 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.000156873 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.000156873 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.858554291 85.8675373134 L 182.000156873 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.814303484 94.6128731343 L 181.858554291 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.724914814 122.306436567 L 181.814303484 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.227190488 162.389225746 L 168.724914814 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.2405919996 202.836403918 L 137.227190488 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(182.00015687254202, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.85855429058023, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.81430348371714, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(193.26641229988002, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(168.72491481362061, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.86788209769071, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.22719048848637, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(74.240591999590521, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfb73c37999104c30b0a6e73a306a3a03"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t36f1a685798c46919e24a3778f94c18d"><g class="toyplot-Edges"><path d="M 76.745187668 202.107625933 L 198.399505896 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.699729032 202.472014925 L 198.399505896 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.151360202 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.151360202 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.699729032 202.472014925 L 193.151360202 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.846974725 160.931669776 L 188.699729032 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.618781112 119.391324627 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.832003806 88.7826492537 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.840853968 97.5279850746 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.053257841 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.053257841 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.840853968 97.5279850746 L 182.053257841 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.832003806 88.7826492537 L 181.840853968 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.618781112 119.391324627 L 181.832003806 88.7826492537" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.846974725 160.931669776 L 169.618781112 119.391324627" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.745187668 202.107625933 L 141.846974725 160.931669776" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.05325784077772, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.84085396783499, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.83200380646235, 88.782649253731364)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(193.15136020203605, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.61878111225468, 119.39132462686571)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.69972903161101, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(141.84697472499104, 160.93166977611943)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(76.745187668040359, 202.10762593283584)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t26b37581436c4ad1ac4d7332bd84f60d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4691aff1cc344725ab87f21166b961ec"><g class="toyplot-Edges"><path d="M 72.7272144049 202.836403918 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.346063752 184.981343284 L 198.399505896 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.346063752 184.981343284 L 198.399505896 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 202.472014925 L 193.346063752 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.466417786 162.389225746 L 187.381054987 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.786934178 122.306436567 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.362945254 94.6128731343 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.398345899 85.8675373134 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.442596706 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.442596706 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.398345899 85.8675373134 L 181.442596706 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.362945254 94.6128731343 L 181.398345899 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.786934178 122.306436567 L 181.362945254 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.466417786 162.389225746 L 169.786934178 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.7272144049 202.836403918 L 141.466417786 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.44259670606735, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.39834589920426, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.3629452537138, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.34606375223353, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(169.78693417833432, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.38105498709152, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.46641778596862, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(72.727214404873479, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdae2e3d4f53f48b1959dd8258113656c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t44504d7c68ae45b5ab58cf2ea5269ecc"><g class="toyplot-Edges"><path d="M 73.9219861902 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.168787584 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.07170875 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.07170875 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.168787584 202.472014925 L 193.07170875 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.351433923 161.660447761 L 189.168787584 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.21194663 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.203710584 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.203710584 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.186010261 91.697761194 L 182.203710584 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.345313166 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.345313166 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.186010261 91.697761194 L 182.345313166 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.21194663 120.848880597 L 182.186010261 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.351433923 161.660447761 L 173.21194663 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.9219861902 202.472014925 L 142.351433923 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(182.34531316607399, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(182.20371058411217, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(182.18601026136693, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.0717087496825, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(173.21194662953604, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(189.16878758435965, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(142.35143392323005, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(73.921986190176426, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1a0c5d7483bb4e9e970656afde566651"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4eb94718e1e14d369190667a2c5515d2"><g class="toyplot-Edges"><path d="M 65.4258312725 201.014458955 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.248507272 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 184.981343284 L 198.399505896 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 184.981343284 L 198.399505896 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.248507272 202.472014925 L 192.806203909 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.643079838 158.745335821 L 190.248507272 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.264911128 115.018656716 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.593049449 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.628450095 103.358208955 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.655000579 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.655000579 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.628450095 103.358208955 L 181.655000579 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.593049449 80.0373134328 L 181.628450095 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.264911128 115.018656716 L 181.593049449 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.643079838 158.745335821 L 171.264911128 115.018656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.4258312725 201.014458955 L 136.643079838 158.745335821" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.39950589599627, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.39950589599627, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.65500057901008, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.6284500948922, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.59304944940178, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.80620390850407, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.26491112756094, 115.01865671641794)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.24850727181854, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(136.64307983789382, 158.74533582089555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(65.425831272466695, 201.01445895522392)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t672f40afd6224407a4248ca5d92e5814"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t98ef85523c1d46d5ae41b628a49aa1e3"><g class="toyplot-Edges"><path d="M 66.8949580603 201.014458955 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.965302108 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.894705522 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.894705522 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.965302108 202.472014925 L 192.894705522 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.466213081 158.745335821 L 189.965302108 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.424282267 115.018656716 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.761202515 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.787753 103.358208955 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.823153645 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.823153645 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.787753 103.358208955 L 181.823153645 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.761202515 80.0373134328 L 181.787753 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.424282267 115.018656716 L 181.761202515 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.466213081 158.745335821 L 172.424282267 115.018656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.8949580603 201.014458955 L 138.466213081 158.745335821" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.82315364508977, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.78775299959926, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.76120251548144, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.89470552223023, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(172.42428226737337, 115.01865671641794)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(189.96530210789493, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(138.46621308065238, 158.74533582089555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(66.894958060320661, 201.01445895522392)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t290f786315974772b530381e031793d4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t53658621be234317a0b9857b98b01667"><g class="toyplot-Edges"><path d="M 59.5050733142 201.014458955 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.292894549 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.292894549 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 202.472014925 L 192.292894549 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.032759879 158.745335821 L 187.478406762 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.406377239 115.018656716 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.486847513 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.486847513 103.358208955 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.575349127 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.575349127 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.486847513 103.358208955 L 181.575349127 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.486847513 80.0373134328 L 181.486847513 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.406377239 115.018656716 L 181.486847513 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.032759879 158.745335821 L 169.406377239 115.018656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.5050733142 201.014458955 L 141.032759879 158.745335821" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.57534912665653, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.48684751293038, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.48684751293038, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.29289454889243, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(169.40637723931189, 115.01865671641794)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.4784067621903, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(141.03275987871049, 158.74533582089555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(59.505073314187726, 201.01445895522392)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t48eac6cdd1854fdd8336e8b331f69b03"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2293221ed16b4824847f0e8ec6c986f5"><g class="toyplot-Edges"><path d="M 68.6826906576 201.014458955 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.0801495 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.0801495 202.472014925 L 193.045158266 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.005868219 158.745335821 L 187.0801495 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 115.018656716 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.938205743 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.947055904 103.358208955 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.079808325 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.079808325 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.947055904 103.358208955 L 182.079808325 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.938205743 80.0373134328 L 181.947055904 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 115.018656716 L 181.938205743 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.005868219 158.745335821 L 169.034670462 115.018656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.6826906576 201.014458955 L 136.005868219 158.745335821" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.07980832489557, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.94705590430635, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.93820574293375, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.04515826556468, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(169.0346704616621, 115.01865671641794)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.08014950042264, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(136.00586821906563, 158.74533582089555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(68.682690657588751, 201.01445895522392)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td19d923b2e63441ba5e057e88aa007ed"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0ebfd6d0daed49afa11aa6bcc4fd5aa4"><g class="toyplot-Edges"><path d="M 73.7538331241 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.434292426 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.514216818 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.514216818 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.434292426 202.472014925 L 193.514216818 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.961753882 161.660447761 L 189.434292426 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.459614678 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.513534467 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.548935113 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.59318592 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.59318592 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.548935113 80.0373134328 L 183.59318592 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.513534467 91.697761194 L 183.548935113 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.459614678 120.848880597 L 183.513534467 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.961753882 161.660447761 L 171.459614678 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.7538331241 202.472014925 L 137.961753882 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.59318591961261, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.54893511274955, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.51353446725906, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(193.5142168183132, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(171.45961467775842, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(189.43429242553802, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.96175388241335, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(73.75383312409673, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tadd34f3504ad4a4c8d64ded1236b3827"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0d47e4a6e7154f50a006ec573727aba6"><g class="toyplot-Edges"><path d="M 76.7628879908 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.425510499 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.177910686 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.177910686 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.425510499 202.472014925 L 193.177910686 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.023500307 161.660447761 L 190.425510499 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.910768202 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.929492052 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.973742859 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.009143504 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.009143504 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.973742859 80.0373134328 L 184.009143504 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.929492052 91.697761194 L 183.973742859 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.910768202 120.848880597 L 183.929492052 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.023500307 161.660447761 L 168.910768202 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.7628879908 202.472014925 L 135.023500307 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.00914350412546, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(183.97374285863501, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(183.92949205177192, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(193.17791068615387, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(168.9107682024455, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.42551049927084, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(135.02350030670542, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(76.762887990785586, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t95d8a57e159047ef95c87050bffe9d41"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td218968002da4fad917618dbc63fd6e1"><g class="toyplot-Edges"><path d="M 75.8070705625 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.239725346 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.239725346 202.472014925 L 192.806203909 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.501545491 163.846781716 L 191.239725346 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.600807849 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.2392477 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.274648345 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.301198829 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.301198829 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.274648345 97.5279850746 L 184.301198829 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.2392477 100.443097015 L 184.274648345 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.600807849 125.221548507 L 184.2392477 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.501545491 163.846781716 L 165.600807849 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.8070705625 203.565181903 L 137.501545491 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.30119882942174, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.27464834530392, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.23924769981346, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.80620390850407, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(165.60080784908777, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.23972534555136, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(137.50154549103743, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(75.807070562543259, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2b5bf510cd334e7eb03db1174eb2d06d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1b42d4fb491c49849e59dd75dba9df13"><g class="toyplot-Edges"><path d="M 71.1695860033 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.885718891 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 184.981343284 L 198.399505896 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 184.981343284 L 198.399505896 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.885718891 202.472014925 L 191.91233761 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.183280857 161.660447761 L 190.885718891 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.565475439 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.663987211 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.717088179 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.72593834 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.72593834 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.717088179 80.0373134328 L 183.72593834 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.663987211 91.697761194 L 183.717088179 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.565475439 120.848880597 L 183.663987211 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.183280857 161.660447761 L 166.565475439 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.1695860033 202.472014925 L 142.183280857 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.72593834020182, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.71708817882921, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.66398721059352, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.91233760987006, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(166.56547543870272, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.88571889064681, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(142.18328085715038, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(71.169586003293361, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4b9ca3740a404b5b9904fd5d96e86a27"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbca87e4155004f5c89d9e0922aaf8278"><g class="toyplot-Edges"><path d="M 64.6204665876 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.974152269 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.39916472 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.39916472 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.974152269 202.472014925 L 193.39916472 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.510532123 163.846781716 L 189.974152269 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.441914355 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.672769137 100.443097015 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.955974301 97.5279850746 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.964824462 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.964824462 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.955974301 97.5279850746 L 182.964824462 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.672769137 100.443097015 L 182.955974301 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.441914355 125.221548507 L 182.672769137 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.510532123 163.846781716 L 171.441914355 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.6204665876 203.565181903 L 139.510532123 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.96482446215703, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.95597430078439, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.67276913686072, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.39916472046926, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.44191435501321, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(189.97415226926751, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(139.51053212262087, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(64.620466587558809, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t35eff5e7b0614665b5134e9b842335da"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t45f98dc4e81a40fb90d37dd3a3dd8a5b"><g class="toyplot-Edges"><path d="M 58.336852013 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.115686616 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.903555684 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.903555684 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.115686616 202.472014925 L 192.903555684 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.510600358 163.846781716 L 189.115686616 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.255788026 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.380713812 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.460365264 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.522316394 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.522316394 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.460365264 97.5279850746 L 182.522316394 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.380713812 100.443097015 L 182.460365264 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.255788026 125.221548507 L 182.380713812 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.510600358 163.846781716 L 167.255788026 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.336852013 203.565181903 L 140.510600358 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874151, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.52231639352624, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.46036526391796, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.38071381156445, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.9035556836028, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.25578802576661, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(189.1156866161239, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(140.51060035772625, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(58.336852013002641, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta6600594faf5427d85c46bf865272cc8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td520fd8c59c54350b7b560eab84c2079"><g class="toyplot-Edges"><path d="M 65.9922416003 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.452060983 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.292962784 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.292962784 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.452060983 202.472014925 L 193.292962784 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.837851623 163.846781716 L 190.452060983 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.901918041 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.849840599 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.902941568 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.000293343 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.000293343 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.902941568 97.5279850746 L 184.000293343 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.849840599 100.443097015 L 183.902941568 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.901918041 125.221548507 L 183.849840599 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.837851623 163.846781716 L 168.901918041 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.9922416003 203.565181903 L 137.837851623 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.00029334275288, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(183.9029415676541, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(183.84984059941843, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.29296278399787, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.90191804107286, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.45206098338866, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.83785162319677, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(65.992241600314003, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t044ac531e44e480c8721467403fd9007"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc20e06b83f93424397d110769a11fb06"><g class="toyplot-Edges"><path d="M 59.761727994 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.213038391 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.10704116 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.10704116 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.213038391 202.472014925 L 192.10704116 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.439935537 163.846781716 L 189.213038391 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.857530764 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.27458011 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.363081724 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.460433499 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.460433499 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.363081724 97.5279850746 L 183.460433499 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.27458011 100.443097015 L 183.363081724 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.857530764 125.221548507 L 183.27458011 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.439935537 163.846781716 L 166.857530764 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.761727994 203.565181903 L 142.439935537 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.4604334990234, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.36308172392461, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.27458011019849, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.10704116006752, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(166.85753076399899, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(189.21303839122271, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(142.4399355369562, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(59.761727993993553, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4d475bac524c4565acd96d11c0bdf966"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t507f798967c34f999622f18b7bd380bc"><g class="toyplot-Edges"><path d="M 57.1597805504 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.443210822 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.345995517 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.345995517 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.443210822 202.472014925 L 192.345995517 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.767186802 163.846781716 L 190.443210822 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.424145797 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.699387856 100.443097015 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.743638663 97.5279850746 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.832140277 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.832140277 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.743638663 97.5279850746 L 183.832140277 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.699387856 100.443097015 L 183.743638663 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.424145797 125.221548507 L 183.699387856 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.767186802 163.846781716 L 170.424145797 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 57.1597805504 203.565181903 L 139.767186802 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.83214027667321, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.74363866294706, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.699387856084, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.34599551712816, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(170.42414579716257, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.44321082201608, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(139.76718680242669, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(57.159780550444957, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t64be1f2c43854600b90715773bcbf178"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t037270be2f0d4eb780484292842cc533"><g class="toyplot-Edges"><path d="M 50.7876643622 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.230670479 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.142305335 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.142305335 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.230670479 202.472014925 L 190.142305335 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.280496162 163.846781716 L 188.230670479 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.326589317 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.442664941 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.584267523 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.584267523 97.5279850746 L 182.601967846 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.442664941 100.443097015 L 182.584267523 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.326589317 125.221548507 L 182.442664941 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.280496162 163.846781716 L 167.326589317 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.7876643622 203.565181903 L 140.280496162 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.60196784587978, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.58426752313457, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.44266494117272, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.14230533534717, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(167.32658931674754, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.23067047886249, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(140.28049616203828, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(50.787664362162658, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te65c8276061c47209a1f98896d6b9180"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t12211de8b5d84fa8b5a71e58225f7353"><g class="toyplot-Edges"><path d="M 50.0 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.717429354 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.540630832 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.540630832 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.717429354 202.472014925 L 191.540630832 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.112479566 163.846781716 L 188.717429354 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.866722101 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.593117685 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.672769137 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.159528012 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.159528012 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.672769137 97.5279850746 L 183.159528012 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.593117685 100.443097015 L 182.672769137 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.866722101 125.221548507 L 182.593117685 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.112479566 163.846781716 L 171.866722101 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 203.565181903 L 142.112479566 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(183.15952801235451, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.67276913686072, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.59311768450718, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.54063083222024, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(171.8667221008987, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(188.71742935435628, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(142.11247956616947, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(50.0, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td4294add695a4b8e9b9eb6ae4ded3f5d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1b3443ade7f84bb6a65c90bac19750e7"><g class="toyplot-Edges"><path d="M 55.3985984373 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.062653883 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.682233414 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.682233414 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.062653883 202.472014925 L 191.682233414 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.563564856 163.846781716 L 190.062653883 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.14972256 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.009075269 100.443097015 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.106427044 97.5279850746 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.59318592 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.59318592 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.106427044 97.5279850746 L 183.59318592 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.009075269 100.443097015 L 183.106427044 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.14972256 125.221548507 L 183.009075269 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.563564856 163.846781716 L 169.14972256 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.3985984373 203.565181903 L 138.563564856 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.59318591961264, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.10642704411882, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.00907526902006, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.68223341418209, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.14972255950607, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.06265388299366, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.56356485575114, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(55.398598437294709, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1356e73fcedb4d3798a572da9fcd4f7a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7363cc5a37c9423cbb249f4b35f07a69"><g class="toyplot-Edges"><path d="M 61.8857667234 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.903419213 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.195542774 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.195542774 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.903419213 202.472014925 L 192.195542774 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.988167896 163.846781716 L 190.903419213 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.725119519 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.345381401 100.443097015 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.425032854 97.5279850746 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.221547377 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.221547377 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.425032854 97.5279850746 L 184.221547377 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.345381401 100.443097015 L 183.425032854 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.725119519 125.221548507 L 183.345381401 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.988167896 163.846781716 L 171.725119519 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.8857667234 203.565181903 L 135.988167896 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(184.22154737706822, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(183.42503285353297, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(183.34538140117942, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.19554277379373, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.72511951893685, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.90341921339203, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(135.98816789632036, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(61.885766723420986, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfa9472e16a2b4cf18bec7a484e7e7f4e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf6805b38e9ec429e81ef106d5ddc0c06"><g class="toyplot-Edges"><path d="M 60.8414476815 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.646764534 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.345927282 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.345927282 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.646764534 202.472014925 L 191.345927282 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.652271175 163.846781716 L 190.646764534 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.318012096 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.416182692 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.478133822 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.708306253 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.708306253 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.478133822 97.5279850746 L 184.708306253 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.416182692 100.443097015 L 183.478133822 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.318012096 125.221548507 L 183.416182692 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.652271175 163.846781716 L 171.318012096 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.8414476815 203.565181903 L 141.652271175 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(184.70830625256201, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(183.47813382176864, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(183.41618269216033, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.34592728202273, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(171.3180120957966, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.64676453358618, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(141.65227117479353, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(60.8414476814525, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t924337422455464ca69c5307a41e38d1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te227585238e74edeacc4af5c1df89667"><g class="toyplot-Edges"><path d="M 63.3106427044 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.460911145 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.460911145 202.472014925 L 191.390178089 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.014854851 163.846781716 L 190.460911145 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.963869171 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.805589793 100.443097015 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.115345441 97.5279850746 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.832208512 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.832208512 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.115345441 97.5279850746 L 184.832208512 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.805589793 100.443097015 L 184.115345441 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.963869171 125.221548507 L 183.805589793 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.014854851 163.846781716 L 168.963869171 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.3106427044 203.565181903 L 138.014854851 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.83220851177859, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.11534544059685, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(183.80558979255537, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.39017808888576, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.96386917068119, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.4609111447613, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(138.01485485064904, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(63.310642704411876, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb5436b1555314393b38176f2f1e20476"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t44960994e5b844bfb4cbd4c89a0abc77"><g class="toyplot-Edges"><path d="M 68.8331434009 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.983002431 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.983002431 202.472014925 L 191.549480994 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.271304825 163.846781716 L 189.983002431 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.211878394 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.602104316 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.841058673 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.478338527 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.478338527 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.841058673 97.5279850746 L 186.478338527 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.602104316 100.443097015 L 184.841058673 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.211878394 125.221548507 L 184.602104316 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.271304825 163.846781716 L 172.211878394 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.8331434009 203.565181903 L 135.271304825 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.47833852708484, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(184.84105867315122, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(184.60210431609062, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.54948099359288, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(172.21187839443064, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(189.98300243064011, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(135.27130482513863, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(68.833143400923191, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="teb385ceb277147e38104058e028e1f5a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t82f0c7a7c3384a1ab5b008b4f976aa05"><g class="toyplot-Edges"><path d="M 64.4080627146 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.726415986 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.94767002 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.94767002 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.726415986 202.472014925 L 190.94767002 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.536809666 163.846781716 L 190.726415986 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.203164703 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.425101089 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.655205284 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.186214967 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.186214967 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.655205284 97.5279850746 L 185.186214967 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.425101089 100.443097015 L 184.655205284 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.203164703 125.221548507 L 184.425101089 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.536809666 163.846781716 L 174.203164703 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.4080627146 203.565181903 L 135.536809666 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.18621496668317, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(184.65520528432631, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(184.42510108863834, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.94767002025509, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(174.20316470326884, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.7264159859397, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(135.53680966631705, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(64.408062714616051, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7c52593d3f0e4b75a27c6dcd68fea29b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t722babba38454305bd04d096d40eaa88"><g class="toyplot-Edges"><path d="M 64.0186556142 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.55826292 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.018471311 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.018471311 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.55826292 202.472014925 L 191.018471311 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.49269533 163.846781716 L 190.55826292 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.468328369 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.451651573 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.602104316 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.602104316 97.5279850746 L 185.345517871 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.451651573 100.443097015 L 184.602104316 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.468328369 125.221548507 L 184.451651573 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.49269533 163.846781716 L 169.468328369 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.0186556142 203.565181903 L 137.49269533 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.34551787139023, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.60210431609062, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.45165157275619, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.01847131123594, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.4683283689202, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.55826291986006, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.4926953296648, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(64.018655614221018, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf65438be6fd34172bc6e60bec0e4d24f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb25b4dc37e2844e9a7430afade712061"><g class="toyplot-Edges"><path d="M 63.2486915748 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.071504044 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.071504044 202.472014925 L 191.788435351 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.138688875 161.660447761 L 190.071504044 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.919481894 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.593390625 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.593390625 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.69060593 91.697761194 L 186.593390625 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.761407221 115.018656716 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.761407221 115.018656716 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.69060593 91.697761194 L 184.761407221 115.018656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.919481894 120.848880597 L 184.69060593 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.138688875 161.660447761 L 166.919481894 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.2486915748 202.472014925 L 137.138688875 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.76140722079771, 115.01865671641794)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.59339062492884, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.69060592981677, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.78843535065346, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(166.9194818936073, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(190.07150404436626, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(137.13868887476022, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(63.248691574803573, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfd93fdcc0a214632a1c4039255e5e2b1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb012049822444be5aaea4b468c5ac094"><g class="toyplot-Edges"><path d="M 68.1074301684 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.045021795 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.000839224 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.000839224 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.045021795 202.472014925 L 192.000839224 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.501409021 165.304337687 L 191.045021795 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.194246307 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.832276747 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.867677392 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.204119995 68.3768656716 L 198.399505896 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.204119995 68.3768656716 L 198.399505896 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.867677392 85.8675373134 L 188.204119995 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.832276747 106.273320896 L 185.867677392 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.194246307 128.136660448 L 185.832276747 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.501409021 165.304337687 L 173.194246307 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.1074301684 204.293959888 L 135.501409021 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.20411999474464, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(185.86767739237447, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(185.83227674688402, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.00083922359619, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(173.1942463067908, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.04502179535382, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(135.5014090208266, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(68.107430168368808, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3dd49b63268c457a82201e0a772c4c21"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t66b45549b4f1406a864d51c2ed5dbf41"><g class="toyplot-Edges"><path d="M 67.9127266182 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.283976152 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.283976152 202.472014925 L 192.505298422 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.767118567 165.304337687 L 191.283976152 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.477110295 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.000429813 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.221888553 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.221888553 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 85.8675373134 L 189.221888553 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.000429813 106.273320896 L 186.04468062 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.477110295 128.136660448 L 186.000429813 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.767118567 165.304337687 L 168.477110295 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.9127266182 204.293959888 L 138.767118567 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(189.22188855259532, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.04468061982678, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.00042981296372, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.50529842183522, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.47711029518743, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.2839761524144, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(138.76711856732126, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(67.91272661817132, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc9ebc3945f884804a5346b0041c93241"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t36e446f792ca4fddabead23664874fe4"><g class="toyplot-Edges"><path d="M 67.5941208088 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.301676475 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.301676475 202.472014925 L 192.381396163 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.342242586 165.304337687 L 191.301676475 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.73396968 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.796876101 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.84997707 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.540289657 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.540289657 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.84997707 85.8675373134 L 186.540289657 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.796876101 106.273320896 L 185.84997707 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.73396968 128.136660448 L 185.796876101 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.342242586 165.304337687 L 171.73396968 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.5941208088 204.293959888 L 137.342242586 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.54028965669318, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.84997706962929, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.79687610139356, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.38139616261861, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(171.73396968030946, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.30167647515967, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(137.34224258633037, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(67.594120808757197, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfd664112b01c4dd480f383e74b76da57"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tafe3338d80cb40b2b79962d02ccf47a6"><g class="toyplot-Edges"><path d="M 61.1512033295 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.983002431 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.115823086 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.115823086 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.983002431 202.472014925 L 191.115823086 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.386356923 165.304337687 L 189.983002431 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.725119519 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.991511416 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.088863192 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.407469001 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.407469001 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.088863192 85.8675373134 L 185.407469001 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.991511416 106.273320896 L 185.088863192 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.725119519 128.136660448 L 184.991511416 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.386356923 165.304337687 L 171.725119519 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.1512033295 204.293959888 L 135.386356923 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(185.40746900099856, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(185.08886319158444, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.99151141648568, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.11582308633476, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(171.72511951893685, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(189.98300243064011, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(135.3863569229826, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(61.151203329494003, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tca1e5412cbd341ea91fac21af5a8859d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9f17cde0facb4a859dadd314a8b6394f"><g class="toyplot-Edges"><path d="M 67.1870133856 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.894569052 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.894569052 202.472014925 L 192.080490676 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.767255038 165.304337687 L 190.894569052 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.662758979 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.062380943 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.142032395 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.142032395 85.8675373134 L 186.575690302 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.062380943 106.273320896 L 186.142032395 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.662758979 128.136660448 L 186.062380943 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.767255038 165.304337687 L 165.662758979 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.1870133856 204.293959888 L 140.767255038 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.57569030218363, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.14203239492554, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.06238094257199, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.0804906759497, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(165.66275897869608, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.89456905201939, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(140.7672550375321, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.187013385616922, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb3d483d5c7ba40fd9df08b9419409f75"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5cde454457134ef8a7840415e4472fdd"><g class="toyplot-Edges"><path d="M 64.9567727197 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.443210822 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.39902825 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.39902825 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.443210822 202.472014925 L 191.39902825 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.643148073 165.304337687 L 190.443210822 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.18505497 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.380918517 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.549071583 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.885377715 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.885377715 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.549071583 85.8675373134 L 185.885377715 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.380918517 106.273320896 L 185.549071583 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.18505497 128.136660448 L 185.380918517 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.643148073 165.304337687 L 168.18505497 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.9567727197 204.293959888 L 137.643148073 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.88537771511972, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.54907158296035, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.38091851688071, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.3990282502584, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(168.18505496989115, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.44321082201608, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.64314807299925, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(64.956772719718145, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3323b84992be4c2e8d993b14838e0f31"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbfa40ceb4d3d4c04b52c8975b33c9476"><g class="toyplot-Edges"><path d="M 71.1607358419 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.027321473 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.222025023 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.222025023 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.027321473 202.472014925 L 191.222025023 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.156525668 165.304337687 L 191.027321473 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.981296553 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.292485138 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.876595789 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.876595789 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.292485138 85.8675373134 L 186.876595789 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 106.273320896 L 186.292485138 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.981296553 128.136660448 L 186.04468062 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.156525668 165.304337687 L 164.981296553 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.1607358419 204.293959888 L 139.156525668 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.87659578885248, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.29248513825999, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.04468061982678, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.22202502280612, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(164.98129655300477, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.02732147260863, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(139.15652566771629, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(71.160735841920769, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t51034f61e96140c28974cd1d407d96e5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb6b5b343df984aa6b807d73d27dcd665"><g class="toyplot-Edges"><path d="M 73.7184324786 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.062722118 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.062722118 202.472014925 L 191.363627605 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.961890353 165.304337687 L 191.062722118 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.662963684 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.655273519 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.938478683 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.319035622 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.319035622 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.938478683 85.8675373134 L 186.319035622 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.655273519 106.273320896 L 185.938478683 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.662963684 128.136660448 L 185.655273519 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.961890353 165.304337687 L 168.662963684 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.7184324786 204.293959888 L 139.961890353 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.31903562237781, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(185.93847868335541, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(185.65527351943174, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.36362760476797, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(168.66296368401231, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.06272211809909, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.96189035262421, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(73.718432478606275, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9bc834e55922481c8bc787448ca3e67b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6af608e0e5744b6fbdc24ddcb79aeb47"><g class="toyplot-Edges"><path d="M 67.9392771023 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.983070666 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.098122764 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.098122764 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.983070666 202.472014925 L 191.098122764 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.598760796 165.304337687 L 190.983070666 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.335371243 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.708306253 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.929560287 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.062312707 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.062312707 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.929560287 85.8675373134 L 185.062312707 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.708306253 106.273320896 L 184.929560287 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.335371243 128.136660448 L 184.708306253 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.598760796 165.304337687 L 166.335371243 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.9392771023 204.293959888 L 135.598760796 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736896, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(185.06231270746659, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(184.9295602868774, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(184.70830625256204, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.09812276358952, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(166.33537124301475, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.98307066574554, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(135.59876079592536, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(67.939277102289168, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t27e39805a4ed44dabd3346fa34814dce"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td8eedbdb4f664095b6b897f824e644aa"><g class="toyplot-Edges"><path d="M 66.080743214 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.045021795 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.425578734 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.425578734 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.045021795 202.472014925 L 191.425578734 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.262795839 165.304337687 L 191.045021795 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.804566266 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.150814321 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.301267065 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.920778361 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.920778361 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.301267065 85.8675373134 L 185.920778361 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.150814321 106.273320896 L 185.301267065 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.804566266 128.136660448 L 185.150814321 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.262795839 165.304337687 L 168.804566266 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.080743214 204.293959888 L 140.262795839 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.92077836061017, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.30126706452717, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.15081432119271, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.42557873437627, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.80456626597416, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.04502179535382, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.26279583929306, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(66.080743214040154, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t37e1923647c04786b6eba57e2ee934b3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t89b815272c0e473fa238c18ac565df18"><g class="toyplot-Edges"><path d="M 65.6205348227 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.018539546 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.018539546 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 202.472014925 L 192.018539546 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.926080297 165.304337687 L 191.363627605 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.124263837 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.354368033 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.248234331 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.248234331 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.354368033 85.8675373134 L 186.248234331 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.124263837 106.273320896 L 185.354368033 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 128.136660448 L 185.124263837 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.926080297 165.304337687 L 169.034670462 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.6205348227 204.293959888 L 133.926080297 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.2482343313969, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.35436803276284, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.12426383707489, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.0185395463414, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(169.0346704616621, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.36362760476797, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(133.92608029650123, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(65.620534822664212, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4269d22516f74d798a012ac4fafb9853"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc310eb99135a4894aa89b59f9ba5b8fa"><g class="toyplot-Edges"><path d="M 64.4080627146 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.151223732 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.151223732 202.472014925 L 191.788435351 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.226985783 165.304337687 L 191.151223732 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.928468525 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.664123681 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.832276747 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.832276747 85.8675373134 L 187.150950791 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.664123681 106.273320896 L 185.832276747 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.928468525 128.136660448 L 185.664123681 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.226985783 165.304337687 L 168.928468525 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.4080627146 204.293959888 L 134.226985783 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.15095079140355, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(185.83227674688402, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(185.66412368080435, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.78843535065346, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.92846852519077, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.15122373182524, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(134.22698578317016, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(64.408062714616065, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf7ae4cb44d1a4dba9c83308cba1a0765"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t861c81cd6a664ce8877dc8d25b75bfb1"><g class="toyplot-Edges"><path d="M 63.6469488366 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.14237357 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.14237357 202.472014925 L 191.761884867 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.651861764 165.304337687 L 191.14237357 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.521497572 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.053462546 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.434019485 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.451788043 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.451788043 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.434019485 85.8675373134 L 186.451788043 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.053462546 106.273320896 L 185.434019485 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.521497572 128.136660448 L 185.053462546 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.651861764 165.304337687 L 170.521497572 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.6469488366 204.293959888 L 135.651861764 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.45178804296702, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.43401948511638, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.05346254609398, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.76188486653558, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.5214975722613, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.14237357045255, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(135.65186176416103, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(63.646948836571227, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t661acaf9167945d182398d2c9bb53f46"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb78824ab8ad640ad81f927a0b8e40c53"><g class="toyplot-Edges"><path d="M 62.9743365723 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 202.472014925 L 191.797285512 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.68767182 165.304337687 L 191.168924055 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.229374012 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.973811094 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.354368033 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.195133363 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.195133363 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.354368033 85.8675373134 L 186.195133363 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.973811094 106.273320896 L 185.354368033 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.229374012 128.136660448 L 184.973811094 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.68767182 165.304337687 L 169.229374012 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.9743365723 204.293959888 L 141.68767182 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.1951333631612, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.35436803276284, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(184.97381109374044, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.79728551202604, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.22937401185962, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.16892405457043, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(141.68767182028398, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(62.974336572252533, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5b6da6067221444b8e75044f7d7574ba"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1edb859635db42de8dff6aa40f41cfd9"><g class="toyplot-Edges"><path d="M 62.0981705964 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.779516954 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.487529864 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.487529864 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.779516954 202.472014925 L 191.487529864 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.598897266 165.304337687 L 190.779516954 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.768960915 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.283498507 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.283566742 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.965029167 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.965029167 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.283566742 85.8675373134 L 185.965029167 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.283498507 106.273320896 L 185.283566742 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.768960915 128.136660448 L 184.283498507 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.598897266 165.304337687 L 165.768960915 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.0981705964 204.293959888 L 137.598897266 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.96502916747323, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.28356674178195, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.28349850667655, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.48752986398455, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(165.76896091516744, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.77951695417542, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.59889726613619, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(62.09817059636373, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t069b6185a4424de6b8bb6cd5de770429"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb534b16131ff40e8bc872d69d5642469"><g class="toyplot-Edges"><path d="M 69.7093093768 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.522930509 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.806135673 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.806135673 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.522930509 202.472014925 L 191.806135673 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.431153611 165.304337687 L 191.522930509 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.76902915 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.354436268 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.876595789 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.876595789 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 85.8675373134 L 186.876595789 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.354436268 106.273320896 L 186.726143046 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.76902915 128.136660448 L 186.354436268 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.431153611 165.304337687 L 166.76902915 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.7093093768 204.293959888 L 143.431153611 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.87659578885248, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.72614304551806, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.35443626786827, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.80613567339864, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(166.76902915027284, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.522930509475, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(143.43115361068899, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(69.709309376812016, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7ce1439d5ad94ea3b04707261ebfa798"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta7f8d7e6d1d441e8be4f0e85b8f7bf72"><g class="toyplot-Edges"><path d="M 71.3377390694 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.841536319 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.841536319 202.472014925 L 191.930037933 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.342515527 165.304337687 L 191.841536319 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.008119978 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.646491593 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.018198371 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.327954019 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.327954019 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.018198371 85.8675373134 L 187.327954019 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.646491593 106.273320896 L 187.018198371 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.008119978 128.136660448 L 186.646491593 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.342515527 165.304337687 L 169.008119978 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.3377390694 204.293959888 L 141.342515527 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.32795401885585, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.01819837081433, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.64649159316454, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.93003793261525, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.00811997754428, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.84153631888913, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(141.34251552675201, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(71.337739069373043, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t35520a475dcf4461b09384c19c5993f0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t515b1df62ed94356b53b8b2746450bec"><g class="toyplot-Edges"><path d="M 63.2575417362 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.496380025 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.496380025 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 202.472014925 L 191.496380025 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.492763565 165.304337687 L 191.168924055 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.468260134 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.867677392 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.354436268 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.354436268 85.8675373134 L 186.743843368 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.867677392 106.273320896 L 186.354436268 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.468260134 128.136660448 L 185.867677392 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.492763565 165.304337687 L 168.468260134 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.2575417362 204.293959888 L 138.492763565 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.7438433682633, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.35443626786827, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.86767739237447, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.49638002535715, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.46826013381477, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.16892405457043, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(138.4927635647702, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(63.257541736176194, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4137e0d87b9d4a4d80f0e848f78bfee7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbe446b90f4ab4a319b36ed8be124fce3"><g class="toyplot-Edges"><path d="M 63.7708510958 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.735334382 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.655751165 184.981343284 L 198.399505896 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.655751165 184.981343284 L 198.399505896 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.735334382 202.472014925 L 192.655751165 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.952971956 165.304337687 L 191.735334382 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.530143028 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991647887 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.53150773 68.3768656716 L 198.399505896 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.53150773 68.3768656716 L 198.399505896 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991647887 85.8675373134 L 187.53150773 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 106.273320896 L 186.991647887 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.530143028 128.136660448 L 186.531439495 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.952971956 165.304337687 L 167.530143028 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.7708510958 204.293959888 L 138.952971956 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.53150773042594, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.99164788669651, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.53143949532057, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.65575116516962, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.53014302831767, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.73533438241773, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(138.95297195614614, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(63.770851095787805, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t11ab6b7c92e74c658619d254c89afa41"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="taf9b062191844b91ad6b0de8e7702e1d"><g class="toyplot-Edges"><path d="M 67.4790687109 204.293959888 L 198.399505896 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.222093258 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.222093258 202.472014925 L 192.381396163 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.209558401 165.304337687 L 192.222093258 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.317943861 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.168651114 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.504957246 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.628927741 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.628927741 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.504957246 85.8675373134 L 188.628927741 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.168651114 106.273320896 L 187.504957246 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.317943861 128.136660448 L 187.168651114 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.209558401 165.304337687 L 170.317943861 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.4790687109 204.293959888 L 138.209558401 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(188.62892774063013, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.50495724630812, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.16865111414876, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.38139616261856, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.3179438606912, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.22209325791155, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(138.20955840084656, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(67.479068710913197, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5b1a448f7e834d6d8ea33882bc812c5a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta177188f1def430f8f1c695fa2afcfbe"><g class="toyplot-Edges"><path d="M 63.2929423817 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.753034705 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.753034705 202.472014925 L 191.797285512 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.934930458 165.304337687 L 191.753034705 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.140940633 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.673042077 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.496107085 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.496107085 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 85.8675373134 L 187.496107085 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.673042077 106.273320896 L 187.106699985 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.140940633 128.136660448 L 186.673042077 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.934930458 165.304337687 L 170.140940633 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.2929423817 204.293959888 L 133.934930458 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.49610708493549, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.10669998454048, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.67304207728239, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.79728551202604, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.14094063323893, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.753034705163, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(133.93493045787386, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(63.292942381666649, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t72f8a467644245afb963b4989b741e2f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t23c3dfad788b46e3b1bc00515b6f63c9"><g class="toyplot-Edges"><path d="M 67.0454108037 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.062790353 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.098190999 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.098190999 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.062790353 202.472014925 L 192.098190999 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.935066928 165.304337687 L 192.062790353 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.070207577 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.301403535 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.566976611 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.566976611 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 85.8675373134 L 188.566976611 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.301403535 106.273320896 L 187.637709667 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.070207577 128.136660448 L 187.301403535 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.935066928 165.304337687 L 171.070207577 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.0454108037 204.293959888 L 135.935066928 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.56697661102186, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.63770966689734, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.301403534738, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.09819099869495, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(171.07020757736342, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.06279035320449, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(135.93506692808469, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(67.045410803655116, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1106149af8fc46bdaad90b6bf87a8914"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td5875b506c30468091da94a23b015a72"><g class="toyplot-Edges"><path d="M 62.2574735011 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.301676475 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.602650197 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.602650197 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.301676475 202.472014925 L 192.602650197 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.775695788 165.304337687 L 191.301676475 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.211605454 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.044748855 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.628859506 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.628859506 85.8675373134 L 187.708510958 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.044748855 106.273320896 L 187.628859506 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.211605454 128.136660448 L 187.044748855 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.775695788 165.304337687 L 168.211605454 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.2574735011 204.293959888 L 134.775695788 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.70851095787827, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.62885950552473, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.04474885493218, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.60265019693398, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(168.21160545400897, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.30167647515967, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(134.77569578827223, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(62.257473501070791, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta1bbd9090aa84e9fa24a0106f61ec5e2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t49a27d36ef314944b52df117646f505d"><g class="toyplot-Edges"><path d="M 62.9743365723 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.49644826 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.885855361 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.885855361 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.49644826 202.472014925 L 192.885855361 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.891020827 165.304337687 L 192.49644826 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.239452405 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.549208053 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.611159183 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.611159183 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.549208053 85.8675373134 L 187.611159183 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.239452405 106.273320896 L 187.549208053 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 128.136660448 L 187.239452405 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.891020827 165.304337687 L 167.007983507 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.9743365723 204.293959888 L 138.891020827 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.61115918277949, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.54920805317118, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.2394524051297, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.88585536085762, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.00798350733342, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.49644826046253, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(138.89102082653784, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(62.974336572252533, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t93a7a41b807c4ecf9edb06ea2921af50"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t89a32677216948dd818a542d933352f5"><g class="toyplot-Edges"><path d="M 64.9656228811 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.735402618 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.974356975 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.974356975 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.735402618 202.472014925 L 192.974356975 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.059242128 165.304337687 L 192.735402618 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.353208036 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.301403535 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.513807408 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.566908376 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.566908376 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.513807408 85.8675373134 L 187.566908376 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.301403535 106.273320896 L 187.513807408 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.353208036 128.136660448 L 187.301403535 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.059242128 165.304337687 L 168.353208036 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.9656228811 204.293959888 L 140.059242128 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.5669083759164, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.51380740768073, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.301403534738, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.97435697458374, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.35320803597079, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.73540261752314, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(140.05924212772294, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(64.965622881090752, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te968f663a7f04ae4a0e52a13dc8cc11d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t383b92c1079e4148a46d12d1d7c47470"><g class="toyplot-Edges"><path d="M 54.7525366571 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.319376798 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.487598099 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.487598099 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.319376798 202.472014925 L 192.487598099 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.094711008 165.304337687 L 191.319376798 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.459137032 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.593390625 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.788094175 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.044748855 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.044748855 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.788094175 85.8675373134 L 187.044748855 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.593390625 106.273320896 L 186.788094175 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.459137032 128.136660448 L 186.593390625 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.094711008 165.304337687 L 164.459137032 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 54.7525366571 204.293959888 L 141.094711008 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.04474885493218, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.78809417512639, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.59339062492884, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.48759809908998, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(164.45913703202052, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.31937679790485, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(141.09471100831882, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(54.752536657093863, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfc7df4d5399c49368f33e4478141ec34"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ted0c48bd4ce54c9eb46468d16726adc8"><g class="toyplot-Edges"><path d="M 53.3542111602 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.151155497 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.018539546 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.018539546 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.151155497 202.472014925 L 192.018539546 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.360011144 165.304337687 L 190.151155497 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.353344506 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.310185461 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.416387397 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.602240786 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.602240786 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.416387397 85.8675373134 L 186.602240786 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.310185461 106.273320896 L 186.416387397 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.353344506 128.136660448 L 186.310185461 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.360011144 165.304337687 L 170.353344506 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 53.3542111602 204.293959888 L 138.360011144 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874151, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.60224078630142, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.41638739747654, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.31018546100518, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.0185395463414, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(170.35334450618163, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.15115549671978, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(138.36001114418099, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(53.354211160220792, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t74473f563370487b86efb6dcb9139664"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t399b9abc9ead4236a95883bbeadbfcc0"><g class="toyplot-Edges"><path d="M 52.6727487345 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.584745169 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.195542774 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.195542774 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.584745169 202.472014925 L 192.195542774 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.484118109 165.304337687 L 189.584745169 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.662827214 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.398687075 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.398687075 85.8675373134 L 186.575690302 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 106.273320896 L 186.398687075 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.662827214 128.136660448 L 186.363286429 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.484118109 165.304337687 L 166.662827214 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 52.6727487345 204.293959888 L 141.484118109 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.57569030218363, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.39868707473136, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.36328642924087, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.19554277379373, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.66282721380151, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(189.58474516887247, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(141.48411810871386, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(52.672748734529513, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta034380f0f57440b94a2df7ddd2fff95"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb7b7f5ad45484123ad295ec33050a14f"><g class="toyplot-Edges"><path d="M 56.2216634449 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 202.472014925 L 191.885787126 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.634229677 165.304337687 L 190.664464856 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.326589317 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.203983525 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.265934654 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.265934654 85.8675373134 L 187.115550146 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.203983525 106.273320896 L 186.265934654 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.326589317 128.136660448 L 186.203983525 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.634229677 165.304337687 L 167.326589317 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 56.2216634449 204.293959888 L 136.634229677 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.11555014591309, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.26593465414214, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.20398352453381, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.88578712575219, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(167.32658931674754, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.66446485633142, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(136.63422967652122, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(56.221663444947829, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbd1eb14336674bbeab5f382a2b07eef5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t977d079bd5d946c29511c6540a82016f"><g class="toyplot-Edges"><path d="M 55.1596440802 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.69101534 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.903555684 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.903555684 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.69101534 202.472014925 L 192.903555684 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.077078921 165.304337687 L 190.69101534 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.813552898 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.84997707 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.911928199 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.380986752 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.380986752 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.911928199 85.8675373134 L 186.380986752 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.84997707 106.273320896 L 185.911928199 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.813552898 128.136660448 L 185.84997707 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.077078921 165.304337687 L 170.813552898 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.1596440802 204.293959888 L 142.077078921 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.38098675198614, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.91192819923754, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.84997706962926, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.90355568360283, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(170.8135528975576, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.6910153404493, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(142.07707892067901, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(55.159644080234131, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb5fd74e463184095a3f4f8ac01f03d1d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tab5871b27c7341c1919ed19925c41fbb"><g class="toyplot-Edges"><path d="M 59.1245163752 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.832617922 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.266344065 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.266344065 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.832617922 202.472014925 L 192.266344065 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.368724835 165.304337687 L 190.832617922 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.503729014 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.690674165 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.752625295 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.699592561 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.699592561 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.752625295 85.8675373134 L 186.699592561 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.690674165 106.273320896 L 185.752625295 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.503729014 128.136660448 L 185.690674165 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.368724835 165.304337687 L 169.503729014 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.1245163752 204.293959888 L 136.368724835 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.69959256140024, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.7526252945305, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.6906741649222, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.26634406477461, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.50372901441068, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.83261792241109, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(136.36872483534279, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(59.124516375165335, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t49d942f88edd471ab94fbee26bf21153"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t99d826348dad42398df072ce1389e899"><g class="toyplot-Edges"><path d="M 66.1869451505 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.496243555 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.611568593 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.611568593 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.496243555 202.472014925 L 193.611568593 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.731922627 165.304337687 L 189.496243555 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.344084934 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.43408772 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.78816241 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.78816241 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.43408772 85.8675373134 L 187.78816241 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 106.273320896 L 186.43408772 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.344084934 128.136660448 L 186.363286429 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.731922627 165.304337687 L 164.344084934 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.1869451505 204.293959888 L 141.731922627 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.78816241023179, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.43408772022178, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.36328642924087, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.61156859341199, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(164.34408493417655, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(189.49624355514635, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.73192262714707, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(66.186945150511534, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t87b5eb2e222741f091ad8afd5c3a8528"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t42659461bc154070bb61f3315892f706"><g class="toyplot-Edges"><path d="M 69.3199022764 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.213174861 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.903623919 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.903623919 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.213174861 202.472014925 L 193.903623919 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.368929541 165.304337687 L 191.213174861 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.680595772 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.88544595 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.522657569 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.522657569 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 85.8675373134 L 187.522657569 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.88544595 106.273320896 L 186.973947564 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.680595772 128.136660448 L 186.88544595 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.368929541 165.304337687 L 167.680595772 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.3199022764 204.293959888 L 139.368929541 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.52265756905334, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.97394756395127, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.88544595022512, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.90362391870826, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(167.68059577165212, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.21317486143349, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(139.36892954065902, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(69.319902276416983, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf914f98d1f9047b59ddfab9873715e9c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb072f51a5890449a952d3017efacec2d"><g class="toyplot-Edges"><path d="M 65.7267367591 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.956520182 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.10717763 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.10717763 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.956520182 202.472014925 L 194.10717763 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.917912486 165.304337687 L 190.956520182 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.096485121 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.257152728 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.389905148 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.832413217 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.832413217 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.389905148 85.8675373134 L 187.832413217 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.257152728 106.273320896 L 187.389905148 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.096485121 128.136660448 L 187.257152728 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.917912486 165.304337687 L 167.096485121 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.7267367591 204.293959888 L 143.917912486 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.83241321709485, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.38990514846412, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.25715272787491, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(194.10717763027836, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.09648512105957, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.9565201816277, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(143.91791248618279, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(65.726736759135576, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t23a206c2a0b54f16b5598f9045cfa7a2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc71c12788d504d09bdcb25ae46f5a572"><g class="toyplot-Edges"><path d="M 69.2668013082 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.230943419 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.00975762 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.00975762 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.230943419 202.472014925 L 193.00975762 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.377506762 165.304337687 L 192.230943419 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.238155938 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.416455633 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.682028709 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.682028709 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 85.8675373134 L 188.682028709 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.416455633 106.273320896 L 187.478406762 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.238155938 128.136660448 L 187.416455633 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.377506762 165.304337687 L 168.238155938 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.2668013082 204.293959888 L 135.377506762 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(188.68202870886583, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.4784067621903, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.41645563258197, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.00975762007423, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(168.23815593812679, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.23094341928413, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(135.37750676160999, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(69.266801308181286, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb10441fb7d0f4f00a445a60d33cd935a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t150299ea0f4648c5b2b2cde30be5c724"><g class="toyplot-Edges"><path d="M 68.0720295229 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.04509003 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.629200681 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.629200681 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.04509003 202.472014925 L 192.629200681 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.377574997 165.304337687 L 192.04509003 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.945895908 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.602309021 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.124468542 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.124468542 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 85.8675373134 L 188.124468542 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.602309021 106.273320896 L 187.637709667 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.945895908 128.136660448 L 187.602309021 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.377574997 165.304337687 L 164.945895908 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.0720295229 204.293959888 L 136.377574997 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(188.12446854239113, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.63770966689734, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.60230902140688, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.62920068105177, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(164.94589590751431, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.04509003045925, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(136.3775749967154, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(68.072029522878353, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4eb8da6079944a798af1f2edec49c10b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf32325ecde8243a2b6725cb1aa76a461"><g class="toyplot-Edges"><path d="M 63.3814439954 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.372477766 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.992057297 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.992057297 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.372477766 202.472014925 L 192.992057297 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.280291457 161.660447761 L 191.372477766 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.716064652 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.04481709 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.04481709 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 91.697761194 L 188.04481709 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.186351437 115.018656716 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.186351437 115.018656716 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 91.697761194 L 187.186351437 115.018656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.716064652 120.848880597 L 187.150950791 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.280291457 161.660447761 L 168.716064652 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.3814439954 202.472014925 L 137.280291457 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.18635143689403, 115.01865671641794)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(188.04481709003758, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.15095079140355, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.99205729732896, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(168.71606465224798, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.37247776614055, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(137.28029145672207, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(63.381443995392786, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t25c1c9f498d84a23819245e004d6c222"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t95c2506925864fd18a0a34dc5dba6bfa"><g class="toyplot-Edges"><path d="M 60.7971968746 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.832617922 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.832617922 202.472014925 L 191.549480994 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.182871447 163.846781716 L 190.832617922 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.760383694 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.894296112 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.53150773 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.53150773 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 97.5279850746 L 187.53150773 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.894296112 100.443097015 L 186.965097403 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.760383694 125.221548507 L 186.894296112 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.182871447 163.846781716 L 169.760383694 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.7971968746 203.565181903 L 136.182871447 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.53150773042594, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.96509740257864, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.89429611159773, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.54948099359288, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.7603836942165, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.83261792241109, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(136.18287144651788, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(60.797196874589432, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9d1dd650d5df4f2f98ebecb72d540eef"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5a087e56dec142b190837278fe1a0745"><g class="toyplot-Edges"><path d="M 72.4528594023 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.36369584 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.36369584 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 202.472014925 L 192.36369584 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.245300222 165.304337687 L 191.930037933 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.50379725 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.009416445 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.062517413 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.575826772 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.575826772 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.062517413 85.8675373134 L 188.575826772 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.009416445 106.273320896 L 188.062517413 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.50379725 128.136660448 L 188.009416445 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.245300222 165.304337687 L 170.50379725 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.4528594023 204.293959888 L 143.245300222 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.57582677239444, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.0625174127828, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.00941644454713, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.36369583987334, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(170.50379724951608, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.93003793261522, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(143.24530022186408, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(72.452859402322431, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3cd974f6a27b44ce8983681f6ca44c82"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td79f110e6bc54c28adaaddc665c9adc7"><g class="toyplot-Edges"><path d="M 67.3994172586 204.293959888 L 198.399505896 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.5937318 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.5937318 202.472014925 L 191.885787126 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.439253186 165.304337687 L 191.5937318 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.618712877 128.136660448 L 198.399505896 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.097849823 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.177501276 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.177501276 85.8675373134 L 187.797012572 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.097849823 106.273320896 L 187.177501276 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.618712877 128.136660448 L 187.097849823 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.439253186 165.304337687 L 168.618712877 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.3994172586 204.293959888 L 132.439253186 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.7970125716044, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.17750127552139, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.09784982316788, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.88578712575219, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(168.61871287714922, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.59373180045594, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(132.43925318590203, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(67.399417258559694, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="teb66043cd1d2409eb918cf81591f40f6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4c6ca3c6286b447f8eb48a762c522256"><g class="toyplot-Edges"><path d="M 68.0543292001 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.699933737 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.699933737 202.472014925 L 192.319445033 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.988372602 165.304337687 L 191.699933737 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.786865943 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.540357892 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584608699 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.894364347 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.894364347 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584608699 85.8675373134 L 187.894364347 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.540357892 106.273320896 L 187.584608699 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.786865943 128.136660448 L 187.540357892 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.988372602 165.304337687 L 168.786865943 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.0543292001 204.293959888 L 138.988372602 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.89436434670313, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.58460869866167, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.54035789179858, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.31944503301028, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.78686594322892, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.69993373692731, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.98837260163663, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(68.054329200133139, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0334015494684a9c975217ba6201d2e7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t95d077fb661646c69037ad424a2d01e6"><g class="toyplot-Edges"><path d="M 62.9123854426 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.753034705 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.753034705 202.472014925 L 192.257493903 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.572210312 165.304337687 L 191.753034705 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.645263361 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.159800953 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.195201598 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.522657569 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.522657569 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.195201598 85.8675373134 L 187.522657569 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.159800953 106.273320896 L 187.195201598 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.645263361 128.136660448 L 187.159800953 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.572210312 165.304337687 L 168.645263361 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.9123854426 204.293959888 L 135.572210312 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.52265756905334, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.19520159826664, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.15980095277618, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.25749390340198, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.64526336126707, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.753034705163, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(135.57221031180751, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(62.912385442644229, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t40c1376b686a4342854ac793ff1b07a6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t911e7865eff14599816d9f67be9f25ff"><g class="toyplot-Edges"><path d="M 66.080743214 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.567181316 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.30174471 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.30174471 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.567181316 202.472014925 L 192.30174471 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.421962274 165.304337687 L 191.567181316 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.406240769 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.425305794 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.487256924 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.761611926 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.761611926 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.487256924 85.8675373134 L 187.761611926 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.425305794 106.273320896 L 187.487256924 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.406240769 128.136660448 L 187.425305794 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.421962274 165.304337687 L 167.406240769 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.080743214 204.293959888 L 138.421962274 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.76161192611394, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.48725692356288, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.42530579395458, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.30174471026507, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.40624076910106, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.56718131633806, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(138.42196227378929, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(66.080743214040154, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6ceef6f536434b8cb7e81a07812bd4c1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t91b737a663284d49829ddc0c61cde022"><g class="toyplot-Edges"><path d="M 69.2756514696 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.770735028 202.472014925 L 198.399505896 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.646901004 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.646901004 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.770735028 202.472014925 L 192.646901004 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.413248583 165.304337687 L 191.770735028 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.601149025 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.903214508 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.080217736 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.080217736 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 85.8675373134 L 188.080217736 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.903214508 106.273320896 L 187.991716122 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.601149025 128.136660448 L 187.903214508 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.413248583 165.304337687 L 170.601149025 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.2756514696 204.293959888 L 140.413248583 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(188.08021773552804, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.99171612180191, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.90321450807576, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.64690100379704, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.60114902461484, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.77073502790819, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(140.41324858262752, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(69.275651469553907, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2ddcda5e59344b6ca49fa97529da79cd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t82f8cceb38524194819e25986cdd9f69"><g class="toyplot-Edges"><path d="M 67.7976745203 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.646832769 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.646832769 202.472014925 L 192.806203909 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.430675965 165.304337687 L 191.646832769 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.317943861 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.805862733 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.894364347 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.98286596 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.98286596 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.894364347 85.8675373134 L 187.98286596 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.805862733 106.273320896 L 187.894364347 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.317943861 128.136660448 L 187.805862733 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.430675965 165.304337687 L 170.317943861 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.7976745203 204.293959888 L 136.430675965 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.98286596042931, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.89436434670313, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.80586273297698, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.80620390850407, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.3179438606912, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.64683276869158, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(136.43067596495109, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.797674520327334, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5b5b296c475e4fb7b136b54f10e03382"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="taf8d244fd8e24b9b899ff10fe86edc07"><g class="toyplot-Edges"><path d="M 69.3907035674 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.089340837 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.089340837 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 202.472014925 L 192.089340837 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.014991321 165.304337687 L 191.168924055 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.459273502 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.956315476 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.142168865 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.142168865 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 85.8675373134 L 188.142168865 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.956315476 106.273320896 L 187.991716122 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.459273502 128.136660448 L 187.956315476 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.014991321 165.304337687 L 166.459273502 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.3907035674 204.293959888 L 140.014991321 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.14216886513634, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.99171612180191, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.95631547631143, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.08934083732231, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.45927350223135, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.16892405457043, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(140.01499132085988, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(69.390703567397907, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6965c2b7da474a9ab9bbba5258e562ed"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdbbcfe4b8a5e40ac9ce18c5fb6e2c6b3"><g class="toyplot-Edges"><path d="M 73.1166215053 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.186692612 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.354845679 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.354845679 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.186692612 202.472014925 L 192.354845679 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.200708239 165.304337687 L 192.186692612 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.910631732 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.416523868 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.505025481 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.628927741 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.628927741 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.505025481 85.8675373134 L 188.628927741 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.416523868 106.273320896 L 188.505025481 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.910631732 128.136660448 L 188.416523868 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.200708239 165.304337687 L 166.910631732 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.1166215053 204.293959888 L 138.200708239 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.62892774063013, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.50502548141353, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.4165238676874, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.35484567850077, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(166.91063173223469, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.1866926124211, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(138.20070823947395, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(73.116621505268512, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t29eb49d1ce124013997468148022196f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2f6abf1a69ff480b8ea978f10fb9676e"><g class="toyplot-Edges"><path d="M 65.1072254631 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.186692612 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.186692612 202.472014925 L 192.567249551 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.262727604 165.304337687 L 192.186692612 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.857735469 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.115618381 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.266071124 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.266071124 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.115618381 85.8675373134 L 188.266071124 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 106.273320896 L 188.115618381 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.857735469 128.136660448 L 187.991716122 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.262727604 165.304337687 L 169.857735469 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.1072254631 204.293959888 L 139.262727604 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(188.26607112435295, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(188.11561838101852, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.99171612180191, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.5672495514435, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(169.85773546931523, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.1866926124211, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.26272760418766, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(65.107225463052586, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tddae23a139b546849172f165f56059f0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t16fed0787f68415a99f16e37aef3fb86"><g class="toyplot-Edges"><path d="M 65.4081309497 204.293959888 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.284044388 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.284044388 202.472014925 L 192.319445033 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.944258265 165.304337687 L 192.284044388 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.062517413 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.168719349 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.363422899 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.363422899 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.168719349 85.8675373134 L 188.363422899 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.062517413 106.273320896 L 188.168719349 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 128.136660448 L 188.062517413 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.944258265 165.304337687 L 169.034670462 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.4081309497 204.293959888 L 140.944258265 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.36342289945173, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.16871934925419, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.06251741278282, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.31944503301028, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.0346704616621, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.28404438751983, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(140.94425826498437, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(65.408130949721482, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1c55a00b0449474da3fe3174273d6be9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td3591da95c6b43c8881bdf8ec1482e9c"><g class="toyplot-Edges"><path d="M 63.9567044846 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.381327928 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.531848906 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.531848906 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.381327928 202.472014925 L 192.531848906 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.537219077 165.304337687 L 191.381327928 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.813348192 128.136660448 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.761611926 106.273320896 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.841263378 85.8675373134 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.071367574 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.071367574 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.841263378 85.8675373134 L 188.071367574 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.761611926 106.273320896 L 187.841263378 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.813348192 128.136660448 L 187.761611926 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.537219077 165.304337687 L 167.813348192 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.9567044846 204.293959888 L 141.537219077 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(188.07136757415543, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.84126337846749, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.76161192611394, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.53184890595304, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.81334819224131, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.38132792751318, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(141.53721907694953, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(63.956704484612729, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb07942276c6b42a1986d8000d256cbc0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t024bd0b228cd437f8a0ec07ef7cac8b2"><g class="toyplot-Edges"><path d="M 56.7792236114 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.735266147 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.735266147 202.472014925 L 192.257493903 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.723072466 165.304337687 L 190.735266147 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.565611909 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.841263378 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.920914831 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.920914831 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.841263378 85.8675373134 L 187.920914831 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 106.273320896 L 187.841263378 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.565611909 128.136660448 L 187.797012572 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.723072466 165.304337687 L 168.565611909 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 56.7792236114 204.293959888 L 141.723072466 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.920914830821, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.84126337846749, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.7970125716044, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.25749390340201, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(168.56561190891355, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.73526614731233, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(141.72307246577444, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(56.77922361142253, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbac3e30359d54c3c805ecd8b007806a8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t06ad588ca0d945fa9bc53aeaeb07651f"><g class="toyplot-Edges"><path d="M 57.2748326483 203.929570896 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.726552456 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.726552456 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 202.472014925 L 192.726552456 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.439935537 164.575559701 L 192.080490676 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.264569952 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.690810635 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 80.0373134328 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.78816241 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.78816241 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 80.0373134328 L 187.78816241 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.690810635 103.358208955 L 187.708510958 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.264569952 126.679104478 L 187.690810635 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.439935537 164.575559701 L 166.264569952 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 57.2748326483 203.929570896 L 142.439935537 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.78816241023176, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.70851095787825, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.690810635133, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.72655245615056, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.26456995203387, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.0804906759497, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(142.4399355369562, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(57.274832648288942, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8a3241ed33954a09a9ffd01bf00dc8fa"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5685b287374c41a9b4d76f4cd816ef5a"><g class="toyplot-Edges"><path d="M 52.327592441 203.929570896 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.310526637 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.310526637 202.472014925 L 192.257493903 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.882443606 164.575559701 L 191.310526637 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.47717853 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.549208053 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.558058215 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.646559828 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.646559828 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.558058215 80.0373134328 L 187.646559828 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.549208053 103.358208955 L 187.558058215 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.47717853 126.679104478 L 187.549208053 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.882443606 164.575559701 L 169.47717853 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 52.327592441 203.929570896 L 142.882443606 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.64655982826994, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.55805821454379, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.54920805317118, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.25749390340198, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(169.4771785302928, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.31052663653224, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(142.8824436055869, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(52.327592440997549, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t458c6bac426a43a381031bed49600e2f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb3fdd72414d342f3a553e8cb32264367"><g class="toyplot-Edges"><path d="M 58.2483503993 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.452197454 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.452197454 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 202.472014925 L 192.452197454 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.856166062 161.660447761 L 191.363627605 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.999133346 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.805862733 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.805862733 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 91.697761194 L 187.805862733 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.85011354 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.85011354 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 91.697761194 L 187.85011354 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.999133346 120.848880597 L 187.797012572 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.856166062 161.660447761 L 166.999133346 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.2483503993 202.472014925 L 146.856166062 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.85011353984007, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.80586273297698, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.7970125716044, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.4521974535995, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.99913334596081, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.36362760476791, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(146.85616606189072, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(58.248350399276504, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb82947f14b0d4ba79521ed54cbc43729"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5da6e81f0c734a7e813189243cc01ada"><g class="toyplot-Edges"><path d="M 55.9473084424 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.151223732 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.514080348 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.514080348 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.151223732 202.472014925 L 191.514080348 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.351092748 161.660447761 L 191.151223732 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.397458843 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991647887 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991647887 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 91.697761194 L 186.991647887 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.345654342 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.345654342 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 91.697761194 L 187.345654342 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.397458843 120.848880597 L 186.973947564 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.351092748 161.660447761 L 168.397458843 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.9473084424 202.472014925 L 137.351092748 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.34565434160106, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.99164788669648, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.97394756395124, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.51408034810237, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(168.39745884283386, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.15122373182518, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.35109274770295, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(55.947308442396789, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf0fd1737b71348aeafc65e1aa7aa6a05"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0ed98ae82d2d493daf93ec179ddac9e2"><g class="toyplot-Edges"><path d="M 58.7528095975 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.053871957 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.637982607 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.637982607 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.053871957 202.472014925 L 191.637982607 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.581333414 161.660447761 L 191.053871957 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.6985008 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.770393852 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.770393852 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.75269353 91.697761194 L 186.770393852 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.823494821 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.823494821 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.75269353 91.697761194 L 186.823494821 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.6985008 120.848880597 L 186.75269353 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.581333414 161.660447761 L 170.6985008 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.7528095975 202.472014925 L 139.581333414 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.82349482061684, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.77039385238115, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.75269352963591, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.637982607319, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(170.69850079971363, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.05387195672645, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.58133341360178, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(58.75280959751553, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tafe7de365a3e4bc082a37918a5c8accd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tecc2e191245744faba549210d999d260"><g class="toyplot-Edges"><path d="M 67.5233195178 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 202.472014925 L 191.788435351 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.174157755 161.660447761 L 191.390178089 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.158504486 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.726211281 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.743911603 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.10676822 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.10676822 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.743911603 103.358208955 L 188.10676822 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.726211281 91.697761194 L 187.743911603 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.158504486 120.848880597 L 187.726211281 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.174157755 161.660447761 L 168.158504486 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.5233195178 202.472014925 L 138.174157755 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.10676821964589, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.7439116033687, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.72621128062346, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.78843535065346, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.15850448577331, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.39017808888582, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.17415775535608, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(67.523319517776272, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="teb5c1d59fdc844709639149e4095f8d5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t84c03ce8de464c7a971eda1a7de95ebd"><g class="toyplot-Edges"><path d="M 65.8771895025 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.469829541 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.222093258 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.222093258 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.469829541 202.472014925 L 192.222093258 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.156593903 161.660447761 L 191.469829541 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.344357875 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.071367574 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.10676822 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.425374029 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.425374029 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.10676822 103.358208955 L 188.425374029 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.071367574 91.697761194 L 188.10676822 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.344357875 120.848880597 L 188.071367574 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.156593903 161.660447761 L 168.344357875 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.8771895025 202.472014925 L 140.156593903 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(188.42537402906004, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(188.10676821964589, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(188.07136757415543, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.22209325791155, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.34435787459819, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.46982954123933, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.1565939028217, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(65.877189502470031, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf86b3cf68e9f42aba589c4d42acdd877"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t44bf4b5ad60a4f11bf211e75773eeafd"><g class="toyplot-Edges"><path d="M 59.2484186344 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.823767761 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.814985835 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.814985835 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.823767761 202.472014925 L 191.814985835 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.537219077 161.660447761 L 190.823767761 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.344289639 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.221752082 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.221752082 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.938546918 91.697761194 L 187.221752082 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.938546918 91.697761194 L 187.115550146 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.344289639 120.848880597 L 186.938546918 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.537219077 161.660447761 L 167.344289639 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.2484186344 202.472014925 L 141.537219077 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736888, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.11555014591309, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.22175208238446, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.93854691846079, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.81498583477122, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.34428963949279, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.82376776103848, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(141.5372190769495, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(59.248418634381906, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tda199562382a428ba394cfa58d60902d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t33cd4f64fa6c4dccae4a12a6e0467228"><g class="toyplot-Edges"><path d="M 56.77037345 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.912269375 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.416796808 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.416796808 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.912269375 202.472014925 L 192.416796808 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.546069238 161.660447761 L 190.912269375 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.63627673 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.584540464 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.584540464 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.504889011 91.697761194 L 186.584540464 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.504889011 91.697761194 L 186.575690302 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.63627673 120.848880597 L 186.504889011 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.546069238 161.660447761 L 166.63627673 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 56.77037345 202.472014925 L 141.546069238 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.57569030218366, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.58454046355627, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.50488901120272, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.41679680810904, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.63627672968366, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.91226937476463, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(141.54606923832219, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.770373450049945, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc57e4381bfda4e7399c40659761b2ac6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4436aaa8fda04b4f9c45b087f9840932"><g class="toyplot-Edges"><path d="M 60.664444454 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.257357433 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.823835996 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.823835996 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.257357433 202.472014925 L 191.823835996 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.71429054 161.660447761 L 190.257357433 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.503592544 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.566840141 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.566840141 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.504889011 91.697761194 L 186.566840141 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.504889011 91.697761194 L 186.557989979 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.503592544 120.848880597 L 186.504889011 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.71429054 161.660447761 L 167.503592544 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.664444454 202.472014925 L 142.71429054 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.55798997943839, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.566840140811, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.50488901120272, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.82383599614386, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(167.50359254419982, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.25735743319117, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(142.71429053950723, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(60.664444454000204, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t56475d5aec8d41c691a5db22dce4b3a6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9fadfee9a3a649538eee662d8ea30f45"><g class="toyplot-Edges"><path d="M 55.6818036012 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.310458401 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.452197454 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.452197454 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.310458401 202.472014925 L 192.452197454 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.917503076 161.660447761 L 190.310458401 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.769302091 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.230534009 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.230534009 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.186283202 91.697761194 L 186.230534009 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.345586106 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.345586106 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.186283202 91.697761194 L 186.345586106 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.769302091 120.848880597 L 186.186283202 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.917503076 161.660447761 L 170.769302091 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.6818036012 202.472014925 L 137.917503076 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.34558610649566, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.23053400865166, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.1862832017886, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.4521974535995, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(170.76930209069451, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.31045840142684, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.91750307555029, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(55.68180360121837, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfd4bbaad29eb44e68fce4a8f9eeded74"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta4386d9cfbb04d4bac8872f8f9279ff3"><g class="toyplot-Edges"><path d="M 58.4519041108 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.053871957 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.407946647 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.407946647 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.053871957 202.472014925 L 192.407946647 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.121056787 161.660447761 L 191.053871957 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.096485121 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.203983525 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.203983525 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.142032395 91.697761194 L 186.203983525 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.142032395 91.697761194 L 186.557989979 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.096485121 120.848880597 L 186.142032395 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.121056787 161.660447761 L 167.096485121 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.4519041108 202.472014925 L 138.121056787 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736896, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736896, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736896, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.55798997943839, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.20398352453381, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.14203239492556, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.40794664673643, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(167.09648512105957, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.05387195672645, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(138.12105678712041, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(58.451904110846641, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t54cb050e28cc41298a1283f8a65e1575"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5f783791af5e40eb9887dd53cd8bc4e6"><g class="toyplot-Edges"><path d="M 70.2934200274 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.540767302 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.540767302 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 202.472014925 L 193.540767302 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.36879307 161.660447761 L 191.761884867 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.698296094 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.009348209 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.009348209 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 91.697761194 L 187.009348209 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 91.697761194 L 187.106699985 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.698296094 120.848880597 L 186.965097403 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.36879307 161.660447761 L 167.698296094 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.2934200274 202.472014925 L 137.36879307 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.10669998454048, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.0093482094417, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.96509740257864, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.54076730243105, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.69829609439734, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.76188486653561, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(137.36879307044819, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(70.293420027404551, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t18b9a2c9cd4345c8b62e0778bc8c8dc8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6c5d6ce8979d47ea99a69266d5368662"><g class="toyplot-Edges"><path d="M 71.9395500427 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.49644826 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.49644826 202.472014925 L 193.248711977 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.935476339 161.660447761 L 192.49644826 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 91.697761194 L 187.363354664 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 91.697761194 L 187.381054987 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 120.848880597 L 187.319103857 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.935476339 161.660447761 L 167.007983507 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.9395500427 202.472014925 L 141.935476339 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.38105498709152, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.36335466434628, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.31910385748324, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.2487119771348, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(167.00798350733342, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.49644826046253, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(141.93547633871717, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(71.939550042710806, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9ec096eab4974d59bd460746b1891d3a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5c123f137d984676b53dbfed388c0495"><g class="toyplot-Edges"><path d="M 66.4701503144 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.682165179 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.682165179 202.472014925 L 192.567249551 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.457499389 161.660447761 L 190.682165179 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.848612368 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.478338527 91.697761194 L 186.531439495 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.478338527 91.697761194 L 186.717292884 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.848612368 120.848880597 L 186.478338527 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.457499389 161.660447761 L 165.848612368 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.4701503144 202.472014925 L 140.457499389 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.71729288414545, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.53143949532057, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.47833852708484, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.5672495514435, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(165.84861236752096, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.68216517907666, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.45749938949058, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(66.470150314435173, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t28a3e139436f4ed5b589ebfe5bc71dd9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9455e5a7169e429f8a726bfe64543f16"><g class="toyplot-Edges"><path d="M 63.7443006117 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.673383253 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.726552456 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.726552456 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.673383253 202.472014925 L 192.726552456 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.36879307 161.660447761 L 191.673383253 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.362058197 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.407537236 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.407537236 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.319035622 91.697761194 L 186.407537236 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.372136591 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.372136591 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.319035622 91.697761194 L 186.372136591 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.362058197 120.848880597 L 186.319035622 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.36879307 161.660447761 L 168.362058197 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.7443006117 202.472014925 L 137.36879307 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.37213659061351, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.40753723610396, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.31903562237781, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.72655245615059, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(168.36205819734343, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.67338325280949, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(137.36879307044822, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(63.744300611669992, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfa5020d8a4174225b23eb6eeb0a66dc4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tddca66b9fcd94671828fecb5ddd27659"><g class="toyplot-Edges"><path d="M 64.3284112623 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.328226959 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.07170875 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.07170875 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.328226959 202.472014925 L 193.07170875 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.351365688 161.660447761 L 191.328226959 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.158572721 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.903146273 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.903146273 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.779244014 91.697761194 L 186.903146273 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.779244014 91.697761194 L 186.814644659 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.158572721 120.848880597 L 186.779244014 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.351365688 161.660447761 L 169.158572721 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.3284112623 202.472014925 L 141.351365688 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.81464465924421, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.90314627297036, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.77924401375378, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.0717087496825, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(169.15857272087871, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.32822695927749, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(141.35136568812464, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(64.32841126226252, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta1a26a82159d46278b1800a8bb1959c5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t082d9d09680942d9ac2ee6069c95648f"><g class="toyplot-Edges"><path d="M 67.3728667744 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.540699067 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.213311332 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.213311332 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.540699067 202.472014925 L 193.213311332 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.820219536 161.660447761 L 192.540699067 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.185259675 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.911996434 91.697761194 L 186.973947564 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.911996434 91.697761194 L 186.973947564 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.185259675 120.848880597 L 186.911996434 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.820219536 161.660447761 L 171.185259675 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.3728667744 202.472014925 L 138.820219536 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.97394756395127, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.97394756395127, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.911996434343, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.21331133164435, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(171.18525967520739, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.54069906732565, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(138.82021953555693, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.372866774441832, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te38712db5f7f4163a9dca2f6346c0b75"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb7bee32078234e35a25c1b6fe6e6ce0a"><g class="toyplot-Edges"><path d="M 72.3820581113 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.930106168 184.981343284 L 198.399505896 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.930106168 184.981343284 L 198.399505896 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 202.472014925 L 192.930106168 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.669698557 161.660447761 L 192.142441806 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.981637729 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.540357892 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.540357892 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.416455633 91.697761194 L 187.540357892 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584608699 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584608699 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.416455633 91.697761194 L 187.584608699 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.981637729 120.848880597 L 187.416455633 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.669698557 161.660447761 L 169.981637729 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.3820581113 202.472014925 L 137.669698557 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.39950589599627, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.39950589599627, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.58460869866167, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.54035789179858, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.41645563258197, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.93010616772068, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.98163772853184, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.14244180555801, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.6696985571171, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(72.382058111341522, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t81dcaa97e4a54af590afd5d37d411bec"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7d57f44dc9304813aa16fc23006b33fc"><g class="toyplot-Edges"><path d="M 66.4347496689 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.974356975 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.974356975 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 202.472014925 L 192.974356975 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.359874674 161.660447761 L 192.142441806 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.875162852 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.018198371 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.018198371 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 91.697761194 L 187.018198371 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 91.697761194 L 187.637709667 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.875162852 120.848880597 L 187.000498048 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.359874674 161.660447761 L 165.875162852 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.4347496689 202.472014925 L 136.359874674 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.63770966689734, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.01819837081433, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.00049804806909, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.97435697458377, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(165.87516285163881, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.14244180555801, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(136.35987467397018, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(66.434749668944733, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t55d0c07b273a43e0bd34f8e7680671e3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta62d9171b07b49ff9a950ee13ccfd4ff"><g class="toyplot-Edges"><path d="M 65.6205348227 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.230875184 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.230875184 202.472014925 L 192.071640515 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.156457433 161.660447761 L 191.230875184 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.043588858 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.938546918 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.938546918 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 91.697761194 L 186.938546918 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.327954019 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.327954019 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 91.697761194 L 187.327954019 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.043588858 120.848880597 L 186.920846596 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.156457433 161.660447761 L 170.043588858 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.6205348227 202.472014925 L 138.156457433 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.32795401885585, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.93854691846082, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.92084659571557, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.07164051457707, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(170.04358885814014, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.23087518417876, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(138.15645743261089, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(65.620534822664212, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t56164419eb9145178a9a51ac917c3b26"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc487b24ae52541c084cc0c5bab1cddb6"><g class="toyplot-Edges"><path d="M 65.4966325634 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.726484221 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.876936964 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.876936964 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.726484221 202.472014925 L 191.876936964 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.076464805 161.660447761 L 191.726484221 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.264979363 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.681892239 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.699592561 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.796944336 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.796944336 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.699592561 103.358208955 L 186.796944336 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.681892239 91.697761194 L 186.699592561 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.264979363 120.848880597 L 186.681892239 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.076464805 161.660447761 L 172.264979363 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.4966325634 202.472014925 L 133.076464805 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.79694433649897, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.69959256140024, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.681892238655, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.87693696437958, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(172.26497936266631, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.72648422104513, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(133.07646480473028, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(65.496632563447605, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t68aeffd5d4d14c21abba2b5837c6f0f4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t789ddea6bf3d4108b64dab780ed0b5c9"><g class="toyplot-Edges"><path d="M 58.3103015289 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.646832769 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.646832769 202.472014925 L 192.381396163 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.068024054 161.660447761 L 191.646832769 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.30923017 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.973879329 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.973879329 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.956179006 91.697761194 L 185.973879329 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.026980297 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.026980297 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.956179006 91.697761194 L 186.026980297 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.30923017 120.848880597 L 185.956179006 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.068024054 161.660447761 L 172.30923017 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.3103015289 202.472014925 L 139.068024054 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736888, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.02698029708154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.97387932884587, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.9561790061006, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.38139616261856, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(172.3092301695294, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.64683276869158, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(139.06802405399014, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(58.3103015288848, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5e15056c9ab5440ca2e7bc1103fae45f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfac93ec5c8cf4842a26dac9c603c6c03"><g class="toyplot-Edges"><path d="M 55.41629876 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.36355937 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.708852133 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.708852133 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.36355937 202.472014925 L 192.708852133 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.52830068 161.660447761 L 190.36355937 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.609794481 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.327817549 91.697761194 L 185.345517871 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.327817549 91.697761194 L 185.345517871 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.609794481 120.848880597 L 185.327817549 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.52830068 161.660447761 L 167.609794481 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.41629876 202.472014925 L 140.52830068 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.34551787139026, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.34551787139026, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.32781754864504, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.70885213340534, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.60979448067121, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.36355936966257, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(140.52830068047152, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(55.416298760039957, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t84879af4862e4af2ae4a5888941177e0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9a4f15788f9343c5950a46e96b162d12"><g class="toyplot-Edges"><path d="M 53.0356053508 202.107625933 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.655751165 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.655751165 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 202.472014925 L 192.655751165 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.625652456 160.931669776 L 190.664464856 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.149790795 119.391324627 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.770257382 88.7826492537 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.770257382 97.5279850746 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.787957705 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.787957705 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.770257382 97.5279850746 L 184.787957705 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.770257382 88.7826492537 L 184.770257382 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.149790795 119.391324627 L 184.770257382 88.7826492537" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.625652456 160.931669776 L 170.149790795 119.391324627" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 53.0356053508 202.107625933 L 140.625652456 160.931669776" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.78795770491553, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.77025738217031, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.77025738217031, 88.782649253731364)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.65575116516962, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.14979079461153, 119.39132462686571)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.66446485633142, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(140.62565245557025, 160.93166977611943)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(53.035605350806691, 202.10762593283584)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t78b25b2919fa459087f3941d90572866"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc2c480f8e42746f19f5bfc6206f61cdb"><g class="toyplot-Edges"><path d="M 62.5937796332 202.472014925 L 198.399505896 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.283976152 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.292894549 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.292894549 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.283976152 202.472014925 L 192.292894549 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.430948905 161.660447761 L 191.283976152 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.318148566 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.026912062 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.026912062 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.044612385 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.044612385 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.026912062 80.0373134328 L 185.044612385 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.026912062 91.697761194 L 185.026912062 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.318148566 120.848880597 L 185.026912062 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.430948905 161.660447761 L 173.318148566 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.5937796332 202.472014925 L 140.430948905 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.04461238472138, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.02691206197613, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.02691206197613, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.29289454889246, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(173.31814856600741, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.2839761524144, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(140.43094890537276, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(62.593779633230113, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6f91815e4ad24bb0a6037f15eec5a4f0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t02c4281d02154a04861b09c600bb1b22"><g class="toyplot-Edges"><path d="M 63.3814439954 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.602513727 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.5937318 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.5937318 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.602513727 202.472014925 L 191.5937318 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.811369374 161.660447761 L 190.602513727 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.654181758 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.434019485 115.018656716 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.434019485 115.018656716 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.425169324 91.697761194 L 185.434019485 115.018656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.442869646 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.442869646 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.425169324 91.697761194 L 185.442869646 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.654181758 120.848880597 L 185.425169324 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.811369374 161.660447761 L 169.654181758 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.3814439954 202.472014925 L 138.811369374 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.44286964648899, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.43401948511638, 115.01865671641794)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.42516932374377, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.59373180045594, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.65418175774511, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.60251372672309, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(138.81136937418432, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(63.381443995392786, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t05136123f6fd44c39c0e90fa6fa4a6b2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t94eca461fcf24510b597050d6f6a9d9c"><g class="toyplot-Edges"><path d="M 55.8942074742 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.239588875 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.239588875 202.472014925 L 191.168924055 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.014377205 161.660447761 L 189.239588875 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.459341737 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.726006575 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.743706898 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.779107544 103.358208955 L 198.399505896 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.779107544 103.358208955 L 198.399505896 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.743706898 80.0373134328 L 184.779107544 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.726006575 91.697761194 L 184.743706898 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.459341737 120.848880597 L 184.726006575 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.014377205 161.660447761 L 167.459341737 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.8942074742 202.472014925 L 131.014377205 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599633, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599633, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.77910754354292, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.74370689805247, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.72600657530725, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.16892405457043, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(167.45934173733679, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(189.23958887534053, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(131.01437720491117, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(55.894207474161114, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1bd53125ca444375881f2c19f6aeaba1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t423dc425d795495ab9a64cabdab6a33c"><g class="toyplot-Edges"><path d="M 62.5229783422 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.328226959 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.328226959 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 202.472014925 L 191.328226959 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.510668593 161.660447761 L 190.664464856 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.618849347 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.965029167 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.009279974 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.018130136 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.018130136 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.009279974 80.0373134328 L 186.018130136 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.965029167 91.697761194 L 186.009279974 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.618849347 120.848880597 L 185.965029167 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.510668593 161.660447761 L 170.618849347 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.5229783422 202.472014925 L 141.510668593 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.01813013570896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.00927997433632, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(185.96502916747323, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.32822695927749, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(170.61884934736008, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(190.66446485633142, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.51066859283171, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(62.52297834224921, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbba0e316cca940a9b271e9d84202415c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1cafbaf39e4242b9ab266c475e54bae2"><g class="toyplot-Edges"><path d="M 61.2131544591 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.788367116 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.514148583 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.514148583 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.788367116 202.472014925 L 192.514148583 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.156525668 161.660447761 L 190.788367116 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.636344965 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.080081265 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.159732718 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.221683847 103.358208955 L 198.399505896 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.221683847 103.358208955 L 198.399505896 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.159732718 80.0373134328 L 186.221683847 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.080081265 91.697761194 L 186.159732718 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.636344965 120.848880597 L 186.080081265 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.156525668 161.660447761 L 167.636344965 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.2131544591 202.472014925 L 139.156525668 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599633, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599633, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.22168384727905, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.15973271767075, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.08008126531723, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.5141485832078, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(167.63634496478909, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.78836711554803, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(139.15652566771632, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(61.213154459102299, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4ce67fc29e4d477cb6d07be12415b403"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te1379e43f3f149fba88f3d32c960b0b1"><g class="toyplot-Edges"><path d="M 62.5937796332 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.868155038 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.868155038 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 202.472014925 L 192.868155038 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.56322368 163.846781716 L 191.549480994 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.875299322 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.487188688 100.443097015 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.540289657 97.5279850746 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.646491593 68.3768656716 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.646491593 68.3768656716 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.540289657 97.5279850746 L 186.646491593 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.487188688 100.443097015 L 186.540289657 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.875299322 125.221548507 L 186.487188688 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.56322368 163.846781716 L 167.875299322 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.5937796332 203.565181903 L 133.56322368 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.64649159316454, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.54028965669318, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.48718868845748, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.86815503811241, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.87529932184967, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.54948099359288, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(133.56322368022407, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(62.593779633230128, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t42c2dcdfffb5433fba2efa21d16df428"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfea5c6dff5f346d2a324246e0a0a3d27"><g class="toyplot-Edges"><path d="M 61.8326657552 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.089340837 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.584949874 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.584949874 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.089340837 202.472014925 L 192.584949874 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.510532123 162.389225746 L 192.089340837 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.255651556 122.306436567 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.425237559 94.6128731343 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.460638204 85.8675373134 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.460638204 85.8675373134 L 186.531439495 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.425237559 94.6128731343 L 186.460638204 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.255651556 122.306436567 L 186.425237559 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.510532123 162.389225746 L 165.255651556 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.8326657552 202.836403918 L 139.510532123 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.53143949532057, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.46063820433966, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.4252375588492, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.58494987418874, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(165.25565155555583, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.08934083732231, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(139.51053212262084, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(61.832665755185296, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf3c9ad871b6e474e91d09087d4b75449"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t847666568ca845bfbb108743c7261c87"><g class="toyplot-Edges"><path d="M 59.9918321897 202.836403918 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 202.472014925 L 198.399505896 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.30174471 184.981343284 L 198.399505896 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.30174471 184.981343284 L 198.399505896 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 202.472014925 L 192.30174471 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.103629405 162.389225746 L 192.071640515 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.317739155 122.306436567 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.858895466 94.6128731343 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.867745627 85.8675373134 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.062449178 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.062449178 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.867745627 85.8675373134 L 187.062449178 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.858895466 94.6128731343 L 186.867745627 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.317739155 122.306436567 L 186.858895466 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.103629405 162.389225746 L 167.317739155 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.9918321897 202.836403918 L 142.103629405 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.06244917767742, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.86774562747991, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.8588954661073, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.3017447102651, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(167.31773915537497, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.07164051457713, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(142.10362940479686, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(59.991832189681546, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3adc37697ddf45539785ea46b5fccc78"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t939dcd38c1f343a98f502b2185d6633e"><g class="toyplot-Edges"><path d="M 66.5232512827 202.836403918 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.611500358 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.611500358 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 202.472014925 L 192.611500358 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.183007917 162.389225746 L 192.071640515 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.609999186 122.306436567 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.177501276 94.6128731343 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.212901921 85.8675373134 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.248302567 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.248302567 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.212901921 85.8675373134 L 187.248302567 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.177501276 94.6128731343 L 187.212901921 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.609999186 122.306436567 L 187.177501276 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.183007917 162.389225746 L 170.609999186 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.5232512827 202.836403918 L 138.183007917 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.2483025665023, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.21290192101185, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.17750127552139, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.61150035830656, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.60999918598748, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.07164051457713, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(138.18300791672871, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(66.52325128267087, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tee7f942dec3f460687fe1a9b105004ac"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te25829a15b7442d081a183f3d8b14119"><g class="toyplot-Edges"><path d="M 65.7355869205 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.133523409 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.133523409 202.472014925 L 192.505298422 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.200571769 162.389225746 L 191.133523409 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.264569952 122.306436567 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 94.6128731343 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.832344982 85.8675373134 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.858895466 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.858895466 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.832344982 85.8675373134 L 186.858895466 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 94.6128731343 L 186.832344982 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.264569952 122.306436567 L 186.726143046 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.200571769 162.389225746 L 166.264569952 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.7355869205 202.836403918 L 136.200571769 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.85889546610727, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.83234498198945, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.72614304551806, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.50529842183516, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.26456995203387, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.13352340908003, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(136.20057176926312, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(65.735586920508197, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tea0ce966cf134dacabcee4ea19fae0ae"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t243016cc266b499daf28abaedc5bda2f"><g class="toyplot-Edges"><path d="M 69.5765569562 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.894637287 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.337145356 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.337145356 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.894637287 202.472014925 L 192.337145356 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.997222763 162.389225746 L 191.894637287 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.485960457 122.306436567 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 94.6128731343 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 85.8675373134 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 91.697761194 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 91.697761194 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 85.8675373134 L 187.150950791 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 94.6128731343 L 187.106699985 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.485960457 122.306436567 L 187.053599016 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.997222763 162.389225746 L 168.485960457 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.5765569562 202.836403918 L 138.997222763 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.15095079140355, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.10669998454048, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.05359901630482, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.33714535575552, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(168.48596045656004, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.89463728712479, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(138.99722276300923, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(69.576556956222802, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tad5008c81fd14ff696552ca7a22816ad"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta617e9eded914f67af3e6c7d7b8eeb16"><g class="toyplot-Edges"><path d="M 63.4787957705 202.836403918 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.505230187 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.213243097 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.213243097 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.505230187 202.472014925 L 192.213243097 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.908379974 162.389225746 L 191.505230187 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.698159624 122.306436567 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.673042077 94.6128731343 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 85.8675373134 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 91.697761194 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 91.697761194 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 85.8675373134 L 186.743843368 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.673042077 94.6128731343 L 186.717292884 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.698159624 122.306436567 L 186.673042077 94.6128731343" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.908379974 162.389225746 L 165.698159624 122.306436567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.4787957705 202.836403918 L 133.908379974 162.389225746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.7438433682633, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.71729288414545, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.67304207728239, 94.612873134328382)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.21324309653892, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(165.69815962418653, 122.3064365671642)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.50523018672979, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(133.90837997375604, 162.38922574626866)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(63.478795770491558, 202.83640391791047)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td5100446139849d2a0c9f10fdee84cd8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc8c6ecc5bd224e6fa029c77aac09891c"><g class="toyplot-Edges"><path d="M 63.8770530323 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.974220504 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.000839224 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.000839224 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.974220504 202.472014925 L 192.000839224 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.652066469 163.846781716 L 190.974220504 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.742615136 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 100.443097015 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 97.5279850746 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 68.3768656716 L 198.399505896 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 68.3768656716 L 198.399505896 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 97.5279850746 L 186.814644659 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 100.443097015 L 186.814644659 97.5279850746" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.742615136 125.221548507 L 186.726143046 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.652066469 163.846781716 L 168.742615136 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.8770530323 203.565181903 L 138.652066469 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.81464465924421, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.81464465924421, 97.527985074626898)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.72614304551806, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.00083922359619, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.74261513636583, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.97422050437291, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.65206646947726, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(63.877053032259198, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t79ad2f1df770468cbb98bcdae3eab7db"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7048c49d9a83429e8fc14c3dd8b38ca5"><g class="toyplot-Edges"><path d="M 71.6120940719 204.293959888 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.593800036 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.593800036 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 202.472014925 L 192.593800036 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.837783388 165.304337687 L 192.319445033 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.946100613 128.136660448 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 106.273320896 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 85.8675373134 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.389905148 68.3768656716 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.389905148 68.3768656716 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 85.8675373134 L 187.389905148 68.3768656716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 106.273320896 L 187.363354664 85.8675373134" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.946100613 128.136660448 L 187.319103857 106.273320896" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.837783388 165.304337687 L 167.946100613 128.136660448" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.6120940719 204.293959888 L 136.837783388 165.304337687" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.38990514846412, 68.376865671641809)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.36335466434628, 85.867537313432862)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.31910385748324, 106.27332089552243)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.59380003556137, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.94610061283052, 128.13666044776122)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.31944503301028, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(136.83778338809134, 165.30433768656718)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(71.612094071924076, 204.29395988805973)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc74bd6df0c8f48af913e8670d3272873"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t54ae8cf19fdf4530b5393b066ed44416"><g class="toyplot-Edges"><path d="M 72.3378073045 203.929570896 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.75310294 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.133659879 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.133659879 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.75310294 202.472014925 L 193.133659879 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.245163752 164.575559701 L 192.75310294 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.786524768 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.566908376 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.646559828 80.0373134328 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.65540999 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.65540999 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.646559828 80.0373134328 L 187.65540999 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.566908376 103.358208955 L 187.646559828 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.786524768 126.679104478 L 187.566908376 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.245163752 164.575559701 L 163.786524768 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.3378073045 203.929570896 L 141.245163752 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.65540998964255, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.64655982826994, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.5669083759164, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.1336598792908, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(163.78652476770185, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.75310294026838, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(141.24516375165325, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(72.337807304478446, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9c6d0c6c2324428c99969129e33f41d6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9abac0eb7d9d41f18f13edfbc6953da8"><g class="toyplot-Edges"><path d="M 64.275310294 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.009689385 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.009689385 202.472014925 L 192.62035052 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.288868678 163.846781716 L 192.009689385 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.981637729 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.49603885 100.443097015 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 74.2070895522 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.708442723 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.708442723 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 74.2070895522 L 186.708442723 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.49603885 100.443097015 L 186.575690302 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.981637729 125.221548507 L 186.49603885 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.288868678 163.846781716 L 169.981637729 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.275310294 203.565181903 L 133.288868678 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.70844272277284, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.57569030218363, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.49603884983009, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.62035051967919, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(169.98163772853184, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.00968938496879, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(133.28886867767301, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(64.275310294026838, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5a30e87ed73049fc850503e993033375"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t23919e3d3f244fdcbc404ea4e7b7dee9"><g class="toyplot-Edges"><path d="M 74.5237971635 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.062858588 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.346063752 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.346063752 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.062858588 202.472014925 L 193.346063752 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.439867302 163.846781716 L 193.062858588 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.866380925 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.628859506 100.443097015 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.673110312 74.2070895522 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.743911603 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.743911603 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.673110312 74.2070895522 L 187.743911603 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.628859506 100.443097015 L 187.673110312 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.866380925 125.221548507 L 187.628859506 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.439867302 163.846781716 L 166.866380925 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.5237971635 203.565181903 L 141.439867302 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.7439116033687, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.67311031238779, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.62885950552473, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.34606375223353, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(166.8663809253716, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.06285858830989, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(141.43986730185077, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(74.523797163514175, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1642cf6bd33a476dbe392b10e55adebf"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8d6826e138e247e2a050d8c513d21852"><g class="toyplot-Edges"><path d="M 72.3555076272 203.565181903 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.540699067 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.2664123 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.2664123 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.540699067 202.472014925 L 193.2664123 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.422166979 163.846781716 L 192.540699067 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 125.221548507 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.195201598 100.443097015 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.274853051 74.2070895522 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 91.697761194 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.274853051 74.2070895522 L 187.319103857 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.195201598 100.443097015 L 187.274853051 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 125.221548507 L 187.195201598 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.422166979 163.846781716 L 167.007983507 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.3555076272 203.565181903 L 141.422166979 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.31910385748324, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.27485305062015, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.19520159826664, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(193.26641229988002, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(167.00798350733342, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.54069906732565, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(141.42216697910555, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(72.355507627223687, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf22f21995e704c12ac4b8d218d2e957d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfae253d10ce04cb89f6b1c9c6eff5894"><g class="toyplot-Edges"><path d="M 71.2138368102 203.565181903 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 202.472014925 L 198.399505896 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 184.981343284 L 198.399505896 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 184.981343284 L 198.399505896 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 202.472014925 L 192.567249551 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.129838713 163.846781716 L 191.65568293 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.388472211 125.221548507 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 100.443097015 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 74.2070895522 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 91.697761194 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 74.2070895522 L 187.000498048 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 100.443097015 L 186.965097403 74.2070895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.388472211 125.221548507 L 186.920846596 100.443097015" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.129838713 163.846781716 L 166.388472211 125.221548507" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.2138368102 203.565181903 L 137.129838713 163.846781716" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.00049804806909, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.96509740257864, 74.207089552238827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.92084659571557, 100.4430970149254)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.5672495514435, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(166.38847221125044, 125.2215485074627)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.65568293006422, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.12983871338761, 163.84678171641792)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(71.213836810156437, 203.5651819029851)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tef3b80e746f2444ba8452d4dfd7bdd36"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc7a6cc23a89e47bc95ae215143c246db"><g class="toyplot-Edges"><path d="M 69.2314006627 203.929570896 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.319513268 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.319513268 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 202.472014925 L 193.319513268 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.758063701 164.575559701 L 192.62035052 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.512442706 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.097849823 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.133250469 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.168651114 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.168651114 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.133250469 80.0373134328 L 187.168651114 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.097849823 103.358208955 L 187.133250469 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.512442706 126.679104478 L 187.097849823 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.758063701 164.575559701 L 167.512442706 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.2314006627 203.929570896 L 135.758063701 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.16865111414876, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.1332504686583, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.09784982316788, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.31951326811571, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.51244270557245, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.62035051967914, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(135.75806370063242, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(69.231400662690831, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="teaca9376f3cb4a438516e1a7c7794135"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbe1aab585c394e638ed3e1f2cffb9127"><g class="toyplot-Edges"><path d="M 68.6561401735 203.929570896 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.938956329 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.231011654 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.231011654 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.938956329 202.472014925 L 193.231011654 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.422030509 164.575559701 L 192.938956329 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.12296737 126.679104478 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.504957246 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.602309021 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.602309021 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.504957246 80.0373134328 L 187.602309021 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 103.358208955 L 187.504957246 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.12296737 126.679104478 L 187.478406762 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.422030509 164.575559701 L 166.12296737 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.6561401735 203.929570896 L 139.422030509 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.60230902140688, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.50495724630812, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.4784067621903, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.23101165438959, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(166.12296737007202, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.93895632909329, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(139.42203050889472, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(68.656140173470916, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc2b4912cc6f1464e84f2d7dd054ac5cb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5e92d55013d34fc4b470a4471f57457c"><g class="toyplot-Edges"><path d="M 64.036355937 203.929570896 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.407946647 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.407946647 202.472014925 L 193.045158266 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.103288229 164.575559701 L 192.407946647 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.370703653 126.679104478 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.903146273 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 80.0373134328 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.292553373 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.292553373 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 80.0373134328 L 187.292553373 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.903146273 103.358208955 L 186.920846596 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.370703653 126.679104478 L 186.903146273 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.103288229 164.575559701 L 165.370703653 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.036355937 203.929570896 L 137.103288229 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.29255337336537, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.92084659571557, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.90314627297036, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.04515826556468, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(165.3707036533998, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.40794664673643, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(137.10328822926976, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(64.03635593696626, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf1027d34fed24a7ab14e05bf736b5abb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td86152c9f0ee4536a1e7053a916cb902"><g class="toyplot-Edges"><path d="M 70.4084721252 203.929570896 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.151360202 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.20446117 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.20446117 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.151360202 202.472014925 L 193.20446117 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.855415476 164.575559701 L 193.151360202 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.618576407 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.345654342 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 80.0373134328 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.496107085 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.496107085 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 80.0373134328 L 187.496107085 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.345654342 103.358208955 L 187.363354664 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.618576407 126.679104478 L 187.345654342 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.855415476 164.575559701 L 166.618576407 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.4084721252 203.929570896 L 135.855415476 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.49610708493549, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.36335466434628, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.34565434160106, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.20446117027171, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(166.61857640693842, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.15136020203605, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(135.85541547573118, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(70.408472125248551, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t620e9f536f4e4335a9d4b897d3ab2120"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta26ae8f29a2241df885b7baceb6471d7"><g class="toyplot-Edges"><path d="M 70.0810161545 203.929570896 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.779585189 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.39916472 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.39916472 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.779585189 202.472014925 L 193.39916472 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.616529354 164.575559701 L 191.779585189 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.220182675 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.266002889 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.283703212 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.699660797 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.699660797 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.283703212 80.0373134328 L 187.699660797 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.266002889 103.358208955 L 187.283703212 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.220182675 126.679104478 L 187.266002889 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.616529354 164.575559701 L 164.220182675 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.0810161545 203.929570896 L 136.616529354 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.69966079650561, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.28370321199273, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.26600288924755, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.39916472046926, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(164.22018267495994, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.77958518928082, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(136.616529353776, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(70.081016154461821, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8c410314fec94d4b99a2d2d66ba98868"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tca0d5bfe430d4fa19ddedb9c387194c0"><g class="toyplot-Edges"><path d="M 67.4967690337 203.929570896 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.487529864 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.903487448 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.903487448 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.487529864 202.472014925 L 191.903487448 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.900143928 164.575559701 L 191.487529864 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.680595772 126.679104478 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.027048532 80.0373134328 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.027048532 80.0373134328 L 187.115550146 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 103.358208955 L 187.027048532 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.680595772 126.679104478 L 187.000498048 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.900143928 164.575559701 L 167.680595772 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.4967690337 203.929570896 L 142.900143928 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.11555014591309, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.02704853218694, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.00049804806909, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.90348744849743, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(167.68059577165212, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.48752986398455, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(142.90014392833211, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.496769033658438, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3a2d5fe7bc6c472cb908d29d4e36079c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t52039bb1e5ae422485f2dd0a5f5a52a7"><g class="toyplot-Edges"><path d="M 66.8772577376 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.443279057 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.567181316 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.567181316 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.443279057 202.472014925 L 191.567181316 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.457499389 161.660447761 L 191.443279057 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.123172075 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 91.697761194 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.0801495 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.0801495 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 103.358208955 L 187.0801495 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 91.697761194 L 186.717292884 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.123172075 120.848880597 L 186.717292884 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.457499389 161.660447761 L 169.123172075 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.8772577376 202.472014925 L 140.457499389 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.08014950042264, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.71729288414545, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.71729288414545, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.56718131633806, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.12317207538825, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.44327905712146, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(140.45749938949058, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(66.877257737575434, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc1edaf886655435c8b463cbe42ba339d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te408c425cd5247a49fe279c0e4b2b435"><g class="toyplot-Edges"><path d="M 65.8683393411 203.929570896 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.682233414 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.85038648 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.85038648 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.682233414 202.472014925 L 191.85038648 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.873525209 164.575559701 L 191.682233414 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.114321914 126.679104478 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.230602244 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.230602244 80.0373134328 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.372204826 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.372204826 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.230602244 80.0373134328 L 187.372204826 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.230602244 103.358208955 L 187.230602244 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.114321914 126.679104478 L 187.230602244 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.873525209 164.575559701 L 169.114321914 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.8683393411 203.929570896 L 141.873525209 164.575559701" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.37220482571891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.23060224375709, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.23060224375709, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.85038648026173, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.11432191401562, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.68223341418206, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(141.87352520910886, 164.57555970149255)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(65.868339341097396, 203.9295708955224)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t40a6075ed73e401a9f9c1e0b31468c4c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0da45ed2d0c9419aa15d6da2e5170723"><g class="toyplot-Edges"><path d="M 57.4606860371 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.133523409 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.239725346 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.239725346 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.133523409 202.472014925 L 191.239725346 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.457431154 161.660447761 L 191.133523409 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.937250451 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.248234331 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.257084493 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.257084493 103.358208955 L 186.363286429 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.248234331 91.697761194 L 186.257084493 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.937250451 120.848880597 L 186.248234331 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.457431154 161.660447761 L 167.937250451 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 57.4606860371 202.472014925 L 139.457431154 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.36328642924087, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.25708449276954, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.24823433139693, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.23972534555136, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.93725045145794, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.13352340907997, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.45743115438518, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(57.460686037113838, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfe787d7a3a61451b95ec218407b8a3a3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5e2a699e7b8346c6b32a7545de86a9fc"><g class="toyplot-Edges"><path d="M 69.6296579245 202.472014925 L 198.408356057 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 202.472014925 L 191.885787126 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.404466656 161.660447761 L 191.65568293 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.609589775 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.239452405 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.239452405 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 91.697761194 L 187.239452405 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 103.358208955 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 103.358208955 L 198.408356057 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 91.697761194 L 187.053599016 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.609589775 120.848880597 L 187.053599016 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.404466656 161.660447761 L 164.609589775 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.6296579245 202.472014925 L 141.404466656 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.05359901630482, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.2394524051297, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.05359901630482, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.88578712575219, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(164.60958977535498, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.65568293006422, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(141.40446665636031, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(69.629657924458485, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t87421f74a8c846499eeb1dd006349af3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t93a04eae0cd543cc8a777d61fbb4db1e"><g class="toyplot-Edges"><path d="M 60.0006823511 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.354777443 202.472014925 L 198.417206219 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.983138901 184.981343284 L 198.408356057 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.983138901 184.981343284 L 198.408356057 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.354777443 202.472014925 L 191.983138901 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.714017599 161.660447761 L 191.354777443 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.468260134 120.848880597 L 198.417206219 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 91.697761194 L 198.408356057 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 80.0373134328 L 198.417206219 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 80.0373134328 L 198.417206219 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 103.358208955 L 186.743843368 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 91.697761194 L 186.557989979 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.468260134 120.848880597 L 186.531439495 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.714017599 161.660447761 L 168.468260134 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.0006823511 202.472014925 L 138.714017599 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.7438433682633, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.55798997943839, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.53143949532057, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.98313890085097, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.46826013381479, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.35477744339536, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(138.71401759908557, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(60.000682351054131, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc1ccccff93414e11a643f9349c9a742d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5c320a47d6404b569576bb778732439e"><g class="toyplot-Edges"><path d="M 65.841788857 202.472014925 L 198.417206219 243.28358209" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.036103399 202.472014925 L 198.408356057 219.962686567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.23965711 184.981343284 L 198.417206219 196.641791045" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.23965711 184.981343284 L 198.417206219 173.320895522" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.036103399 202.472014925 L 190.23965711 184.981343284" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.156866843 161.660447761 L 190.036103399 202.472014925" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.60108079 120.848880597 L 198.408356057 150.0" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.88544595 80.0373134328 L 198.408356057 56.7164179104" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.88544595 80.0373134328 L 198.408356057 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.584540464 91.697761194 L 186.88544595 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.664191916 103.358208955 L 198.417206219 80.0373134328" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.664191916 103.358208955 L 198.417206219 126.679104478" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.584540464 91.697761194 L 186.664191916 103.358208955" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.60108079 120.848880597 L 186.584540464 91.697761194" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.156866843 161.660447761 L 169.60108079 120.848880597" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.841788857 202.472014925 L 144.156866843 161.660447761" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.67910447761197)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.716417910447767)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 150.00000000000003)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 173.32089552238807)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 196.64179104477614)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 219.96268656716418)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 243.28358208955225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.66419191590978, 103.35820895522389)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.88544595022512, 80.037313432835845)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.58454046355624, 91.69776119402988)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.23965711044593, 184.98134328358211)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(169.60108078950941, 120.84888059701495)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.03610339887581, 202.47201492537314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(144.15686684324336, 161.66044776119404)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(65.841788856979562, 202.47201492537314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8f83fe3e555e4afa999f284543d30f6a"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(198.41720621874154,126.67910447761197)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">lip</text></g><g class="toyplot-Datum" transform="translate(198.41720621874154,80.037313432835845)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">rex</text></g><g class="toyplot-Datum" transform="translate(198.40835605736891,103.35820895522389)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">rck</text></g><g class="toyplot-Datum" transform="translate(198.40835605736891,56.716417910447767)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">tha</text></g><g class="toyplot-Datum" transform="translate(198.40835605736891,150.00000000000003)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">cup</text></g><g class="toyplot-Datum" transform="translate(198.41720621874154,173.32089552238807)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">sup</text></g><g class="toyplot-Datum" transform="translate(198.41720621874154,196.64179104477614)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">cya</text></g><g class="toyplot-Datum" transform="translate(198.40835605736891,219.96268656716418)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">cys</text></g><g class="toyplot-Datum" transform="translate(198.41720621874154,243.28358208955225)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">prz</text></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t0f708f8e46e64bca8d7b944b6f7ea1d1";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t6b834ee6651a47939e163eecf930d4c6";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te5e5508097d34c2badd26aa75e7370b3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -0.0018270000000000005, -0.0019690000000000003, -0.0045850000000000005, -0.0011720000000000003, -0.00459, -0.0034000000000000002, -0.005255, -0.005531], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te5e5508097d34c2badd26aa75e7370b3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t42d5a45fe8ec4f1f89e250c9f6167070","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -0.001736000000000001, -0.0017870000000000008, -0.004414000000000001, -0.0008810000000000007, -0.004425000000000001, -0.003944000000000001, -0.005030000000000001, -0.005326000000000001], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t42d5a45fe8ec4f1f89e250c9f6167070","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t86bd757d33d34e8d9635dbe72c9aba31","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -0.0019330000000000007, -0.0019470000000000008, -0.0048400000000000006, -0.0009990000000000008, -0.004847000000000001, -0.0037750000000000006, -0.005496000000000001, -0.005815000000000001], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t86bd757d33d34e8d9635dbe72c9aba31","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta81ff826e7ca41e6a55c0b69449eee1b","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000018675e-06, -1.0000000000018675e-06, -1.0000000000018675e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, -0.0019459999999999998, -0.0019770000000000005, -0.0048660000000000005, -0.0007350000000000004, -0.004889, -0.0035020000000000003, -0.005553000000000001, -0.005909], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta81ff826e7ca41e6a55c0b69449eee1b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t48ea4f9650844ae5b02016c7895dddb5","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -0.0019050000000000004, -0.001922, -0.004764000000000001, -0.0006500000000000004, -0.004808000000000001, -0.003723, -0.0054930000000000005, -0.005838], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t48ea4f9650844ae5b02016c7895dddb5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf2b77caa85d7496fbec041eb1e01da75","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0020310000000000007, -0.002052000000000001, -0.005093, -0.000648000000000001, -0.005111, -0.003673, -0.0058130000000000005, -0.00619], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf2b77caa85d7496fbec041eb1e01da75","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5e17b4df7cbf4ef8b9ee56bc50a16882","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -0.0020870000000000003, -0.0021400000000000004, -0.005289000000000001, -0.0007390000000000009, -0.005323000000000001, -0.003439000000000001, -0.006121000000000001, -0.006417000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5e17b4df7cbf4ef8b9ee56bc50a16882","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td414dd31b5bc408497c623c68b041dfe","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -1.999999999999398e-06, -1.999999999999398e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.0019839999999999997, -0.0020109999999999998, -0.005032999999999999, -0.0007349999999999995, -0.005044, -0.0029929999999999996, -0.0058649999999999996, -0.006167], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td414dd31b5bc408497c623c68b041dfe","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tff7880ac8ff246dc93cef7625b36aad0","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.0019460000000000007, -0.001960000000000001, -0.004880000000000001, -0.0006500000000000004, -0.004896, -0.0026230000000000003, -0.0057540000000000004, -0.0060420000000000005], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tff7880ac8ff246dc93cef7625b36aad0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6b581d573fcc4a369db205bb83d605cf","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -1.0000000000001327e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0018019999999999998, -0.0018129999999999995, -0.004495, -0.0007159999999999996, -0.004519, -0.0025659999999999997, -0.005403, -0.005637], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6b581d573fcc4a369db205bb83d605cf","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t968a2b82d63543b399c4183330df5bf4","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -0.0019910000000000006, -0.0019960000000000004, -0.004894000000000001, -0.0006820000000000003, -0.004966, -0.00237, -0.005945000000000001, -0.006224], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t968a2b82d63543b399c4183330df5bf4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3c31a181fd9a4e9cb34b00bfcd81afce","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0019379999999999996, -0.0019429999999999994, -0.0046949999999999995, -0.0006680000000000002, -0.004777, -0.002445, -0.0057859999999999995, -0.006063], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3c31a181fd9a4e9cb34b00bfcd81afce","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t419723cab929472da934cf154e7f7eb3","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.0000000000001327e-06, -2.0000000000002655e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -0.0020620000000000005, -0.002066, -0.004966, -0.0008599999999999997, -0.005038000000000001, -0.00262, -0.006137, -0.006439], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t419723cab929472da934cf154e7f7eb3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7bdf31a2b1fa4152b34b7dad33e1c69a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -0.0020170000000000006, -0.0020250000000000008, -0.004854000000000001, -0.0007910000000000009, -0.004936000000000001, -0.0034160000000000006, -0.0060030000000000005, -0.006351000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7bdf31a2b1fa4152b34b7dad33e1c69a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8689baeab9a1482ca058c49834b9d080","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.001962, -0.0019660000000000007, -0.004712000000000001, -0.0006880000000000011, -0.004778000000000001, -0.002998000000000001, -0.005912000000000001, -0.006182000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8689baeab9a1482ca058c49834b9d080","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tea8c9f86b6f4427a9e19e77267bb9f2c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.673617379884035e-19, 0.0, -0.002097, -0.00211, -0.005038000000000001, -0.0007520000000000001, -0.005098, -0.0036090000000000002, -0.006315, -0.006616], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tea8c9f86b6f4427a9e19e77267bb9f2c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2f1cb1f88c3a495dbfab83c82e3b11cc","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002012999999999999, -0.0020619999999999996, -0.004912, -0.0006549999999999993, -0.004971, -0.003351, -0.006196999999999999, -0.006493], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2f1cb1f88c3a495dbfab83c82e3b11cc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td889acaf26cf4162849c0691edb0c81c","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -1.0000000000001327e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0019439999999999995, -0.001959, -0.004644, -0.0005419999999999991, -0.004716, -0.0038969999999999994, -0.0059229999999999994, -0.006225], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td889acaf26cf4162849c0691edb0c81c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t068684e8906a4db4bc3f96b1f7ae8ea3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -1.0000000000001327e-06, -0.001967, -0.0019959999999999995, -0.004706, -0.0004989999999999994, -0.004772, -0.003789, -0.0059559999999999995, -0.006312], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t068684e8906a4db4bc3f96b1f7ae8ea3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t542cf0fa38e548dd93dafc1bcab1e0a2","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.0000000000018675e-06, -0.0018950000000000009, -0.001980000000000001, -0.0046250000000000015, -0.0006020000000000018, -0.004713000000000002, -0.0035920000000000014, -0.005963000000000001, -0.0062850000000000015], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t542cf0fa38e548dd93dafc1bcab1e0a2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0be0d6e7d0834d1abcaf25bf30ed4efb","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -1.0000000000001327e-06, 0.0, -0.0020090000000000004, -0.0020740000000000003, -0.004669, -0.0004889999999999999, -0.0047810000000000005, -0.003595, -0.006106, -0.006479], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0be0d6e7d0834d1abcaf25bf30ed4efb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2a41fbbac8c04cbaa5c84a8b4848497d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -2.0000000000002655e-06, -0.002084, -0.002175, -0.004483, -0.0005830000000000002, -0.00474, -0.0032220000000000005, -0.006312, -0.006726], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2a41fbbac8c04cbaa5c84a8b4848497d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0d1754155b89404ab0ed41f4a00c1801","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -8.673617379884035e-19, -8.673617379884035e-19, -0.0021290000000000007, -0.002145000000000001, -0.003944000000000001, -0.0005840000000000012, -0.004149000000000001, -0.0034910000000000006, -0.006504000000000001, -0.006965000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0d1754155b89404ab0ed41f4a00c1801","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcb7ad009f4d541d998e6e19b43bff03b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -1.734723475976807e-18, -0.002268000000000001, -0.0022790000000000015, -0.0037930000000000017, -0.0006070000000000016, -0.0040240000000000015, -0.004061000000000002, -0.006844000000000001, -0.0073170000000000015], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcb7ad009f4d541d998e6e19b43bff03b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3501b96537ad40789187b483244804d6","vertex_data","graph vertex data",["x", "y"],[[-8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, 0.0, 0.0, -8.673617379884035e-19, -0.0022860000000000016, -0.002294000000000001, -0.0036150000000000015, -0.0005840000000000012, -0.0037060000000000014, -0.003983000000000001, -0.006927000000000001, -0.007400000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3501b96537ad40789187b483244804d6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3157de9e8e364e54acf3d41c027f2feb","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.002321, -0.0023239999999999997, -0.0035789999999999997, -0.0006300000000000004, -0.003699, -0.003509, -0.007066, -0.007587], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3157de9e8e364e54acf3d41c027f2feb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t604447fa951948eda59ba41528487ed9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0023999999999999994, -0.0024029999999999998, -0.0036559999999999995, -0.0006559999999999995, -0.003798, -0.0035179999999999994, -0.007316, -0.007861], [7.0, 6.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t604447fa951948eda59ba41528487ed9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tae4730938b614482bf72b3e39fdbb58a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0023809999999999994, -0.002385, -0.003568, -0.0007100000000000006, -0.0036879999999999994, -0.0036689999999999995, -0.007337, -0.007909], [7.0, 6.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tae4730938b614482bf72b3e39fdbb58a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8b01a3b1b1234a59ab881022536627ea","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002353, -0.0023569999999999997, -0.0034399999999999995, -0.0006579999999999997, -0.0035700000000000003, -0.0038979999999999996, -0.007467, -0.007894], [7.0, 8.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8b01a3b1b1234a59ab881022536627ea","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tad6306f9d1ca49ea8c7a86a54eefdbb7","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.734723475976807e-18, -0.002367000000000002, -0.0023710000000000016, -0.003190000000000001, -0.0007090000000000022, -0.0034220000000000014, -0.003914000000000002, -0.0073500000000000015, -0.007925000000000001], [7.0, 8.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tad6306f9d1ca49ea8c7a86a54eefdbb7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta755c08b7ff2477d8896e265d08ef2c4","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0023439999999999997, -0.0024269999999999995, -0.0028909999999999995, -0.0006220000000000002, -0.003439, -0.004514, -0.007324, -0.008038], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta755c08b7ff2477d8896e265d08ef2c4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta6f00b606bc1475985ab540257d12547","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0023699999999999997, -0.0023819999999999996, -0.0026889999999999996, -0.0008159999999999999, -0.003117, -0.0036950000000000004, -0.007487, -0.008326], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta6f00b606bc1475985ab540257d12547","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t284137fba7e5474bbc54325ec83c58f9","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002366, -0.002372, -0.002436, -0.0007160000000000005, -0.002824, -0.003562000000000001, -0.0073820000000000005, -0.008368], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t284137fba7e5474bbc54325ec83c58f9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfa00a92beacf426897360b8c08613052","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.002502999999999999, -0.002568, -0.002666, -0.0009349999999999983, -0.0027739999999999996, -0.003704, -0.007598, -0.008853], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfa00a92beacf426897360b8c08613052","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2fc2fcb85bc34218bad4318d0556022b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0025330000000000005, -0.0026440000000000005, -0.002725, -0.0007800000000000012, -0.0029969999999999997, -0.003573, -0.0072440000000000004, -0.009247], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2fc2fcb85bc34218bad4318d0556022b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4d6d8de9ad6a41b78f81e0ecf4caf72f","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -0.002404999999999999, -0.0025429999999999993, -0.00258, -0.0007399999999999993, -0.003072, -0.0032759999999999994, -0.006657, -0.008721], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4d6d8de9ad6a41b78f81e0ecf4caf72f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t241b036311cd4dd4b33485f3fd55b935","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.002644999999999999, -0.002689999999999999, -0.002728999999999999, -0.0007480000000000004, -0.002927999999999999, -0.003240999999999999, -0.007470999999999999, -0.00929], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t241b036311cd4dd4b33485f3fd55b935","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7c4d222715d343b7a8ec88580fd3e10d","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.002686000000000001, -0.002714000000000001, -0.002759000000000001, -0.0007640000000000008, -0.0030830000000000007, -0.0035020000000000008, -0.007099000000000001, -0.009756], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7c4d222715d343b7a8ec88580fd3e10d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfb6b356741be4294b833a41344a1919c","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0025249999999999995, -0.002548999999999999, -0.002576, -0.000699, -0.0030489999999999996, -0.0025509999999999994, -0.006591, -0.009757], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfb6b356741be4294b833a41344a1919c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t611f1c79bf1e4e2f8909b5e94aaa4ac1","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002293999999999999, -0.0023510000000000007, -0.0023560000000000005, -0.0006540000000000001, -0.0028129999999999995, -0.0017579999999999991, -0.007228, -0.009576], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t611f1c79bf1e4e2f8909b5e94aaa4ac1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf7a4e13ce9694782bd7c80afe82c3f59","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -1.9999999999985307e-06, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, -9.999999999992654e-07, -1.9999999999985307e-06, -0.0023139999999999983, -0.002325999999999998, -0.0023469999999999984, -0.000677999999999998, -0.0027249999999999983, -0.002062999999999999, -0.0072489999999999985, -0.009659999999999998], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf7a4e13ce9694782bd7c80afe82c3f59","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t682cd8c2c11240e9a4d455a6d0eae071","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.002328, -0.0023700000000000006, -0.0024010000000000004, -0.0006390000000000007, -0.0028470000000000006, -0.0017810000000000013, -0.007385000000000001, -0.009688], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t682cd8c2c11240e9a4d455a6d0eae071","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t08d6790eb26c411693dff29e7579e631","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.002301000000000001, -0.0023090000000000003, -0.002347, -0.0006270000000000008, -0.0028600000000000006, -0.0018130000000000004, -0.007308, -0.009648], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t08d6790eb26c411693dff29e7579e631","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc02170a7cf3c44fda9a2a1395df32a89","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002092, -0.0021020000000000006, -0.002138000000000001, -0.0006010000000000008, -0.0026380000000000006, -0.001609000000000001, -0.006849000000000001, -0.009430000000000001], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc02170a7cf3c44fda9a2a1395df32a89","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1819d6cf222e4a47b0de79b5c3ad97bc","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, 0.0, -0.0021799999999999996, -0.002180999999999999, -0.0022049999999999986, -0.0007359999999999988, -0.0030219999999999986, -0.0018279999999999998, -0.007179, -0.009954], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1819d6cf222e4a47b0de79b5c3ad97bc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1aec3dcaa6a04617be80d3001223a6aa","vertex_data","graph vertex data",["x", "y"],[[-2.000000000002e-06, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.0022520000000000005, -0.0022520000000000005, -0.0022650000000000014, -0.0007489999999999997, -0.0027930000000000003, -0.0016770000000000014, -0.007384000000000001, -0.010807], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1aec3dcaa6a04617be80d3001223a6aa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t32c3ae6d24114f6b917262d26b950e2e","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.734723475976807e-18, 0.0, -0.002242000000000001, -0.002242000000000001, -0.002254000000000001, -0.0006620000000000011, -0.002659, -0.0016510000000000014, -0.007379, -0.010859], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t32c3ae6d24114f6b917262d26b950e2e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td4b26fce5f3743cb846f3af13f922599","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.002261000000000001, -0.0022640000000000004, -0.0022850000000000006, -0.0008510000000000011, -0.002567, -0.0018060000000000003, -0.007513000000000001, -0.011067], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td4b26fce5f3743cb846f3af13f922599","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9dc1fc2853d24c4ca941c56b278fb38a","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -0.0022099999999999984, -0.0022169999999999985, -0.002227, -0.0008979999999999995, -0.0027019999999999995, -0.0016169999999999986, -0.007110999999999998, -0.011362999999999998], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9dc1fc2853d24c4ca941c56b278fb38a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb1fe2b6e9fc14986b3e2fda866b5ccfa","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002116, -0.0021379999999999993, -0.0021469999999999996, -0.0007939999999999996, -0.0030080000000000003, -0.0016699999999999996, -0.007069, -0.011594], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb1fe2b6e9fc14986b3e2fda866b5ccfa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4373ae0c7bb146468ee49a51cb055d30","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0019900000000000004, -0.0020020000000000003, -0.0020100000000000014, -0.0007140000000000011, -0.0035960000000000002, -0.0015350000000000016, -0.006670000000000001, -0.011511], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4373ae0c7bb146468ee49a51cb055d30","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfb001b56dd424c288e55a8ab84f417da","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0018410000000000024, -0.0018450000000000012, -0.0018540000000000015, -0.0007660000000000011, -0.0029830000000000013, -0.0009300000000000003, -0.006720000000000001, -0.011435], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfb001b56dd424c288e55a8ab84f417da","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95f9e38607ea49149a160511ff7a7036","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0018449999999999994, -0.0018519999999999995, -0.001856, -0.0006080000000000009, -0.002863000000000001, -0.0012099999999999993, -0.006675, -0.011792], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95f9e38607ea49149a160511ff7a7036","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taeb39256f30b4421bcdf3443b37a772d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0019019999999999992, -0.001934, -0.0019369999999999995, -0.0006370000000000004, -0.0032169999999999994, -0.0014509999999999992, -0.006569, -0.012366], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taeb39256f30b4421bcdf3443b37a772d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tae084ad4ce79473b8098d26b79335d3f","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001745, -0.0017590000000000001, -0.0017600000000000011, -0.000596000000000001, -0.003262000000000001, -0.001262000000000001, -0.0066240000000000005, -0.011511], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tae084ad4ce79473b8098d26b79335d3f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5d6cbe3bea944000ae99127dc9d31768","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, 0.0, -0.001831000000000001, -0.0018499999999999992, -0.0018510000000000002, -0.0006589999999999999, -0.003051, -0.0015099999999999992, -0.006648, -0.012324], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5d6cbe3bea944000ae99127dc9d31768","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc9090f04f84d436b90ea594daa3447fc","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0019950000000000002, -0.001975000000000001, -0.0020020000000000003, -0.0007769999999999999, -0.003013, -0.001398, -0.007052, -0.013516], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc9090f04f84d436b90ea594daa3447fc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t96575ddb160e44be92b07a4c0ec09f76","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -0.0019030000000000002, -0.0018539999999999997, -0.0019140000000000008, -0.0007329999999999993, -0.003027, -0.0012490000000000001, -0.006875, -0.013479], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t96575ddb160e44be92b07a4c0ec09f76","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t208c16a624944996aa9b1454c23b9583","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, -0.0019330000000000007, -0.0019280000000000026, -0.0019380000000000022, -0.0006620000000000011, -0.0033050000000000024, -0.0011450000000000002, -0.007373000000000001, -0.01352], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t208c16a624944996aa9b1454c23b9583","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t708427411a01426e8ec2d95645233c7a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0019019999999999992, -0.0019039999999999994, -0.001908, -0.0006300000000000004, -0.003266, -0.0015530000000000006, -0.006709, -0.013347], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t708427411a01426e8ec2d95645233c7a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t411b3673f72c44d6a3962a6c93b8165d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0019570000000000004, -0.00196, -0.0019629999999999995, -0.000621, -0.003266, -0.0012759999999999994, -0.006873, -0.013998], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t411b3673f72c44d6a3962a6c93b8165d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t094a9688c0db46bea819a9e996a70ba0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.001850000000000001, -0.001857000000000001, -0.0018589999999999995, -0.000536, -0.0037549999999999997, -0.0012050000000000012, -0.006111, -0.014096000000000001], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t094a9688c0db46bea819a9e996a70ba0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1091585a5a6c46a8af3094ff17e8bd43","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.0017990000000000003, -0.0018090000000000016, -0.0018110000000000001, -0.0005320000000000012, -0.003564000000000001, -0.0009460000000000007, -0.006868000000000001, -0.014266000000000001], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1091585a5a6c46a8af3094ff17e8bd43","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfa12e1a5049b45e9b5f1e299fc0547ee","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.001854999999999999, -0.0018609999999999998, -0.001864000000000001, -0.000593999999999999, -0.0033550000000000003, -0.0011590000000000003, -0.006827, -0.014178], [8.0, 5.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfa12e1a5049b45e9b5f1e299fc0547ee","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t16b2c81fad2440d6baf2d23caf4552b9","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.0017560000000000006, -0.0017840000000000009, -0.0017850000000000019, -0.0005980000000000013, -0.003124, -0.0010280000000000011, -0.0066430000000000005, -0.013586], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t16b2c81fad2440d6baf2d23caf4552b9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3b73898cbeea4087a2a04e0b7d0f509b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -0.0018239999999999992, -0.0017870000000000004, -0.0018260000000000012, -0.0006180000000000005, -0.003143, -0.0012469999999999998, -0.006543, -0.013731], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3b73898cbeea4087a2a04e0b7d0f509b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8d7efe6dab8041bb94fb60d00e2c198c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0018550000000000007, -0.0018709999999999994, -0.001876000000000001, -0.0005820000000000009, -0.0033550000000000003, -0.001079, -0.006914, -0.014031], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8d7efe6dab8041bb94fb60d00e2c198c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t36f1a685798c46919e24a3778f94c18d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -0.001849, -0.0018729999999999997, -0.0018740000000000007, -0.000595, -0.003254, -0.001098, -0.006392, -0.013748], [8.0, 5.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t36f1a685798c46919e24a3778f94c18d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4691aff1cc344725ab87f21166b961ec","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0019179999999999996, -0.0019229999999999994, -0.001927, -0.0005730000000000006, -0.003235, -0.0012469999999999998, -0.006435, -0.014202], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4691aff1cc344725ab87f21166b961ec","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t44504d7c68ae45b5ab58cf2ea5269ecc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0018159999999999982, -0.0018320000000000003, -0.0018339999999999988, -0.0006040000000000004, -0.002848, -0.001044999999999999, -0.0063349999999999995, -0.014067], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t44504d7c68ae45b5ab58cf2ea5269ecc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4eb94718e1e14d369190667a2c5515d2","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, -1.000000000001e-06, -0.0018939999999999999, -0.0018970000000000011, -0.001901, -0.0006340000000000009, -0.0030679999999999995, -0.0009230000000000002, -0.00698, -0.015027], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4eb94718e1e14d369190667a2c5515d2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t98ef85523c1d46d5ae41b628a49aa1e3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -0.001875, -0.0018790000000000005, -0.001882, -0.0006240000000000013, -0.0029370000000000004, -0.0009549999999999993, -0.0067740000000000005, -0.014861000000000001], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t98ef85523c1d46d5ae41b628a49aa1e3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t53658621be234317a0b9857b98b01667","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001903000000000002, -0.0019130000000000015, -0.0019130000000000015, -0.0006920000000000016, -0.0032780000000000014, -0.001236000000000001, -0.006484000000000002, -0.015696], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t53658621be234317a0b9857b98b01667","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2293221ed16b4824847f0e8ec6c986f5","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0018459999999999987, -0.0018609999999999998, -0.0018620000000000008, -0.0006069999999999999, -0.00332, -0.0012809999999999992, -0.007052, -0.014659], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2293221ed16b4824847f0e8ec6c986f5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ebfd6d0daed49afa11aa6bcc4fd5aa4","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0016750000000000011, -0.001680000000000001, -0.0016840000000000015, -0.0005540000000000024, -0.003046, -0.001015000000000002, -0.006831000000000001, -0.014086000000000001], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ebfd6d0daed49afa11aa6bcc4fd5aa4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0d47e4a6e7154f50a006ec573727aba6","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.001628000000000001, -0.0016320000000000015, -0.0016370000000000013, -0.0005920000000000022, -0.003334, -0.000903000000000001, -0.007163000000000001, -0.013746000000000001], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0d47e4a6e7154f50a006ec573727aba6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td218968002da4fad917618dbc63fd6e1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001595000000000001, -0.0015980000000000005, -0.001602000000000001, -0.0006340000000000009, -0.0037080000000000012, -0.000811000000000001, -0.006883, -0.013854], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td218968002da4fad917618dbc63fd6e1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1b42d4fb491c49849e59dd75dba9df13","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, -1.000000000001e-06, -0.00166, -0.001661000000000001, -0.001667, -0.0007350000000000013, -0.0035989999999999998, -0.0008509999999999993, -0.006354, -0.014378], [5.0, 7.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1b42d4fb491c49849e59dd75dba9df13","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbca87e4155004f5c89d9e0922aaf8278","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999975306e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0017459999999999976, -0.0017469999999999986, -0.0017789999999999993, -0.0005669999999999981, -0.0030479999999999986, -0.000954, -0.006655999999999999, -0.015118], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbca87e4155004f5c89d9e0922aaf8278","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t45f98dc4e81a40fb90d37dd3a3dd8a5b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.469446951953614e-18, -0.0017960000000000025, -0.0018030000000000025, -0.0018120000000000011, -0.000623000000000002, -0.0035210000000000016, -0.0010510000000000016, -0.006543000000000002, -0.015828000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t45f98dc4e81a40fb90d37dd3a3dd8a5b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td520fd8c59c54350b7b560eab84c2079","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0016290000000000002, -0.0016400000000000008, -0.001646, -0.0005789999999999997, -0.003335000000000001, -0.0009000000000000015, -0.006845, -0.014963], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td520fd8c59c54350b7b560eab84c2079","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc20e06b83f93424397d110769a11fb06","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0016900000000000005, -0.0017010000000000011, -0.0017110000000000007, -0.0007130000000000018, -0.0035659999999999997, -0.001040000000000001, -0.006325000000000001, -0.015667], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc20e06b83f93424397d110769a11fb06","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t507f798967c34f999622f18b7bd380bc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -1.000000000001e-06, -0.0016480000000000002, -0.0016579999999999998, -0.0016629999999999995, -0.0006859999999999991, -0.003162999999999999, -0.000900999999999999, -0.006626999999999999, -0.015961], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t507f798967c34f999622f18b7bd380bc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t037270be2f0d4eb780484292842cc533","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -0.0017870000000000021, -0.0017890000000000024, -0.001805000000000001, -0.0009350000000000018, -0.0035130000000000022, -0.0011510000000000027, -0.006569000000000002, -0.016681], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t037270be2f0d4eb780484292842cc533","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t12211de8b5d84fa8b5a71e58225f7353","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0017239999999999998, -0.0017789999999999993, -0.0017879999999999997, -0.0007769999999999999, -0.002999999999999999, -0.0010959999999999998, -0.006362, -0.01677], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t12211de8b5d84fa8b5a71e58225f7353","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1b3443ade7f84bb6a65c90bac19750e7","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0016749999999999994, -0.0017300000000000006, -0.0017409999999999995, -0.0007609999999999995, -0.003307000000000001, -0.0009440000000000004, -0.006763, -0.01616], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1b3443ade7f84bb6a65c90bac19750e7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7363cc5a37c9423cbb249f4b35f07a69","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0016039999999999995, -0.0016939999999999993, -0.0017029999999999997, -0.0007029999999999988, -0.0030159999999999996, -0.0008489999999999991, -0.0070539999999999995, -0.015427], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7363cc5a37c9423cbb249f4b35f07a69","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf6805b38e9ec429e81ef106d5ddc0c06","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -0.001549, -0.0016879999999999985, -0.0016949999999999986, -0.0007989999999999994, -0.0030619999999999988, -0.0008780000000000003, -0.0064139999999999996, -0.015545], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf6805b38e9ec429e81ef106d5ddc0c06","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te227585238e74edeacc4af5c1df89667","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0015350000000000016, -0.0016160000000000011, -0.0016510000000000014, -0.0007940000000000013, -0.003328000000000001, -0.0008990000000000005, -0.006825000000000001, -0.015266000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te227585238e74edeacc4af5c1df89667","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t44960994e5b844bfb4cbd4c89a0abc77","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0013490000000000012, -0.0015340000000000006, -0.0015610000000000016, -0.0007760000000000006, -0.002961, -0.0009530000000000007, -0.007135000000000001, -0.014642], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t44960994e5b844bfb4cbd4c89a0abc77","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82f0c7a7c3384a1ab5b008b4f976aa05","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0014950000000000015, -0.0015550000000000008, -0.0015810000000000008, -0.0008439999999999993, -0.0027360000000000006, -0.000869, -0.007105, -0.015142000000000001], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82f0c7a7c3384a1ab5b008b4f976aa05","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t722babba38454305bd04d096d40eaa88","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -0.0014770000000000009, -0.0015610000000000016, -0.0015780000000000013, -0.0008360000000000017, -0.0032710000000000013, -0.0008880000000000016, -0.006884000000000001, -0.015186000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t722babba38454305bd04d096d40eaa88","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb25b4dc37e2844e9a7430afade712061","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.001543000000000001, -0.0013360000000000021, -0.001551000000000002, -0.0007490000000000014, -0.0035590000000000014, -0.0009430000000000011, -0.006924000000000001, -0.015273000000000002], [5.0, 6.0, 8.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 5.5, 7.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb25b4dc37e2844e9a7430afade712061","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb012049822444be5aaea4b468c5ac094","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0011540000000000005, -0.0014180000000000009, -0.0014220000000000014, -0.000725, -0.002850000000000002, -0.0008330000000000004, -0.007109000000000001, -0.014724000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb012049822444be5aaea4b468c5ac094","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t66b45549b4f1406a864d51c2ed5dbf41","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0010389999999999983, -0.001398, -0.0014029999999999997, -0.0006679999999999985, -0.003382999999999999, -0.0008059999999999994, -0.0067399999999999995, -0.014745999999999999], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t66b45549b4f1406a864d51c2ed5dbf41","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t36e446f792ca4fddabead23664874fe4","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013419999999999994, -0.0014199999999999994, -0.0014260000000000002, -0.0006819999999999986, -0.0030149999999999986, -0.0008039999999999992, -0.006900999999999999, -0.014782], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t36e446f792ca4fddabead23664874fe4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tafe3338d80cb40b2b79962d02ccf47a6","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001469999999999999, -0.0015060000000000004, -0.0015169999999999993, -0.0008249999999999993, -0.0030159999999999996, -0.000952999999999999, -0.007122, -0.01551], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tafe3338d80cb40b2b79962d02ccf47a6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9f17cde0facb4a859dadd314a8b6394f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013380000000000006, -0.001387000000000001, -0.0013960000000000014, -0.0007160000000000014, -0.003701000000000001, -0.0008500000000000001, -0.006514000000000001, -0.014828000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9f17cde0facb4a859dadd314a8b6394f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5cde454457134ef8a7840415e4472fdd","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -0.0014160000000000006, -0.0014540000000000004, -0.0014729999999999986, -0.0007930000000000003, -0.003415999999999999, -0.000900999999999999, -0.006867, -0.01508], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5cde454457134ef8a7840415e4472fdd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbfa40ceb4d3d4c04b52c8975b33c9476","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0013039999999999996, -0.0013699999999999997, -0.001398, -0.0008129999999999995, -0.003778, -0.0008349999999999989, -0.006696, -0.014379], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbfa40ceb4d3d4c04b52c8975b33c9476","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb6b5b343df984aa6b807d73d27dcd665","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0013670000000000002, -0.0014099999999999998, -0.0014420000000000006, -0.0007970000000000008, -0.0033620000000000004, -0.0008310000000000001, -0.006605, -0.01409], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb6b5b343df984aa6b807d73d27dcd665","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6af608e0e5744b6fbdc24ddcb79aeb47","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.001509, -0.0015239999999999993, -0.0015489999999999983, -0.0008269999999999996, -0.0036249999999999998, -0.0008400000000000005, -0.007097999999999999, -0.014743], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6af608e0e5744b6fbdc24ddcb79aeb47","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td8eedbdb4f664095b6b897f824e644aa","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.001412, -0.0014820000000000007, -0.0014990000000000003, -0.0007900000000000008, -0.003346, -0.0008330000000000004, -0.0065710000000000005, -0.014953000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td8eedbdb4f664095b6b897f824e644aa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89b815272c0e473fa238c18ac565df18","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013750000000000012, -0.0014760000000000016, -0.0015019999999999999, -0.0007230000000000014, -0.00332, -0.0007970000000000008, -0.007287000000000001, -0.015005000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89b815272c0e473fa238c18ac565df18","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc310eb99135a4894aa89b59f9ba5b8fa","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012729999999999998, -0.0014219999999999997, -0.0014409999999999978, -0.0007489999999999997, -0.003331999999999998, -0.0008209999999999988, -0.007252999999999999, -0.015142], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc310eb99135a4894aa89b59f9ba5b8fa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t861c81cd6a664ce8877dc8d25b75bfb1","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0013520000000000008, -0.0014670000000000013, -0.001510000000000001, -0.0007520000000000009, -0.0031520000000000003, -0.0008220000000000015, -0.007092000000000001, -0.015228], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t861c81cd6a664ce8877dc8d25b75bfb1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb78824ab8ad640ad81f927a0b8e40c53","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.0013810000000000003, -0.0014760000000000016, -0.0015189999999999995, -0.0007480000000000021, -0.0032980000000000006, -0.0008190000000000003, -0.006410000000000001, -0.015304000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb78824ab8ad640ad81f927a0b8e40c53","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1edb859635db42de8dff6aa40f41cfd9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0014069999999999985, -0.0014839999999999992, -0.0015969999999999995, -0.000782999999999999, -0.0036889999999999996, -0.0008629999999999992, -0.006872, -0.015403], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1edb859635db42de8dff6aa40f41cfd9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb534b16131ff40e8bc872d69d5642469","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013039999999999996, -0.0013209999999999993, -0.0013629999999999996, -0.0007470000000000011, -0.0035759999999999993, -0.0007790000000000002, -0.006213, -0.014543], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb534b16131ff40e8bc872d69d5642469","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta7f8d7e6d1d441e8be4f0e85b8f7bf72","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0012530000000000006, -0.001288000000000001, -0.0013299999999999996, -0.000733000000000001, -0.0033229999999999996, -0.0007430000000000006, -0.006449, -0.014359], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta7f8d7e6d1d441e8be4f0e85b8f7bf72","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t515b1df62ed94356b53b8b2746450bec","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013190000000000007, -0.0013630000000000014, -0.0014180000000000009, -0.0007820000000000014, -0.0033840000000000016, -0.0008190000000000003, -0.006771000000000001, -0.015272], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t515b1df62ed94356b53b8b2746450bec","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbe446b90f4ab4a319b36ed8be124fce3","vertex_data","graph vertex data",["x", "y"],[[-2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.001230000000000002, -0.0012910000000000005, -0.0013430000000000004, -0.0006510000000000023, -0.00349, -0.0007550000000000022, -0.006719000000000001, -0.015214000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbe446b90f4ab4a319b36ed8be124fce3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taf9b062191844b91ad6b0de8e7702e1d","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -0.0011059999999999993, -0.0012329999999999997, -0.0012709999999999996, -0.0006820000000000003, -0.003174999999999999, -0.000700000000000001, -0.006803, -0.014795], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taf9b062191844b91ad6b0de8e7702e1d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta177188f1def430f8f1c695fa2afcfbe","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012340000000000007, -0.0012780000000000014, -0.0013270000000000018, -0.0007480000000000021, -0.003195, -0.0007530000000000002, -0.007286000000000001, -0.015268], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta177188f1def430f8f1c695fa2afcfbe","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t23c3dfad788b46e3b1bc00515b6f63c9","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0011129999999999994, -0.0012180000000000003, -0.0012560000000000002, -0.0007139999999999994, -0.003089999999999999, -0.0007179999999999999, -0.0070599999999999994, -0.014844], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t23c3dfad788b46e3b1bc00515b6f63c9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td5875b506c30468091da94a23b015a72","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012099999999999993, -0.0012189999999999996, -0.0012849999999999997, -0.0006569999999999996, -0.0034129999999999994, -0.0008039999999999992, -0.0071909999999999995, -0.015385], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td5875b506c30468091da94a23b015a72","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t49a27d36ef314944b52df117646f505d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0012210000000000016, -0.0012280000000000017, -0.0012630000000000002, -0.0006250000000000006, -0.003549, -0.0006690000000000012, -0.006726000000000001, -0.015304000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t49a27d36ef314944b52df117646f505d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89a32677216948dd818a542d933352f5","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0012259999999999997, -0.0012320000000000005, -0.0012560000000000002, -0.000615000000000001, -0.0033970000000000007, -0.0006420000000000019, -0.006594000000000001, -0.015079], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89a32677216948dd818a542d933352f5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t383b92c1079e4148a46d12d1d7c47470","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012849999999999997, -0.0013139999999999992, -0.0013360000000000004, -0.0006700000000000005, -0.003837, -0.0008020000000000006, -0.006477, -0.016233], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t383b92c1079e4148a46d12d1d7c47470","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ted0c48bd4ce54c9eb46468d16726adc8","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -3.469446951953614e-18, -0.0013350000000000029, -0.001356000000000003, -0.0013680000000000012, -0.0007230000000000014, -0.003171000000000002, -0.0009340000000000008, -0.006786000000000002, -0.016391000000000003], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ted0c48bd4ce54c9eb46468d16726adc8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t399b9abc9ead4236a95883bbeadbfcc0","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, -0.001337999999999999, -0.0013579999999999998, -0.0013619999999999986, -0.0007029999999999988, -0.003587999999999999, -0.0009979999999999989, -0.0064329999999999995, -0.016468], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t399b9abc9ead4236a95883bbeadbfcc0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb7b7f5ad45484123ad295ec33050a14f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012770000000000004, -0.001373000000000001, -0.001380000000000001, -0.0007380000000000008, -0.0035130000000000005, -0.0008760000000000018, -0.006981000000000001, -0.016067], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb7b7f5ad45484123ad295ec33050a14f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t977d079bd5d946c29511c6540a82016f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.00136, -0.001413000000000001, -0.0014200000000000011, -0.0006230000000000003, -0.0031190000000000002, -0.0008730000000000005, -0.006366, -0.016187], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t977d079bd5d946c29511c6540a82016f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tab5871b27c7341c1919ed19925c41fbb","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013240000000000005, -0.001431, -0.001438, -0.0006950000000000012, -0.003266999999999999, -0.0008570000000000001, -0.007011, -0.015739], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tab5871b27c7341c1919ed19925c41fbb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t99d826348dad42398df072ce1389e899","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.001200999999999999, -0.0013539999999999993, -0.0013619999999999986, -0.0005429999999999983, -0.0038499999999999993, -0.0010079999999999985, -0.006404999999999999, -0.014941], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t99d826348dad42398df072ce1389e899","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t42659461bc154070bb61f3315892f706","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012310000000000012, -0.0012930000000000007, -0.0013030000000000003, -0.00051, -0.0034730000000000004, -0.0008140000000000005, -0.006672000000000001, -0.014587000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t42659461bc154070bb61f3315892f706","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb072f51a5890449a952d3017efacec2d","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0011960000000000009, -0.0012460000000000006, -0.001261, -0.0004869999999999996, -0.0035390000000000005, -0.000843, -0.006158, -0.014993000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb072f51a5890449a952d3017efacec2d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc71c12788d504d09bdcb25ae46f5a572","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.0011000000000000003, -0.001236000000000001, -0.001243000000000001, -0.0006110000000000004, -0.0034100000000000016, -0.0006990000000000017, -0.007123000000000002, -0.014593000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc71c12788d504d09bdcb25ae46f5a572","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t150299ea0f4648c5b2b2cde30be5c724","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -0.0011630000000000008, -0.0012180000000000003, -0.0012220000000000009, -0.0006540000000000018, -0.0037820000000000006, -0.0007200000000000019, -0.0070100000000000015, -0.014728000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t150299ea0f4648c5b2b2cde30be5c724","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf32325ecde8243a2b6725cb1aa76a461","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.001269000000000001, -0.0011720000000000012, -0.0012729999999999998, -0.0006130000000000007, -0.0033560000000000013, -0.0007960000000000016, -0.006908000000000001, -0.015258], [5.0, 6.0, 8.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 5.5, 7.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf32325ecde8243a2b6725cb1aa76a461","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95c2506925864fd18a0a34dc5dba6bfa","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012300000000000002, -0.001294, -0.0013019999999999993, -0.0007760000000000006, -0.0032379999999999996, -0.0008570000000000001, -0.007032, -0.01555], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95c2506925864fd18a0a34dc5dba6bfa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5a087e56dec142b190837278fe1a0745","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.0000000000027348e-06, -1.0000000000027348e-06, -1.734723475976807e-18, 0.0, -0.0011120000000000019, -0.0011700000000000026, -0.0011760000000000017, -0.0006840000000000023, -0.0031540000000000023, -0.0007330000000000027, -0.006234000000000002, -0.014233], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5a087e56dec142b190837278fe1a0745","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td79f110e6bc54c28adaaddc665c9adc7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -0.0011999999999999997, -0.0012700000000000003, -0.0012790000000000006, -0.0007380000000000008, -0.003367, -0.0007709999999999991, -0.007455, -0.014804], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td79f110e6bc54c28adaaddc665c9adc7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4c6ca3c6286b447f8eb48a762c522256","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011890000000000008, -0.0012240000000000011, -0.001229000000000001, -0.0006890000000000004, -0.0033480000000000003, -0.0007589999999999993, -0.0067150000000000005, -0.01473], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4c6ca3c6286b447f8eb48a762c522256","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95d077fb661646c69037ad424a2d01e6","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0012310000000000012, -0.0012680000000000018, -0.0012720000000000023, -0.0006960000000000022, -0.0033640000000000024, -0.0007530000000000002, -0.007101000000000001, -0.015311000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95d077fb661646c69037ad424a2d01e6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t911e7865eff14599816d9f67be9f25ff","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012040000000000002, -0.001235, -0.001242, -0.0006910000000000006, -0.003504, -0.0007740000000000004, -0.006779, -0.014953000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t911e7865eff14599816d9f67be9f25ff","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t91b737a663284d49829ddc0c61cde022","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.000000000002e-06, -1.000000000001e-06, -0.0011680000000000006, -0.0011780000000000002, -0.0011880000000000016, -0.0006519999999999998, -0.003143, -0.0007510000000000017, -0.006554000000000001, -0.014592], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t91b737a663284d49829ddc0c61cde022","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82f8cceb38524194819e25986cdd9f69","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011789999999999995, -0.0011890000000000008, -0.0011990000000000004, -0.0006340000000000009, -0.003174999999999999, -0.0007650000000000001, -0.007004, -0.014759], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82f8cceb38524194819e25986cdd9f69","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taf8d244fd8e24b9b899ff10fe86edc07","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0011610000000000006, -0.0011780000000000002, -0.0011820000000000008, -0.0007150000000000004, -0.0036110000000000014, -0.0008190000000000003, -0.006599000000000001, -0.014579], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taf8d244fd8e24b9b899ff10fe86edc07","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdbbcfe4b8a5e40ac9ce18c5fb6e2c6b3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0011059999999999993, -0.0011199999999999995, -0.001129999999999999, -0.0006849999999999998, -0.0035600000000000007, -0.0007039999999999998, -0.006804, -0.014158], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdbbcfe4b8a5e40ac9ce18c5fb6e2c6b3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2f6abf1a69ff480b8ea978f10fb9676e","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0011470000000000004, -0.001164, -0.0011780000000000002, -0.0006610000000000019, -0.0032270000000000007, -0.0007039999999999998, -0.006684000000000001, -0.015063], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2f6abf1a69ff480b8ea978f10fb9676e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t16fed0787f68415a99f16e37aef3fb86","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0011359999999999999, -0.0011579999999999993, -0.0011699999999999992, -0.0006890000000000004, -0.00332, -0.0006930000000000009, -0.006494, -0.015028999999999999], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t16fed0787f68415a99f16e37aef3fb86","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td3591da95c6b43c8881bdf8ec1482e9c","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, 0.0, -0.0011690000000000016, -0.0011949999999999999, -0.0012040000000000002, -0.0006650000000000007, -0.003458000000000001, -0.0007950000000000006, -0.006427, -0.015193], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td3591da95c6b43c8881bdf8ec1482e9c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t024bd0b228cd437f8a0ec07ef7cac8b2","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0011859999999999996, -0.0011949999999999999, -0.0011999999999999997, -0.0006959999999999987, -0.003373000000000001, -0.0008680000000000007, -0.006406, -0.016004], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t024bd0b228cd437f8a0ec07ef7cac8b2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t06ad588ca0d945fa9bc53aeaeb07651f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012010000000000007, -0.001210000000000001, -0.0012120000000000013, -0.0006430000000000012, -0.003633000000000001, -0.0007160000000000014, -0.006325000000000001, -0.015948], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t06ad588ca0d945fa9bc53aeaeb07651f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5685b287374c41a9b4d76f4cd816ef5a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001217000000000001, -0.0012270000000000007, -0.0012280000000000017, -0.0006960000000000022, -0.003270000000000002, -0.0008030000000000016, -0.006275000000000001, -0.016507], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5685b287374c41a9b4d76f4cd816ef5a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb3fdd72414d342f3a553e8cb32264367","vertex_data","graph vertex data",["x", "y"],[[-3.469446951953614e-18, -3.469446951953614e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, 0.0, -0.0011940000000000006, -0.0011990000000000021, -0.0012000000000000014, -0.000674000000000001, -0.003550000000000001, -0.0007970000000000026, -0.005826000000000001, -0.015838], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb3fdd72414d342f3a553e8cb32264367","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5da6e81f0c734a7e813189243cc01ada","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0012510000000000021, -0.0012910000000000022, -0.0012930000000000025, -0.0007800000000000012, -0.0033920000000000027, -0.0008210000000000023, -0.006900000000000002, -0.016098], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5da6e81f0c734a7e813189243cc01ada","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ed98ae82d2d493daf93ec179ddac9e2","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999975306e-07, 0.0, -0.0013099999999999987, -0.0013159999999999995, -0.0013179999999999997, -0.0007659999999999993, -0.0031319999999999994, -0.0008319999999999994, -0.006647999999999999, -0.015781], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ed98ae82d2d493daf93ec179ddac9e2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tecc2e191245744faba549210d999d260","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.001165000000000001, -0.0012060000000000005, -0.0012080000000000007, -0.0007489999999999997, -0.003419, -0.0007939999999999996, -0.0068070000000000006, -0.014790000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tecc2e191245744faba549210d999d260","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t84c03ce8de464c7a971eda1a7de95ebd","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011289999999999998, -0.0011649999999999994, -0.001169, -0.0006999999999999992, -0.003398, -0.000785000000000001, -0.006583, -0.014976], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t84c03ce8de464c7a971eda1a7de95ebd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t44bf4b5ad60a4f11bf211e75773eeafd","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.0000000000044695e-06, -0.001277000000000002, -0.0012650000000000022, -0.001297000000000003, -0.0007460000000000019, -0.003511000000000002, -0.0008580000000000011, -0.006427000000000002, -0.015725000000000003], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t44bf4b5ad60a4f11bf211e75773eeafd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t33cd4f64fa6c4dccae4a12a6e0467228","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, -9.999999999975306e-07, -0.0013379999999999972, -0.001336999999999998, -0.0013459999999999982, -0.000677999999999998, -0.003590999999999997, -0.0008479999999999981, -0.006425999999999998, -0.016005], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t33cd4f64fa6c4dccae4a12a6e0467228","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4436aaa8fda04b4f9c45b087f9840932","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.001340000000000001, -0.0013390000000000016, -0.0013460000000000017, -0.0007450000000000009, -0.0034930000000000013, -0.0009220000000000009, -0.006294000000000001, -0.015565], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4436aaa8fda04b4f9c45b087f9840932","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9fadfee9a3a649538eee662d8ea30f45","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013640000000000006, -0.0013769999999999998, -0.0013819999999999995, -0.000674000000000001, -0.003124, -0.0009160000000000001, -0.006836, -0.016128], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9fadfee9a3a649538eee662d8ea30f45","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta4386d9cfbb04d4bac8872f8f9279ff3","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, -0.0013399999999999992, -0.0013799999999999993, -0.0013869999999999993, -0.000678999999999999, -0.0035390000000000005, -0.0008319999999999994, -0.006813, -0.015815], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta4386d9cfbb04d4bac8872f8f9279ff3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5f783791af5e40eb9887dd53cd8bc4e6","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012780000000000014, -0.001289000000000002, -0.001294, -0.0005509999999999994, -0.003471, -0.0007519999999999992, -0.0068980000000000005, -0.014477], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5f783791af5e40eb9887dd53cd8bc4e6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6c5d6ce8979d47ea99a69266d5368662","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012469999999999998, -0.0012490000000000001, -0.001254, -0.0005839999999999995, -0.003549, -0.0006690000000000012, -0.0063820000000000005, -0.014291], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6c5d6ce8979d47ea99a69266d5368662","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c123f137d984676b53dbfed388c0495","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013220000000000003, -0.0013430000000000004, -0.0013490000000000012, -0.0006610000000000001, -0.003680000000000001, -0.0008740000000000015, -0.006549000000000001, -0.014909], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c123f137d984676b53dbfed388c0495","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9455e5a7169e429f8a726bfe64543f16","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0013609999999999994, -0.0013569999999999988, -0.0013670000000000002, -0.0006429999999999995, -0.0033959999999999997, -0.0007620000000000005, -0.006898, -0.015217], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9455e5a7169e429f8a726bfe64543f16","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tddca66b9fcd94671828fecb5ddd27659","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013109999999999997, -0.001301, -0.0013150000000000002, -0.0006040000000000004, -0.003306, -0.0008009999999999996, -0.006448000000000001, -0.015151000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tddca66b9fcd94671828fecb5ddd27659","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t082d9d09680942d9ac2ee6069c95648f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012930000000000007, -0.0012930000000000007, -0.0013000000000000008, -0.0005880000000000017, -0.003077, -0.0006640000000000014, -0.006734, -0.014807], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t082d9d09680942d9ac2ee6069c95648f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb7bee32078234e35a25c1b6fe6e6ce0a","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0012239999999999994, -0.001229000000000001, -0.001243000000000001, -0.0006200000000000008, -0.0032130000000000006, -0.0007090000000000013, -0.006864, -0.014241], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb7bee32078234e35a25c1b6fe6e6ce0a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7d57f44dc9304813aa16fc23006b33fc","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0012180000000000003, -0.0012879999999999992, -0.0012899999999999995, -0.0006149999999999992, -0.0036769999999999997, -0.0007089999999999996, -0.007011999999999999, -0.014913], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7d57f44dc9304813aa16fc23006b33fc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta62d9171b07b49ff9a950ee13ccfd4ff","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012530000000000006, -0.0012970000000000013, -0.0012990000000000015, -0.0007170000000000024, -0.0032060000000000005, -0.0008120000000000002, -0.006809000000000001, -0.015005000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta62d9171b07b49ff9a950ee13ccfd4ff","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc487b24ae52541c084cc0c5bab1cddb6","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0013130000000000017, -0.0013240000000000005, -0.0013260000000000008, -0.0007390000000000001, -0.002955000000000001, -0.0007559999999999997, -0.007383000000000001, -0.015019000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc487b24ae52541c084cc0c5bab1cddb6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t789ddea6bf3d4108b64dab780ed0b5c9","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.0000000000044695e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.001400000000000002, -0.001406000000000001, -0.001408000000000003, -0.000682000000000002, -0.0029500000000000012, -0.0007650000000000018, -0.006706000000000002, -0.015831], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t789ddea6bf3d4108b64dab780ed0b5c9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfac93ec5c8cf4842a26dac9c603c6c03","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999975306e-07, -0.0014769999999999991, -0.0014769999999999991, -0.0014789999999999977, -0.0006449999999999997, -0.003480999999999998, -0.0009099999999999976, -0.006540999999999998, -0.016158], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfac93ec5c8cf4842a26dac9c603c6c03","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9a4f15788f9343c5950a46e96b162d12","vertex_data","graph vertex data",["x", "y"],[[-3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0015400000000000014, -0.0015420000000000017, -0.0015420000000000017, -0.0006510000000000023, -0.0031940000000000007, -0.0008760000000000018, -0.006530000000000001, -0.016427], [5.0, 8.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9a4f15788f9343c5950a46e96b162d12","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc2c480f8e42746f19f5bfc6206f61cdb","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -9.999999999992654e-07, -2.000000000002e-06, -0.0015110000000000002, -0.0015130000000000005, -0.0015130000000000005, -0.0006919999999999999, -0.002836, -0.0008059999999999994, -0.0065520000000000005, -0.015347000000000001], [5.0, 7.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc2c480f8e42746f19f5bfc6206f61cdb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t02c4281d02154a04861b09c600bb1b22","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.001466000000000002, -0.0014670000000000013, -0.0014680000000000006, -0.0007710000000000009, -0.003250000000000001, -0.0008830000000000018, -0.006735000000000001, -0.015258], [7.0, 8.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 5.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t02c4281d02154a04861b09c600bb1b22","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t94eca461fcf24510b597050d6f6a9d9c","vertex_data","graph vertex data",["x", "y"],[[-1.9999999999985307e-06, -1.9999999999985307e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.001540999999999999, -0.0015449999999999995, -0.0015469999999999998, -0.0008190000000000003, -0.0034979999999999994, -0.0010369999999999997, -0.0076159999999999995, -0.016104], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t94eca461fcf24510b597050d6f6a9d9c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t423dc425d795495ab9a64cabdab6a33c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0014009999999999995, -0.0014020000000000005, -0.0014070000000000003, -0.0008009999999999996, -0.0031409999999999997, -0.000876, -0.00643, -0.015355], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t423dc425d795495ab9a64cabdab6a33c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1cafbaf39e4242b9ab266c475e54bae2","vertex_data","graph vertex data",["x", "y"],[[-1.9999999999985307e-06, -1.9999999999985307e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.001377999999999999, -0.001384999999999999, -0.0013939999999999994, -0.0006669999999999992, -0.0034779999999999985, -0.0008619999999999982, -0.006695999999999999, -0.015503], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1cafbaf39e4242b9ab266c475e54bae2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1379e43f3f149fba88f3d32c960b0b1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013299999999999996, -0.0013419999999999994, -0.0013480000000000002, -0.0006269999999999991, -0.003450999999999999, -0.0007759999999999989, -0.0073279999999999994, -0.015347], [7.0, 8.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1379e43f3f149fba88f3d32c960b0b1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfea5c6dff5f346d2a324246e0a0a3d27","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013430000000000004, -0.0013509999999999998, -0.0013550000000000003, -0.0006590000000000016, -0.0037470000000000003, -0.0007150000000000004, -0.0066560000000000005, -0.015433], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfea5c6dff5f346d2a324246e0a0a3d27","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t847666568ca845bfbb108743c7261c87","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -1.9999999999985307e-06, -1.9999999999985307e-06, -1.9999999999985307e-06, -9.999999999975306e-07, -0.0012829999999999994, -0.0013049999999999989, -0.0013059999999999981, -0.0006909999999999989, -0.0035139999999999998, -0.0007169999999999989, -0.006362999999999999, -0.015641], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t847666568ca845bfbb108743c7261c87","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t939dcd38c1f343a98f502b2185d6633e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0012619999999999992, -0.0012659999999999998, -0.0012700000000000003, -0.0006560000000000003, -0.003141999999999999, -0.0007169999999999989, -0.0068059999999999996, -0.014903], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t939dcd38c1f343a98f502b2185d6633e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te25829a15b7442d081a183f3d8b14119","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0013059999999999999, -0.0013089999999999994, -0.001321000000000001, -0.0006680000000000002, -0.003632999999999999, -0.0008229999999999991, -0.00703, -0.014992], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te25829a15b7442d081a183f3d8b14119","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t243016cc266b499daf28abaedc5bda2f","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012729999999999998, -0.0012779999999999996, -0.0012839999999999987, -0.0006870000000000001, -0.0033819999999999996, -0.0007369999999999998, -0.0067139999999999995, -0.014558], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t243016cc266b499daf28abaedc5bda2f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta617e9eded914f67af3e6c7d7b8eeb16","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013190000000000007, -0.0013220000000000003, -0.001327, -0.0007010000000000002, -0.0036970000000000006, -0.0007810000000000004, -0.007289, -0.015247], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta617e9eded914f67af3e6c7d7b8eeb16","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc8c6ecc5bd224e6fa029c77aac09891c","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013109999999999997, -0.0013109999999999997, -0.001321000000000001, -0.000725, -0.003353, -0.0008410000000000015, -0.006753, -0.015202], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc8c6ecc5bd224e6fa029c77aac09891c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7048c49d9a83429e8fc14c3dd8b38ca5","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.0012460000000000006, -0.0012490000000000001, -0.0012540000000000016, -0.0006580000000000006, -0.0034430000000000016, -0.0006890000000000004, -0.006958000000000001, -0.014328], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7048c49d9a83429e8fc14c3dd8b38ca5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t54ae8cf19fdf4530b5393b066ed44416","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.001216, -0.001217000000000001, -0.0012259999999999997, -0.0005970000000000003, -0.003913, -0.0006399999999999999, -0.00646, -0.014246], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t54ae8cf19fdf4530b5393b066ed44416","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9abac0eb7d9d41f18f13edfbc6953da8","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013229999999999995, -0.001337999999999999, -0.001347000000000001, -0.0006549999999999993, -0.0032130000000000006, -0.000723999999999999, -0.007359, -0.015157], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9abac0eb7d9d41f18f13edfbc6953da8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t23919e3d3f244fdcbc404ea4e7b7dee9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.000000000001e-06, -0.0012060000000000005, -0.0012140000000000015, -0.0012190000000000013, -0.0005730000000000006, -0.0035650000000000005, -0.0006050000000000014, -0.006438000000000001, -0.013999000000000001], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t23919e3d3f244fdcbc404ea4e7b7dee9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8d6826e138e247e2a050d8c513d21852","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.001254, -0.0012589999999999997, -0.001268, -0.0005819999999999992, -0.003549, -0.0006639999999999997, -0.0064399999999999995, -0.014244], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8d6826e138e247e2a050d8c513d21852","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfae253d10ce04cb89f6b1c9c6eff5894","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.000000000002e-06, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -0.0012900000000000012, -0.001294, -0.0012990000000000015, -0.0006610000000000019, -0.0036190000000000007, -0.0007640000000000008, -0.006925000000000001, -0.014373], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfae253d10ce04cb89f6b1c9c6eff5894","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc7a6cc23a89e47bc95ae215143c246db","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, -0.0012709999999999996, -0.001275, -0.0012790000000000006, -0.0005760000000000001, -0.0034920000000000003, -0.0006550000000000011, -0.00708, -0.014597], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc7a6cc23a89e47bc95ae215143c246db","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbe1aab585c394e638ed3e1f2cffb9127","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012219999999999991, -0.0012329999999999997, -0.0012359999999999993, -0.0005859999999999997, -0.0036489999999999995, -0.0006189999999999998, -0.006666, -0.014662], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbe1aab585c394e638ed3e1f2cffb9127","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5e92d55013d34fc4b470a4471f57457c","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0012570000000000012, -0.0012990000000000015, -0.001301, -0.0006069999999999999, -0.003734000000000001, -0.000678999999999999, -0.006928, -0.015184], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5e92d55013d34fc4b470a4471f57457c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td86152c9f0ee4536a1e7053a916cb902","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012340000000000007, -0.0012490000000000001, -0.0012510000000000004, -0.000589000000000001, -0.0035930000000000007, -0.000595, -0.007069, -0.014464], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td86152c9f0ee4536a1e7053a916cb902","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta26ae8f29a2241df885b7baceb6471d7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -0.0012110000000000003, -0.0012580000000000004, -0.0012600000000000007, -0.0005669999999999998, -0.0038639999999999994, -0.0007500000000000007, -0.006983, -0.014501], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta26ae8f29a2241df885b7baceb6471d7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tca0d5bfe430d4fa19ddedb9c387194c0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -0.0012770000000000004, -0.001287, -0.0012900000000000012, -0.0007360000000000005, -0.0034730000000000004, -0.0007830000000000007, -0.006273000000000001, -0.014793], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tca0d5bfe430d4fa19ddedb9c387194c0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t52039bb1e5ae422485f2dd0a5f5a52a7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0012810000000000009, -0.0013220000000000003, -0.0013220000000000003, -0.0007740000000000004, -0.0033100000000000004, -0.0007880000000000005, -0.006549000000000001, -0.014863000000000001], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t52039bb1e5ae422485f2dd0a5f5a52a7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te408c425cd5247a49fe279c0e4b2b435","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.0012480000000000008, -0.0012640000000000012, -0.0012640000000000012, -0.0007419999999999996, -0.0033110000000000014, -0.0007610000000000013, -0.006389000000000001, -0.014977], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te408c425cd5247a49fe279c0e4b2b435","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0da45ed2d0c9419aa15d6da2e5170723","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013619999999999986, -0.0013740000000000002, -0.0013749999999999995, -0.0008109999999999992, -0.003443999999999999, -0.0008230000000000008, -0.0066619999999999995, -0.015927], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0da45ed2d0c9419aa15d6da2e5170723","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5e2a699e7b8346c6b32a7545de86a9fc","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0012840000000000004, -0.0012630000000000002, -0.0012840000000000004, -0.0007379999999999991, -0.0038200000000000005, -0.0007640000000000008, -0.006442, -0.014551999999999999], [5.0, 7.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5e2a699e7b8346c6b32a7545de86a9fc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t93a04eae0cd543cc8a777d61fbb4db1e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013190000000000007, -0.001340000000000001, -0.0013430000000000004, -0.0007270000000000002, -0.003384, -0.0007980000000000001, -0.006746, -0.01564], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t93a04eae0cd543cc8a777d61fbb4db1e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c320a47d6404b569576bb778732439e","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.001328000000000001, -0.001303000000000002, -0.0013370000000000014, -0.0009240000000000012, -0.003256000000000002, -0.0009469999999999999, -0.006131000000000001, -0.01498], [5.0, 7.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c320a47d6404b569576bb778732439e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
})();</script></div></div>


And of course you can dress it up a bit nicer with better tip labels, and by adjusting the opacity of edges on the tree. 


```python
tips = [
    "<em>P. przewalskii</em>",
    "<em>P. cyathophylloides</em>",
    "<em>P. cyathophylla</em>",
    "<em>P. superba</em>",
    "<em>P. thamnophila cup.</em>",
    "<em>P. thamnophila tham.</em>",
    "<em>P. rex rockii</em>",
    "<em>P. rex rex</em>",
    "<em>P. rex lipskyana</em>",
]
```


```python
## plot the tree
trees.draw_cloudtree(
    width=400, 
    height=350,
    orient='right',
    edge_style={"opacity": 0.05},
    use_edge_lengths=True,
    tip_labels=tips[::-1],
    );
```


<div class="toyplot" id="t317754a2b83e4386bdd5081f7d0fff49" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="350.0px" id="t875c40612a294cac9514744c4adb1fc9" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 400.0 350.0" width="400.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t35d23a8a843846b9b59134834e536f2e"><clipPath id="ta121a27cd7a94f61b448cdd55602aad3"><rect height="350.0" width="400.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#ta121a27cd7a94f61b448cdd55602aad3)"><g class="toyplot-mark-Text" id="tcb761faf770d41f38ba93ff103a41817"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t82b27e0632f34ee88c37476810cc4e9d"><g class="toyplot-Edges"><path d="M 191.798013787 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.683997182 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.793791177 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.793791177 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.683997182 241.483074887 L 246.793791177 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.280196526 190.697392682 L 218.683997182 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.67023827 139.911710477 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.733321291 134.371454236 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.738357688 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.529915474 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.529915474 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.738357688 93.742908472 L 238.529915474 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.733321291 134.371454236 L 236.738357688 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.67023827 139.911710477 L 203.733321291 134.371454236" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.280196526 190.697392682 L 203.67023827 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.798013787 241.944762907 L 195.280196526 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(238.52991547396724, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(236.73835768789326, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(203.73332129092489, 134.37145423600606)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.79379117733663, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(203.67023827028848, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(218.68399718175348, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(195.28019652564632, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.79801378651661, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcd72c011ab3345bfb91c8a6eac9f8812"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbc5e2cd0e3a64549974277de62b559c3"><g class="toyplot-Edges"><path d="M 194.384417633 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.820564537 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.465222978 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.465222978 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.820564537 241.483074887 L 250.465222978 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.118932454 190.697392682 L 211.820564537 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.751977951 139.911710477 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.890760597 134.371454236 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.034579639 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.67802645 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.67802645 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.034579639 93.742908472 L 239.67802645 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.890760597 134.371454236 L 239.034579639 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.751977951 139.911710477 L 205.890760597 134.371454236" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.118932454 190.697392682 L 205.751977951 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.384417633 241.944762907 L 198.118932454 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(239.6780264495498, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(239.03457963905845, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(205.89076059669, 134.37145423600606)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(250.46522297837555, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(205.75197795128992, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(211.82056453651231, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.11893245428462, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(194.38441763260928, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7cfbda8969f946d0afd96c15140ae4b9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7415ea21fbf44ea993f79eb17d824643"><g class="toyplot-Edges"><path d="M 188.214898214 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.952770634 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.976463691 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.976463691 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.952770634 241.483074887 L 248.976463691 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.239594931 190.697392682 L 213.952770634 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.42777101 139.911710477 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.516087238 134.371454236 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.015922979 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.192555436 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.192555436 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.015922979 93.742908472 L 237.192555436 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.516087238 134.371454236 L 237.015922979 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.42777101 139.911710477 L 200.516087238 134.371454236" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.239594931 190.697392682 L 200.42777101 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.214898214 241.944762907 L 192.239594931 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(237.1925554364754, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(237.01592297869345, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(200.51608723846812, 134.37145423600606)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(248.97646369135632, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(200.42777100957716, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(213.9527706340229, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.23959493097146, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.21489821436865, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tddd1ea5f6aff4281b16cbda6a7141037"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0069e64e743d4b46b8f9b2f203dd942e"><g class="toyplot-Edges"><path d="M 187.028937426 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.397103561 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.307247181 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.307247181 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.397103561 241.483074887 L 252.307247181 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.520448496 190.697392682 L 217.397103561 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.897873636 139.911710477 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.188055531 134.371454236 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.637424855 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.028539583 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.028539583 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.637424855 93.742908472 L 237.028539583 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.188055531 134.371454236 L 236.637424855 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.897873636 139.911710477 L 200.188055531 134.371454236" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.520448496 190.697392682 L 199.897873636 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.028937426 241.944762907 L 191.520448496 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(237.02853958282071, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(236.63742485487504, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(200.18805553115882, 134.37145423600606)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.3072471809586, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(199.89787363623131, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(217.39710356077077, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.52044849571644, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.02893742640418, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1d18b3a590564f11bd961a5ce2eaccd8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta13ebba49f2444398373e0dea8df329b"><g class="toyplot-Edges"><path d="M 187.924716319 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.608834049 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.379658532 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.379658532 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.608834049 241.483074887 L 253.379658532 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.277444743 194.390896842 L 214.608834049 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.919818571 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.474949152 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.331338082 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.545820352 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.545820352 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.331338082 93.742908472 L 237.545820352 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.474949152 119.597437595 L 237.331338082 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.919818571 147.298718797 L 201.474949152 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.277444743 194.390896842 L 200.919818571 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.924716319 243.791514987 L 192.277444743 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(237.54582035203924, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(237.33133808187549, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(201.47494915214153, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.37965853177752, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(200.91981857054114, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(214.60883404864151, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.2774447433533, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.92471631944122, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc6023ac21e1a4a82b14ba0d1bcea219f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb205812098a745d29310a854dd83e842"><g class="toyplot-Edges"><path d="M 183.483671667 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.239664255 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.40489174 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.40489174 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.239664255 241.483074887 L 253.40489174 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.240131423 194.390896842 L 215.239664255 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.09698752 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.324086394 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.691179545 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.956128232 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.956128232 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.691179545 93.742908472 L 235.956128232 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.324086394 119.597437595 L 235.691179545 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.09698752 147.298718797 L 197.324086394 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.240131423 194.390896842 L 197.09698752 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.483671667 243.791514987 L 188.240131423 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(235.95612823200182, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(235.69117954532888, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(197.32408639426589, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(253.40489174003207, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(197.09698751997485, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(215.23966425500561, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.24013142262322, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.48367166663812, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t17164186caee4f21aeb2b075a4f33975"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc3691247630b40c2a9bc3122343a052b"><g class="toyplot-Edges"><path d="M 180.61970253 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.191949621 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.256780764 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.256780764 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.191949621 241.483074887 L 252.256780764 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.354217351 194.390896842 L 218.191949621 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.422267445 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.851231985 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.580918382 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.249598401 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.249598401 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.580918382 93.742908472 L 235.249598401 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.851231985 119.597437595 L 234.580918382 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.422267445 147.298718797 L 194.851231985 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.354217351 194.390896842 L 194.422267445 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.61970253 243.791514987 L 184.354217351 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(235.24959840087402, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(234.58091838212815, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(194.85123198531872, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.25678076444947, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(194.42226744499112, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(218.19194962078947, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(184.35421735142052, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(180.61970252974521, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t10686fefbff64bc098fb1973b286c119"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t89c4ec5f03244a15a411d6269dd96901"><g class="toyplot-Edges"><path d="M 183.773853562 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.818955062 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.307247181 219.322049924 L 261.555218006 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.307247181 219.322049924 L 261.555218006 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.818955062 241.483074887 L 252.307247181 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584068008 194.390896842 L 223.818955062 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.942299997 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.081082642 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.208460315 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.549108626 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.549108626 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.208460315 93.742908472 L 236.549108626 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.081082642 119.597437595 L 236.208460315 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.942299997 147.298718797 L 198.081082642 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584068008 194.390896842 L 197.942299997 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.773853562 243.791514987 L 187.584068008 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.55521800625598, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.55521800625598, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(236.54910862598405, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(236.20846031454744, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.08108264190278, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.3072471809586, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(197.9422999965027, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(223.81895506155703, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.58406800800458, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(183.7738535615656, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3068d8571f6c4f049771b70448dff7c4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t05e383cf12e04a9c8b9bc41dc1310a4c"><g class="toyplot-Edges"><path d="M 185.350929077 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.487098589 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.379658532 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.379658532 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.487098589 241.483074887 L 253.379658532 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.984511066 194.390896842 L 228.487098589 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.809557407 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.011423073 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.851907125 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.028539583 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.028539583 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.851907125 93.742908472 L 237.028539583 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.011423073 119.597437595 L 236.851907125 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.809557407 147.298718797 L 200.011423073 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.984511066 194.390896842 L 199.809557407 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.350929077 243.791514987 L 188.984511066 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(237.02853958282071, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(236.85190712503879, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(200.01142307337682, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.37965853177752, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(199.80955740734032, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(228.48709858865118, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(188.98451106613285, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(185.35092907747577, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdf120f2364fa4124bba0428a4d494240"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t077cb99fa65549aa8ac68b7fb26ec25e"><g class="toyplot-Edges"><path d="M 190.460653749 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.206245024 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.546962659 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.546962659 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.206245024 241.483074887 L 252.546962659 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.412939115 194.390896842 L 229.206245024 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.566017163 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.868815662 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.706547932 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.845330577 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.845330577 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.706547932 93.742908472 L 238.845330577 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.868815662 119.597437595 L 238.706547932 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.566017163 147.298718797 L 204.868815662 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.412939115 194.390896842 L 204.566017163 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.460653749 243.791514987 L 193.412939115 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(238.84533057714927, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(238.70654793174918, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(204.86881566238026, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.54696265937696, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(204.56601716332551, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(229.20624502390621, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.41293911480864, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.4606537490248, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te22e12aea686482b9a50fadddbd3642b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8e030174b4a94ddebbd5c4619f20e5b0"><g class="toyplot-Edges"><path d="M 183.054707126 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.679099433 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.9759272 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.9759272 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.679099433 241.483074887 L 252.9759272 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.574739678 194.390896842 L 231.679099433 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.926395118 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.834790616 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.397709376 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.460792397 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.460792397 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.397709376 93.742908472 L 236.460792397 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.834790616 119.597437595 L 236.397709376 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.926395118 147.298718797 L 199.834790616 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.574739678 194.390896842 L 198.926395118 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.054707126 243.791514987 L 186.574739678 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(236.46079239709309, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(236.39770937645665, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(199.8347906155949, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.9759271997045, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.92639511843063, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(231.67909943285338, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.57473967782207, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.05470712631055, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0273bf1135954076be57a11339db24a5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1f176a2d9043401b8e1073705ef2e552"><g class="toyplot-Edges"><path d="M 185.085980391 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.732854123 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.152559657 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.152559657 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.732854123 241.483074887 L 253.152559657 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.580779734 194.390896842 L 230.732854123 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.310933298 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.345494837 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.066389395 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.129472416 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.129472416 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.066389395 93.742908472 L 237.129472416 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.345494837 119.597437595 L 237.066389395 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.310933298 147.298718797 L 202.345494837 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.580779734 194.390896842 L 201.310933298 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.085980391 243.791514987 L 188.580779734 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(237.12947241583902, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(237.06638939520255, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(202.34549483692393, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(253.15255965748642, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(201.31093329848684, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(230.73285412330728, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.58077973405986, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.08598039080289, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1ed8225ff0d6406c865e53f04c8c87f6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6a69b1dd0ecf469897be000bb8f8911f"><g class="toyplot-Edges"><path d="M 180.342137239 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.524948401 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.730171665 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.730171665 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.524948401 241.483074887 L 250.730171665 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.152351685 194.390896842 L 228.524948401 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.017999621 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.926395118 119.597437595 L 261.555218006 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.514547088 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.565013504 71.5818835098 L 261.555218006 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.565013504 71.5818835098 L 261.555218006 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.514547088 93.742908472 L 235.565013504 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.926395118 119.597437595 L 235.514547088 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.017999621 147.298718797 L 198.926395118 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.152351685 194.390896842 L 198.017999621 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.342137239 243.791514987 L 184.152351685 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.55521800625593, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.55521800625593, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.55521800625593, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(235.56501350405605, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(235.51454708754696, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.92639511843063, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(250.73017166504843, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.0179996212664, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(228.52494840103299, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.15235168538402, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.34213723894501, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbe5db3b59ec64267907f2a9bf4e972e8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0e542732795748b7809f6ad32d2b8904"><g class="toyplot-Edges"><path d="M 181.452398402 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.482131516 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.60071735 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.60071735 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.482131516 241.483074887 L 251.60071735 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.842976638 194.390896842 L 218.482131516 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.304893242 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.339454781 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.031827857 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.13276069 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.13276069 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.031827857 93.742908472 L 236.13276069 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.339454781 119.597437595 L 236.031827857 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.304893242 147.298718797 L 200.339454781 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.842976638 194.390896842 L 199.304893242 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.452398402 243.791514987 L 185.842976638 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(236.13276068978374, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(236.03182785676549, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(200.33945478068617, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(251.60071734983083, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(199.30489324224911, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(218.48213151571696, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(185.84297663843972, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.45239840214577, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf10faed82dfc43198d21e57624edfce8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfdcd868b815c4b23a2fd8388701ae5f3"><g class="toyplot-Edges"><path d="M 183.5846045 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.755872041 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.900227575 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.900227575 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.755872041 241.483074887 L 252.900227575 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991087614 194.390896842 L 223.755872041 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.298316694 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.131012567 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.7762075 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.826673917 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.826673917 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.7762075 93.742908472 L 236.826673917 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.131012567 119.597437595 L 236.7762075 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.298316694 147.298718797 L 202.131012567 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991087614 194.390896842 L 201.298316694 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.5846045 243.791514987 L 186.991087614 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(236.82667391678422, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(236.77620750027509, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(202.13101256676015, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.90022757494083, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(201.29831669435953, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(223.75587204092062, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.99108761402235, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(183.58460449965639, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb0c2a293b5d64420a614bd3c4affbefc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t27d4044631604894bfa0f05ab1aa0773"><g class="toyplot-Edges"><path d="M 178.108998308 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.047126919 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.092764911 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.092764911 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.047126919 241.483074887 L 252.092764911 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.906596151 194.390896842 L 216.047126919 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.261003374 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.017999621 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.959416506 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.12343236 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.12343236 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.959416506 93.742908472 L 235.12343236 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.017999621 119.597437595 L 234.959416506 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.261003374 147.298718797 L 198.017999621 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.906596151 194.390896842 L 197.261003374 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.108998308 243.791514987 L 181.906596151 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(235.12343235960122, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(234.95941650594656, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.0179996212664, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.09276491079484, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(197.26100337362951, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(216.04712691915159, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.90659615072792, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.1089983084162, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1fc3c61039744c58b3ad199ad01fbc6c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t750ed77a4c094b44ae7930479353fd13"><g class="toyplot-Edges"><path d="M 179.660840616 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.302210784 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.316575511 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.316575511 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.302210784 241.483074887 L 253.316575511 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.395355438 194.390896842 L 219.302210784 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.863312098 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.607691741 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.565013504 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.183227106 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.183227106 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.565013504 93.742908472 L 236.183227106 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.607691741 119.597437595 L 235.565013504 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.863312098 147.298718797 L 199.607691741 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.395355438 194.390896842 L 198.863312098 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.660840616 243.791514987 L 183.395355438 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(236.18322710629289, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(235.56501350405608, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(199.60769174130388, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.31657551114114, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.86331209779428, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(219.30221078399026, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(183.39535543774716, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(179.66084061607182, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9c1cc7f85a6c4f3b902aa5b8f6c2c87a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf3c26699f81b4ad88fc9b6ef773c8e8f"><g class="toyplot-Edges"><path d="M 183.042090522 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.41354493 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.742251778 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.742251778 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.41354493 241.483074887 L 254.742251778 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.852304969 194.390896842 L 212.41354493 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.08054615 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.988941647 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.864523729 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.053772791 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.053772791 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.864523729 93.742908472 L 237.053772791 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.988941647 119.597437595 L 236.864523729 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.08054615 147.298718797 L 202.988941647 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.852304969 194.390896842 L 202.08054615 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.042090522 243.791514987 L 186.852304969 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(237.05377279107529, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(236.86452372916608, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(202.98894164741529, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(254.74225177752393, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(202.08054615025105, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(212.41354493049457, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.85230496862229, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.04209052218329, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta30c1d49eb714c1684ad9ec55426f1c0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfcf2f9fe848f44d8a08b714eb516d1ee"><g class="toyplot-Edges"><path d="M 181.944445963 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.776138176 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.284765755 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.284765755 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.776138176 241.483074887 L 255.284765755 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.435957032 194.390896842 L 213.776138176 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.374016319 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.206712192 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.397709376 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.763590896 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.763590896 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.397709376 93.742908472 L 236.763590896 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.206712192 119.597437595 L 236.397709376 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.374016319 147.298718797 L 202.206712192 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.435957032 194.390896842 L 201.374016319 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.944445963 243.791514987 L 186.435957032 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(236.76359089614783, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(236.3977093764567, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(202.20671219152385, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(255.28476575499704, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(201.37401631912329, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(213.77613817624095, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.43595703242201, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.94444596310979, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5362a32003ee43939c9ddf2bc1bd597a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6a994c325e974037bb405584b8a436dc"><g class="toyplot-Edges"><path d="M 182.285094275 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.261609189 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.98525553 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.98525553 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.261609189 241.483074887 L 253.98525553 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.347640804 194.390896842 L 216.261609189 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.118395963 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.228657126 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.599575042 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.671986393 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.671986393 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.599575042 93.742908472 L 237.671986393 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.228657126 119.597437595 L 236.599575042 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.118395963 147.298718797 L 203.228657126 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.347640804 194.390896842 L 202.118395963 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.285094275 243.791514987 L 186.347640804 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(237.67198639331207, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(236.59957504249317, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(203.22865712583362, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(253.98525552988704, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(202.11839596263283, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(216.26160918931541, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.34764080353099, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.28509427454634, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t95d7273982e4463595e2fbf78b44f568"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t40e49f0432a74921a1b85650dac30c73"><g class="toyplot-Edges"><path d="M 179.837473074 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.223759377 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.410931796 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.410931796 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.223759377 241.483074887 L 255.410931796 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.543466413 194.390896842 L 216.223759377 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.260466882 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.673526544 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.413614255 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.233693523 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.233693523 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.413614255 93.742908472 L 236.233693523 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.673526544 119.597437595 L 235.413614255 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.260466882 147.298718797 L 202.673526544 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.543466413 194.390896842 L 201.260466882 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.837473074 243.791514987 L 184.543466413 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(236.23369352280201, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(235.41361425452871, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(202.67352654423328, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(255.41093179626986, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(201.26046688197769, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(216.22375937693357, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.54346641332975, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(179.83747307385377, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te5f3c213a3024aa5b4aa42cc25870e4e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcc998e3b13354a67a9816bbbb345d54c"><g class="toyplot-Edges"><path d="M 176.721171854 243.791514987 L 261.555218006 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.929752716 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.224971008 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.224971008 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.929752716 241.483074887 L 254.224971008 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.944445963 194.390896842 L 220.929752716 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.777747651 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.020214912 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.139337238 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.287448213 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.287448213 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.139337238 93.742908472 L 235.287448213 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.020214912 119.597437595 L 234.139337238 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.777747651 147.298718797 L 205.020214912 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.944445963 194.390896842 L 201.777747651 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.721171854 243.791514987 L 181.944445963 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(235.28744821325591, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(234.13933723767329, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(205.0202149119076, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(254.22497100830543, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(201.77774765119625, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(220.92975271640955, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.94444596310979, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(176.72117185441527, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t800b4aff58f548c09efe97c8c9e56321"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5c98a13bd9f14976b309f8c72b96b444"><g class="toyplot-Edges"><path d="M 173.705803468 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.535886206 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.212354404 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.212354404 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.535886206 241.483074887 L 254.212354404 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.522057971 194.390896842 L 217.535886206 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 209.23416069 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.820564537 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.517835361 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.719701028 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.719701028 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.517835361 93.742908472 L 234.719701028 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.820564537 119.597437595 L 234.517835361 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 209.23416069 147.298718797 L 211.820564537 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.522057971 194.390896842 L 209.23416069 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.705803468 243.791514987 L 179.522057971 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(234.71970102752823, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(234.51783536149173, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(211.82056453651231, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(254.21235440417809, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(209.23416069041963, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(217.53588620617083, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.52205797067171, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(173.70580346799494, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3773bb943cd0445ba9a2e1d741d52dc0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8d9a8f93c0b743968295e97050401273"><g class="toyplot-Edges"><path d="M 169.264758815 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 210.344421854 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.922172509 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.922172509 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 210.344421854 241.483074887 L 253.922172509 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.232412567 194.390896842 L 210.344421854 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 210.811236206 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.72567176 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.827210408 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.965993054 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.965993054 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.827210408 93.742908472 L 232.965993054 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.72567176 119.597437595 L 232.827210408 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 210.811236206 147.298718797 L 213.72567176 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.232412567 194.390896842 L 210.811236206 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.264758815 243.791514987 L 175.232412567 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(232.96599305383609, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(232.82721040843595, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(213.72567175973182, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.92217250925057, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(210.8112362063298, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(210.34442185362036, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(175.23241256739601, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(169.2647588151919, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t255c172357f542aea8d7443ade70d39d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t533ad1708fba44238f620e92358caeb2"><g class="toyplot-Edges"><path d="M 168.217580673 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.328516976 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.212354404 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.212354404 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.328516976 241.483074887 L 254.212354404 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.185234425 194.390896842 L 211.328516976 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.823316319 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.971427294 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.637961347 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.73889418 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.73889418 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.637961347 93.742908472 L 232.73889418 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.971427294 119.597437595 L 232.637961347 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.823316319 147.298718797 L 215.971427294 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.185234425 194.390896842 L 214.823316319 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.217580673 243.791514987 L 174.185234425 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(232.73889417954504, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(232.63796134652677, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(215.97142729438792, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(254.21235440417809, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(214.8233163188053, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(211.32851697554835, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(174.18523442483163, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.21758067262752, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t68c23a6f240b4588836cbc8f96209b8e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0561566573f045a6bb9e51587027e44b"><g class="toyplot-Edges"><path d="M 165.858275701 243.329826967 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.308787332 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.631990614 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.631990614 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.308787332 241.483074887 L 253.631990614 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.431526451 193.467520802 L 217.308787332 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.911632548 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.425625043 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.259463223 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.297313035 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.297313035 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.259463223 86.3559001513 L 232.297313035 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.425625043 115.903933434 L 232.259463223 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.911632548 145.451966717 L 216.425625043 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.431526451 193.467520802 L 214.911632548 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.858275701 243.329826967 L 172.431526451 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(232.29731303509018, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(232.25946322270835, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(216.42562504297007, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.6319906143232, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(214.91163254769629, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(217.30878733187976, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(172.43152645113955, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(165.85827570082589, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6222fea700484c269360292b21ba8d21"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb78db087fdb44ef89a2d685ceba13a90"><g class="toyplot-Edges"><path d="M 162.40132617 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.195237895 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.303958907 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.303958907 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.195237895 241.483074887 L 253.303958907 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.277375419 192.544144762 L 217.195237895 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.662588739 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.454146525 112.210429274 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.262751497 78.9688918306 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.300601309 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.300601309 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.262751497 78.9688918306 L 231.300601309 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.454146525 112.210429274 L 231.262751497 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.662588739 143.605214637 L 215.454146525 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.277375419 192.544144762 L 213.662588739 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.40132617 242.868138947 L 169.277375419 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(231.30060130903496, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(231.2627514966531, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(215.45414652516936, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.30395890701385, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(213.66258873909544, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(217.19523789473425, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.27737541931916, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(162.40132616995075, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta49df074836c487ca4751e6d891e00b3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3277151ded06444c92e96ee43477fb25"><g class="toyplot-Edges"><path d="M 161.795729172 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.290130672 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.622662284 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.622662284 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.290130672 241.483074887 L 252.622662284 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.012426733 192.544144762 L 215.290130672 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.050415193 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.564407688 112.210429274 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.489850371 78.9688918306 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.540316787 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.540316787 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.489850371 78.9688918306 L 231.540316787 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.564407688 112.210429274 L 231.489850371 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.050415193 143.605214637 L 216.564407688 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.012426733 192.544144762 L 215.050415193 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 161.795729172 242.868138947 L 169.012426733 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(231.54031678745329, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(231.48985037094417, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(216.56440768837015, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.6226622841406, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(215.0504151930964, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(215.29013067151476, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.01242673264625, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(161.79572917184126, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te185874a8e3d4ead8fa3cd755ff2fbb7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tac4e037833ce42af9246658cad8dad02"><g class="toyplot-Edges"><path d="M 161.984978234 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.400928326 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.278725699 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.278725699 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.400928326 241.483074887 L 253.278725699 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.372268196 194.390896842 L 212.400928326 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.53917448 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.179333017 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.843115287 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.893581703 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.893581703 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.843115287 93.742908472 L 231.893581703 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.179333017 119.597437595 L 231.843115287 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.53917448 147.298718797 L 218.179333017 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.372268196 194.390896842 L 216.53917448 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 161.984978234 243.791514987 L 167.372268196 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(231.89358170301716, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(231.84311528650804, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(218.17933301666221, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.2787256987593, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(216.53917448011558, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(212.40092832636731, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.37226819609967, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(161.98497823375047, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t91d065be781040c88e3c53031f296099"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8793b0d3d5054b49bc294f0febffbc5b"><g class="toyplot-Edges"><path d="M 161.593863506 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.19906266 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.635278888 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.635278888 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.19906266 241.483074887 L 252.635278888 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.848410879 194.390896842 L 212.19906266 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.406431891 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.333484048 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.666482829 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.716949245 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.716949245 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.666482829 93.742908472 L 231.716949245 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.333484048 119.597437595 L 231.666482829 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.406431891 147.298718797 L 221.333484048 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.848410879 194.390896842 L 218.406431891 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 161.593863506 243.791514987 L 168.848410879 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(231.71694924523521, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(231.66648282872609, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(221.33348404848252, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.63527888826792, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(218.40643189095326, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(212.19906266033075, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.84841087899156, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(161.59386350580473, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6f665360cd7f443388cfb4434026c0cd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2e66521e9f934b7fa273bba3136f9a54"><g class="toyplot-Edges"><path d="M 160.168187239 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.629100184 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.732923447 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.732923447 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.629100184 241.483074887 L 253.732923447 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.176442586 194.390896842 L 204.629100184 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.191949621 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.105848683 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.959952998 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.00713114 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.00713114 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.959952998 93.742908472 L 232.00713114 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.105848683 119.597437595 L 230.959952998 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.191949621 147.298718797 L 225.105848683 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.176442586 194.390896842 L 218.191949621 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 160.168187239 243.791514987 L 169.176442586 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(232.00713114016273, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(230.95995299759835, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(225.10584868253974, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.73292344734142, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(218.19194962078947, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(204.6291001839619, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(169.17644258630088, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(160.16818723942191, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t62a81449c4784772b4bdabfa4fbaa836"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0a7d58f6289748a3ae9f768121c1b624"><g class="toyplot-Edges"><path d="M 156.534605251 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.962098964 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.285302247 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.285302247 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.962098964 241.483074887 L 251.285302247 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.119936114 194.390896842 L 214.962098964 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.25449615 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.654402716 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.527700183 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.679099433 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.679099433 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.527700183 93.742908472 L 231.679099433 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.654402716 119.597437595 L 231.527700183 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.25449615 147.298718797 L 227.654402716 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.119936114 194.390896842 L 222.25449615 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.534605251 243.791514987 L 167.119936114 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(231.67909943285338, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(231.52770018332603, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(227.65440271625062, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(251.2853022466488, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(222.2544961497741, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(214.96209896420544, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.11993611355405, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(156.53460525076486, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t01ca960fed594b0db291a93d24b009b1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t440dc0fd59234d1aa6a30f9c6876284e"><g class="toyplot-Edges"><path d="M 156.004707877 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.640107313 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.546962659 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.546962659 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.640107313 241.483074887 L 252.546962659 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.444679547 194.390896842 L 216.640107313 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.951161159 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.84640356 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.653866225 93.742908472 L 261.555218006 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.729565849 71.5818835098 L 261.555218006 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.729565849 71.5818835098 L 261.555218006 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.653866225 93.742908472 L 231.729565849 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.84640356 119.597437595 L 231.653866225 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.951161159 147.298718797 L 230.84640356 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.444679547 194.390896842 L 225.951161159 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.004707877 243.791514987 L 168.444679547 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625593, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625593, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625593, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(231.72956584936253, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(231.65386622459883, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(230.84640356045281, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.54696265937696, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(225.9511611590676, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(216.64010731313383, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.44467954691859, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(156.00470787741904, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdc7ed83849e341fd9ad602d31a685524"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0b9e085a9a7d47bf9e94871710436b28"><g class="toyplot-Edges"><path d="M 149.885654876 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.848549527 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.783926356 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.783926356 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.848549527 241.483074887 L 249.783926356 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.719493055 194.390896842 L 214.848549527 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.581991365 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.944584611 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.181011816 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.001091084 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.001091084 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.181011816 93.742908472 L 230.001091084 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.944584611 119.597437595 L 229.181011816 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.581991365 147.298718797 L 227.944584611 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.719493055 194.390896842 L 226.581991365 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.885654876 243.791514987 L 165.719493055 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(230.00109108392499, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(229.18101181565163, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(227.94458461117807, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(249.78392635550236, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(226.58199136543169, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(214.8485495270599, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(165.71949305542577, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(149.88565487568752, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tac0c832d29424103b643aa182f1d2683"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc894489227894d55965d15fef650c8ba"><g class="toyplot-Edges"><path d="M 144.91471285 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.501324668 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.739499995 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.739499995 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.501324668 241.483074887 L 251.739499995 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.185770916 194.390896842 L 216.501324668 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.768488645 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.200204968 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.222149902 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.62259296 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.62259296 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.222149902 93.742908472 L 229.62259296 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.200204968 119.597437595 L 228.222149902 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.768488645 147.298718797 L 227.200204968 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.185770916 194.390896842 L 223.768488645 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.91471285 243.791514987 L 170.185770916 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(229.62259296010652, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(228.22214990197827, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(227.20020496766847, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.73949999523091, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(223.76848864504791, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(216.50132466773374, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(170.18577091648342, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(144.9147128495386, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t65344cd7800a4176ab72a9ea5c571c07"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tae594af00427463e89652d532c400594"><g class="toyplot-Edges"><path d="M 151.55104662 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.248456094 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.24416416 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.24416416 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.248456094 241.483074887 L 252.24416416 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.591717539 194.390896842 L 220.248456094 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.822243336 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.029612566 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.496426919 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.237518288 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.237518288 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.496426919 93.742908472 L 231.237518288 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.029612566 119.597437595 L 229.496426919 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.822243336 147.298718797 L 229.029612566 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.591717539 194.390896842 L 222.822243336 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.55104662 243.791514987 L 177.591717539 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(231.23751828839852, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(229.49642691883366, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(229.02961256612429, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.24416416032224, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(222.82224333550178, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(220.24845609353636, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(177.59171753919765, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(151.55104662048868, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9e56233bcf9a40dbad5600fadff68f1e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7ea78ce96384471780f877e8986f3231"><g class="toyplot-Edges"><path d="M 144.372198872 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.690037238 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.143231327 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.143231327 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.690037238 241.483074887 L 252.143231327 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.32180178 194.390896842 L 220.690037238 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.63903433 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.149738551 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.641786112 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.209533298 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.209533298 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.641786112 93.742908472 L 228.209533298 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.149738551 119.597437595 L 227.641786112 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.63903433 147.298718797 L 227.149738551 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.32180178 194.390896842 L 224.63903433 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.372198872 243.791514987 L 167.32180178 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(228.20953329785101, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(227.64178611212333, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(227.14973855115934, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.14323132730397, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(224.63903432983031, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(220.69003723799122, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.32180177959054, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(144.3721988720655, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t312e35812cfe4b99984426501948a9a5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9fb554ebead04be884b8042e6c35d561"><g class="toyplot-Edges"><path d="M 138.492861349 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.397103561 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.941365661 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.941365661 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.397103561 241.483074887 L 251.941365661 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.015178515 194.390896842 L 217.397103561 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.68346069 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.771240427 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.338987613 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.692252529 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.692252529 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.338987613 93.742908472 L 227.692252529 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.771240427 119.597437595 L 227.338987613 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.68346069 147.298718797 L 226.771240427 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.015178515 194.390896842 L 222.68346069 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.492861349 243.791514987 L 172.015178515 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(227.69225252863245, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(227.33898761306853, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(226.77124042734087, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(251.94136566126747, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(222.6834606901017, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(217.39710356077072, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(172.01517851493924, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.49286134875234, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t299cfebf83bb492696260d8e680030b9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t439a56a27b684d90822e7dae95d46de9"><g class="toyplot-Edges"><path d="M 138.480244745 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.395494086 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.76144493 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.76144493 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.395494086 241.483074887 L 252.76144493 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.424413412 194.390896842 L 229.395494086 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.11242523 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.080078983 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.420727294 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.723525793 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.723525793 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.420727294 93.742908472 L 229.723525793 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.080078983 119.597437595 L 229.420727294 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.11242523 147.298718797 L 229.080078983 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.424413412 194.390896842 L 223.11242523 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.480244745 243.791514987 L 178.424413412 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(229.72352579312476, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(229.42072729407005, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(229.08007898263341, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.76144492954074, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(223.11242523042927, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(229.39549408581547, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.42441341159824, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(138.48024474462505, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc03ac59135384d77aad3a37116a7d740"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5667ce474a7d45558b77ccc06d3bdcfe"><g class="toyplot-Edges"><path d="M 140.763850092 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.400461159 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.329192115 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.329192115 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.400461159 241.483074887 L 253.329192115 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.387636583 194.390896842 L 239.400461159 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.089943804 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.855731891 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.918814911 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.637961347 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.637961347 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.918814911 93.742908472 L 232.637961347 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.855731891 119.597437595 L 231.918814911 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.089943804 147.298718797 L 231.855731891 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.387636583 194.390896842 L 226.089943804 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.763850092 243.791514987 L 170.387636583 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(232.63796134652682, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(231.91881491127171, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(231.8557318906353, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.32919211526843, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(226.08994380446768, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(239.40046115874966, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(170.38763658251992, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(140.76385009166302, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6af9450cc3994512920019fe8a962f84"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9fe3ca6d04384b9cb7614b06b258850f"><g class="toyplot-Edges"><path d="M 139.704055345 243.791514987 L 261.555218006 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.5523969 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.026393616 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.026393616 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.5523969 241.483074887 L 253.026393616 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.122687896 194.390896842 L 235.5523969 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.200204968 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.969281328 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.234230014 93.742908472 L 261.555218006 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.385629264 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.385629264 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.234230014 93.742908472 L 232.385629264 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.969281328 119.597437595 L 232.234230014 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.200204968 147.298718797 L 231.969281328 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.122687896 194.390896842 L 227.200204968 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.704055345 243.791514987 L 170.122687896 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625598, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625598, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(232.3856292639812, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(232.23423001445377, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(231.96928132778089, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.02639361621368, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(227.20020496766847, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(235.55239689992879, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.12268789584704, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(139.70405534497138, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t77996e9be8b64a229b1fc7bc4fd8af39"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t36caf7a7014241d8ab364ac786c510cc"><g class="toyplot-Edges"><path d="M 139.350790429 243.329826967 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.110279264 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.518441177 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.518441177 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.110279264 241.483074887 L 253.518441177 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.406829735 193.467520802 L 239.110279264 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.660979264 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.287984705 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.679099433 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.208996806 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.208996806 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.679099433 86.3559001513 L 232.208996806 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.287984705 115.903933434 L 231.679099433 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.660979264 145.451966717 L 231.287984705 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.406829735 193.467520802 L 225.660979264 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.350790429 243.329826967 L 168.406829735 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(232.20899680619922, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(231.67909943285338, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(231.28798470490764, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.51844117717764, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(225.66097926414014, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(239.11027926382215, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(168.40682973453676, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(139.35079042940748, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfaa515a915664358aaebdf4e66960531"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9a76365d280942f88af0d8b106a35b4b"><g class="toyplot-Edges"><path d="M 139.855454594 243.329826967 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.706547932 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.669840427 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.669840427 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.706547932 241.483074887 L 253.669840427 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.378308252 193.467520802 L 238.706547932 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.49696341 145.451966717 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.969281328 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.448712285 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.549645118 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.549645118 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.448712285 86.3559001513 L 232.549645118 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.969281328 115.903933434 L 232.448712285 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.49696341 145.451966717 L 231.969281328 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.378308252 193.467520802 L 225.49696341 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.855454594 243.329826967 L 169.378308252 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(232.54964511763578, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(232.44871228461756, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(231.96928132778089, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.66984042670498, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(225.49696341048545, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(238.70654793174918, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.3783082523374, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(139.85545459449872, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdda80f4c941c44fc9795b99fc3afbfd5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t362ababfb2cb40f9979e6536cc33c644"><g class="toyplot-Edges"><path d="M 142.605874294 243.329826967 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.280335174 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.997872134 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.997872134 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.280335174 241.483074887 L 253.997872134 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.169329547 193.467520802 L 241.280335174 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.297849527 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.60615159 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.060349339 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.18651538 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.18651538 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 235.060349339 86.3559001513 L 235.18651538 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.60615159 115.903933434 L 235.060349339 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.297849527 145.451966717 L 234.60615159 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.169329547 193.467520802 L 228.297849527 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.605874294 243.329826967 L 175.169329547 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(235.18651538023767, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(235.06034933896481, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(234.60615159038267, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(253.99787213401433, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(228.29784952674197, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(241.2803351737146, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(175.1693295467596, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(142.60587429424609, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7ab141a04ab9448d97b8fc50e83c6045"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tff0e4186a3ff42cb9193e7c60b163808"><g class="toyplot-Edges"><path d="M 135.994773732 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.51729887 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.294630577 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.294630577 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.51729887 241.483074887 L 252.294630577 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.005850185 194.390896842 L 238.51729887 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.453073542 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.760839114 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.063637613 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.076254217 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.076254217 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.063637613 93.742908472 L 234.076254217 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.760839114 119.597437595 L 234.063637613 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.453073542 147.298718797 L 233.760839114 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.005850185 194.390896842 L 223.453073542 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.994773732 243.791514987 L 171.005850185 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(234.07625421703688, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(234.06363761290962, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(233.76083911385484, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.29463057683131, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(223.45307354186585, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(238.51729886983995, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(171.00585018475672, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(135.99477373155059, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf2c9c3ba08674cbf92ecd575b6cf88d7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1ede4fc78b624c9c920bd6ad3ff27f3f"><g class="toyplot-Edges"><path d="M 125.232810411 243.329826967 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.422406093 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.130614723 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.130614723 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.422406093 241.483074887 L 252.130614723 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.419446339 193.467520802 L 240.422406093 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.342275887 145.451966717 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.003842866 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.16785872 86.3559001513 L 261.555218006 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.16785872 86.3559001513 L 261.555218006 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.16785872 86.3559001513 L 261.555218006 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.16785872 86.3559001513 L 233.16785872 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.003842866 115.903933434 L 233.16785872 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.342275887 145.451966717 L 233.003842866 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.419446339 193.467520802 L 226.342275887 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 125.232810411 243.329826967 L 168.419446339 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(233.16785871987258, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(233.16785871987258, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(233.00384286621792, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.13061472317668, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(226.34227588701333, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(240.42240609305946, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.41944633866402, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(125.23281041097948, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te3efe269c6d249be8d5a97306ca5fbdd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te5251a377a774176a3b422f87434c09f"><g class="toyplot-Edges"><path d="M 124.576746996 243.329826967 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.7504378 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.228259282 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.228259282 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.7504378 241.483074887 L 253.228259282 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.482529359 193.467520802 L 240.7504378 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.03290084 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.142625512 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.294024761 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.294024761 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.294024761 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.294024761 86.3559001513 L 233.294024761 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.142625512 115.903933434 L 233.294024761 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.03290084 145.451966717 L 233.142625512 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.482529359 193.467520802 L 228.03290084 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 124.576746996 243.329826967 L 168.482529359 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(233.29402476114538, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(233.29402476114538, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(233.14262551161801, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.22825928225012, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(228.03290084006903, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(240.75043780036876, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.48252935930043, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(124.57674699636085, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1829c591c2034fc098937ffd63ca5a77"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t997bb60063a848afbacaf75ce4a739c0"><g class="toyplot-Edges"><path d="M 121.952493338 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.794864161 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.843721102 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.843721102 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.794864161 241.483074887 L 250.843721102 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.791904406 192.544144762 L 238.794864161 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.19362842 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.751510784 112.210429274 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.01645947 78.9688918306 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.054309283 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.054309283 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.01645947 78.9688918306 L 233.054309283 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.751510784 112.210429274 L 233.01645947 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.19362842 143.605214637 L 232.751510784 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.791904406 192.544144762 L 229.19362842 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 121.952493338 242.868138947 L 166.791904406 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(233.05430928272705, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(233.01645947034521, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(232.75151078367233, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(250.84372110219394, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(229.19362841977895, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.79486416064012, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(166.7919044062447, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(121.95249333788632, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9225456439f54cf99aaae324bab88f74"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1d6854d87ca7456db1fb575be0fbc29c"><g class="toyplot-Edges"><path d="M 118.217978516 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.179402341 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.250740708 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.250740708 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.179402341 241.483074887 L 250.250740708 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.863779265 192.544144762 L 241.179402341 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.490386863 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.483273823 112.210429274 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.609439864 78.9688918306 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.697756093 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.697756093 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.609439864 78.9688918306 L 233.697756093 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.483273823 112.210429274 L 233.609439864 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.490386863 143.605214637 L 233.483273823 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.863779265 192.544144762 L 227.490386863 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 118.217978516 242.868138947 L 171.863779265 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(233.69775609321843, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(233.60943986432747, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(233.48327382305465, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.25074070821171, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(227.49038686259593, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(241.17940234069636, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(171.86377926541189, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(118.21797851621102, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb55510ee2243432dabf7123dc1497874"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t54a85352b20f487486f7757e33332395"><g class="toyplot-Edges"><path d="M 115.303542963 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.510722322 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.562867537 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.562867537 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.510722322 241.483074887 L 251.562867537 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.393676639 192.544144762 L 240.510722322 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.629706 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.492602153 112.210429274 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.60615159 78.9688918306 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.883716881 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.883716881 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.60615159 78.9688918306 L 234.883716881 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.492602153 112.210429274 L 234.60615159 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.629706 143.605214637 L 234.492602153 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.393676639 192.544144762 L 223.629706 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.303542963 242.868138947 L 172.393676639 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(234.88371688118289, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(234.60615159038272, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(234.49260215323713, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(251.56286753744899, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(223.6297059996478, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(240.51072232195042, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(172.39367663875771, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(115.30354296280896, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t66efe648d0734889a10301132fbc9701"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0106a2575b5d4aab9bd563c4c80d4ff0"><g class="toyplot-Edges"><path d="M 116.350721105 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.213963879 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.572195868 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.572195868 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.213963879 241.483074887 L 252.572195868 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.427701686 192.544144762 L 242.213963879 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.211142773 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.221076919 112.210429274 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.322009752 78.9688918306 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.473409001 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.473409001 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.322009752 78.9688918306 L 236.473409001 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.221076919 112.210429274 L 236.322009752 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.211142773 143.605214637 L 236.221076919 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.427701686 192.544144762 L 216.211142773 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 116.350721105 242.868138947 L 177.427701686 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(236.47340900122038, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(236.32200975169295, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(236.2210769186747, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.57219586763154, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(216.21114277280631, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(242.21396387913339, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.42770168554298, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(116.35072110537334, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t626547e23d394f538f26bc01ec1bf195"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf78ed82960864282b7c0ae571dcab1c6"><g class="toyplot-Edges"><path d="M 117.309583019 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.847009376 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.916132453 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.916132453 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.847009376 241.483074887 L 251.916132453 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.796871479 192.544144762 L 249.847009376 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.945121103 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.189267163 112.210429274 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.3028166 78.9688918306 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.353283016 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.353283016 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.3028166 78.9688918306 L 238.353283016 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.189267163 112.210429274 L 238.3028166 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.945121103 143.605214637 L 238.189267163 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.796871479 192.544144762 L 223.945121103 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 117.309583019 242.868138947 L 176.796871479 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(238.35328301618526, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(238.30281659967613, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(238.1892671625306, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.91613245301284, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(223.94512110282983, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(249.84700937613871, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(176.79687147917892, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(117.30958301904671, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf440dac48c364c009c30c9017b4ef9e0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0e706fe755ee4a09abdc8110f046ebf3"><g class="toyplot-Edges"><path d="M 112.805455346 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.31436022 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.909555905 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.909555905 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.31436022 241.483074887 L 253.909555905 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.364618665 194.390896842 L 246.31436022 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.459113598 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.164033954 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.214500371 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.3028166 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.3028166 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.214500371 93.742908472 L 238.3028166 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.164033954 119.597437595 L 238.214500371 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.459113598 147.298718797 L 238.164033954 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.364618665 194.390896842 L 225.459113598 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 112.805455346 243.791514987 L 177.364618665 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(238.30281659967616, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(238.21450037078517, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(238.16403395427608, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.90955590512337, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(225.45911359810361, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.31436022049991, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(177.3646186649066, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(112.80545534560723, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9576ee580e9e4022926bce5025d0882e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tba5594fb15e34ba5a63cfdf912aed4f3"><g class="toyplot-Edges"><path d="M 105.563524577 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.273758626 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.543674385 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.543674385 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.273758626 241.483074887 L 253.543674385 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.701978702 192.544144762 L 243.273758626 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.992835737 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.14208902 112.210429274 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.179938832 78.9688918306 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.583670164 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.583670164 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.179938832 78.9688918306 L 237.583670164 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.14208902 112.210429274 L 237.179938832 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.992835737 143.605214637 L 237.14208902 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.701978702 192.544144762 L 220.992835737 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 105.563524577 242.868138947 L 178.701978702 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(237.58367016442111, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(237.17993883234814, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(237.14208901996631, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(253.54367438543224, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(220.99283573704597, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(243.27375862582505, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(178.70197870239843, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(105.56352457654765, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta1ac6d44787047a19d5e0aa07d476f21"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0813dbdb809a47c78b405b8e24145b17"><g class="toyplot-Edges"><path d="M 116.350721105 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.658296806 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.060955155 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.060955155 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.658296806 241.483074887 L 254.060955155 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.008065475 192.544144762 L 245.658296806 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.425088551 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.37522795 112.210429274 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.387844555 78.9688918306 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.564477012 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.564477012 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.387844555 78.9688918306 L 239.564477012 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.37522795 112.210429274 L 239.387844555 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.425088551 143.605214637 L 239.37522795 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.008065475 192.544144762 L 220.425088551 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 116.350721105 242.868138947 L 178.008065475 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(239.5644770124043, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(239.38784455462238, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(239.37522795049509, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(254.06095515465074, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(220.42508855131828, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.65829680588126, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.00806547539793, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(116.35072110537334, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta852b137b4694dec950707add0a9414e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t057788a70d6f40439f49dfbd1175585b"><g class="toyplot-Edges"><path d="M 106.09342195 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.529378982 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.266109095 219.322049924 L 261.555218006 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.266109095 219.322049924 L 261.555218006 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.529378982 241.483074887 L 253.266109095 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.705266976 189.774016641 L 242.529378982 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.087192022 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.239733579 101.129916793 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.239733579 101.129916793 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.227116975 101.129916793 L 238.239733579 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.479449057 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.479449057 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.227116975 101.129916793 L 238.479449057 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.087192022 138.064958396 L 238.227116975 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.705266976 189.774016641 L 223.087192022 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 106.09342195 241.483074887 L 177.705266976 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.55521800625593, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.55521800625593, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.47944905745811, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.23973357903975, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.22711697491246, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.26610909463201, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(223.08719202217472, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(242.52937898231545, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.70526697634318, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(106.0934219498935, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6ef7bcf9b49042bf9c6171ed43e3521e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te2d356498f1843ddbb0a939bdedcb207"><g class="toyplot-Edges"><path d="M 91.0544298302 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.942438645 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.777349808 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.777349808 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.942438645 241.483074887 L 251.777349808 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.608158909 189.774016641 L 243.942438645 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.566622979 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.662658063 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.662658063 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.322009752 101.129916793 L 236.662658063 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.410325981 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.410325981 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.322009752 101.129916793 L 236.410325981 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.566622979 138.064958396 L 236.322009752 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.608158909 189.774016641 L 223.566622979 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 91.0544298302 241.483074887 L 172.608158909 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(236.41032598058393, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(236.66265806312958, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(236.32200975169295, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(251.77734980761278, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(223.56662297901138, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(243.94243864457098, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(172.60815890892147, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(91.054429830173959, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb8d9180185b54052ac3fedb480f90f57"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta9229b67e9234006893718a7d75ed916"><g class="toyplot-Edges"><path d="M 91.5212441829 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.82231266 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.332480389 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.332480389 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.82231266 241.483074887 L 252.332480389 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.841297839 189.774016641 L 245.82231266 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.389990521 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.189267163 101.129916793 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.189267163 101.129916793 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.432270915 101.129916793 L 238.189267163 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.57105356 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.57105356 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.432270915 101.129916793 L 237.57105356 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.389990521 138.064958396 L 237.432270915 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.841297839 189.774016641 L 223.389990521 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 91.5212441829 241.483074887 L 174.841297839 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(237.57105356029382, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(238.18926716253063, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(237.43227091489373, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.33248038921323, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(223.38999052122944, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.82231265953592, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(174.84129783945031, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(91.521244182883379, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7417e092b45c40c0be2ad2cc861f2c3a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t72af349b97be420d9402dc264d29a9e4"><g class="toyplot-Edges"><path d="M 91.0039634137 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.134439489 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.228259282 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.228259282 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.134439489 241.483074887 L 253.228259282 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.558228984 189.774016641 L 247.134439489 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.882574574 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.255638457 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.255638457 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.129472416 101.129916793 L 237.255638457 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.192555436 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.192555436 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.129472416 101.129916793 L 237.192555436 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.882574574 138.064958396 L 237.129472416 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.558228984 189.774016641 L 219.882574574 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 91.0039634137 241.483074887 L 168.558228984 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(237.1925554364754, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(237.25563845711176, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(237.12947241583893, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.22825928225012, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(219.88257457384515, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(247.13443948877318, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(168.5582289840641, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(91.00396341366482, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta5edddda1bc54a0d9e1d3998de44c972"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t721120d8319c4871bc14a73cdbcbad67"><g class="toyplot-Edges"><path d="M 93.1866359277 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.986865005 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.631990614 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.631990614 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.986865005 241.483074887 L 253.631990614 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.935654125 189.774016641 L 241.986865005 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.374622135 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.558436956 101.129916793 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.558436956 101.129916793 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.50797054 101.129916793 L 237.558436956 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.583670164 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.583670164 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.50797054 101.129916793 L 237.583670164 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.374622135 138.064958396 L 237.50797054 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.935654125 189.774016641 L 220.374622135 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 93.1866359277 241.483074887 L 176.935654125 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(237.58367016442111, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(237.55843695616656, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(237.50797053965741, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(253.6319906143232, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(220.37462213480916, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(241.98686500484234, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(176.93565412457903, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(93.186635927684534, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t42105cccdc634ee2a4fa4b5ca927ef69"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7d773fbe6cbe44dd815ca3d28f5097bd"><g class="toyplot-Edges"><path d="M 84.9732266408 241.944762907 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.481664348 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.745540051 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.745540051 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.481664348 241.483074887 L 253.745540051 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.866531048 190.697392682 L 245.481664348 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.374622135 139.911710477 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.814057313 104.823420953 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.851907125 93.742908472 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.889756937 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.889756937 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.851907125 93.742908472 L 236.889756937 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 236.814057313 104.823420953 L 236.851907125 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.374622135 139.911710477 L 236.814057313 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.866531048 190.697392682 L 220.374622135 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 84.9732266408 241.944762907 L 174.866531048 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(236.88975693742063, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(236.85190712503879, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(236.81405731265696, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.74554005146868, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(220.37462213480916, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.48166434809934, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(174.86653104770485, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(84.973226640824279, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0e917465ee684c4780e2d46d19d8add5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t62c7ae7ff828446fb220be33cd4eee8c"><g class="toyplot-Edges"><path d="M 83.7367994364 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.377443241 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.817951402 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.817951402 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.377443241 241.483074887 L 254.817951402 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.480383393 190.697392682 L 246.377443241 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.205102717 139.911710477 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.126184142 104.823420953 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.15141735 93.742908472 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.239733579 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.239733579 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.15141735 93.742908472 L 238.239733579 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.126184142 104.823420953 L 238.15141735 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.205102717 139.911710477 L 238.126184142 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.480383393 190.697392682 L 214.205102717 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 83.7367994364 241.944762907 L 184.480383393 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(238.23973357903975, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(238.15141735014876, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(238.12618414189421, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(254.8179514022876, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(214.20510271656849, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.37744324113629, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(184.48038339269337, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(83.73679943635068, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t43f979fc87424e758152eced304652c4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc05c9bfd4e5048348d41a963b5fc2ec3"><g class="toyplot-Edges"><path d="M 81.5919767347 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.64514371 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.868417819 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.868417819 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.64514371 241.483074887 L 254.868417819 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.929614068 189.774016641 L 249.64514371 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.614874105 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.757014348 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.757014348 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.73178114 101.129916793 L 238.757014348 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.88318039 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.88318039 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.73178114 101.129916793 L 238.88318039 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.614874105 138.064958396 L 238.73178114 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.929614068 189.774016641 L 216.614874105 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 81.5919767347 241.483074887 L 174.929614068 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(238.88318038953111, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(238.75701434825828, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(238.73178114000373, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(254.86841781879673, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(216.61487410487928, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(249.64514371010219, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(174.92961406834124, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(81.59197673471283, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1180a013bd5d4099ba912651be7abfa7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t50f957954e024f8781f67cdd2b4e8037"><g class="toyplot-Edges"><path d="M 82.7022378979 241.021386866 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.957807031 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.086188363 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.086188363 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.957807031 241.483074887 L 254.086188363 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.446894838 188.850640601 L 246.957807031 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.251744367 136.218206316 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.063101121 97.4364126324 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.100950934 108.516925113 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.176650558 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.176650558 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.100950934 108.516925113 L 238.176650558 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.063101121 97.4364126324 L 238.100950934 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.251744367 136.218206316 L 238.063101121 97.4364126324" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.446894838 188.850640601 L 219.251744367 136.218206316" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.7022378979 241.021386866 L 175.446894838 188.850640601" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.1766505584034, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.10095093363967, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.0631011212578, 97.43641263237518)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(254.08618836290538, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(219.25174436748108, 136.2182063161876)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.95780703099126, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(175.4468948375598, 188.85064060136156)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(82.702237897913619, 241.02138686649019)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taa8394cdcdec410ea43774617af7411f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td0b947cc88654ee7854541f772d680a7"><g class="toyplot-Edges"><path d="M 90.1712675413 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.610582172 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.035721946 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.035721946 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.610582172 241.483074887 L 254.035721946 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.768349997 189.774016641 L 248.610582172 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.166179921 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.072429451 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.072429451 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.059812847 101.129916793 L 239.072429451 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.425694367 101.129916793 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.425694367 101.129916793 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.059812847 101.129916793 L 239.425694367 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.166179921 138.064958396 L 239.059812847 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.768349997 189.774016641 L 222.166179921 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 90.1712675413 241.483074887 L 177.768349997 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(239.42569436700421, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(239.07242945144031, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(239.05981284731305, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(254.03572194639617, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(222.16617992088314, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(248.6105821716651, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.76834999697959, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(90.171267541264228, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8ee63662772e4c649fc19bdcf7167542"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8c2a6c763f2b4481b7de939bbc9a719c"><g class="toyplot-Edges"><path d="M 88.3418599428 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.847545868 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.783389864 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.783389864 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.847545868 241.483074887 L 253.783389864 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.03001041 189.774016641 L 245.847545868 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.926464442 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.034579639 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.034579639 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.542532078 101.129916793 L 239.034579639 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.567765286 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.567765286 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.542532078 101.129916793 L 238.567765286 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.926464442 138.064958396 L 238.542532078 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.03001041 189.774016641 L 221.926464442 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.3418599428 241.483074887 L 179.03001041 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(238.5677652863491, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(239.03457963905845, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(238.54253207809452, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.78338986385052, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(221.92646444246481, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.84754586779047, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(179.03001040970773, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(88.341859942808441, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf495590e4d1c48d4b5f123a0b3b2e3b8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t63fa5183a0ab4702abc42fe0d979007c"><g class="toyplot-Edges"><path d="M 84.5568787046 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.967135361 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.237587612 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.237587612 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.967135361 241.483074887 L 254.237587612 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.349250278 190.697392682 L 247.967135361 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.251744367 139.911710477 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.911701872 104.823420953 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.974784892 93.742908472 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.176650558 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.176650558 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.974784892 93.742908472 L 238.176650558 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.911701872 104.823420953 L 237.974784892 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.251744367 139.911710477 L 237.911701872 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.349250278 190.697392682 L 219.251744367 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 84.5568787046 241.944762907 L 174.349250278 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(238.17665055840334, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(237.97478489236684, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(237.91170187173043, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(254.23758761243266, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(219.25174436748108, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(247.9671353611738, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(174.34925027848632, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(84.556878704623983, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td7a4a7ba48684917882aa1ba5a34b758"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc98b27d9c51d44449106468017d879bc"><g class="toyplot-Edges"><path d="M 88.1273776726 241.021386866 L 261.555218006 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.727419883 241.483074887 L 261.555218006 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.073571759 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.073571759 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.727419883 241.483074887 L 254.073571759 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.935117633 188.850640601 L 247.727419883 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.526021384 136.218206316 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.93693508 97.4364126324 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.949551684 108.516925113 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.252350183 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.252350183 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.949551684 108.516925113 L 238.252350183 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.93693508 97.4364126324 L 237.949551684 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.526021384 136.218206316 L 237.93693508 97.4364126324" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.935117633 188.850640601 L 220.526021384 136.218206316" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.1273776726 241.021386866 L 180.935117633 188.850640601" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.55521800625593, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.55521800625593, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(238.25235018316701, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(237.94955168411229, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(237.93693507998501, 97.43641263237518)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(254.07357175877803, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(220.52602138433653, 136.2182063161876)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.72741988275541, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(180.93511763292724, 188.85064060136156)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(88.127377672644656, 241.02138686649019)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc006643559114bb88d98bb74b7983152"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t201b08ab004242c7abf5eea81e9f70c4"><g class="toyplot-Edges"><path d="M 82.3994393989 241.944762907 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.847545868 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.35113705 219.322049924 L 261.555218006 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.35113705 219.322049924 L 261.555218006 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.847545868 241.483074887 L 254.35113705 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.392603655 190.697392682 L 245.847545868 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.765736863 139.911710477 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.268255061 104.823420953 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.318721478 93.742908472 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.381804498 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.381804498 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.318721478 93.742908472 L 237.381804498 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.268255061 104.823420953 L 237.318721478 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.765736863 139.911710477 L 237.268255061 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.392603655 190.697392682 L 220.765736863 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.3994393989 241.944762907 L 180.392603655 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.55521800625593, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.55521800625593, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(237.38180449838461, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(237.31872147774823, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(237.26825506123907, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(254.3511370495782, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(220.76573686275489, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.84754586779047, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.39260365545414, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(82.399439398858874, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc8c6fce6a966446e87b1c78406dee578"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te56b3e92bd0247dbbc2ff2aae6aa072a"><g class="toyplot-Edges"><path d="M 84.102680956 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.396099902 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.960022322 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.960022322 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.396099902 241.483074887 L 253.960022322 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.654264068 189.774016641 L 248.396099902 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.64836266 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.466832453 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.466832453 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.441599245 101.129916793 L 238.466832453 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.668698119 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.668698119 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.441599245 101.129916793 L 238.668698119 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.64836266 138.064958396 L 238.441599245 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.654264068 189.774016641 L 225.64836266 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 84.102680956 241.483074887 L 181.654264068 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(238.66869811936732, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(238.46683245333085, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(238.44159924507628, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(253.96002232163249, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(225.64836266001285, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(248.3960999015014, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.65426406818227, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(84.102680956041866, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t93a02b1400294a54949dab12accd782e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tee9539d6b85b48728ccb8db46c7af9d1"><g class="toyplot-Edges"><path d="M 71.9907409939 239.636322806 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.935325605 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.581524198 219.322049924 L 261.555218006 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.581524198 219.322049924 L 261.555218006 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.935325605 241.483074887 L 253.581524198 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.516554406 186.080512481 L 249.935325605 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.872709752 130.677950076 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.596286769 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.646753185 115.903933434 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.684602997 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.684602997 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.646753185 115.903933434 L 237.684602997 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.596286769 86.3559001513 L 237.646753185 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.872709752 130.677950076 L 237.596286769 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.516554406 186.080512481 L 222.872709752 130.677950076" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.9907409939 239.636322806 L 173.516554406 186.080512481" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.55521800625593, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.55521800625593, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(237.68460299743941, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(237.64675318505749, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(237.5962867685484, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.58152419781402, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(222.87270975201091, 130.67795007564297)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(249.9353256050297, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(173.51655440608573, 186.08051248108927)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(71.990740993851631, 239.63632280635403)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t812f13af66434c7b90b42ea6e83f3a3e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf32674d1febc489d8790baef5c2e11a6"><g class="toyplot-Edges"><path d="M 74.085097279 239.636322806 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.531594273 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.707690239 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.707690239 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.531594273 241.483074887 L 253.707690239 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.115574856 186.080512481 L 249.531594273 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.525484893 130.677950076 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.836002247 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.873852059 115.903933434 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.924318476 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.924318476 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.873852059 115.903933434 L 237.924318476 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.836002247 86.3559001513 L 237.873852059 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.525484893 130.677950076 L 237.836002247 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.115574856 186.080512481 L 224.525484893 130.677950076" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.085097279 239.636322806 L 176.115574856 186.080512481" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(237.92431847585775, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(237.87385205934859, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(237.83600224696676, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.7076902390869, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(224.52548489268477, 130.67795007564297)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(249.53159427295671, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(176.11557485630573, 186.08051248108927)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(74.085097278980342, 239.63632280635403)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t62374b4252f640ba9b44fd7302983b71"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td75751771fa04fe3beb976d4773d3906"><g class="toyplot-Edges"><path d="M 63.5502328327 239.636322806 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.986328513 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.849761158 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.849761158 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.986328513 241.483074887 L 252.849761158 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.774390053 186.080512481 L 245.986328513 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.223222885 130.677950076 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.444887519 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.444887519 115.903933434 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.57105356 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.57105356 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.444887519 115.903933434 L 237.57105356 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 237.444887519 86.3559001513 L 237.444887519 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.223222885 130.677950076 L 237.444887519 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.774390053 186.080512481 L 220.223222885 130.677950076" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.5502328327 239.636322806 L 179.774390053 186.080512481" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(237.57105356029382, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(237.44488751902102, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(237.44488751902102, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.8497611584317, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(220.22322288528179, 130.67795007564297)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.98632851319059, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(179.77439005321733, 186.08051248108927)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(63.550232832700303, 239.63632280635403)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8ee713ef6c0541ba80efc735b3e28d64"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t61dfdc90de474ee8a73d33f099ddd7e4"><g class="toyplot-Edges"><path d="M 76.6336513127 239.636322806 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.418581327 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.922172509 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.922172509 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.418581327 241.483074887 L 253.922172509 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.608158909 186.080512481 L 245.418581327 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.693325512 130.677950076 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.08833433 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.100950934 115.903933434 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.290199996 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.290199996 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.100950934 115.903933434 L 238.290199996 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.08833433 86.3559001513 L 238.100950934 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.693325512 130.677950076 L 238.08833433 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.608158909 186.080512481 L 219.693325512 130.677950076" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.6336513127 239.636322806 L 172.608158909 186.080512481" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(238.2901999955489, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(238.10095093363967, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(238.08833432951238, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.92217250925066, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(219.69332551193597, 130.67795007564297)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.41858132746296, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(172.60815890892147, 186.08051248108927)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(76.633651312691214, 239.63632280635403)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0b316b83192c4d69945c2529d260efea"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8df5b1e45b8d446e98d565a9ef876076"><g class="toyplot-Edges"><path d="M 83.8629654776 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.774598025 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.590852528 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.590852528 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.774598025 241.483074887 L 254.590852528 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.396428421 189.774016641 L 248.774598025 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.150275043 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.334089864 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.384556281 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.447639301 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.447639301 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.384556281 86.3559001513 L 240.447639301 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.334089864 101.129916793 L 240.384556281 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.150275043 138.064958396 L 240.334089864 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.396428421 189.774016641 L 223.150275043 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 83.8629654776 241.483074887 L 175.396428421 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(240.44763930131401, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(240.3845562806776, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(240.33408986416845, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(254.59085252799656, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(223.15027504281113, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(248.77459802531979, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(175.39642842105067, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(83.86296547762349, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t00c850a116454ee2885318af09b7ce27"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcaf768e758af42148a37ab18f7fa7535"><g class="toyplot-Edges"><path d="M 88.1526108809 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.187657688 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.111421571 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.111421571 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.187657688 241.483074887 L 254.111421571 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.207715851 189.774016641 L 250.187657688 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.516693054 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.927070258 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.990153279 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.040619695 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.040619695 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.990153279 86.3559001513 L 241.040619695 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.927070258 101.129916793 L 240.990153279 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.516693054 138.064958396 L 240.927070258 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.207715851 189.774016641 L 219.516693054 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.1526108809 241.483074887 L 171.207715851 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(241.04061969529621, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(240.99015327878712, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(240.92707025815068, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(254.11142157115984, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(219.51669305415402, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(250.18765768757532, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(171.20771585079319, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(88.152610880899203, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4e84e794a03a4943939e08d9d9c34469"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2587c8999088436bb1c62d71e9db588b"><g class="toyplot-Edges"><path d="M 86.7900176352 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.348385267 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.581524198 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.581524198 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.348385267 241.483074887 L 253.581524198 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.740365006 192.544144762 L 251.348385267 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.798083111 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.368651403 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.419117819 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.456967631 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.456967631 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.419117819 108.516925113 L 241.456967631 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.368651403 112.210429274 L 241.419117819 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.798083111 143.605214637 L 241.368651403 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.740365006 192.544144762 L 214.798083111 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 86.7900176352 242.868138947 L 174.740365006 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(241.45696763149652, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(241.41911781911469, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(241.36865140260554, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.58152419781402, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(214.79808311055072, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.34838526728524, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(174.74036500643203, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(86.790017635152807, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta4f2dc53cc244f1e8bb3d3861ab9548d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t65ba82cf87444f2da3375e0693c784cc"><g class="toyplot-Edges"><path d="M 80.1789170725 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.843721102 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.307247181 219.322049924 L 261.555218006 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.307247181 219.322049924 L 261.555218006 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.843721102 241.483074887 L 252.307247181 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.41454859 189.774016641 L 250.843721102 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.17329296 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.548572134 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.624271759 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.636888363 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.636888363 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.624271759 86.3559001513 L 240.636888363 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.548572134 101.129916793 L 240.624271759 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.17329296 138.064958396 L 240.548572134 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.41454859 189.774016641 L 216.17329296 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.1789170725 241.483074887 L 181.41454859 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(240.63688836322325, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(240.62427175909596, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(240.54857213433226, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.3072471809586, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(216.17329296042448, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(250.84372110219402, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.41454858976394, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(80.178917072457324, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t006aee98cff249dc89f7fdd0d001a0e0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2dd7f66e6807432f96e7af87c60d5d1e"><g class="toyplot-Edges"><path d="M 70.8426300183 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.544210877 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.426836674 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.426836674 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.544210877 241.483074887 L 254.426836674 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.604334143 192.544144762 L 249.544210877 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.125041835 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.135512472 112.210429274 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.539243804 108.516925113 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.551860408 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.551860408 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.539243804 108.516925113 L 239.551860408 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.135512472 112.210429274 L 239.539243804 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.125041835 143.605214637 L 239.135512472 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.604334143 192.544144762 L 223.125041835 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.8426300183 242.868138947 L 177.604334143 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038327, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(239.55186040827709, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(239.53924380414978, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(239.13551247207675, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(254.42683667434193, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(223.12504183455658, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(249.54421087708397, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(177.60433414332496, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(70.84263001826902, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t504641a318d04faab49ebb47d44b6fb5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t47e0cc05cdb94c30b7fd308e5c0a4d00"><g class="toyplot-Edges"><path d="M 61.8848410879 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.320400277 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.720306843 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.720306843 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.320400277 241.483074887 L 253.720306843 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.03001041 192.544144762 L 248.320400277 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.157388082 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.719164536 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.832713973 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.921030202 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.921030202 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.832713973 108.516925113 L 238.921030202 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.719164536 112.210429274 L 238.832713973 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.157388082 143.605214637 L 238.719164536 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.03001041 192.544144762 L 217.157388082 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.8848410879 242.868138947 L 179.03001041 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.92103020191291, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.83271397302195, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(238.71916453587644, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.7203068432141, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(217.15738808235238, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(248.32040027673764, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(179.03001040970773, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(61.88484108789914, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta2d79d8106ec4607a26e4b508b42ed46"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta24aeb67b5a140a185491ecc1f36a49a"><g class="toyplot-Edges"><path d="M 72.798203658 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.2255075 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.275437425 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.275437425 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.2255075 241.483074887 L 254.275437425 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.219795963 192.544144762 L 250.2255075 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.50407645 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.813520821 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.889220446 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.028003091 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.028003091 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.889220446 108.516925113 L 241.028003091 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.813520821 112.210429274 L 240.889220446 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.50407645 143.605214637 L 240.813520821 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.219795963 192.544144762 L 219.50407645 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.798203658 242.868138947 L 175.219795963 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(241.02800309116896, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(240.88922044576884, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(240.81352082100517, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(254.2754374248145, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(219.50407645002676, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.22550749995716, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(175.21979596326872, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(72.798203657997647, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te5be8648de194f5c96056bce61bc3e08"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3228d372cff04bdd9058f95e51c416f2"><g class="toyplot-Edges"><path d="M 63.9161143524 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.459182922 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.584812472 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.584812472 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.459182922 241.483074887 L 252.584812472 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.780430109 192.544144762 L 248.459182922 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.589640897 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.993441553 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.119607594 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.258390239 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.258390239 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.119607594 108.516925113 L 240.258390239 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.993441553 112.210429274 L 240.119607594 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.589640897 143.605214637 L 239.993441553 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.780430109 192.544144762 L 216.589640897 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.9161143524 242.868138947 L 181.780430109 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(240.25839023940483, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(240.11960759400466, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(239.99344155273189, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.58481247175877, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(216.58964089662473, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(248.45918292213776, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.7804301094551, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(63.916114352391482, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2b43e64fd89a4e23afcef15f0888e42e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="taddcd459956c48b2905307f6aaf14ad9"><g class="toyplot-Edges"><path d="M 60.206832739 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.212890896 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.925460783 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.925460783 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.212890896 241.483074887 L 252.925460783 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.970215663 192.544144762 L 250.212890896 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.67413236 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.599038551 112.210429274 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.662121571 108.516925113 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.788287613 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.788287613 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.662121571 108.516925113 L 240.788287613 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.599038551 112.210429274 L 240.662121571 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.67413236 143.605214637 L 240.599038551 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.970215663 192.544144762 L 221.67413236 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.206832739 242.868138947 L 177.970215663 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038327, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038327, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038327, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038327, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038327, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038327, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(240.78828761275059, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(240.6621215714778, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(240.59903855084139, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.92546078319543, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(221.67413235991921, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.21289089582987, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.97021566301612, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(60.206832738970732, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3f006b9cc3dc47119070b7eeeb76b092"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t015c2ea397e3439e9ac9ad1a767a58c3"><g class="toyplot-Edges"><path d="M 51.1228777673 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.058739864 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.783926356 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.783926356 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.058739864 241.483074887 L 249.783926356 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.701978702 192.544144762 L 247.058739864 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.258320915 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.807480765 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.009346431 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.034579639 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.034579639 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.009346431 108.516925113 L 239.034579639 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.807480765 112.210429274 L 239.009346431 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.258320915 143.605214637 L 238.807480765 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.701978702 192.544144762 L 217.258320915 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 51.1228777673 242.868138947 L 178.701978702 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(239.03457963905845, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(239.0093464308039, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(238.8074807647674, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(249.7839263555023, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(217.25832091537063, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.05873986400951, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(178.70197870239843, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(51.122877767328035, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8e2fc8ffcdd243be8d7975c42791755d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td48b205889044b8ebf23f5b119a9d28b"><g class="toyplot-Edges"><path d="M 50.0 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.752653091 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.777349808 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.777349808 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.752653091 241.483074887 L 251.777349808 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.313615757 192.544144762 L 247.752653091 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.730638833 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.021963035 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.135512472 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.829425699 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.829425699 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.135512472 108.516925113 L 239.829425699 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.021963035 112.210429274 L 239.135512472 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.730638833 143.605214637 L 239.021963035 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.313615757 192.544144762 L 223.730638833 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 242.868138947 L 181.313615757 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(239.82942569907723, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(239.13551247207675, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(239.02196303493122, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.77734980761278, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(223.73063883266607, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(247.75265309100999, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.31361575674569, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(50.0, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t82b35d5a0ae8400fa89a7531f91547d4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t25408a8845ea4a8f964b63a05d74563a"><g class="toyplot-Edges"><path d="M 57.6961285176 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.670376918 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.979215474 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.979215474 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.670376918 241.483074887 L 251.979215474 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.254357502 192.544144762 L 249.670376918 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.857341366 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.614943429 112.210429274 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.753726074 108.516925113 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.447639301 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.447639301 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.753726074 108.516925113 L 240.447639301 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.614943429 112.210429274 L 239.753726074 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.857341366 143.605214637 L 239.614943429 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.254357502 192.544144762 L 219.857341366 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 57.6961285176 242.868138947 L 176.254357502 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(240.44763930131404, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(239.75372607431356, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(239.61494342891348, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(251.9792154736493, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(219.8573413655906, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(249.67037691835677, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(176.25435750170581, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(57.696128517641696, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t943524d41ca94d3cb74a4782694c70de"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0fb1e99a6942414aa77711c4d97e88aa"><g class="toyplot-Edges"><path d="M 66.9440993429 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.86895431 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.710978513 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.710978513 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.86895431 241.483074887 L 252.710978513 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.582925701 192.544144762 L 250.86895431 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.528773167 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.094374386 112.210429274 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.207923823 108.516925113 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.343418194 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.343418194 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.207923823 108.516925113 L 241.343418194 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.094374386 112.210429274 L 240.207923823 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.528773167 143.605214637 L 240.094374386 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.582925701 192.544144762 L 223.528773167 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.9440993429 242.868138947 L 172.582925701 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(241.34341819435099, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(240.20792382289565, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(240.09437438575014, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.71097851303162, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(223.52877316662955, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(250.86895431044854, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(172.58292570066692, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(66.94409934293904, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5f3bb5ed9641418a91e3711e3b477b5b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t57979dbf5445415b8a9aa4c9453c2d77"><g class="toyplot-Edges"><path d="M 65.4553400559 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.503072791 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.499784517 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.499784517 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.503072791 241.483074887 L 251.499784517 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.657552342 192.544144762 L 250.503072791 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.948409377 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.195307219 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.283623448 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.037331421 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.037331421 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.283623448 108.516925113 L 242.037331421 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.195307219 112.210429274 L 240.283623448 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.948409377 143.605214637 L 240.195307219 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.657552342 192.544144762 L 222.948409377 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.4553400559 242.868138947 L 180.657552342 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(242.03733142135147, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(240.28362344765938, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(240.19530721876839, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(251.49978451681258, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(222.94840937677458, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(250.50307279075739, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(180.65755234212708, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(65.45534005591982, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf4895668db6143ec845788e66815f0d0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcef46735146549dabb2c5c998868d9dc"><g class="toyplot-Edges"><path d="M 68.9753726074 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.238124104 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.562867537 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.562867537 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.238124104 241.483074887 L 251.562867537 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.472128046 192.544144762 L 250.238124104 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.592392679 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.7504378 112.210429274 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.192018945 108.516925113 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.213963879 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.213963879 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.192018945 108.516925113 L 242.213963879 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.7504378 112.210429274 L 241.192018945 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.592392679 143.605214637 L 240.7504378 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.472128046 192.544144762 L 219.592392679 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.9753726074 242.868138947 L 175.472128046 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(242.21396387913339, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(241.19201894482362, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(240.75043780036876, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(251.56286753744899, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(219.59239267891772, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.23812410408445, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(175.47212804581434, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(68.975372607431339, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t84790e6018e645769b63e284d3d9d8d8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t525fb85d7ed145e6964fb5ee2176558d"><g class="toyplot-Edges"><path d="M 76.8481335829 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.556827481 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.789966412 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.789966412 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.556827481 241.483074887 L 251.789966412 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.560980766 192.544144762 L 249.556827481 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.222686394 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.885932172 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.226580483 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.560652247 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.560652247 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.226580483 108.516925113 L 244.560652247 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.885932172 112.210429274 L 242.226580483 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.222686394 143.605214637 L 241.885932172 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.560980766 192.544144762 L 224.222686394 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.8481335829 242.868138947 L 171.560980766 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.56065224680776, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(242.22658048326073, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(241.88593217182409, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(251.7899664117401, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(224.22268639363006, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(249.55682748121123, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(171.56098076635712, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(76.848133582854999, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t42bc7ec8ec6e4cb990c71233e9c8c465"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdcefff4e9fc942299277884d5a4ba381"><g class="toyplot-Edges"><path d="M 70.5398315192 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.616622228 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.932037331 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.932037331 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.616622228 241.483074887 L 250.932037331 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.93947889 192.544144762 L 250.616622228 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.061422322 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.633600089 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.961631797 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.718628044 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.718628044 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.961631797 108.516925113 L 242.718628044 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.633600089 112.210429274 L 241.961631797 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.061422322 143.605214637 L 241.633600089 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.93947889 192.544144762 L 227.061422322 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.5398315192 242.868138947 L 171.93947889 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(242.71862804422466, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(241.9616317965878, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(241.63360008927847, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.93203733108498, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(227.06142232226836, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.61662222790284, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(171.93947889017556, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(70.539831519214246, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t90e29f02a42646a2aef273812b41cbde"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t209d7bc7c894476a84ed1fbb6379b3b1"><g class="toyplot-Edges"><path d="M 69.9847009376 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.376906749 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.032970164 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.032970164 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.376906749 241.483074887 L 251.032970164 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.727748402 192.544144762 L 250.376906749 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.311539114 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.671449902 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.885932172 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.945726919 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.945726919 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.885932172 108.516925113 L 242.945726919 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.671449902 112.210429274 L 241.885932172 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.311539114 143.605214637 L 241.671449902 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.727748402 192.544144762 L 220.311539114 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.9847009376 242.868138947 L 174.727748402 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(242.94572691851576, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(241.88593217182409, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(241.67144990166031, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.03297016410315, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(220.31153911417275, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(250.37690674948453, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(174.72774840230474, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(69.984700937613866, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc83beaaf639a461681d9fc7c97b46203"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1732d06924644976acf2c9ecf3b44343"><g class="toyplot-Edges"><path d="M 68.8870563785 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.682993522 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.130614723 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.130614723 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.682993522 241.483074887 L 252.130614723 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.223084237 189.774016641 L 249.682993522 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.677957126 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.7246681 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.7246681 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.012098213 101.129916793 L 244.7246681 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.113031046 130.677950076 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.113031046 130.677950076 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.012098213 101.129916793 L 242.113031046 130.677950076" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.677957126 138.064958396 L 242.012098213 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.223084237 189.774016641 L 216.677957126 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.8870563785 241.483074887 L 174.223084237 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(242.11303104611514, 130.67795007564297)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.7246681004624, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(242.01209821309689, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.13061472317668, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(216.67795712551566, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(249.68299352248411, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(174.22308423721347, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(68.887056378540365, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te4894535bc784a218d58db8f3333d535"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3bcc9472336f4f6e8e9c726f7702e393"><g class="toyplot-Edges"><path d="M 75.8135720444 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.070819976 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.433413222 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.433413222 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.070819976 241.483074887 L 252.433413222 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.889012474 194.390896842 L 251.070819976 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.623129452 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.639640146 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.690106562 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.020890052 71.5818835098 L 261.555218006 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.020890052 71.5818835098 L 261.555218006 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.690106562 93.742908472 L 247.020890052 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.639640146 119.597437595 L 243.690106562 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.623129452 147.298718797 L 243.639640146 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.889012474 194.390896842 L 225.623129452 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.8135720444 243.791514987 L 171.889012474 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(247.02089005162765, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(243.69010656202536, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(243.63964014551624, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.43341322223145, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(225.62312945175825, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(251.07081997648501, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(171.88901247366641, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(75.81357204441791, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t159001c5836c4ee0a976bfe978ffa340"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t147f33592b2245f59a9652ed7774fbf1"><g class="toyplot-Edges"><path d="M 75.5360067536 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.411468288 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.152559657 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.152559657 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.411468288 241.483074887 L 253.152559657 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.544539397 194.390896842 L 251.411468288 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.898479452 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.879355624 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.942438645 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.471799526 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.471799526 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.942438645 93.742908472 L 248.471799526 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.879355624 119.597437595 L 243.942438645 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.898479452 147.298718797 L 243.879355624 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.544539397 194.390896842 L 218.898479452 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.5360067536 243.791514987 L 176.544539397 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(248.47179952626507, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(243.94243864457098, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(243.87935562393457, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.15255965748651, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(218.89847945191727, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.41146828792162, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(176.54453939663333, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(75.536006753617741, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tec362eee71b54eb1844df4d11a97b883"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb3cb396f91b1494aba5c094b5c61ec1b"><g class="toyplot-Edges"><path d="M 75.081809005 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.436701496 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.9759272 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.9759272 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.436701496 241.483074887 L 252.9759272 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.513266132 194.390896842 L 251.436701496 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.541389771 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.589173729 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.664873354 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.648968476 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.648968476 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.664873354 93.742908472 L 244.648968476 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.589173729 119.597437595 L 243.664873354 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.541389771 147.298718797 L 243.589173729 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.513266132 194.390896842 L 223.541389771 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.081809005 243.791514987 L 174.513266132 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.64896847569878, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(243.66487335377082, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(243.58917372900711, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.97592719970456, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(223.54138977075684, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(251.4367014961762, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(174.51326613214098, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(75.081809005035595, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t095ac03255a64672908c76a129c32753"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t125e11ff89dc49a988c3ad8666731997"><g class="toyplot-Edges"><path d="M 65.8969212004 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.556827481 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.17175281 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.17175281 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.556827481 241.483074887 L 251.17175281 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.72499662 194.390896842 L 249.556827481 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.528773167 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.441062753 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.579845399 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.034043147 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.034043147 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.579845399 93.742908472 L 243.034043147 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.441062753 119.597437595 L 242.579845399 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.528773167 147.298718797 L 242.441062753 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.72499662 194.390896842 L 223.528773167 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.8969212004 243.791514987 L 171.72499662 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(243.03404314740675, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(242.57984539882457, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(242.44106275342452, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(251.17175280950332, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(223.52877316662955, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(249.55682748121126, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(171.72499662001178, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(65.896921200374678, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta46216daadeb4164b827b5073684dbf7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t57771ed550084c499c6748c984e9db5c"><g class="toyplot-Edges"><path d="M 74.5014452152 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.856337706 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.546962659 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.546962659 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.856337706 241.483074887 L 252.546962659 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.395891929 194.390896842 L 250.856337706 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.886399339 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.967671853 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.08122129 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.699434892 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.699434892 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.08122129 93.742908472 L 244.699434892 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.967671853 119.597437595 L 244.08122129 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.886399339 147.298718797 L 243.967671853 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.395891929 194.390896842 L 214.886399339 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.5014452152 243.791514987 L 179.395891929 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.69943489220788, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.08122128997104, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(243.96767185282553, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.54696265937696, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(214.88639933944174, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(250.85633770632123, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(179.39589192939891, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(74.501445215180638, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t40053c93b3a141649f9476648e203143"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdd30131c768b47e288fae7d04b764aa6"><g class="toyplot-Edges"><path d="M 71.3220609751 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.212890896 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.575484142 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.575484142 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.212890896 241.483074887 L 251.575484142 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.942230672 194.390896842 L 250.212890896 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.482131516 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.996193335 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.235908813 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.71533977 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.71533977 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.235908813 93.742908472 L 243.71533977 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.996193335 119.597437595 L 243.235908813 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.482131516 147.298718797 L 242.996193335 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.942230672 194.390896842 L 218.482131516 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.3220609751 243.791514987 L 174.942230672 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.71533977027994, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.23590881344322, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(242.99619333502488, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.57548414157628, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(218.48213151571696, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.21289089582987, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(174.94223067246855, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(71.322060975105714, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5694bc43ee314c57a7407a39151878ad"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tccba7921f1d9426e8d3bd511c65591a9"><g class="toyplot-Edges"><path d="M 80.1663004683 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.045586768 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.323152059 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.323152059 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.045586768 241.483074887 L 251.323152059 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.099669978 194.390896842 L 251.045586768 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.914920822 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.942438645 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.29570356 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.128399433 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.128399433 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.29570356 93.742908472 L 245.128399433 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.942438645 119.597437595 L 244.29570356 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.914920822 147.298718797 L 243.942438645 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.099669978 194.390896842 L 213.914920822 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.1663004683 243.791514987 L 177.099669978 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.12839943253545, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(244.29570356013488, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(243.94243864457098, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.32315205903063, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(213.91492082164106, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.04558676823049, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(177.09966997823366, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(80.166300468330036, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te627144576314a6cb02afd3e4b273b65"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t42df7a625c3a420cb9d412603b799541"><g class="toyplot-Edges"><path d="M 83.8124990611 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.096053185 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.525017725 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.525017725 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.096053185 241.483074887 L 251.525017725 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.247780954 194.390896842 L 251.096053185 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.163428139 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.387308063 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.791039395 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.333553373 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.333553373 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.791039395 93.742908472 L 244.333553373 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.387308063 119.597437595 L 243.791039395 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.163428139 147.298718797 L 243.387308063 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.247780954 194.390896842 L 219.163428139 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 83.8124990611 243.791514987 L 178.247780954 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.33355337251672, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(243.79103939504361, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(243.38730806297059, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.52501772506716, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(219.16342813859015, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.09605318473962, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(178.24778095381629, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(83.81249906111438, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t914cc01f08b24f52b6760e7f468d3961"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t057de8b2cfa9490fa40fb209feef5b62"><g class="toyplot-Edges"><path d="M 75.573856566 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.982503748 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.146519601 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.146519601 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.982503748 241.483074887 L 251.146519601 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.027795119 194.390896842 L 250.982503748 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.845261253 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.037331421 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.352746525 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.541995586 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.541995586 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.352746525 93.742908472 L 242.541995586 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.037331421 119.597437595 L 242.352746525 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.845261253 147.298718797 L 242.037331421 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.027795119 194.390896842 L 215.845261253 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.573856566 243.791514987 L 172.027795119 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038327, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038327, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038327, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(242.54199558644274, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(242.35274652453353, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(242.03733142135152, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(251.14651960124868, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(215.84526125311513, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(250.98250374759405, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(172.0277951190665, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(75.573856565999577, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf0e9236a2ef84e55850c89c48f986dd8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t664823fb33e84232a9aed90e26295796"><g class="toyplot-Edges"><path d="M 72.9243696993 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.070819976 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.613333954 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.613333954 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.070819976 241.483074887 L 251.613333954 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.676745494 194.390896842 L 251.070819976 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.365293805 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.668161628 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.882643898 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.765806187 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.765806187 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.882643898 93.742908472 L 243.765806187 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.668161628 119.597437595 L 242.882643898 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.365293805 147.298718797 L 242.668161628 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.676745494 194.390896842 L 219.365293805 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.9243696993 243.791514987 L 178.676745494 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(243.76580618678904, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(242.88264389787935, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(242.66816162771556, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.61333395395818, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(219.36529380462667, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.07081997648501, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.67674549414386, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(72.924369699270457, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta373977e32304efb93e2c7b52cd5c560"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0f065b747f4d4c1590697e61c0a107c0"><g class="toyplot-Edges"><path d="M 72.2683062847 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.525017725 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.45864643 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.45864643 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.525017725 241.483074887 L 252.45864643 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.643256939 194.390896842 L 251.525017725 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.693325512 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.630311815 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.958343523 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.232620539 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.232620539 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.958343523 93.742908472 L 244.232620539 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.630311815 119.597437595 L 242.958343523 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.693325512 147.298718797 L 242.630311815 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.643256939 194.390896842 L 219.693325512 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.2683062847 243.791514987 L 169.643256939 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.23262053949847, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(242.95834352264302, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(242.6303118153337, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.45864643048597, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(219.69332551193597, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(251.52501772506716, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(169.64325693901029, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(72.268306284651814, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tae7eed8fbe3b47eeb33abb025bc3c8cf"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4c26fc4e7b384a41bc1f21ba8e5b9571"><g class="toyplot-Edges"><path d="M 70.5398315192 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.222219226 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.130614723 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.130614723 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.222219226 241.483074887 L 252.130614723 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.072221479 194.390896842 L 251.222219226 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.541926262 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.399924667 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.639640146 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.51951416 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.51951416 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.639640146 93.742908472 L 245.51951416 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.399924667 119.597437595 L 243.639640146 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.541926262 147.298718797 L 243.399924667 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.072221479 194.390896842 L 219.541926262 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.5398315192 243.791514987 L 170.072221479 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.51951416048118, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(243.63964014551624, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(243.39992466709791, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.13061472317668, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(219.54192626240862, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(251.22221922601241, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.07222147933794, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(70.539831519214275, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t42d28a84f99b430bb9052ba8e4256a08"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcca53b70b1d94266bb45170470de8abc"><g class="toyplot-Edges"><path d="M 69.4548035643 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.209602622 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.092764911 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.092764911 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.209602622 241.483074887 L 252.092764911 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.103494744 194.390896842 L 251.209602622 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.812915005 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.529378982 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.07189296 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.522802434 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.522802434 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.07189296 93.742908472 L 244.522802434 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.529378982 119.597437595 L 243.07189296 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.812915005 147.298718797 L 242.529378982 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.103494744 194.390896842 L 221.812915005 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.4548035643 243.791514987 L 172.103494744 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.52280243442593, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(243.07189295978856, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(242.52937898231545, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.09276491079481, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(221.81291500531924, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(251.20960262188507, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(172.1034947438302, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(69.454803564268047, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="teba7edcf88d4413aac80c973c2a91030"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t48937f11cf084f27884df124b4ab16c8"><g class="toyplot-Edges"><path d="M 68.4959416506 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.247452434 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.143231327 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.143231327 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.247452434 241.483074887 L 252.143231327 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.708018759 194.390896842 L 251.247452434 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.970890803 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.415829545 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.958343523 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.156920915 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.156920915 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.958343523 93.742908472 L 244.156920915 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.415829545 119.597437595 L 242.958343523 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.970890803 147.298718797 L 242.415829545 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.708018759 194.390896842 L 219.970890803 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.4959416506 243.791514987 L 180.708018759 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(244.1569209147348, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(242.95834352264302, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(242.41582954516994, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.14323132730394, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(219.97089080273619, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.24745243426699, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.70801875863617, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(68.495941650594645, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4ad22b90ed3649b4adc5af86977f1adc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t56617da54115430ea4e426f807219e19"><g class="toyplot-Edges"><path d="M 67.246897842 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.692321853 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.701650183 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.701650183 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.692321853 241.483074887 L 251.701650183 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.879147652 194.390896842 L 250.692321853 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.037798589 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.431734423 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.85741069 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.828889207 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.828889207 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.85741069 93.742908472 L 243.828889207 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.431734423 119.597437595 L 242.85741069 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.037798589 147.298718797 L 241.431734423 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.879147652 194.390896842 L 215.037798589 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.246897842 243.791514987 L 174.879147652 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(243.82888920742548, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(242.8574106896248, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(241.43173442324201, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.70165018284908, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(215.03779858896911, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(250.69232185266659, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(174.87914765183214, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(67.2468978419938, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t721538b2950249dd90a08d1b45a5b980"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5fcc290628074be280e6857d4775c707"><g class="toyplot-Edges"><path d="M 78.0971773915 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.752116599 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.155847931 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.155847931 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.752116599 241.483074887 L 252.155847931 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.193489772 194.390896842 L 251.752116599 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.463474855 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.384019789 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.913917162 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.128399433 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.128399433 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.913917162 93.742908472 L 245.128399433 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.384019789 119.597437595 L 244.913917162 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.463474855 147.298718797 L 244.384019789 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.193489772 194.390896842 L 216.463474855 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.0971773915 243.791514987 L 183.193489772 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.12839943253545, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.91391716237169, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.38401978902584, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.15584793143123, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(216.4634748553519, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.7521165993582, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(183.19348977171066, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(78.097177391455858, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t976453ee82be4ae6bf09380b9244839f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t52674c4b4f2b48dab6926f4865b61bc2"><g class="toyplot-Edges"><path d="M 80.4186325509 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.206314348 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.332480389 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.332480389 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.206314348 241.483074887 L 252.332480389 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.215971198 194.390896842 L 252.206314348 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.6554757 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.800367725 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.330265099 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.771846243 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.771846243 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.330265099 93.742908472 L 245.771846243 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.800367725 119.597437595 L 245.330265099 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.6554757 147.298718797 L 244.800367725 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.215971198 194.390896842 L 219.6554757 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.4186325509 243.791514987 L 180.215971198 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.7718462430268, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.33026509857191, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(244.80036772522615, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.33248038921315, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(219.65547569955413, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.20631434794035, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.21597119767222, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(80.418632550875657, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2b7b621ad4854837ab641c99ef4ddb04"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta322ac2344fa45f2a94014bb6b84c238"><g class="toyplot-Edges"><path d="M 68.8996729827 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.247452434 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.714266787 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.714266787 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.247452434 241.483074887 L 251.714266787 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.153424669 194.390896842 L 251.247452434 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.885862848 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.690106562 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.384019789 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.939150371 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.939150371 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.384019789 93.742908472 L 244.939150371 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.690106562 119.597437595 L 244.384019789 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.885862848 147.298718797 L 243.690106562 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.153424669 194.390896842 L 218.885862848 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.8996729827 243.791514987 L 176.153424669 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.93915037062624, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.38401978902584, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(243.69010656202536, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.71426678697637, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(218.88586284778995, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.24745243426699, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(176.15342466868756, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(68.899672982667653, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t25e2cf4c62494bdf8860980f6aba7de6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta5cdd802da4844fb82f9c5fe38cc2e3f"><g class="toyplot-Edges"><path d="M 69.631436022 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.054915098 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.367041928 219.322049924 L 261.555218006 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.367041928 219.322049924 L 261.555218006 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.054915098 241.483074887 L 253.367041928 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.809488083 194.390896842 L 252.054915098 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.54850281 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.636351872 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.292415286 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.062028138 71.5818835098 L 261.555218006 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.062028138 71.5818835098 L 261.555218006 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.292415286 93.742908472 L 246.062028138 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.636351872 119.597437595 L 245.292415286 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.54850281 147.298718797 L 244.636351872 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.809488083 194.390896842 L 217.54850281 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.631436022 243.791514987 L 176.809488083 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.55521800625593, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.55521800625593, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.55521800625593, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.55521800625593, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.06202813795426, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.29241528619008, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.63635187157146, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.36704192765023, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(217.54850281029812, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.05491509841298, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(176.80948808330621, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(69.631436022049968, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9127a283ec1e432eba97d7c47edfe2e3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td314e28bb8884fad925bfd29b3bb1fb2"><g class="toyplot-Edges"><path d="M 74.9177931514 243.791514987 L 261.555218006 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.748828325 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.9759272 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.9759272 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.748828325 241.483074887 L 252.9759272 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.749693337 194.390896842 L 252.748828325 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.52273311 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.544747369 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.024178326 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.62648705 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.62648705 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.024178326 93.742908472 L 247.62648705 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.544747369 119.597437595 L 246.024178326 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.52273311 147.298718797 L 245.544747369 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.749693337 194.390896842 L 221.52273311 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.9177931514 243.791514987 L 175.749693337 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625593, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(247.62648704973719, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.02417832557242, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.54474736873576, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.9759271997045, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(221.52273311039178, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.74882832541346, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(175.74969333661457, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(74.91779315138092, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7eb6f162842044099330c03a5f69f8f2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te1f19840b91b47d38247a050528bff0d"><g class="toyplot-Edges"><path d="M 68.9501393992 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.080148307 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.143231327 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.143231327 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.080148307 241.483074887 L 252.143231327 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.655873543 194.390896842 L 252.080148307 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.270401028 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.838217538 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.45643114 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.011561721 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.011561721 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.45643114 93.742908472 L 246.011561721 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.838217538 119.597437595 L 245.45643114 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.270401028 147.298718797 L 244.838217538 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.655873543 194.390896842 L 221.270401028 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.9501393992 243.791514987 L 169.655873543 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.01156172144516, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.45643113984477, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.83821753760793, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.14323132730394, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(221.27040102784616, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.08014830666755, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(169.6558735431376, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(68.950139399176791, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t56b9198b6cda40bba31073cca4a3fe40"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0ca2b84414be4852a9375677fe206e4e"><g class="toyplot-Edges"><path d="M 74.2995795491 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.521729451 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.572195868 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.572195868 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.521729451 241.483074887 L 252.572195868 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.507226076 194.390896842 L 252.521729451 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.595144461 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.733996431 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.213427387 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.538170821 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.538170821 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.213427387 93.742908472 L 247.538170821 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.733996431 119.597437595 L 246.213427387 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.595144461 147.298718797 L 245.733996431 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.507226076 194.390896842 L 222.595144461 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.2995795491 243.791514987 L 172.507226076 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(247.53817082084623, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.21342738748166, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.73399643064496, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.57219586763154, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(222.59514446121074, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.52172945112241, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(172.50722607590325, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(74.299579549144141, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta34ff2384cc546a09de1c89ea23edf81"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4339045e494f42868872b80abee0a7d2"><g class="toyplot-Edges"><path d="M 67.4739967163 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.436701496 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.291342303 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.291342303 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.436701496 241.483074887 L 253.291342303 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.854450935 194.390896842 L 251.436701496 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.519981328 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.368114911 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.200810783 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.31436022 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.31436022 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.200810783 93.742908472 L 246.31436022 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.368114911 119.597437595 L 246.200810783 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.519981328 147.298718797 L 245.368114911 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.854450935 194.390896842 L 218.519981328 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.4739967163 243.791514987 L 170.854450935 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(246.31436022049991, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(246.2008107833544, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.36811491095381, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(253.29134230288659, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(218.51998132809879, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.4367014961762, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(170.85445093522935, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(67.473996716284859, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf23af0a60a864deeac7503b389e888d1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3e51dfd476c448b29d535d1a3cceaad1"><g class="toyplot-Edges"><path d="M 68.4959416506 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.139943053 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.695073635 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.695073635 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.139943053 241.483074887 L 253.695073635 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.721171854 194.390896842 L 253.139943053 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.804123167 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.645680202 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.087261346 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.175577575 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.175577575 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.087261346 93.742908472 L 246.175577575 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.645680202 119.597437595 L 246.087261346 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.804123167 147.298718797 L 245.645680202 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.721171854 194.390896842 L 216.804123167 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.4959416506 243.791514987 L 176.721171854 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.17557757509979, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.08726134620881, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.645680201754, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.69507363495958, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(216.80412316678851, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.13994305335913, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(176.72117185441522, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(68.495941650594645, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta32ecf95a26a4e37a9e08ec7e1adbba9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t89ee5fc60dca465b974cc0970fa56e81"><g class="toyplot-Edges"><path d="M 71.3346775792 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.480591365 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.821239676 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.821239676 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.480591365 241.483074887 L 253.821239676 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.386563599 194.390896842 L 253.480591365 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.721846994 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.733996431 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.03679493 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.112494554 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.112494554 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.03679493 93.742908472 L 246.112494554 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.733996431 119.597437595 L 246.03679493 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.721846994 147.298718797 L 245.733996431 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.386563599 194.390896842 L 218.721846994 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.3346775792 243.791514987 L 178.386563599 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.11249455446341, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.03679492969968, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.73399643064496, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(253.82123967623238, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(218.72184699413532, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(253.48059136479574, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(178.38656359921637, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(71.334677579232988, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7b2fbc3636a54ea2b1f71c701f202742"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc2108a6764d24e64bf81a82c5103a697"><g class="toyplot-Edges"><path d="M 56.7751164164 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.461934704 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.127326449 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.127326449 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.461934704 241.483074887 L 253.127326449 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.862706282 194.390896842 L 251.461934704 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.170541178 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.7246681 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.002233391 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.368114911 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.368114911 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.002233391 93.742908472 L 245.368114911 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.7246681 119.597437595 L 245.002233391 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.170541178 147.298718797 L 244.7246681 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.862706282 194.390896842 L 213.170541178 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 56.7751164164 243.791514987 L 179.862706282 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.36811491095381, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.00223339126265, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.72466810046245, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.12732644923193, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(213.17054117813146, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.46193470443075, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.86270628210835, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(56.775116416350144, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7ccef836fa4441d582cf6589e531a5a6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t31b48c62c73747f0b8e56bb621dcee64"><g class="toyplot-Edges"><path d="M 54.7816929642 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.79654296 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.45864643 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.45864643 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.79654296 241.483074887 L 252.45864643 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.964175607 194.390896842 L 249.79654296 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.573199527 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.320936768 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.472336018 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.737284705 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.737284705 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.472336018 93.742908472 L 244.737284705 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.320936768 119.597437595 L 244.472336018 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.573199527 147.298718797 L 244.320936768 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.964175607 194.390896842 L 221.573199527 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 54.7816929642 243.791514987 L 175.964175607 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.73728470458968, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.47233601791677, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.32093676838943, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.45864643048597, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(221.57319952690088, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(249.79654295962956, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(175.96417560677833, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(54.781692964239653, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb5ed52b30a8147d6a33c448d67b43bcc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t853390842ad2450ba505cdd8a990fcbd"><g class="toyplot-Edges"><path d="M 53.8102144464 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.989080295 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.710978513 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.710978513 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.989080295 241.483074887 L 252.710978513 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.417836864 194.390896842 L 248.989080295 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.312075606 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.396636393 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.44710281 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.699434892 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.699434892 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.44710281 93.742908472 L 244.699434892 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.396636393 119.597437595 L 244.44710281 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.312075606 147.298718797 L 244.396636393 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.417836864 194.390896842 L 216.312075606 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 53.8102144464 243.791514987 L 180.417836864 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.69943489220788, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.44710280966225, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.39663639315313, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.71097851303162, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(216.31207560582453, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(248.98908029548357, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.41783686370871, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(53.810214446439012, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taa85671232ea477cbac40a2e6bf08483"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t66e0fd2d37734f149cc3053308a0911b"><g class="toyplot-Edges"><path d="M 58.8694727015 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.528305999 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.269397369 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.269397369 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.528305999 241.483074887 L 252.269397369 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.503937802 194.390896842 L 250.528305999 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.258320915 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.169537519 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.257853748 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.469047744 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.469047744 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.257853748 93.742908472 L 245.469047744 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.169537519 119.597437595 L 244.257853748 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.258320915 147.298718797 L 244.169537519 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.503937802 194.390896842 L 217.258320915 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.8694727015 243.791514987 L 173.503937802 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.46904774397206, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.25785374775305, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.16953751886206, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.26939736857673, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(217.25832091537063, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(250.52830599901191, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(173.50393780195844, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(58.86947270147887, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t93e255dd17d34403a45be59e0344ece0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t73ce80bd3c9545acac67271df435a554"><g class="toyplot-Edges"><path d="M 57.3554802062 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.566155811 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.720306843 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.720306843 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.566155811 241.483074887 L 253.720306843 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.26314934 194.390896842 L 250.566155811 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.229262942 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.664873354 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.753189583 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.421869601 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.421869601 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.753189583 93.742908472 L 244.421869601 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.664873354 119.597437595 L 243.753189583 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.229262942 147.298718797 L 243.664873354 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.26314934 194.390896842 L 222.229262942 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 57.3554802062 243.791514987 L 181.26314934 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(244.42186960140768, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.75318958266178, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.66487335377079, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.72030684321416, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(222.22926294151955, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.5661558113938, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.26314934023659, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(57.355480206205101, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4d76223c074c4a799f3c9103603046f8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcc98be573d98433cb3b710e8afe0e088"><g class="toyplot-Edges"><path d="M 63.0077188552 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.768021477 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.811911346 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.811911346 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.768021477 241.483074887 L 252.811911346 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.125439678 194.390896842 L 250.768021477 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.362005531 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.437774479 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.526090708 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.87606735 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.87606735 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.526090708 93.742908472 L 244.87606735 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.437774479 119.597437595 L 243.526090708 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.362005531 147.298718797 L 243.437774479 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.125439678 194.390896842 L 220.362005531 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.0077188552 243.791514987 L 173.125439678 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(244.87606734998982, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(243.5260907083707, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(243.43777447947974, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.81191134604984, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(220.36200553068193, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(250.76802147743027, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(173.12543967814003, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(63.007718855227225, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t314bd2d9c16e42d5bfafcd273c80074c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t992486234ae54faa890be4ce791875b9"><g class="toyplot-Edges"><path d="M 73.0757689488 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.862914254 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.729635173 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.729635173 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.862914254 241.483074887 L 254.729635173 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.771101779 194.390896842 L 248.862914254 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.006525324 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.396636393 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.497569226 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.427909658 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.427909658 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.497569226 93.742908472 L 246.427909658 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.396636393 119.597437595 L 244.497569226 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.006525324 147.298718797 L 244.396636393 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.771101779 194.390896842 L 213.006525324 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.0757689488 243.791514987 L 180.771101779 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.4279096576455, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.49756922617138, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.39663639315313, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(254.72963517339667, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(213.0065253244768, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(248.86291425421078, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.77110177927258, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(73.075768948797844, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc70545e317684b0cb24e22325cac98d1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfebfb6e6354e43ff949d3cd8f94eb907"><g class="toyplot-Edges"><path d="M 77.5420468099 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.310535455 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.14598311 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.14598311 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.310535455 241.483074887 L 255.14598311 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.402468477 194.390896842 L 251.310535455 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.76298508 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.141016037 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.267182078 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.049411534 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.049411534 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.267182078 93.742908472 L 246.049411534 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.141016037 119.597437595 L 245.267182078 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.76298508 147.298718797 L 245.141016037 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.402468477 194.390896842 L 217.76298508 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.5420468099 243.791514987 L 177.402468477 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.04941153382697, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.26718207793553, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.14101603666273, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(255.14598310959695, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(217.7629850804619, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(251.31053545490337, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(177.40246847728844, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(77.542046809855478, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6c5758d3b9534b2bb847a914fd335d85"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t497459553beb4cb8b35face70f4618f8"><g class="toyplot-Edges"><path d="M 72.4197055342 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.944653935 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.436165005 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.436165005 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.944653935 241.483074887 L 255.436165005 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.887402999 194.390896842 L 250.944653935 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.930289208 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.67091341 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.860162472 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.490992678 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.490992678 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.860162472 93.742908472 L 246.490992678 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.67091341 119.597437595 L 245.860162472 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.930289208 147.298718797 L 245.67091341 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.887402999 194.390896842 L 216.930289208 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.4197055342 243.791514987 L 183.887402999 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(246.49099267828183, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.86016247191776, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.67091341000855, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(255.43616500452441, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(216.93028920806134, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(250.94465393521222, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(183.88740299871111, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(72.419705534179172, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6f0a6e2306ac47b1bf6a34b99ce83c65"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t132edc863c794cc4b8748d1992a58856"><g class="toyplot-Edges"><path d="M 77.4663471851 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.76144493 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.871706093 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.871706093 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.76144493 241.483074887 L 253.871706093 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.712380016 194.390896842 L 252.76144493 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.55783114 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.898012284 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.986328513 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.702186675 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.702186675 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.986328513 93.742908472 L 247.702186675 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.898012284 119.597437595 L 245.986328513 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.55783114 147.298718797 L 245.898012284 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.712380016 194.390896842 L 218.55783114 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.4663471851 243.791514987 L 171.712380016 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(247.70218667450087, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.98632851319059, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.8980122842996, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.87170609274153, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(218.5578311404806, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.76144492954074, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(171.71238001588446, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(77.466347185091763, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t149b1bcc5d80458aaa70b5922c515761"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3904f4a52469467a81459ce8cb228ec2"><g class="toyplot-Edges"><path d="M 75.7631056279 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.496496243 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.329192115 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.329192115 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.496496243 241.483074887 L 253.329192115 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.138056282 194.390896842 L 252.496496243 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.864454405 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.162960971 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.213427387 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.907340614 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.907340614 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.213427387 93.742908472 L 246.907340614 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.162960971 119.597437595 L 246.213427387 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.864454405 147.298718797 L 246.162960971 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.138056282 194.390896842 L 213.864454405 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.7631056279 243.791514987 L 173.138056282 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.90734061448214, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.21342738748166, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.16296097097253, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.32919211526843, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(213.86445440513191, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.49649624286781, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(173.13805628226726, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(75.763105627908772, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t08d5f80766e84468b924b4f064c82077"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t99d8cb1b8d294950b9ca03e3724f64a7"><g class="toyplot-Edges"><path d="M 69.0763054404 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.537634329 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.846472884 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.846472884 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.537634329 241.483074887 L 253.846472884 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.424949903 189.774016641 L 251.537634329 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.239127763 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.793791177 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.793791177 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.51951416 101.129916793 L 246.793791177 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.569980577 130.677950076 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.569980577 130.677950076 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.51951416 101.129916793 L 245.569980577 130.677950076" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.239127763 138.064958396 L 245.51951416 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.424949903 189.774016641 L 219.239127763 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.0763054404 241.483074887 L 174.424949903 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.5699805769903, 130.67795007564297)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.79379117733663, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.51951416048118, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.84647288448696, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(219.23912776335382, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(251.53763432919442, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(174.42494990325, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(69.076305440449602, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t58412c5f651c4952a80ccc64e85b2e77"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t273d1c6fcdd745b590e8e5f1ef696980"><g class="toyplot-Edges"><path d="M 65.3922570353 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.768021477 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.789966412 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.789966412 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.768021477 241.483074887 L 251.789966412 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.860490991 192.544144762 L 250.768021477 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.72788705 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.153632641 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.254565474 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.062028138 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.062028138 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.254565474 108.516925113 L 246.062028138 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.153632641 112.210429274 L 245.254565474 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.72788705 143.605214637 L 245.153632641 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.860490991 192.544144762 L 220.72788705 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.3922570353 242.868138947 L 172.860490991 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.06202813795426, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.25456547380824, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.15363264079002, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.7899664117401, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(220.72788705037306, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.76802147743027, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(172.86049099146712, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(65.392257035283421, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te0970d96f8c349d5b021125eace20fb6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdd349d4f27664e95940fe8841b13aa3e"><g class="toyplot-Edges"><path d="M 82.0083246709 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.332480389 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.950693991 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.950693991 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.332480389 241.483074887 L 252.950693991 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.928541085 194.390896842 L 252.332480389 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.787681797 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.743324761 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.819024386 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.550787425 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.550787425 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.819024386 93.742908472 L 247.550787425 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.743324761 119.597437595 L 246.819024386 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.787681797 147.298718797 L 246.743324761 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.928541085 194.390896842 L 221.787681797 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.0083246709 243.791514987 L 182.928541085 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.55078742497349, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(246.81902438559115, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(246.74332476082748, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.95069399144992, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(221.78768179706466, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.33248038921312, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.92854108503769, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(82.008324670913112, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t30a9f7763468423ea383b5db05fd6edc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t564bad117cdf458182b347ae267d0f4b"><g class="toyplot-Edges"><path d="M 74.8042437142 243.791514987 L 261.555218006 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.853049432 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.269397369 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.269397369 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.853049432 241.483074887 L 252.269397369 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.523667446 194.390896842 L 251.853049432 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.100345118 147.298718797 L 261.555218006 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.443814536 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.557363973 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.440526262 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.440526262 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.557363973 93.742908472 L 246.440526262 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.443814536 119.597437595 L 245.557363973 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.100345118 147.298718797 L 245.443814536 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.523667446 194.390896842 L 219.100345118 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.8042437142 243.791514987 L 167.523667446 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.55521800625593, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.55521800625593, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.44052626177273, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.55736397286302, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.44381453571751, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.26939736857673, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(219.10034511795374, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.85304943237645, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.52366744562701, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(74.804243714235412, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taaab660cf73e43cdbd0ba7493cfae7d6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdd446efd96174db8896122c84bf1b560"><g class="toyplot-Edges"><path d="M 75.7378724197 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.004448682 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.887610971 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.887610971 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.004448682 241.483074887 L 252.887610971 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.8599545 194.390896842 L 252.004448682 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.340060596 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.074644742 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.137727763 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.579308907 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.579308907 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.137727763 93.742908472 L 246.579308907 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.074644742 119.597437595 L 246.137727763 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.340060596 147.298718797 L 246.074644742 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.8599545 194.390896842 L 219.340060596 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.7378724197 243.791514987 L 176.8599545 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.57930890717279, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.13772776271796, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.07464474208152, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.88761097081354, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(219.3400605963721, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.00444868190385, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(176.85995449981533, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(75.737872419654224, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb00ccd8e6cb0419697774d9056d73079"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0a2e0e0d9ed949a99fd653b612f40c75"><g class="toyplot-Edges"><path d="M 68.4076254217 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.080148307 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.799294742 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.799294742 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.080148307 241.483074887 L 252.799294742 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.989945307 194.390896842 L 252.080148307 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.13819493 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.532130765 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.582597181 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.049411534 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.049411534 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.582597181 93.742908472 L 246.049411534 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.532130765 119.597437595 L 245.582597181 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.13819493 147.298718797 L 245.532130765 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.989945307 194.390896842 L 219.13819493 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.4076254217 243.791514987 L 171.989945307 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(246.04941153382697, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.58259718111754, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.53213076460844, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.79929474192258, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(219.13819493033554, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.08014830666755, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.98994530668466, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(68.407625421703671, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfce53587807541b9a3bf1fd386953d32"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5e658392b4234fe2b79a00c800bc84ba"><g class="toyplot-Edges"><path d="M 72.9243696993 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.81519962 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.862377763 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.862377763 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.81519962 241.483074887 L 252.862377763 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.052491836 194.390896842 L 251.81519962 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.371870353 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.910628888 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.998945117 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.390059845 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.390059845 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.998945117 93.742908472 L 246.390059845 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.910628888 119.597437595 L 245.998945117 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.371870353 147.298718797 L 245.910628888 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.052491836 194.390896842 L 217.371870353 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.9243696993 243.791514987 L 176.052491836 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.39005984526358, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.99894511731785, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.91062888842688, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.86237776255899, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(217.3718703525162, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(251.81519961999462, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(176.05249183566931, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(72.924369699270457, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdf1564a283a7463b8974f306a7c640ce"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tda50990b29ce4eaa9cabd1d268e5b981"><g class="toyplot-Edges"><path d="M 77.4789637892 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.105381515 241.483074887 L 261.555218006 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.354425324 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.354425324 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.105381515 241.483074887 L 253.354425324 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.891227764 194.390896842 L 252.105381515 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.926464442 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.591925511 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.718091553 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.844257594 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.844257594 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.718091553 93.742908472 L 246.844257594 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.591925511 119.597437595 L 246.718091553 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.926464442 147.298718797 L 246.591925511 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.891227764 194.390896842 L 221.926464442 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.4789637892 243.791514987 L 178.891227764 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625593, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.84425759384573, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.71809155257293, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.59192551130008, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.35442532352297, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(221.92646444246481, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.1053815149221, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.89122776430764, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(77.478963789219065, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t49c79447a20946dab14088b7360c499f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf241cb1c8a3f4238ad4694004eb24b93"><g class="toyplot-Edges"><path d="M 75.3719909 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.928749057 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.581524198 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.581524198 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.928749057 241.483074887 L 253.581524198 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.213755907 194.390896842 L 251.928749057 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.52273311 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.453142866 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.579308907 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.705474948 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.705474948 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.579308907 93.742908472 L 246.705474948 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.453142866 119.597437595 L 246.579308907 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.52273311 147.298718797 L 246.453142866 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.213755907 194.390896842 L 221.52273311 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.3719909 243.791514987 L 173.213755907 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.70547494844567, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.57930890717279, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.45314286589999, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.58152419781402, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(221.52273311039178, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(251.92874905714015, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(173.21375590703099, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(75.371990899963066, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb752d07ef3534e239905d5b7efd36fb7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t04568d91c59448cd8a3ac9dfce46ce62"><g class="toyplot-Edges"><path d="M 77.6429796429 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.247452434 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.559579264 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.559579264 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.247452434 241.483074887 L 252.559579264 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.323480579 194.390896842 L 251.247452434 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.021893711 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.667625136 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.718091553 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.932573823 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.932573823 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.718091553 93.742908472 L 246.932573823 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.667625136 119.597437595 L 246.718091553 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.021893711 147.298718797 L 246.667625136 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.323480579 194.390896842 L 216.021893711 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.6429796429 243.791514987 L 178.323480579 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.93257382273671, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.71809155257293, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.66762513606378, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.55957926350425, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(216.02189371089705, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.24745243426699, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(178.32348057857996, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(77.64297964287374, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb0b9a1da7f6a43dfbb439303fb1ef48c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t88cd36cef1504ce480ecb76fb1932010"><g class="toyplot-Edges"><path d="M 82.9545699805 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.698361909 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.938077387 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.938077387 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.698361909 241.483074887 L 252.938077387 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.737076732 194.390896842 L 252.698361909 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.665340521 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.323688551 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.449854592 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.62648705 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.62648705 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.449854592 93.742908472 L 247.62648705 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.323688551 119.597437595 L 247.449854592 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.665340521 147.298718797 L 247.323688551 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.737076732 194.390896842 L 216.665340521 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.9545699805 243.791514987 L 175.737076732 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.62648704973719, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.44985459195527, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.32368855068245, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.93807738732272, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(216.6653405213884, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.69836190890436, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(175.73707673248728, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(82.95456998045924, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tea8a8aa3b62d4b7da48ca7e619622e58"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t037ca6995bb44bb8be02a480c2203847"><g class="toyplot-Edges"><path d="M 71.5365432453 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.698361909 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.240875886 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.240875886 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.698361909 241.483074887 L 253.240875886 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.251069228 194.390896842 L 252.698361909 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.866669696 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.718091553 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.89472401 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.109206281 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.109206281 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.89472401 93.742908472 L 247.109206281 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.718091553 119.597437595 L 246.89472401 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.866669696 147.298718797 L 246.718091553 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.251069228 194.390896842 L 220.866669696 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.5365432453 243.791514987 L 177.251069228 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(247.10920628051863, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.89472401035488, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.71809155257293, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.24087588637744, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(220.86666969577314, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.69836190890436, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(177.25106922776106, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(71.536543245269499, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7b05e15fd93d4ce8b4861ac320e0789b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t10fffbd2c4584f71831f5e7fa9b2e2f9"><g class="toyplot-Edges"><path d="M 71.9655077856 243.791514987 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.837144554 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.887610971 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.887610971 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.837144554 241.483074887 L 252.887610971 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.648224012 194.390896842 L 252.837144554 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.693325512 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.819024386 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.970423635 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.247988926 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.247988926 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.970423635 93.742908472 L 247.247988926 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.819024386 119.597437595 L 246.970423635 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.693325512 147.298718797 L 246.819024386 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.648224012 194.390896842 L 219.693325512 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.9655077856 243.791514987 L 179.648224012 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(247.24798892591878, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.97042363511855, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.81902438559118, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.88761097081354, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(219.69332551193597, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.83714455430444, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(179.64822401194454, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(71.965507785597083, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7bd9f1318add4c5bb0544dc86ca11523"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8756e070013c453a877ac6e45324ebfd"><g class="toyplot-Edges"><path d="M 69.8963847087 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.550250933 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.19040947 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.19040947 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.550250933 241.483074887 L 253.19040947 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.493536488 194.390896842 L 251.550250933 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.952234142 147.298718797 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.390059845 119.597437595 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.503609282 93.742908472 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.83164099 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.83164099 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.503609282 93.742908472 L 246.83164099 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.390059845 119.597437595 L 246.503609282 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.952234142 147.298718797 L 246.390059845 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.493536488 194.390896842 L 217.952234142 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.8963847087 243.791514987 L 180.493536488 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(246.83164098971841, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(246.50360928240912, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(246.39005984526358, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.19040946986831, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(217.95223414237111, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.55025093332171, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(180.49353648847239, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(69.896384708722906, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7e9e92b874ee4afd95678056a42f86e6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6ffbf6884e6a46249738dc0c34f522dd"><g class="toyplot-Edges"><path d="M 59.6643187615 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.629238832 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.799294742 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.799294742 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.629238832 241.483074887 L 252.799294742 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.758485175 194.390896842 L 250.629238832 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.024645493 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.440526262 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.503609282 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.61715872 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.61715872 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.503609282 93.742908472 L 246.61715872 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.440526262 119.597437595 L 246.503609282 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.024645493 147.298718797 L 246.440526262 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.758485175 194.390896842 L 219.024645493 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.6643187615 243.791514987 L 180.758485175 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.61715871955468, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.50360928240912, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.44052626177273, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.79929474192261, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(219.02464549319004, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(250.62923883203018, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(180.75848517514532, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(59.664318761497604, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4331316f4807420a8c1e674091581239"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8625a34b35e64b258ef0bbf9ece383b8"><g class="toyplot-Edges"><path d="M 60.3708485926 243.329826967 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.546962659 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.467974761 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.467974761 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.546962659 241.483074887 L 253.467974761 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.780430109 193.467520802 L 252.546962659 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.74432842 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.289127012 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.31436022 86.3559001513 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.427909658 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.427909658 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.31436022 86.3559001513 L 246.427909658 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.289127012 115.903933434 L 246.31436022 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.74432842 145.451966717 L 246.289127012 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.780430109 193.467520802 L 215.74432842 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.3708485926 243.329826967 L 181.780430109 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.42790965764544, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.31436022049991, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.28912701224536, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.46797476066848, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(215.74432842009688, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.54696265937696, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.7804301094551, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(60.370848592625372, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t381814daadbc4c80bfbba5e0c9f2df38"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3345360b2b274c0581969e9f7ed0a197"><g class="toyplot-Edges"><path d="M 53.3181668855 243.329826967 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.4493181 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.799294742 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.799294742 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.4493181 241.483074887 L 252.799294742 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.411260316 193.467520802 L 251.4493181 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.324155718 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.087261346 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.09987795 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.226043992 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.226043992 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.09987795 86.3559001513 L 246.226043992 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.087261346 115.903933434 L 246.09987795 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.324155718 145.451966717 L 246.087261346 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.411260316 193.467520802 L 220.324155718 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 53.3181668855 243.329826967 L 182.411260316 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.22604399160895, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.09987795033612, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.08726134620881, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.79929474192258, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(220.32415571830001, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(251.44931810030346, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.41126031581919, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(53.318166885475023, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2327f1ccb2da4ae6ad818d0ec4959022"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcb0aebc618074cb78a0f1de96c4e1f64"><g class="toyplot-Edges"><path d="M 61.7586750466 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.525017725 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.076860033 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.076860033 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.525017725 241.483074887 L 253.076860033 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.076115569 189.774016641 L 251.525017725 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.791506563 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.453142866 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.453142866 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.440526262 101.129916793 L 246.453142866 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.516225887 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.516225887 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.440526262 101.129916793 L 246.516225887 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.791506563 138.064958396 L 246.440526262 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.076115569 189.774016641 L 216.791506563 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.7586750466 241.483074887 L 188.076115569 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.5162258865364, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.45314286589999, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.4405262617727, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.07686003272275, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(216.7915065626612, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.52501772506713, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.07611556896856, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(61.75867504662633, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta9db45edd57f4ca79f9c3128c7f01266"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t09a63d28f54c4bb49a22ee493ebb7087"><g class="toyplot-Edges"><path d="M 58.4783579735 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.222219226 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.739499995 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.739499995 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.222219226 241.483074887 L 251.739499995 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.525882736 189.774016641 L 251.222219226 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.784930015 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.292415286 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.292415286 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.267182078 101.129916793 L 245.292415286 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.797079451 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.797079451 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.267182078 101.129916793 L 245.797079451 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.784930015 138.064958396 L 245.267182078 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.525882736 189.774016641 L 218.784930015 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.4783579735 241.483074887 L 174.525882736 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.79707945128135, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.29241528619008, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.2671820779355, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.73949999523091, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(218.7849300147717, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.22221922601236, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(174.52588273626824, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(58.47835797353315, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7aabdb1788354fdf96e6b117dc66e9c2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9b62e5da1d6e420489c5f9f238064e23"><g class="toyplot-Edges"><path d="M 62.4778214819 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.083436581 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.916132453 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.916132453 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.083436581 241.483074887 L 251.916132453 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.705266976 189.774016641 L 251.083436581 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.065247088 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.977000183 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.977000183 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.951766975 101.129916793 L 244.977000183 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.052699808 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.052699808 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.951766975 101.129916793 L 245.052699808 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.065247088 138.064958396 L 244.951766975 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.705266976 189.774016641 L 222.065247088 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.4778214819 241.483074887 L 177.705266976 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038327, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038327, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038327, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.05269980777177, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.97700018300807, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.95176697475353, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.91613245301292, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(222.06524708786489, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.08343658061233, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(177.70526697634321, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(62.477821481881392, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t424ea4ef5a7e4288ab45ea2959ea7476"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9014c0fa915a47fa89b27c9a71d2f615"><g class="toyplot-Edges"><path d="M 74.980876172 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.562867537 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.130614723 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.130614723 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.562867537 241.483074887 L 252.130614723 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.69922692 189.774016641 L 251.562867537 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.444281703 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.339593429 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.364826637 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.882107406 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.882107406 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.364826637 115.903933434 L 246.882107406 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.339593429 101.129916793 L 246.364826637 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.444281703 138.064958396 L 246.339593429 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.69922692 189.774016641 L 218.444281703 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.980876172 241.483074887 L 175.69922692 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.88210740622756, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.36482663700903, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.33959342875445, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.13061472317668, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(218.44428170333509, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(251.56286753744899, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(175.69922692010545, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(74.980876172017332, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6cb1b9dcc85c4e708fa5947c24221e43"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8c4e41e8e702495c830659c513e2aa04"><g class="toyplot-Edges"><path d="M 72.6341878043 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.676416975 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.748828325 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.748828325 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.676416975 241.483074887 L 252.748828325 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.525346245 189.774016641 L 251.676416975 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.70923039 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.83164099 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.882107406 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.336305155 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.336305155 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.882107406 115.903933434 L 247.336305155 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.83164099 101.129916793 L 246.882107406 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.70923039 138.064958396 L 246.83164099 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.525346245 189.774016641 L 218.70923039 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.6341878043 241.483074887 L 178.525346245 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(247.33630515480974, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(246.88210740622759, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(246.83164098971847, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.74882832541346, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(218.70923039000803, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.67641697459453, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.52534624461649, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(72.634187804342986, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9d53cbc134234b8d9ae7793e0a0513b6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5d103cc103e744ae976651c1fae7ad5f"><g class="toyplot-Edges"><path d="M 63.184351313 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.755404873 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.168464536 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.168464536 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.755404873 241.483074887 L 252.168464536 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.493536488 189.774016641 L 250.755404873 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.283554124 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.620446993 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.620446993 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.216715661 101.129916793 L 245.620446993 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.469047744 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.469047744 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.216715661 101.129916793 L 245.469047744 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.283554124 138.064958396 L 245.216715661 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.493536488 189.774016641 L 217.283554124 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.184351313 241.483074887 L 180.493536488 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038316, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.469047743972, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.62044699349937, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.21671566142638, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.16846453555848, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(217.28355412362518, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(250.75540487330301, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(180.49353648847239, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(63.184351313009117, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t08a743502dc94a3186fac9f731568e5b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t162509821edb432988e49d065b1768e2"><g class="toyplot-Edges"><path d="M 59.6517021574 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.881570915 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.026393616 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.026393616 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.881570915 241.483074887 L 253.026393616 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.506153093 189.774016641 L 250.881570915 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.274225793 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.712051496 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.712051496 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.598502059 101.129916793 L 244.712051496 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.699434892 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.699434892 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.598502059 101.129916793 L 244.699434892 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.274225793 138.064958396 L 244.598502059 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.506153093 189.774016641 L 216.274225793 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.6517021574 241.483074887 L 180.506153093 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.69943489220793, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.71205149633519, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.59850205918968, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.02639361621368, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(216.27422579344272, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.88157091457586, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.5061530925997, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(59.651702157370359, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta11a6a7a57424232a009a21ce73e6302"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5158d2677c3047b1871037b4a0a26454"><g class="toyplot-Edges"><path d="M 65.2030079734 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.947942209 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.18108114 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.18108114 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.947942209 241.483074887 L 252.18108114 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.171544837 189.774016641 L 249.947942209 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.510652998 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.686818288 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.686818288 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.598502059 101.129916793 L 244.686818288 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.674201684 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.674201684 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.598502059 101.129916793 L 244.674201684 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.510652998 138.064958396 L 244.598502059 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.171544837 189.774016641 L 217.510652998 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.2030079734 241.483074887 L 182.171544837 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.6742016839533, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.68681828808056, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.5985020591896, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.18108113968577, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(217.51065299791628, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(249.94794220915699, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.17154483740083, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(65.203007973374184, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3aa1f01ee9484d378f90fc25941fb250"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0c1d2b3efd154e069386cba8bb057b93"><g class="toyplot-Edges"><path d="M 58.0998598497 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.023641834 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.076860033 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.076860033 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.023641834 241.483074887 L 253.076860033 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.3333454 189.774016641 L 250.023641834 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.166179921 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.207387331 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.207387331 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.144304311 101.129916793 L 244.207387331 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.371403185 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.371403185 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.144304311 101.129916793 L 244.371403185 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.166179921 138.064958396 L 244.144304311 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.3333454 189.774016641 L 222.166179921 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.0998598497 241.483074887 L 175.3333454 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(244.37140318489855, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(244.20738733124392, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(244.14430431060751, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.07686003272275, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(222.16617992088314, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.02364183392066, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(175.33334540041429, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(58.099859849714711, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3a67d791aa984a578869786af2bc1e6a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3a7d40ef2b3f4b5dbfe6763c3deb579d"><g class="toyplot-Edges"><path d="M 62.0488569416 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.083436581 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.013777012 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.013777012 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.083436581 241.483074887 L 253.013777012 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.623527295 189.774016641 L 251.083436581 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.930289208 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.169537519 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.169537519 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.08122129 101.129916793 L 244.169537519 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.674201684 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.674201684 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.08122129 101.129916793 L 244.674201684 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.930289208 138.064958396 L 244.08122129 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.623527295 189.774016641 L 216.930289208 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.0488569416 241.483074887 L 175.623527295 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038327, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038327, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038327, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(244.67420168395336, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(244.16953751886209, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(244.0812212899711, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(253.01377701208639, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(216.93028920806134, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.08343658061233, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(175.62352729534175, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(62.048856941553829, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1a1902ab16e54dcd8f70ac879e69ecc4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb94c6219b2684b6ebf2926bf8e1e9815"><g class="toyplot-Edges"><path d="M 78.9298732639 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.092764911 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.62870234 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.62870234 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.092764911 241.483074887 L 254.62870234 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.551115945 189.774016641 L 252.092764911 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.788218289 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.317648494 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.317648494 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.254565474 101.129916793 L 245.317648494 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.45643114 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.45643114 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.254565474 101.129916793 L 245.45643114 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.788218289 138.064958396 L 245.254565474 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.551115945 189.774016641 L 217.788218289 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.9298732639 241.483074887 L 174.551115945 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.45643113984477, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.31764849444465, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.25456547380824, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(254.62870234037842, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(217.78821828871645, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.09276491079484, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(174.55111594452282, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(78.92987326385645, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t90c559758633440594329b0aa10d0def"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2e5346a3fda24eb0a68408dfc0387cb9"><g class="toyplot-Edges"><path d="M 81.2765616315 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.139943053 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.212354404 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.212354404 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.139943053 241.483074887 L 254.212354404 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.061283674 189.774016641 L 253.139943053 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.804123167 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.82231266 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.82231266 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.759229639 101.129916793 L 245.82231266 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.847545868 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.847545868 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.759229639 101.129916793 L 245.847545868 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.804123167 138.064958396 L 245.759229639 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.061283674 189.774016641 L 216.804123167 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 81.2765616315 241.483074887 L 181.061283674 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.84754586779047, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.82231265953592, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.75922963889951, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(254.21235440417809, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(216.80412316678851, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(253.13994305335913, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.06128367420007, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(81.276561631530797, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8313598f826c434997abd63935f04576"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t05e1a55c6c174ecb9047de06cfb03cf4"><g class="toyplot-Edges"><path d="M 73.4795002809 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.553539207 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.240875886 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.240875886 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.553539207 241.483074887 L 253.240875886 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.954310785 189.774016641 L 250.553539207 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.151348026 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.636351872 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.636351872 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.560652247 101.129916793 L 244.636351872 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.901300558 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.901300558 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.560652247 101.129916793 L 244.901300558 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.151348026 138.064958396 L 244.560652247 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.954310785 189.774016641 L 215.151348026 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.4795002809 241.483074887 L 178.954310785 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.9013005582444, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.63635187157146, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.56065224680776, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.24087588637744, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(215.15134802611462, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(250.55353920726651, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.95431078494406, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(73.479500280870838, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7e2f3269fa7b4820a2f4951f58339857"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbc65b539762943e9b42e2e5b6ab3ba8e"><g class="toyplot-Edges"><path d="M 69.5935862097 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.96659887 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.467974761 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.467974761 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.96659887 241.483074887 L 253.467974761 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.551115945 189.774016641 L 251.96659887 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.734463598 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.459719414 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.459719414 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.333553373 101.129916793 L 244.459719414 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.409252997 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.409252997 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.333553373 101.129916793 L 244.409252997 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.734463598 138.064958396 L 244.333553373 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.551115945 189.774016641 L 218.734463598 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.5935862097 241.483074887 L 174.551115945 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.40925299728042, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.45971941378951, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.33355337251672, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.46797476066851, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(218.73446359826258, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(251.96659886952202, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(174.55111594452282, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(69.59358620966816, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td7b361ea02a349909510cccd02c21cd7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbbf56a208f514730b810ecf3cf16af7c"><g class="toyplot-Edges"><path d="M 70.4262820821 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.474551309 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.960022322 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.960022322 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.474551309 241.483074887 L 253.960022322 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.228587802 189.774016641 L 251.474551309 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.86995797 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.166249245 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.166249245 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.989616787 101.129916793 L 245.166249245 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.040083204 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.040083204 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.989616787 101.129916793 L 245.040083204 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.86995797 138.064958396 L 244.989616787 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.228587802 189.774016641 L 219.86995797 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.4262820821 241.483074887 L 180.228587802 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.04008320364449, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.16624924491728, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.98961678713536, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.96002232163249, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(219.86995796971794, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(251.47455130855803, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.22858780179951, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(70.42628208206871, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3f35562660284013bea21ef8ebb90135"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t663073762e0b45b08aa8d47e552b069c"><g class="toyplot-Edges"><path d="M 74.7663939019 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.203026074 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.161887988 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.161887988 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.203026074 241.483074887 L 254.161887988 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.620239021 189.774016641 L 253.203026074 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.759160315 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.267182078 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.267182078 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.178865849 101.129916793 L 245.267182078 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.267182078 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.267182078 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.178865849 101.129916793 L 245.267182078 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 222.759160315 138.064958396 L 245.178865849 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.620239021 189.774016641 L 222.759160315 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.7663939019 241.483074887 L 176.620239021 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.26718207793553, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.26718207793553, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.17886584904457, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(254.16188798766896, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(222.75916031486537, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.2030260739956, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(176.620239021397, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(74.766393901853547, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t30ce390fe2614445a70b244fe5364739"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta7a84bf84b944f439482b3f027170a6b"><g class="toyplot-Edges"><path d="M 81.9073918379 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.635278888 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.758156656 219.322049924 L 261.555218006 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.758156656 219.322049924 L 261.555218006 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.635278888 241.483074887 L 253.758156656 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.980080485 189.774016641 L 252.635278888 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.043302154 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.074644742 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.074644742 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.898012284 101.129916793 L 246.074644742 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.137727763 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.137727763 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.898012284 101.129916793 L 246.137727763 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.043302154 138.064958396 L 245.898012284 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.980080485 189.774016641 L 221.043302154 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 81.9073918379 241.483074887 L 174.980080485 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.55521800625593, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.55521800625593, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.13772776271799, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.07464474208152, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.8980122842996, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.75815665559594, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(221.04330215355506, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.63527888826792, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(174.98008048485039, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(81.907391837894878, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6c40930a307c4a7d8a116072700d1bb7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t37ba938855b6453992d3c0cbd6f67543"><g class="toyplot-Edges"><path d="M 73.4290338644 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.635278888 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.821239676 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.821239676 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.635278888 241.483074887 L 253.821239676 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.112823074 189.774016641 L 252.635278888 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.189197838 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.330265099 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.330265099 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.30503189 101.129916793 L 245.330265099 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.213427387 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.213427387 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.30503189 101.129916793 L 246.213427387 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.189197838 138.064958396 L 245.30503189 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.112823074 189.774016641 L 215.189197838 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.4290338644 241.483074887 L 173.112823074 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(246.21342738748166, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.33026509857197, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.30503189031737, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(253.82123967623244, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(215.18919783849648, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.63527888826792, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(173.11282307401274, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(73.429033864361728, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb248c60f37a8479e934a569047579f29"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te926c937edb1433fb77bbb7a04860789"><g class="toyplot-Edges"><path d="M 72.2683062847 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.335768663 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.534346055 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.534346055 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.335768663 241.483074887 L 252.534346055 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.673993712 189.774016641 L 251.335768663 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.131618382 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.216715661 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.216715661 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.191482453 101.129916793 L 245.216715661 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.771846243 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.771846243 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.191482453 101.129916793 L 245.771846243 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.131618382 138.064958396 L 245.191482453 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.673993712 189.774016641 L 221.131618382 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.2683062847 241.483074887 L 175.673993712 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.7718462430268, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.21671566142641, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.19148245317183, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.53434605524967, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(221.13161838244605, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.33576866315795, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(175.67399371185084, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(72.268306284651814, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td58c370ffaaa44dd934664084f0ab124"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t93abb7be3e674d06be2e77ec65a11f80"><g class="toyplot-Edges"><path d="M 72.0916738269 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.042298494 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.256780764 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.256780764 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.042298494 241.483074887 L 252.256780764 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.432062943 189.774016641 L 252.042298494 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.298386018 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.850834142 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.87606735 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.014849995 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.014849995 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.87606735 115.903933434 L 245.014849995 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.850834142 101.129916793 L 244.87606735 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.298386018 138.064958396 L 244.850834142 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.432062943 189.774016641 L 224.298386018 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.0916738269 241.483074887 L 168.432062943 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.01484999538991, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(244.87606734998982, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(244.85083414173525, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.25678076444947, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(224.29838601839367, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.04229849428572, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.43206294279128, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(72.091673826869865, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5dc61d677a1842e997755ae6e0063512"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t75aa247023474b2ba7c38c68ed121803"><g class="toyplot-Edges"><path d="M 61.8469912755 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.928749057 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.9759272 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.9759272 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.928749057 241.483074887 L 252.9759272 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.973503937 189.774016641 L 251.928749057 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.361469039 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.841505812 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.841505812 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.816272603 101.129916793 L 243.841505812 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.917205436 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.917205436 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.816272603 101.129916793 L 243.917205436 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.361469039 138.064958396 L 243.816272603 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.973503937 189.774016641 L 224.361469039 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.8469912755 241.483074887 L 176.973503937 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038316, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(243.91720543631641, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(243.84150581155274, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(243.81627260329816, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.9759271997045, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(224.36146903903008, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.92874905714015, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(176.97350393696084, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(61.846991275517297, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9c3aa39c37ab40bab1c3c67e50f613cf"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t85d1117ed8aa4f459e1b0a94052cbde1"><g class="toyplot-Edges"><path d="M 57.7213617259 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.099341459 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.442741552 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.442741552 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.099341459 241.483074887 L 253.442741552 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.055243618 189.774016641 L 250.099341459 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.662052247 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.945726919 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.945726919 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.92049371 101.129916793 L 242.945726919 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.945726919 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.945726919 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.92049371 101.129916793 L 242.945726919 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.662052247 138.064958396 L 242.92049371 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.055243618 189.774016641 L 217.662052247 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 57.7213617259 241.483074887 L 179.055243618 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038327, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038327, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038327, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038327, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038327, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(242.94572691851576, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(242.94572691851576, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(242.92049371026121, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.44274155241396, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(217.66205224744365, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(250.09934145868439, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(179.05524361796233, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(57.721361725896287, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5cf41aec2ee24221a9c59dd46f17bea2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tba134459e4c34c059f0aeaa9c829dc01"><g class="toyplot-Edges"><path d="M 54.3274952157 241.021386866 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.528305999 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.367041928 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.367041928 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.528305999 241.483074887 L 253.367041928 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.194026263 188.850640601 L 250.528305999 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.283017632 136.218206316 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.12564765 97.4364126324 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.12564765 108.516925113 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.150880858 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.150880858 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.12564765 108.516925113 L 242.150880858 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.12564765 97.4364126324 L 242.12564765 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.283017632 136.218206316 L 242.12564765 97.4364126324" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.194026263 188.850640601 L 221.283017632 136.218206316" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 54.3274952157 241.021386866 L 179.194026263 188.850640601" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(242.15088085849698, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(242.12564765024243, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(242.12564765024243, 97.43641263237518)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.36704192765023, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(221.28301763197339, 136.2182063161876)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.52830599901191, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(179.19402626336239, 188.85064060136156)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(54.327495215657542, 241.02138686649019)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2116cdc30b044f1ebbdc0bd6a002af31"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t29e71a07313247f3a433307b0d19b7e7"><g class="toyplot-Edges"><path d="M 67.9534276731 241.483074887 L 261.555218006 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.411468288 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.849761158 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.849761158 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.411468288 241.483074887 L 252.849761158 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.916460973 189.774016641 L 251.411468288 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.79976191 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.49152917 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.49152917 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.516762378 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.516762378 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.49152917 86.3559001513 L 242.516762378 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.49152917 101.129916793 L 242.49152917 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.79976191 138.064958396 L 242.49152917 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.916460973 189.774016641 L 225.79976191 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.9534276731 241.483074887 L 178.916460973 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(242.51676237818816, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(242.49152916993361, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(242.49152916993361, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.84976115843176, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(225.79976190954022, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(251.41146828792162, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(178.91646097256222, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.953427673121553, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfa2bcf72e5484e3da956de74ef9ea048"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb64378f44bc1494383ae10763a2f9d71"><g class="toyplot-Edges"><path d="M 69.0763054404 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.43998977 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.853049432 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.853049432 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.43998977 241.483074887 L 251.853049432 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.607622417 189.774016641 L 250.43998977 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.576487801 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.07189296 130.677950076 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.07189296 130.677950076 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.059276356 101.129916793 L 243.07189296 130.677950076" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.084509564 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.084509564 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.059276356 101.129916793 L 243.084509564 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.576487801 138.064958396 L 243.059276356 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.607622417 189.774016641 L 220.576487801 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.0763054404 241.483074887 L 176.607622417 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.08450956391584, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.07189295978856, 130.67795007564297)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.05927635566127, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.85304943237645, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(220.57648780084565, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.43998977012092, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(176.60762241726968, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(69.076305440449602, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2bc6adf4fc614d7f9263ddef8ef92249"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="teef4e7133aaa4860844bae377a39c47e"><g class="toyplot-Edges"><path d="M 58.4026583488 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.497032735 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.247452434 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.247452434 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.497032735 241.483074887 L 251.247452434 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.492394181 189.774016641 L 248.497032735 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.447569977 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.06256463 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.087797838 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.138264254 115.903933434 L 261.555218006 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.138264254 115.903933434 L 261.555218006 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.087797838 86.3559001513 L 242.138264254 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.06256463 101.129916793 L 242.087797838 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.447569977 138.064958396 L 242.06256463 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.492394181 189.774016641 L 217.447569977 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.4026583488 241.483074887 L 165.492394181 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.55521800625598, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.55521800625598, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(242.13826425436977, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(242.08779783786059, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(242.06256462960604, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.24745243426699, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(217.44756997727987, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(248.49703273451959, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(165.4923941811347, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(58.402658348769478, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4fd09ddf7e4d428897a9e4e06529a3ef"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0dfd86ae081e4d918d96f407692398ca"><g class="toyplot-Edges"><path d="M 67.8524948401 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.528305999 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.474551309 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.474551309 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.528305999 241.483074887 L 251.474551309 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.455686676 189.774016641 L 250.528305999 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.951697651 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.828889207 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.891972228 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.904588832 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.904588832 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.891972228 86.3559001513 L 243.904588832 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.828889207 101.129916793 L 243.891972228 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.951697651 138.064958396 L 243.828889207 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.455686676 189.774016641 L 221.951697651 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.8524948401 241.483074887 L 180.455686676 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(243.90458883218915, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(243.89197222806186, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(243.82888920742545, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.47455130855803, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(221.95169765071938, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(250.52830599901191, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.45568667609055, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(67.85249484010329, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8897bad672e64358b17edaf061b0d655"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te425e5acbfe344f2be3ee05aa1cf37e9"><g class="toyplot-Edges"><path d="M 65.9852374293 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.704938457 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.165176262 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.165176262 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.704938457 241.483074887 L 253.165176262 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.099669978 189.774016641 L 250.704938457 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.69990206 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.992905061 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.106454498 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.194770727 115.903933434 L 261.555218006 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.194770727 115.903933434 L 261.555218006 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.106454498 86.3559001513 L 244.194770727 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.992905061 101.129916793 L 244.106454498 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.69990206 138.064958396 L 243.992905061 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.099669978 189.774016641 L 217.69990206 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.9852374293 241.483074887 L 177.099669978 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625598, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625598, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(244.19477072711663, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(244.10645449822567, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(243.99290506108011, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(253.16517626161377, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(217.69990205982549, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(250.70493845679388, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(177.09966997823369, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(65.985237429265652, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbf5f8deb446a4e059689d635a62675ba"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdec147f8dd774f48ba8f39d0090aec2d"><g class="toyplot-Edges"><path d="M 67.9534276731 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.789966412 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.669840427 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.669840427 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.789966412 241.483074887 L 253.669840427 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.12597617 192.544144762 L 251.789966412 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.040550371 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.573268851 112.210429274 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.648968476 108.516925113 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.800367725 71.5818835098 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.800367725 71.5818835098 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.648968476 108.516925113 L 244.800367725 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.573268851 112.210429274 L 244.648968476 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.040550371 143.605214637 L 244.573268851 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.12597617 192.544144762 L 218.040550371 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.9534276731 242.868138947 L 169.12597617 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.80036772522615, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.64896847569878, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.57326885093505, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.66984042670504, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(218.04055037126213, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.7899664117401, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(169.12597616979178, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(67.953427673121567, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5d92b0739f7146899f922b91baebf8db"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2c540427956849b6918c3f0a12daa031"><g class="toyplot-Edges"><path d="M 66.8683997182 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.559579264 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.266109095 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.266109095 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.559579264 241.483074887 L 253.266109095 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.604334143 190.697392682 L 252.559579264 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.30603555 139.911710477 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.484952622 104.823420953 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.535419039 93.742908472 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.636351872 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.636351872 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.535419039 93.742908472 L 244.636351872 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.484952622 104.823420953 L 244.535419039 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.30603555 139.911710477 L 244.484952622 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.604334143 190.697392682 L 214.30603555 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.8683997182 241.944762907 L 177.604334143 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.63635187157146, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.53541903855321, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.48495262204409, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.26610909463201, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(214.3060355495868, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.55957926350425, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.60433414332493, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(66.86839971817534, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t397e8b7c8b2244bab8f25ec7ea5c6ec6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8e0453e8ec6544ca996e7a0b57c3c5b8"><g class="toyplot-Edges"><path d="M 64.2441460597 241.944762907 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.534346055 241.483074887 L 261.555218006 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.862377763 219.322049924 L 261.555218006 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.862377763 219.322049924 L 261.555218006 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.534346055 241.483074887 L 252.862377763 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.300999153 190.697392682 L 252.534346055 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.245704311 139.911710477 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.103166224 104.823420953 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.115782828 93.742908472 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.393348119 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.393348119 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.115782828 93.742908472 L 245.393348119 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.103166224 104.823420953 L 245.115782828 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.245704311 139.911710477 L 245.103166224 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.300999153 190.697392682 L 217.245704311 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.2441460597 241.944762907 L 181.300999153 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625598, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625598, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.55521800625598, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038327, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.39334811920838, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.11578282840819, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.1031662242809, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.86237776255905, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(217.24570431124334, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.5343460552497, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.30099915261843, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(64.24414605970081, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0469e023a07746f3ad4d278f16671a02"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf77fe31535814aada0c8570aab7140a0"><g class="toyplot-Edges"><path d="M 73.5551999056 241.944762907 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.534346055 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.303958907 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.303958907 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.534346055 241.483074887 L 253.303958907 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.711843524 190.697392682 L 252.534346055 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.939081047 139.911710477 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.557363973 104.823420953 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.607830389 93.742908472 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.658296806 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.658296806 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.607830389 93.742908472 L 245.658296806 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.557363973 104.823420953 L 245.607830389 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.939081047 139.911710477 L 245.557363973 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.711843524 190.697392682 L 221.939081047 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.5551999056 241.944762907 L 175.711843524 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.65829680588129, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.60783038937217, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.55736397286302, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.30395890701385, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(221.93908104659209, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.5343460552497, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(175.71184352423273, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(73.555199905634538, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7e085135561449c982f2f066b638df6a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t13cff71e63534155a2abce0fc26bddaf"><g class="toyplot-Edges"><path d="M 72.4323221383 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.196986018 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.152559657 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.152559657 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.196986018 241.483074887 L 253.152559657 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.8857242 190.697392682 L 251.196986018 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.74432842 139.911710477 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.913917162 104.823420953 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.065316412 93.742908472 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.103166224 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.103166224 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.065316412 93.742908472 L 245.103166224 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.913917162 104.823420953 L 245.065316412 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.74432842 139.911710477 L 244.913917162 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.8857242 190.697392682 L 215.74432842 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.4323221383 241.944762907 L 172.8857242 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.10316622428087, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.06531641189903, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(244.91391716237166, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.15255965748642, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(215.74432842009688, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.19698601775787, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(172.88572419972166, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(72.432322138306489, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2a1244c543f14110a96e97e013396365"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tccc73f13e06f46519ddde65a490c36c7"><g class="toyplot-Edges"><path d="M 77.9079283295 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.282013973 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.912844179 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.912844179 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.282013973 241.483074887 L 252.912844179 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.872571104 190.697392682 L 252.282013973 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.911096056 139.911710477 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.380731515 104.823420953 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.45643114 93.742908472 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.51951416 101.129916793 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.51951416 101.129916793 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.45643114 93.742908472 L 245.51951416 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.380731515 104.823420953 L 245.45643114 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.911096056 139.911710477 L 245.380731515 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.872571104 190.697392682 L 218.911096056 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.9079283295 241.944762907 L 176.872571104 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.51951416048118, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.4564311398448, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.38073151508112, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.91284417906812, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(218.91109605604453, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.28201397270402, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(176.87257110394262, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(77.90792832954665, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8178c0282ead4cd0b7f4d69aefe1e5cc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tde797fdeed844ad182c2dfc02315e9b1"><g class="toyplot-Edges"><path d="M 69.2150880858 241.944762907 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.726883391 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.736211721 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.736211721 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.726883391 241.483074887 L 252.736211721 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.618023731 190.697392682 L 251.726883391 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.936865756 139.911710477 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.838217538 104.823420953 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.901300558 93.742908472 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.939150371 101.129916793 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.939150371 101.129916793 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.901300558 93.742908472 L 244.939150371 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.838217538 104.823420953 L 244.901300558 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.936865756 139.911710477 L 244.838217538 104.823420953" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.618023731 190.697392682 L 214.936865756 139.911710477" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.2150880858 241.944762907 L 169.618023731 190.697392682" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.93915037062624, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.9013005582444, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.83821753760799, 104.82342095310136)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.7362117212862, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(214.93686575595086, 139.91171047655067)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.72688339110368, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(169.61802373075577, 190.69739268154314)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(69.2150880858497, 241.94476290658096)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbf18cfa5fb6d4ab8936ffe58ac7fb1cb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t221d2e25c6224508ba07c94be1ed5a5a"><g class="toyplot-Edges"><path d="M 69.7828352716 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.969887143 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.433413222 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.433413222 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.969887143 241.483074887 L 252.433413222 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.380523543 192.544144762 L 250.969887143 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.276977576 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.913917162 112.210429274 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.040083204 108.516925113 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.040083204 71.5818835098 L 261.555218006 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.040083204 71.5818835098 L 261.555218006 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.040083204 108.516925113 L 245.040083204 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.913917162 112.210429274 L 245.040083204 108.516925113" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.276977576 143.605214637 L 244.913917162 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.380523543 192.544144762 L 219.276977576 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.7828352716 242.868138947 L 176.380523543 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.55521800625593, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.04008320364449, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.04008320364449, 108.51692511346442)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(244.91391716237166, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.43341322223145, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(219.27697757573566, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(250.96988714346676, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(176.38052354297864, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(69.782835271577369, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t418efb49ca454d7986c9c36456101fc9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0f0d22b0a2b24da6a012e3716159b4d7"><g class="toyplot-Edges"><path d="M 80.8097472788 243.791514987 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.887610971 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.278725699 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.278725699 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.887610971 241.483074887 L 253.278725699 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.794119697 194.390896842 L 252.887610971 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.141483204 147.298718797 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.759229639 119.597437595 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.82231266 93.742908472 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.860162472 71.5818835098 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.860162472 71.5818835098 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.82231266 93.742908472 L 245.860162472 71.5818835098" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.759229639 119.597437595 L 245.82231266 93.742908472" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.141483204 147.298718797 L 245.759229639 119.597437595" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.794119697 194.390896842 L 218.141483204 147.298718797" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.8097472788 243.791514987 L 173.794119697 194.390896842" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.86016247191776, 71.58188350983356)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.82231265953592, 93.74290847201209)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.75922963889951, 119.5974375945537)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.2787256987593, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(218.14148320428035, 147.29871879727688)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.88761097081354, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(173.7941196968859, 194.3908968419062)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(80.809747278821391, 243.79151498676248)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta3d91b9da444401a9de1bb0ed8994115"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc0d37af871f84fe097a2b29ec795c2f4"><g class="toyplot-Edges"><path d="M 81.8443088173 243.329826967 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.505824573 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.048338551 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.048338551 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.505824573 241.483074887 L 254.048338551 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.077188552 193.467520802 L 253.505824573 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.211679264 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.112494554 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.226043992 86.3559001513 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.238660596 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.238660596 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.226043992 86.3559001513 L 246.238660596 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.112494554 115.903933434 L 246.226043992 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.211679264 145.451966717 L 246.112494554 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.077188552 193.467520802 L 212.211679264 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 81.8443088173 243.329826967 L 180.077188552 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.23866059573623, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.22604399160895, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.11249455446341, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(254.04833855052345, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(212.21167926445804, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.50582457305035, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(180.0771885522721, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(81.844308817258465, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t27744df2d19b4291b05473c7ba667c9a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2a6d789a68f0413cace838188b77cd4a"><g class="toyplot-Edges"><path d="M 70.3505824573 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.446029826 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.316575511 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.316575511 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.446029826 241.483074887 L 253.316575511 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.734861442 192.544144762 L 252.446029826 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.043302154 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.585885455 112.210429274 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.699434892 78.9688918306 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.888683954 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.888683954 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.699434892 78.9688918306 L 244.888683954 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.585885455 112.210429274 L 244.699434892 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.043302154 143.605214637 L 244.585885455 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.734861442 192.544144762 L 221.043302154 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.3505824573 242.868138947 L 168.734861442 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.88868395411711, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.69943489220788, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.58588545506231, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.31657551114114, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(221.04330215355506, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.44602982635871, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.73486144184605, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(70.350582457305023, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t97034ba96ad34fd2a4fb2a50f813e2dd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t50fda7996a1a471ab3edca15b02c6338"><g class="toyplot-Edges"><path d="M 84.9606100367 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.947405718 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.35113705 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.35113705 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.947405718 241.483074887 L 254.35113705 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.354753843 192.544144762 L 253.947405718 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.602257501 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.200810783 112.210429274 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.263893804 78.9688918306 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.364826637 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.364826637 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.263893804 78.9688918306 L 246.364826637 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.200810783 112.210429274 L 246.263893804 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.602257501 143.605214637 L 246.200810783 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.354753843 192.544144762 L 216.602257501 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 84.9606100367 242.868138947 L 180.354753843 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.36482663700903, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.26389380399078, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.20081078335437, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(254.3511370495782, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(216.60225750075199, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.94740571750521, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(180.35475384307227, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(84.960610036696977, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t355ba478f3f7400880d9707d3283ac61"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tba46bfc61a814cf7b9efd4763cb3a314"><g class="toyplot-Edges"><path d="M 81.8695420255 242.868138947 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.203026074 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.237587612 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.237587612 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.203026074 241.483074887 L 254.237587612 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.329520635 192.544144762 L 253.203026074 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.804123167 143.605214637 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.582597181 112.210429274 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.696146618 78.9688918306 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.759229639 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.759229639 101.129916793 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.696146618 78.9688918306 L 245.759229639 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.582597181 112.210429274 L 245.696146618 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.804123167 143.605214637 L 245.582597181 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.329520635 192.544144762 L 216.804123167 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 81.8695420255 242.868138947 L 180.329520635 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.75922963889951, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.69614661826313, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.58259718111759, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(254.23758761243266, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(216.80412316678851, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.20302607399563, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.32952063481775, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(81.869542025513041, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc1c8b0030c6148209ed897771e7e2603"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t674ae1656ac14392aa398ed271d099d7"><g class="toyplot-Edges"><path d="M 80.2420000931 242.868138947 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.941365661 241.483074887 L 261.555218006 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.240875886 219.322049924 L 261.555218006 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.240875886 219.322049924 L 261.555218006 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.941365661 241.483074887 L 253.240875886 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.210467633 192.544144762 L 251.941365661 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.920960878 143.605214637 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.191482453 112.210429274 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.254565474 78.9688918306 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.30503189 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.30503189 101.129916793 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.254565474 78.9688918306 L 245.30503189 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.191482453 112.210429274 L 245.254565474 78.9688918306" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.920960878 143.605214637 L 245.191482453 112.210429274" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.210467633 192.544144762 L 215.920960878 143.605214637" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.2420000931 242.868138947 L 174.210467633 192.544144762" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.55521800625593, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.55521800625593, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.55521800625593, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.30503189031737, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.25456547380824, 78.968891830559755)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.19148245317183, 112.21042927382753)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(253.24087588637744, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(215.9209608778788, 143.60521463691376)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.94136566126747, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(174.21046763308621, 192.54414476172465)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(80.242000093093708, 242.86813894667171)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t24b0fa5dc6494e3ea3736463b8f6ed4d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tde8eb95cbd8d49619505b49427ed739f"><g class="toyplot-Edges"><path d="M 77.4158807686 243.329826967 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.316575511 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.313287237 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.313287237 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.316575511 241.483074887 L 254.313287237 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.254893993 193.467520802 L 253.316575511 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.523269602 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.443814536 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.494280952 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.544747369 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.544747369 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.494280952 86.3559001513 L 245.544747369 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.443814536 115.903933434 L 245.494280952 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.523269602 145.451966717 L 245.443814536 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.254893993 193.467520802 L 217.523269602 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.4158807686 243.329826967 L 172.254893993 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.54474736873576, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.4942809522266, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(245.44381453571751, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(254.31328723719633, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(217.52326960204357, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.31657551114111, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(172.2548939933576, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(77.415880768582667, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t191b9e29c7c94ee8a86a1ec987c3d539"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tad297cb60f9a4152bb0e0cc2c8b8a895"><g class="toyplot-Edges"><path d="M 76.5958015003 243.329826967 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.77077326 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.187121196 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.187121196 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.77077326 241.483074887 L 254.187121196 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.478168102 193.467520802 L 253.77077326 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.542462754 145.451966717 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.986328513 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.024178326 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.162960971 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.162960971 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.024178326 86.3559001513 L 246.162960971 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.986328513 115.903933434 L 246.024178326 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.542462754 145.451966717 L 245.986328513 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.478168102 193.467520802 L 215.542462754 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.5958015003 243.329826967 L 177.478168102 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.16296097097256, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.02417832557242, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.98632851319059, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(254.18712119592359, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(215.54246275406038, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(253.77077325972328, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(177.47816810205214, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(76.595801500309378, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc8e8ab835b6e41d8babdea807dfdb91f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te8cdb1184bca4cb5aa525a7bcf798d1d"><g class="toyplot-Edges"><path d="M 70.0099341459 243.329826967 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.013777012 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.922172509 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.922172509 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.013777012 241.483074887 L 253.922172509 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.172617821 193.467520802 L 253.013777012 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.470051403 145.451966717 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.166249245 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.191482453 86.3559001513 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.721379827 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.721379827 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.191482453 86.3559001513 L 245.721379827 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.166249245 115.903933434 L 245.191482453 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.470051403 145.451966717 L 245.166249245 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.172617821 193.467520802 L 214.470051403 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.0099341459 243.329826967 L 174.172617821 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.72137982651768, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.19148245317183, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.16624924491728, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.92217250925066, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(214.47005140324143, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(253.01377701208639, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(174.17261782070437, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(70.009934145868442, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb7817b3096914e45b9551953a5f628be"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb0205b89e5ec4fb4a17ec0b72e5aeb35"><g class="toyplot-Edges"><path d="M 79.0938891175 243.329826967 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.073571759 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.149271384 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.149271384 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.073571759 241.483074887 L 254.149271384 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.393676639 193.467520802 L 254.073571759 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.248992585 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.797079451 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.82231266 86.3559001513 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.011561721 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.011561721 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.82231266 86.3559001513 L 246.011561721 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.797079451 115.903933434 L 245.82231266 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 216.248992585 145.451966717 L 245.797079451 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.393676639 193.467520802 L 216.248992585 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.0938891175 243.329826967 L 172.393676639 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.01156172144516, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.82231265953592, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.79707945128135, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(254.14927138354176, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(216.24899258518815, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(254.07357175877803, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(172.39367663875771, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(79.093889117511111, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbcc38ff5751742fc9cab47b8d1363a3a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te887f74bd53647e7af91e15e2dc870dd"><g class="toyplot-Edges"><path d="M 78.6270747648 243.329826967 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.117998119 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.426836674 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.426836674 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.117998119 241.483074887 L 254.426836674 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.478704594 193.467520802 L 252.117998119 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.829892867 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.683530014 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.708763222 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.301743616 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.301743616 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.708763222 86.3559001513 L 246.301743616 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.683530014 115.903933434 L 245.708763222 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.829892867 145.451966717 L 245.683530014 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.478704594 193.467520802 L 212.829892867 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.6270747648 243.329826967 L 173.478704594 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.30174361637262, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.70876322239039, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.68353001413584, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(254.42683667434193, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(212.82989286669488, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.11799811904939, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(173.4787045937039, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(78.627074764801691, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6da2e124894f4deba66dff74810a73c0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc69da87dca7c473f8072420a7a898c26"><g class="toyplot-Edges"><path d="M 74.9430263596 243.329826967 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.701650183 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.294630577 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.294630577 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.701650183 241.483074887 L 252.294630577 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.436493524 193.467520802 L 251.701650183 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.76298508 145.451966717 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.30503189 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.342881703 86.3559001513 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.469047744 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.469047744 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.342881703 86.3559001513 L 245.469047744 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.30503189 115.903933434 L 245.342881703 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.76298508 145.451966717 L 245.30503189 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.436493524 193.467520802 L 217.76298508 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.9430263596 243.329826967 L 182.436493524 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.46904774397206, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.34288170269923, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(245.30503189031737, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.29463057683131, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(217.7629850804619, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(251.70165018284908, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.43649352407374, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(74.943026359635496, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9e1c8807ae054acead12d21a50d7bf77"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta0a9859751884e1b9b3079ff476cd53c"><g class="toyplot-Edges"><path d="M 74.0598640707 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.638567162 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.81519962 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.81519962 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.638567162 241.483074887 L 251.81519962 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.954310785 189.774016641 L 251.638567162 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.819491553 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.901300558 101.129916793 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.901300558 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.418581327 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.418581327 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.901300558 115.903933434 L 245.418581327 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.901300558 101.129916793 L 244.901300558 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.819491553 138.064958396 L 244.901300558 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.954310785 189.774016641 L 219.819491553 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.0598640707 241.483074887 L 178.954310785 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.4185813274629, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(244.9013005582444, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(244.9013005582444, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.81519961999462, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(219.81949155320876, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.63856716221267, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(178.95431078494406, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(74.05986407072578, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t825634b07b3940afae3e76dfd67b6b33"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t958a193cba52442abac645612d2cbfd2"><g class="toyplot-Edges"><path d="M 72.6215712002 243.329826967 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.979215474 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.218930952 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.218930952 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.979215474 241.483074887 L 252.218930952 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.972967445 193.467520802 L 251.979215474 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.806874949 145.451966717 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.633063598 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.633063598 86.3559001513 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.834929264 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.834929264 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.633063598 86.3559001513 L 245.834929264 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.633063598 115.903933434 L 245.633063598 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.806874949 145.451966717 L 245.633063598 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.972967445 193.467520802 L 219.806874949 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.6215712002 243.329826967 L 180.972967445 193.467520802" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.83492926366318, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.63306359762669, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.63306359762669, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.21893095206769, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(219.80687494908148, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.9792154736493, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(180.97296744530908, 193.46752080181543)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(72.621571200215698, 243.32982696671712)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t708981bc115f4fcf9cc037f949d49194"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2ed7f320a5bc404ca85eb53a4740fa14"><g class="toyplot-Edges"><path d="M 60.6357972793 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.196986018 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.348385267 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.348385267 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.196986018 241.483074887 L 251.348385267 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.528634519 189.774016641 L 251.196986018 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.1288666 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.232620539 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.245237144 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.396636393 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.396636393 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.245237144 115.903933434 L 244.396636393 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.232620539 101.129916793 L 244.245237144 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.1288666 138.064958396 L 244.232620539 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.528634519 189.774016641 L 218.1288666 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.6357972793 241.483074887 L 177.528634519 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038327, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038327, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038327, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038327, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.39663639315313, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.24523714362576, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.23262053949847, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.34838526728524, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(218.12886660015309, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.19698601775787, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(177.52863451856126, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(60.635797279298295, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te32f3ad1c3af49ebb5d324b97fcfa6a9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta0b5f26e1b2b4992aaff1ca254e3c85f"><g class="toyplot-Edges"><path d="M 77.9836279543 241.483074887 L 261.56783461 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.941365661 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.269397369 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.269397369 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.941365661 241.483074887 L 252.269397369 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.304287427 189.774016641 L 251.941365661 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.385023448 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.645680202 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.645680202 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.380731515 101.129916793 L 245.645680202 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.380731515 115.903933434 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.380731515 115.903933434 L 261.56783461 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.380731515 101.129916793 L 245.380731515 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.385023448 138.064958396 L 245.380731515 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.304287427 189.774016641 L 213.385023448 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.9836279543 241.483074887 L 180.304287427 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(261.56783461038322, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.38073151508107, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.645680201754, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.38073151508107, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.26939736857676, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(213.38502344829521, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(251.94136566126747, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.30428742656318, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(77.98362795431035, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t77eb846b8c894c6fa3664e85317cf5d7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te225b8861f7142a7a86af8c08e3647d3"><g class="toyplot-Edges"><path d="M 64.2567626638 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.512401121 241.483074887 L 261.580451215 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.408180014 219.322049924 L 261.56783461 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.408180014 219.322049924 L 261.56783461 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.512401121 241.483074887 L 252.408180014 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.468839772 189.774016641 L 251.512401121 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.885862848 138.064958396 L 261.580451215 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.636351872 101.129916793 L 261.56783461 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.674201684 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.939150371 86.3559001513 L 261.580451215 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.939150371 86.3559001513 L 261.580451215 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.674201684 115.903933434 L 244.939150371 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.636351872 101.129916793 L 244.674201684 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.885862848 138.064958396 L 244.636351872 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.468839772 189.774016641 L 218.885862848 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.2567626638 241.483074887 L 176.468839772 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.56783461038322, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.93915037062624, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.6742016839533, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.63635187157146, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(252.4081800139769, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(218.88586284778995, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.51240112093987, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(176.4688397718696, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(64.25676266382807, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4f4495e0df084a728cbee46fe1be321a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf2813c1ca62245f7907ba7a82c7cc81c"><g class="toyplot-Edges"><path d="M 72.5837213878 241.483074887 L 261.580451215 293.192133132" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.632527106 241.483074887 L 261.56783461 263.644099849" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.922709001 219.322049924 L 261.580451215 234.096066566" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.922709001 219.322049924 L 261.580451215 204.548033283" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.632527106 241.483074887 L 249.922709001 219.322049924" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.22805131 189.774016641 L 249.632527106 241.483074887" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.500788176 138.064958396 L 261.56783461 175.0" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.141016037 86.3559001513 L 261.56783461 56.8078668684" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.141016037 86.3559001513 L 261.56783461 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.712051496 101.129916793 L 245.141016037 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.825600933 115.903933434 L 261.580451215 86.3559001513" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.825600933 115.903933434 L 261.580451215 145.451966717" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.712051496 101.129916793 L 244.825600933 115.903933434" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.500788176 138.064958396 L 244.712051496 101.129916793" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.22805131 189.774016641 L 220.500788176 138.064958396" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.5837213878 241.483074887 L 184.22805131 189.774016641" style="fill:none;opacity:0.05;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 145.4519667170953)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 56.807866868381225)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 204.54803328290467)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 234.09606656580942)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.56783461038322, 263.64409984871406)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.5804512145105, 293.19213313161879)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.82560093348064, 115.90393343419063)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(245.14101603666271, 86.355900151285923)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.71205149633514, 101.12991679273827)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(249.92270900090239, 219.32204992435703)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(220.50078817608195, 138.06495839636912)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(249.63252710597493, 241.48307488653555)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(184.22805131014769, 189.77401664145233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(72.583721387833862, 241.48307488653555)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc3a9ec09adef4b9c9a0dd25d4c96f132"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(261.5804512145105,145.4519667170953)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">P. rex lipskyana</text></g><g class="toyplot-Datum" transform="translate(261.5804512145105,86.355900151285923)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">P. rex rex</text></g><g class="toyplot-Datum" transform="translate(261.56783461038322,115.90393343419063)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">P. rex rockii</text></g><g class="toyplot-Datum" transform="translate(261.56783461038322,56.807866868381225)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">P. thamnophila tham.</text></g><g class="toyplot-Datum" transform="translate(261.56783461038322,175.0)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">P. thamnophila cup.</text></g><g class="toyplot-Datum" transform="translate(261.5804512145105,204.54803328290467)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">P. superba</text></g><g class="toyplot-Datum" transform="translate(261.5804512145105,234.09606656580942)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">P. cyathophylla</text></g><g class="toyplot-Datum" transform="translate(261.56783461038322,263.64409984871406)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">P. cyathophylloides</text></g><g class="toyplot-Datum" transform="translate(261.5804512145105,293.19213313161879)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">P. przewalskii</text></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t317754a2b83e4386bdd5081f7d0fff49";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t875c40612a294cac9514744c4adb1fc9";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82b27e0632f34ee88c37476810cc4e9d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -0.0018270000000000005, -0.0019690000000000003, -0.0045850000000000005, -0.0011720000000000003, -0.00459, -0.0034000000000000002, -0.005255, -0.005531], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82b27e0632f34ee88c37476810cc4e9d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbc5e2cd0e3a64549974277de62b559c3","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -0.001736000000000001, -0.0017870000000000008, -0.004414000000000001, -0.0008810000000000007, -0.004425000000000001, -0.003944000000000001, -0.005030000000000001, -0.005326000000000001], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbc5e2cd0e3a64549974277de62b559c3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7415ea21fbf44ea993f79eb17d824643","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -0.0019330000000000007, -0.0019470000000000008, -0.0048400000000000006, -0.0009990000000000008, -0.004847000000000001, -0.0037750000000000006, -0.005496000000000001, -0.005815000000000001], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7415ea21fbf44ea993f79eb17d824643","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0069e64e743d4b46b8f9b2f203dd942e","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000018675e-06, -1.0000000000018675e-06, -1.0000000000018675e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, -0.0019459999999999998, -0.0019770000000000005, -0.0048660000000000005, -0.0007350000000000004, -0.004889, -0.0035020000000000003, -0.005553000000000001, -0.005909], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0069e64e743d4b46b8f9b2f203dd942e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta13ebba49f2444398373e0dea8df329b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -0.0019050000000000004, -0.001922, -0.004764000000000001, -0.0006500000000000004, -0.004808000000000001, -0.003723, -0.0054930000000000005, -0.005838], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta13ebba49f2444398373e0dea8df329b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb205812098a745d29310a854dd83e842","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0020310000000000007, -0.002052000000000001, -0.005093, -0.000648000000000001, -0.005111, -0.003673, -0.0058130000000000005, -0.00619], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb205812098a745d29310a854dd83e842","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc3691247630b40c2a9bc3122343a052b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -0.0020870000000000003, -0.0021400000000000004, -0.005289000000000001, -0.0007390000000000009, -0.005323000000000001, -0.003439000000000001, -0.006121000000000001, -0.006417000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc3691247630b40c2a9bc3122343a052b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89c4ec5f03244a15a411d6269dd96901","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -1.999999999999398e-06, -1.999999999999398e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.0019839999999999997, -0.0020109999999999998, -0.005032999999999999, -0.0007349999999999995, -0.005044, -0.0029929999999999996, -0.0058649999999999996, -0.006167], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89c4ec5f03244a15a411d6269dd96901","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t05e383cf12e04a9c8b9bc41dc1310a4c","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.0019460000000000007, -0.001960000000000001, -0.004880000000000001, -0.0006500000000000004, -0.004896, -0.0026230000000000003, -0.0057540000000000004, -0.0060420000000000005], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t05e383cf12e04a9c8b9bc41dc1310a4c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t077cb99fa65549aa8ac68b7fb26ec25e","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -1.0000000000001327e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0018019999999999998, -0.0018129999999999995, -0.004495, -0.0007159999999999996, -0.004519, -0.0025659999999999997, -0.005403, -0.005637], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t077cb99fa65549aa8ac68b7fb26ec25e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8e030174b4a94ddebbd5c4619f20e5b0","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -0.0019910000000000006, -0.0019960000000000004, -0.004894000000000001, -0.0006820000000000003, -0.004966, -0.00237, -0.005945000000000001, -0.006224], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8e030174b4a94ddebbd5c4619f20e5b0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1f176a2d9043401b8e1073705ef2e552","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0019379999999999996, -0.0019429999999999994, -0.0046949999999999995, -0.0006680000000000002, -0.004777, -0.002445, -0.0057859999999999995, -0.006063], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1f176a2d9043401b8e1073705ef2e552","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a69b1dd0ecf469897be000bb8f8911f","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.0000000000001327e-06, -2.0000000000002655e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -0.0020620000000000005, -0.002066, -0.004966, -0.0008599999999999997, -0.005038000000000001, -0.00262, -0.006137, -0.006439], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a69b1dd0ecf469897be000bb8f8911f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0e542732795748b7809f6ad32d2b8904","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -0.0020170000000000006, -0.0020250000000000008, -0.004854000000000001, -0.0007910000000000009, -0.004936000000000001, -0.0034160000000000006, -0.0060030000000000005, -0.006351000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0e542732795748b7809f6ad32d2b8904","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfdcd868b815c4b23a2fd8388701ae5f3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.001962, -0.0019660000000000007, -0.004712000000000001, -0.0006880000000000011, -0.004778000000000001, -0.002998000000000001, -0.005912000000000001, -0.006182000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfdcd868b815c4b23a2fd8388701ae5f3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t27d4044631604894bfa0f05ab1aa0773","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.673617379884035e-19, 0.0, -0.002097, -0.00211, -0.005038000000000001, -0.0007520000000000001, -0.005098, -0.0036090000000000002, -0.006315, -0.006616], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t27d4044631604894bfa0f05ab1aa0773","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t750ed77a4c094b44ae7930479353fd13","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002012999999999999, -0.0020619999999999996, -0.004912, -0.0006549999999999993, -0.004971, -0.003351, -0.006196999999999999, -0.006493], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t750ed77a4c094b44ae7930479353fd13","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf3c26699f81b4ad88fc9b6ef773c8e8f","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -1.0000000000001327e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0019439999999999995, -0.001959, -0.004644, -0.0005419999999999991, -0.004716, -0.0038969999999999994, -0.0059229999999999994, -0.006225], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf3c26699f81b4ad88fc9b6ef773c8e8f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfcf2f9fe848f44d8a08b714eb516d1ee","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -1.0000000000001327e-06, -0.001967, -0.0019959999999999995, -0.004706, -0.0004989999999999994, -0.004772, -0.003789, -0.0059559999999999995, -0.006312], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfcf2f9fe848f44d8a08b714eb516d1ee","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a994c325e974037bb405584b8a436dc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.0000000000018675e-06, -0.0018950000000000009, -0.001980000000000001, -0.0046250000000000015, -0.0006020000000000018, -0.004713000000000002, -0.0035920000000000014, -0.005963000000000001, -0.0062850000000000015], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a994c325e974037bb405584b8a436dc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t40e49f0432a74921a1b85650dac30c73","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -1.0000000000001327e-06, 0.0, -0.0020090000000000004, -0.0020740000000000003, -0.004669, -0.0004889999999999999, -0.0047810000000000005, -0.003595, -0.006106, -0.006479], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t40e49f0432a74921a1b85650dac30c73","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcc998e3b13354a67a9816bbbb345d54c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -2.0000000000002655e-06, -0.002084, -0.002175, -0.004483, -0.0005830000000000002, -0.00474, -0.0032220000000000005, -0.006312, -0.006726], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcc998e3b13354a67a9816bbbb345d54c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c98a13bd9f14976b309f8c72b96b444","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -8.673617379884035e-19, -8.673617379884035e-19, -0.0021290000000000007, -0.002145000000000001, -0.003944000000000001, -0.0005840000000000012, -0.004149000000000001, -0.0034910000000000006, -0.006504000000000001, -0.006965000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c98a13bd9f14976b309f8c72b96b444","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8d9a8f93c0b743968295e97050401273","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -1.734723475976807e-18, -0.002268000000000001, -0.0022790000000000015, -0.0037930000000000017, -0.0006070000000000016, -0.0040240000000000015, -0.004061000000000002, -0.006844000000000001, -0.0073170000000000015], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8d9a8f93c0b743968295e97050401273","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t533ad1708fba44238f620e92358caeb2","vertex_data","graph vertex data",["x", "y"],[[-8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, 0.0, 0.0, -8.673617379884035e-19, -0.0022860000000000016, -0.002294000000000001, -0.0036150000000000015, -0.0005840000000000012, -0.0037060000000000014, -0.003983000000000001, -0.006927000000000001, -0.007400000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t533ad1708fba44238f620e92358caeb2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0561566573f045a6bb9e51587027e44b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.002321, -0.0023239999999999997, -0.0035789999999999997, -0.0006300000000000004, -0.003699, -0.003509, -0.007066, -0.007587], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0561566573f045a6bb9e51587027e44b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb78db087fdb44ef89a2d685ceba13a90","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0023999999999999994, -0.0024029999999999998, -0.0036559999999999995, -0.0006559999999999995, -0.003798, -0.0035179999999999994, -0.007316, -0.007861], [7.0, 6.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb78db087fdb44ef89a2d685ceba13a90","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3277151ded06444c92e96ee43477fb25","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0023809999999999994, -0.002385, -0.003568, -0.0007100000000000006, -0.0036879999999999994, -0.0036689999999999995, -0.007337, -0.007909], [7.0, 6.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3277151ded06444c92e96ee43477fb25","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tac4e037833ce42af9246658cad8dad02","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002353, -0.0023569999999999997, -0.0034399999999999995, -0.0006579999999999997, -0.0035700000000000003, -0.0038979999999999996, -0.007467, -0.007894], [7.0, 8.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tac4e037833ce42af9246658cad8dad02","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8793b0d3d5054b49bc294f0febffbc5b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.734723475976807e-18, -0.002367000000000002, -0.0023710000000000016, -0.003190000000000001, -0.0007090000000000022, -0.0034220000000000014, -0.003914000000000002, -0.0073500000000000015, -0.007925000000000001], [7.0, 8.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8793b0d3d5054b49bc294f0febffbc5b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2e66521e9f934b7fa273bba3136f9a54","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0023439999999999997, -0.0024269999999999995, -0.0028909999999999995, -0.0006220000000000002, -0.003439, -0.004514, -0.007324, -0.008038], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2e66521e9f934b7fa273bba3136f9a54","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0a7d58f6289748a3ae9f768121c1b624","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0023699999999999997, -0.0023819999999999996, -0.0026889999999999996, -0.0008159999999999999, -0.003117, -0.0036950000000000004, -0.007487, -0.008326], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0a7d58f6289748a3ae9f768121c1b624","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t440dc0fd59234d1aa6a30f9c6876284e","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002366, -0.002372, -0.002436, -0.0007160000000000005, -0.002824, -0.003562000000000001, -0.0073820000000000005, -0.008368], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t440dc0fd59234d1aa6a30f9c6876284e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0b9e085a9a7d47bf9e94871710436b28","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.002502999999999999, -0.002568, -0.002666, -0.0009349999999999983, -0.0027739999999999996, -0.003704, -0.007598, -0.008853], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0b9e085a9a7d47bf9e94871710436b28","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc894489227894d55965d15fef650c8ba","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0025330000000000005, -0.0026440000000000005, -0.002725, -0.0007800000000000012, -0.0029969999999999997, -0.003573, -0.0072440000000000004, -0.009247], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc894489227894d55965d15fef650c8ba","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tae594af00427463e89652d532c400594","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -0.002404999999999999, -0.0025429999999999993, -0.00258, -0.0007399999999999993, -0.003072, -0.0032759999999999994, -0.006657, -0.008721], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tae594af00427463e89652d532c400594","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7ea78ce96384471780f877e8986f3231","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.002644999999999999, -0.002689999999999999, -0.002728999999999999, -0.0007480000000000004, -0.002927999999999999, -0.003240999999999999, -0.007470999999999999, -0.00929], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7ea78ce96384471780f877e8986f3231","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9fb554ebead04be884b8042e6c35d561","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.002686000000000001, -0.002714000000000001, -0.002759000000000001, -0.0007640000000000008, -0.0030830000000000007, -0.0035020000000000008, -0.007099000000000001, -0.009756], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9fb554ebead04be884b8042e6c35d561","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t439a56a27b684d90822e7dae95d46de9","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0025249999999999995, -0.002548999999999999, -0.002576, -0.000699, -0.0030489999999999996, -0.0025509999999999994, -0.006591, -0.009757], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t439a56a27b684d90822e7dae95d46de9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5667ce474a7d45558b77ccc06d3bdcfe","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002293999999999999, -0.0023510000000000007, -0.0023560000000000005, -0.0006540000000000001, -0.0028129999999999995, -0.0017579999999999991, -0.007228, -0.009576], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5667ce474a7d45558b77ccc06d3bdcfe","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9fe3ca6d04384b9cb7614b06b258850f","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -1.9999999999985307e-06, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, -9.999999999992654e-07, -1.9999999999985307e-06, -0.0023139999999999983, -0.002325999999999998, -0.0023469999999999984, -0.000677999999999998, -0.0027249999999999983, -0.002062999999999999, -0.0072489999999999985, -0.009659999999999998], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9fe3ca6d04384b9cb7614b06b258850f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t36caf7a7014241d8ab364ac786c510cc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.002328, -0.0023700000000000006, -0.0024010000000000004, -0.0006390000000000007, -0.0028470000000000006, -0.0017810000000000013, -0.007385000000000001, -0.009688], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t36caf7a7014241d8ab364ac786c510cc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9a76365d280942f88af0d8b106a35b4b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.002301000000000001, -0.0023090000000000003, -0.002347, -0.0006270000000000008, -0.0028600000000000006, -0.0018130000000000004, -0.007308, -0.009648], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9a76365d280942f88af0d8b106a35b4b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t362ababfb2cb40f9979e6536cc33c644","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002092, -0.0021020000000000006, -0.002138000000000001, -0.0006010000000000008, -0.0026380000000000006, -0.001609000000000001, -0.006849000000000001, -0.009430000000000001], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t362ababfb2cb40f9979e6536cc33c644","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tff0e4186a3ff42cb9193e7c60b163808","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, 0.0, -0.0021799999999999996, -0.002180999999999999, -0.0022049999999999986, -0.0007359999999999988, -0.0030219999999999986, -0.0018279999999999998, -0.007179, -0.009954], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tff0e4186a3ff42cb9193e7c60b163808","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1ede4fc78b624c9c920bd6ad3ff27f3f","vertex_data","graph vertex data",["x", "y"],[[-2.000000000002e-06, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.0022520000000000005, -0.0022520000000000005, -0.0022650000000000014, -0.0007489999999999997, -0.0027930000000000003, -0.0016770000000000014, -0.007384000000000001, -0.010807], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1ede4fc78b624c9c920bd6ad3ff27f3f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te5251a377a774176a3b422f87434c09f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.734723475976807e-18, 0.0, -0.002242000000000001, -0.002242000000000001, -0.002254000000000001, -0.0006620000000000011, -0.002659, -0.0016510000000000014, -0.007379, -0.010859], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te5251a377a774176a3b422f87434c09f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t997bb60063a848afbacaf75ce4a739c0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.002261000000000001, -0.0022640000000000004, -0.0022850000000000006, -0.0008510000000000011, -0.002567, -0.0018060000000000003, -0.007513000000000001, -0.011067], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t997bb60063a848afbacaf75ce4a739c0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1d6854d87ca7456db1fb575be0fbc29c","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -0.0022099999999999984, -0.0022169999999999985, -0.002227, -0.0008979999999999995, -0.0027019999999999995, -0.0016169999999999986, -0.007110999999999998, -0.011362999999999998], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1d6854d87ca7456db1fb575be0fbc29c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t54a85352b20f487486f7757e33332395","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002116, -0.0021379999999999993, -0.0021469999999999996, -0.0007939999999999996, -0.0030080000000000003, -0.0016699999999999996, -0.007069, -0.011594], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t54a85352b20f487486f7757e33332395","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0106a2575b5d4aab9bd563c4c80d4ff0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0019900000000000004, -0.0020020000000000003, -0.0020100000000000014, -0.0007140000000000011, -0.0035960000000000002, -0.0015350000000000016, -0.006670000000000001, -0.011511], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0106a2575b5d4aab9bd563c4c80d4ff0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf78ed82960864282b7c0ae571dcab1c6","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0018410000000000024, -0.0018450000000000012, -0.0018540000000000015, -0.0007660000000000011, -0.0029830000000000013, -0.0009300000000000003, -0.006720000000000001, -0.011435], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf78ed82960864282b7c0ae571dcab1c6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0e706fe755ee4a09abdc8110f046ebf3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0018449999999999994, -0.0018519999999999995, -0.001856, -0.0006080000000000009, -0.002863000000000001, -0.0012099999999999993, -0.006675, -0.011792], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0e706fe755ee4a09abdc8110f046ebf3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tba5594fb15e34ba5a63cfdf912aed4f3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0019019999999999992, -0.001934, -0.0019369999999999995, -0.0006370000000000004, -0.0032169999999999994, -0.0014509999999999992, -0.006569, -0.012366], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tba5594fb15e34ba5a63cfdf912aed4f3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0813dbdb809a47c78b405b8e24145b17","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001745, -0.0017590000000000001, -0.0017600000000000011, -0.000596000000000001, -0.003262000000000001, -0.001262000000000001, -0.0066240000000000005, -0.011511], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0813dbdb809a47c78b405b8e24145b17","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t057788a70d6f40439f49dfbd1175585b","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, 0.0, -0.001831000000000001, -0.0018499999999999992, -0.0018510000000000002, -0.0006589999999999999, -0.003051, -0.0015099999999999992, -0.006648, -0.012324], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t057788a70d6f40439f49dfbd1175585b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te2d356498f1843ddbb0a939bdedcb207","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0019950000000000002, -0.001975000000000001, -0.0020020000000000003, -0.0007769999999999999, -0.003013, -0.001398, -0.007052, -0.013516], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te2d356498f1843ddbb0a939bdedcb207","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta9229b67e9234006893718a7d75ed916","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -0.0019030000000000002, -0.0018539999999999997, -0.0019140000000000008, -0.0007329999999999993, -0.003027, -0.0012490000000000001, -0.006875, -0.013479], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta9229b67e9234006893718a7d75ed916","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t72af349b97be420d9402dc264d29a9e4","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, -0.0019330000000000007, -0.0019280000000000026, -0.0019380000000000022, -0.0006620000000000011, -0.0033050000000000024, -0.0011450000000000002, -0.007373000000000001, -0.01352], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t72af349b97be420d9402dc264d29a9e4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t721120d8319c4871bc14a73cdbcbad67","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0019019999999999992, -0.0019039999999999994, -0.001908, -0.0006300000000000004, -0.003266, -0.0015530000000000006, -0.006709, -0.013347], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t721120d8319c4871bc14a73cdbcbad67","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7d773fbe6cbe44dd815ca3d28f5097bd","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0019570000000000004, -0.00196, -0.0019629999999999995, -0.000621, -0.003266, -0.0012759999999999994, -0.006873, -0.013998], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7d773fbe6cbe44dd815ca3d28f5097bd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t62c7ae7ff828446fb220be33cd4eee8c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.001850000000000001, -0.001857000000000001, -0.0018589999999999995, -0.000536, -0.0037549999999999997, -0.0012050000000000012, -0.006111, -0.014096000000000001], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t62c7ae7ff828446fb220be33cd4eee8c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc05c9bfd4e5048348d41a963b5fc2ec3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.0017990000000000003, -0.0018090000000000016, -0.0018110000000000001, -0.0005320000000000012, -0.003564000000000001, -0.0009460000000000007, -0.006868000000000001, -0.014266000000000001], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc05c9bfd4e5048348d41a963b5fc2ec3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t50f957954e024f8781f67cdd2b4e8037","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.001854999999999999, -0.0018609999999999998, -0.001864000000000001, -0.000593999999999999, -0.0033550000000000003, -0.0011590000000000003, -0.006827, -0.014178], [8.0, 5.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t50f957954e024f8781f67cdd2b4e8037","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td0b947cc88654ee7854541f772d680a7","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.0017560000000000006, -0.0017840000000000009, -0.0017850000000000019, -0.0005980000000000013, -0.003124, -0.0010280000000000011, -0.0066430000000000005, -0.013586], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td0b947cc88654ee7854541f772d680a7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8c2a6c763f2b4481b7de939bbc9a719c","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -0.0018239999999999992, -0.0017870000000000004, -0.0018260000000000012, -0.0006180000000000005, -0.003143, -0.0012469999999999998, -0.006543, -0.013731], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8c2a6c763f2b4481b7de939bbc9a719c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t63fa5183a0ab4702abc42fe0d979007c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0018550000000000007, -0.0018709999999999994, -0.001876000000000001, -0.0005820000000000009, -0.0033550000000000003, -0.001079, -0.006914, -0.014031], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t63fa5183a0ab4702abc42fe0d979007c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc98b27d9c51d44449106468017d879bc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -0.001849, -0.0018729999999999997, -0.0018740000000000007, -0.000595, -0.003254, -0.001098, -0.006392, -0.013748], [8.0, 5.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc98b27d9c51d44449106468017d879bc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t201b08ab004242c7abf5eea81e9f70c4","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0019179999999999996, -0.0019229999999999994, -0.001927, -0.0005730000000000006, -0.003235, -0.0012469999999999998, -0.006435, -0.014202], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t201b08ab004242c7abf5eea81e9f70c4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te56b3e92bd0247dbbc2ff2aae6aa072a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0018159999999999982, -0.0018320000000000003, -0.0018339999999999988, -0.0006040000000000004, -0.002848, -0.001044999999999999, -0.0063349999999999995, -0.014067], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te56b3e92bd0247dbbc2ff2aae6aa072a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tee9539d6b85b48728ccb8db46c7af9d1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, -1.000000000001e-06, -0.0018939999999999999, -0.0018970000000000011, -0.001901, -0.0006340000000000009, -0.0030679999999999995, -0.0009230000000000002, -0.00698, -0.015027], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tee9539d6b85b48728ccb8db46c7af9d1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf32674d1febc489d8790baef5c2e11a6","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -0.001875, -0.0018790000000000005, -0.001882, -0.0006240000000000013, -0.0029370000000000004, -0.0009549999999999993, -0.0067740000000000005, -0.014861000000000001], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf32674d1febc489d8790baef5c2e11a6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td75751771fa04fe3beb976d4773d3906","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001903000000000002, -0.0019130000000000015, -0.0019130000000000015, -0.0006920000000000016, -0.0032780000000000014, -0.001236000000000001, -0.006484000000000002, -0.015696], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td75751771fa04fe3beb976d4773d3906","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t61dfdc90de474ee8a73d33f099ddd7e4","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0018459999999999987, -0.0018609999999999998, -0.0018620000000000008, -0.0006069999999999999, -0.00332, -0.0012809999999999992, -0.007052, -0.014659], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t61dfdc90de474ee8a73d33f099ddd7e4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8df5b1e45b8d446e98d565a9ef876076","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0016750000000000011, -0.001680000000000001, -0.0016840000000000015, -0.0005540000000000024, -0.003046, -0.001015000000000002, -0.006831000000000001, -0.014086000000000001], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8df5b1e45b8d446e98d565a9ef876076","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcaf768e758af42148a37ab18f7fa7535","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.001628000000000001, -0.0016320000000000015, -0.0016370000000000013, -0.0005920000000000022, -0.003334, -0.000903000000000001, -0.007163000000000001, -0.013746000000000001], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcaf768e758af42148a37ab18f7fa7535","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2587c8999088436bb1c62d71e9db588b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001595000000000001, -0.0015980000000000005, -0.001602000000000001, -0.0006340000000000009, -0.0037080000000000012, -0.000811000000000001, -0.006883, -0.013854], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2587c8999088436bb1c62d71e9db588b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t65ba82cf87444f2da3375e0693c784cc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, -1.000000000001e-06, -0.00166, -0.001661000000000001, -0.001667, -0.0007350000000000013, -0.0035989999999999998, -0.0008509999999999993, -0.006354, -0.014378], [5.0, 7.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t65ba82cf87444f2da3375e0693c784cc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2dd7f66e6807432f96e7af87c60d5d1e","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999975306e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0017459999999999976, -0.0017469999999999986, -0.0017789999999999993, -0.0005669999999999981, -0.0030479999999999986, -0.000954, -0.006655999999999999, -0.015118], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2dd7f66e6807432f96e7af87c60d5d1e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t47e0cc05cdb94c30b7fd308e5c0a4d00","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.469446951953614e-18, -0.0017960000000000025, -0.0018030000000000025, -0.0018120000000000011, -0.000623000000000002, -0.0035210000000000016, -0.0010510000000000016, -0.006543000000000002, -0.015828000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t47e0cc05cdb94c30b7fd308e5c0a4d00","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta24aeb67b5a140a185491ecc1f36a49a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0016290000000000002, -0.0016400000000000008, -0.001646, -0.0005789999999999997, -0.003335000000000001, -0.0009000000000000015, -0.006845, -0.014963], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta24aeb67b5a140a185491ecc1f36a49a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3228d372cff04bdd9058f95e51c416f2","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0016900000000000005, -0.0017010000000000011, -0.0017110000000000007, -0.0007130000000000018, -0.0035659999999999997, -0.001040000000000001, -0.006325000000000001, -0.015667], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3228d372cff04bdd9058f95e51c416f2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taddcd459956c48b2905307f6aaf14ad9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -1.000000000001e-06, -0.0016480000000000002, -0.0016579999999999998, -0.0016629999999999995, -0.0006859999999999991, -0.003162999999999999, -0.000900999999999999, -0.006626999999999999, -0.015961], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taddcd459956c48b2905307f6aaf14ad9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t015c2ea397e3439e9ac9ad1a767a58c3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -0.0017870000000000021, -0.0017890000000000024, -0.001805000000000001, -0.0009350000000000018, -0.0035130000000000022, -0.0011510000000000027, -0.006569000000000002, -0.016681], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t015c2ea397e3439e9ac9ad1a767a58c3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td48b205889044b8ebf23f5b119a9d28b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0017239999999999998, -0.0017789999999999993, -0.0017879999999999997, -0.0007769999999999999, -0.002999999999999999, -0.0010959999999999998, -0.006362, -0.01677], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td48b205889044b8ebf23f5b119a9d28b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t25408a8845ea4a8f964b63a05d74563a","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0016749999999999994, -0.0017300000000000006, -0.0017409999999999995, -0.0007609999999999995, -0.003307000000000001, -0.0009440000000000004, -0.006763, -0.01616], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t25408a8845ea4a8f964b63a05d74563a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0fb1e99a6942414aa77711c4d97e88aa","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0016039999999999995, -0.0016939999999999993, -0.0017029999999999997, -0.0007029999999999988, -0.0030159999999999996, -0.0008489999999999991, -0.0070539999999999995, -0.015427], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0fb1e99a6942414aa77711c4d97e88aa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t57979dbf5445415b8a9aa4c9453c2d77","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -0.001549, -0.0016879999999999985, -0.0016949999999999986, -0.0007989999999999994, -0.0030619999999999988, -0.0008780000000000003, -0.0064139999999999996, -0.015545], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t57979dbf5445415b8a9aa4c9453c2d77","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcef46735146549dabb2c5c998868d9dc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0015350000000000016, -0.0016160000000000011, -0.0016510000000000014, -0.0007940000000000013, -0.003328000000000001, -0.0008990000000000005, -0.006825000000000001, -0.015266000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcef46735146549dabb2c5c998868d9dc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t525fb85d7ed145e6964fb5ee2176558d","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0013490000000000012, -0.0015340000000000006, -0.0015610000000000016, -0.0007760000000000006, -0.002961, -0.0009530000000000007, -0.007135000000000001, -0.014642], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t525fb85d7ed145e6964fb5ee2176558d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdcefff4e9fc942299277884d5a4ba381","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0014950000000000015, -0.0015550000000000008, -0.0015810000000000008, -0.0008439999999999993, -0.0027360000000000006, -0.000869, -0.007105, -0.015142000000000001], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdcefff4e9fc942299277884d5a4ba381","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t209d7bc7c894476a84ed1fbb6379b3b1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -0.0014770000000000009, -0.0015610000000000016, -0.0015780000000000013, -0.0008360000000000017, -0.0032710000000000013, -0.0008880000000000016, -0.006884000000000001, -0.015186000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t209d7bc7c894476a84ed1fbb6379b3b1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1732d06924644976acf2c9ecf3b44343","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.001543000000000001, -0.0013360000000000021, -0.001551000000000002, -0.0007490000000000014, -0.0035590000000000014, -0.0009430000000000011, -0.006924000000000001, -0.015273000000000002], [5.0, 6.0, 8.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 5.5, 7.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1732d06924644976acf2c9ecf3b44343","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3bcc9472336f4f6e8e9c726f7702e393","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0011540000000000005, -0.0014180000000000009, -0.0014220000000000014, -0.000725, -0.002850000000000002, -0.0008330000000000004, -0.007109000000000001, -0.014724000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3bcc9472336f4f6e8e9c726f7702e393","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t147f33592b2245f59a9652ed7774fbf1","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0010389999999999983, -0.001398, -0.0014029999999999997, -0.0006679999999999985, -0.003382999999999999, -0.0008059999999999994, -0.0067399999999999995, -0.014745999999999999], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t147f33592b2245f59a9652ed7774fbf1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb3cb396f91b1494aba5c094b5c61ec1b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013419999999999994, -0.0014199999999999994, -0.0014260000000000002, -0.0006819999999999986, -0.0030149999999999986, -0.0008039999999999992, -0.006900999999999999, -0.014782], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb3cb396f91b1494aba5c094b5c61ec1b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t125e11ff89dc49a988c3ad8666731997","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001469999999999999, -0.0015060000000000004, -0.0015169999999999993, -0.0008249999999999993, -0.0030159999999999996, -0.000952999999999999, -0.007122, -0.01551], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t125e11ff89dc49a988c3ad8666731997","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t57771ed550084c499c6748c984e9db5c","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013380000000000006, -0.001387000000000001, -0.0013960000000000014, -0.0007160000000000014, -0.003701000000000001, -0.0008500000000000001, -0.006514000000000001, -0.014828000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t57771ed550084c499c6748c984e9db5c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd30131c768b47e288fae7d04b764aa6","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -0.0014160000000000006, -0.0014540000000000004, -0.0014729999999999986, -0.0007930000000000003, -0.003415999999999999, -0.000900999999999999, -0.006867, -0.01508], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd30131c768b47e288fae7d04b764aa6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tccba7921f1d9426e8d3bd511c65591a9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0013039999999999996, -0.0013699999999999997, -0.001398, -0.0008129999999999995, -0.003778, -0.0008349999999999989, -0.006696, -0.014379], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tccba7921f1d9426e8d3bd511c65591a9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t42df7a625c3a420cb9d412603b799541","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0013670000000000002, -0.0014099999999999998, -0.0014420000000000006, -0.0007970000000000008, -0.0033620000000000004, -0.0008310000000000001, -0.006605, -0.01409], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t42df7a625c3a420cb9d412603b799541","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t057de8b2cfa9490fa40fb209feef5b62","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.001509, -0.0015239999999999993, -0.0015489999999999983, -0.0008269999999999996, -0.0036249999999999998, -0.0008400000000000005, -0.007097999999999999, -0.014743], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t057de8b2cfa9490fa40fb209feef5b62","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t664823fb33e84232a9aed90e26295796","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.001412, -0.0014820000000000007, -0.0014990000000000003, -0.0007900000000000008, -0.003346, -0.0008330000000000004, -0.0065710000000000005, -0.014953000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t664823fb33e84232a9aed90e26295796","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0f065b747f4d4c1590697e61c0a107c0","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013750000000000012, -0.0014760000000000016, -0.0015019999999999999, -0.0007230000000000014, -0.00332, -0.0007970000000000008, -0.007287000000000001, -0.015005000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0f065b747f4d4c1590697e61c0a107c0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4c26fc4e7b384a41bc1f21ba8e5b9571","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012729999999999998, -0.0014219999999999997, -0.0014409999999999978, -0.0007489999999999997, -0.003331999999999998, -0.0008209999999999988, -0.007252999999999999, -0.015142], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4c26fc4e7b384a41bc1f21ba8e5b9571","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcca53b70b1d94266bb45170470de8abc","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0013520000000000008, -0.0014670000000000013, -0.001510000000000001, -0.0007520000000000009, -0.0031520000000000003, -0.0008220000000000015, -0.007092000000000001, -0.015228], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcca53b70b1d94266bb45170470de8abc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t48937f11cf084f27884df124b4ab16c8","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.0013810000000000003, -0.0014760000000000016, -0.0015189999999999995, -0.0007480000000000021, -0.0032980000000000006, -0.0008190000000000003, -0.006410000000000001, -0.015304000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t48937f11cf084f27884df124b4ab16c8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t56617da54115430ea4e426f807219e19","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0014069999999999985, -0.0014839999999999992, -0.0015969999999999995, -0.000782999999999999, -0.0036889999999999996, -0.0008629999999999992, -0.006872, -0.015403], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t56617da54115430ea4e426f807219e19","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5fcc290628074be280e6857d4775c707","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013039999999999996, -0.0013209999999999993, -0.0013629999999999996, -0.0007470000000000011, -0.0035759999999999993, -0.0007790000000000002, -0.006213, -0.014543], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5fcc290628074be280e6857d4775c707","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t52674c4b4f2b48dab6926f4865b61bc2","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0012530000000000006, -0.001288000000000001, -0.0013299999999999996, -0.000733000000000001, -0.0033229999999999996, -0.0007430000000000006, -0.006449, -0.014359], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t52674c4b4f2b48dab6926f4865b61bc2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta322ac2344fa45f2a94014bb6b84c238","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013190000000000007, -0.0013630000000000014, -0.0014180000000000009, -0.0007820000000000014, -0.0033840000000000016, -0.0008190000000000003, -0.006771000000000001, -0.015272], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta322ac2344fa45f2a94014bb6b84c238","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta5cdd802da4844fb82f9c5fe38cc2e3f","vertex_data","graph vertex data",["x", "y"],[[-2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.001230000000000002, -0.0012910000000000005, -0.0013430000000000004, -0.0006510000000000023, -0.00349, -0.0007550000000000022, -0.006719000000000001, -0.015214000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta5cdd802da4844fb82f9c5fe38cc2e3f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td314e28bb8884fad925bfd29b3bb1fb2","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -0.0011059999999999993, -0.0012329999999999997, -0.0012709999999999996, -0.0006820000000000003, -0.003174999999999999, -0.000700000000000001, -0.006803, -0.014795], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td314e28bb8884fad925bfd29b3bb1fb2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1f19840b91b47d38247a050528bff0d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012340000000000007, -0.0012780000000000014, -0.0013270000000000018, -0.0007480000000000021, -0.003195, -0.0007530000000000002, -0.007286000000000001, -0.015268], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1f19840b91b47d38247a050528bff0d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ca2b84414be4852a9375677fe206e4e","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0011129999999999994, -0.0012180000000000003, -0.0012560000000000002, -0.0007139999999999994, -0.003089999999999999, -0.0007179999999999999, -0.0070599999999999994, -0.014844], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ca2b84414be4852a9375677fe206e4e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4339045e494f42868872b80abee0a7d2","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012099999999999993, -0.0012189999999999996, -0.0012849999999999997, -0.0006569999999999996, -0.0034129999999999994, -0.0008039999999999992, -0.0071909999999999995, -0.015385], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4339045e494f42868872b80abee0a7d2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3e51dfd476c448b29d535d1a3cceaad1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0012210000000000016, -0.0012280000000000017, -0.0012630000000000002, -0.0006250000000000006, -0.003549, -0.0006690000000000012, -0.006726000000000001, -0.015304000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3e51dfd476c448b29d535d1a3cceaad1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89ee5fc60dca465b974cc0970fa56e81","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0012259999999999997, -0.0012320000000000005, -0.0012560000000000002, -0.000615000000000001, -0.0033970000000000007, -0.0006420000000000019, -0.006594000000000001, -0.015079], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89ee5fc60dca465b974cc0970fa56e81","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc2108a6764d24e64bf81a82c5103a697","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012849999999999997, -0.0013139999999999992, -0.0013360000000000004, -0.0006700000000000005, -0.003837, -0.0008020000000000006, -0.006477, -0.016233], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc2108a6764d24e64bf81a82c5103a697","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t31b48c62c73747f0b8e56bb621dcee64","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -3.469446951953614e-18, -0.0013350000000000029, -0.001356000000000003, -0.0013680000000000012, -0.0007230000000000014, -0.003171000000000002, -0.0009340000000000008, -0.006786000000000002, -0.016391000000000003], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t31b48c62c73747f0b8e56bb621dcee64","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t853390842ad2450ba505cdd8a990fcbd","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, -0.001337999999999999, -0.0013579999999999998, -0.0013619999999999986, -0.0007029999999999988, -0.003587999999999999, -0.0009979999999999989, -0.0064329999999999995, -0.016468], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t853390842ad2450ba505cdd8a990fcbd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t66e0fd2d37734f149cc3053308a0911b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012770000000000004, -0.001373000000000001, -0.001380000000000001, -0.0007380000000000008, -0.0035130000000000005, -0.0008760000000000018, -0.006981000000000001, -0.016067], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t66e0fd2d37734f149cc3053308a0911b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t73ce80bd3c9545acac67271df435a554","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.00136, -0.001413000000000001, -0.0014200000000000011, -0.0006230000000000003, -0.0031190000000000002, -0.0008730000000000005, -0.006366, -0.016187], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t73ce80bd3c9545acac67271df435a554","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcc98be573d98433cb3b710e8afe0e088","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013240000000000005, -0.001431, -0.001438, -0.0006950000000000012, -0.003266999999999999, -0.0008570000000000001, -0.007011, -0.015739], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcc98be573d98433cb3b710e8afe0e088","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t992486234ae54faa890be4ce791875b9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.001200999999999999, -0.0013539999999999993, -0.0013619999999999986, -0.0005429999999999983, -0.0038499999999999993, -0.0010079999999999985, -0.006404999999999999, -0.014941], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t992486234ae54faa890be4ce791875b9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfebfb6e6354e43ff949d3cd8f94eb907","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012310000000000012, -0.0012930000000000007, -0.0013030000000000003, -0.00051, -0.0034730000000000004, -0.0008140000000000005, -0.006672000000000001, -0.014587000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfebfb6e6354e43ff949d3cd8f94eb907","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t497459553beb4cb8b35face70f4618f8","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0011960000000000009, -0.0012460000000000006, -0.001261, -0.0004869999999999996, -0.0035390000000000005, -0.000843, -0.006158, -0.014993000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t497459553beb4cb8b35face70f4618f8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t132edc863c794cc4b8748d1992a58856","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.0011000000000000003, -0.001236000000000001, -0.001243000000000001, -0.0006110000000000004, -0.0034100000000000016, -0.0006990000000000017, -0.007123000000000002, -0.014593000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t132edc863c794cc4b8748d1992a58856","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3904f4a52469467a81459ce8cb228ec2","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -0.0011630000000000008, -0.0012180000000000003, -0.0012220000000000009, -0.0006540000000000018, -0.0037820000000000006, -0.0007200000000000019, -0.0070100000000000015, -0.014728000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3904f4a52469467a81459ce8cb228ec2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t99d8cb1b8d294950b9ca03e3724f64a7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.001269000000000001, -0.0011720000000000012, -0.0012729999999999998, -0.0006130000000000007, -0.0033560000000000013, -0.0007960000000000016, -0.006908000000000001, -0.015258], [5.0, 6.0, 8.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 5.5, 7.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t99d8cb1b8d294950b9ca03e3724f64a7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t273d1c6fcdd745b590e8e5f1ef696980","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012300000000000002, -0.001294, -0.0013019999999999993, -0.0007760000000000006, -0.0032379999999999996, -0.0008570000000000001, -0.007032, -0.01555], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t273d1c6fcdd745b590e8e5f1ef696980","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd349d4f27664e95940fe8841b13aa3e","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.0000000000027348e-06, -1.0000000000027348e-06, -1.734723475976807e-18, 0.0, -0.0011120000000000019, -0.0011700000000000026, -0.0011760000000000017, -0.0006840000000000023, -0.0031540000000000023, -0.0007330000000000027, -0.006234000000000002, -0.014233], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd349d4f27664e95940fe8841b13aa3e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t564bad117cdf458182b347ae267d0f4b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -0.0011999999999999997, -0.0012700000000000003, -0.0012790000000000006, -0.0007380000000000008, -0.003367, -0.0007709999999999991, -0.007455, -0.014804], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t564bad117cdf458182b347ae267d0f4b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd446efd96174db8896122c84bf1b560","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011890000000000008, -0.0012240000000000011, -0.001229000000000001, -0.0006890000000000004, -0.0033480000000000003, -0.0007589999999999993, -0.0067150000000000005, -0.01473], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd446efd96174db8896122c84bf1b560","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0a2e0e0d9ed949a99fd653b612f40c75","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0012310000000000012, -0.0012680000000000018, -0.0012720000000000023, -0.0006960000000000022, -0.0033640000000000024, -0.0007530000000000002, -0.007101000000000001, -0.015311000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0a2e0e0d9ed949a99fd653b612f40c75","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5e658392b4234fe2b79a00c800bc84ba","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012040000000000002, -0.001235, -0.001242, -0.0006910000000000006, -0.003504, -0.0007740000000000004, -0.006779, -0.014953000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5e658392b4234fe2b79a00c800bc84ba","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tda50990b29ce4eaa9cabd1d268e5b981","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.000000000002e-06, -1.000000000001e-06, -0.0011680000000000006, -0.0011780000000000002, -0.0011880000000000016, -0.0006519999999999998, -0.003143, -0.0007510000000000017, -0.006554000000000001, -0.014592], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tda50990b29ce4eaa9cabd1d268e5b981","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf241cb1c8a3f4238ad4694004eb24b93","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011789999999999995, -0.0011890000000000008, -0.0011990000000000004, -0.0006340000000000009, -0.003174999999999999, -0.0007650000000000001, -0.007004, -0.014759], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf241cb1c8a3f4238ad4694004eb24b93","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t04568d91c59448cd8a3ac9dfce46ce62","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0011610000000000006, -0.0011780000000000002, -0.0011820000000000008, -0.0007150000000000004, -0.0036110000000000014, -0.0008190000000000003, -0.006599000000000001, -0.014579], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t04568d91c59448cd8a3ac9dfce46ce62","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t88cd36cef1504ce480ecb76fb1932010","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0011059999999999993, -0.0011199999999999995, -0.001129999999999999, -0.0006849999999999998, -0.0035600000000000007, -0.0007039999999999998, -0.006804, -0.014158], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t88cd36cef1504ce480ecb76fb1932010","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t037ca6995bb44bb8be02a480c2203847","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0011470000000000004, -0.001164, -0.0011780000000000002, -0.0006610000000000019, -0.0032270000000000007, -0.0007039999999999998, -0.006684000000000001, -0.015063], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t037ca6995bb44bb8be02a480c2203847","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t10fffbd2c4584f71831f5e7fa9b2e2f9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0011359999999999999, -0.0011579999999999993, -0.0011699999999999992, -0.0006890000000000004, -0.00332, -0.0006930000000000009, -0.006494, -0.015028999999999999], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t10fffbd2c4584f71831f5e7fa9b2e2f9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8756e070013c453a877ac6e45324ebfd","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, 0.0, -0.0011690000000000016, -0.0011949999999999999, -0.0012040000000000002, -0.0006650000000000007, -0.003458000000000001, -0.0007950000000000006, -0.006427, -0.015193], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8756e070013c453a877ac6e45324ebfd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6ffbf6884e6a46249738dc0c34f522dd","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0011859999999999996, -0.0011949999999999999, -0.0011999999999999997, -0.0006959999999999987, -0.003373000000000001, -0.0008680000000000007, -0.006406, -0.016004], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6ffbf6884e6a46249738dc0c34f522dd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8625a34b35e64b258ef0bbf9ece383b8","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012010000000000007, -0.001210000000000001, -0.0012120000000000013, -0.0006430000000000012, -0.003633000000000001, -0.0007160000000000014, -0.006325000000000001, -0.015948], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8625a34b35e64b258ef0bbf9ece383b8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3345360b2b274c0581969e9f7ed0a197","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001217000000000001, -0.0012270000000000007, -0.0012280000000000017, -0.0006960000000000022, -0.003270000000000002, -0.0008030000000000016, -0.006275000000000001, -0.016507], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3345360b2b274c0581969e9f7ed0a197","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcb0aebc618074cb78a0f1de96c4e1f64","vertex_data","graph vertex data",["x", "y"],[[-3.469446951953614e-18, -3.469446951953614e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, 0.0, -0.0011940000000000006, -0.0011990000000000021, -0.0012000000000000014, -0.000674000000000001, -0.003550000000000001, -0.0007970000000000026, -0.005826000000000001, -0.015838], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcb0aebc618074cb78a0f1de96c4e1f64","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t09a63d28f54c4bb49a22ee493ebb7087","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0012510000000000021, -0.0012910000000000022, -0.0012930000000000025, -0.0007800000000000012, -0.0033920000000000027, -0.0008210000000000023, -0.006900000000000002, -0.016098], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t09a63d28f54c4bb49a22ee493ebb7087","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9b62e5da1d6e420489c5f9f238064e23","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999975306e-07, 0.0, -0.0013099999999999987, -0.0013159999999999995, -0.0013179999999999997, -0.0007659999999999993, -0.0031319999999999994, -0.0008319999999999994, -0.006647999999999999, -0.015781], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9b62e5da1d6e420489c5f9f238064e23","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9014c0fa915a47fa89b27c9a71d2f615","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.001165000000000001, -0.0012060000000000005, -0.0012080000000000007, -0.0007489999999999997, -0.003419, -0.0007939999999999996, -0.0068070000000000006, -0.014790000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9014c0fa915a47fa89b27c9a71d2f615","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8c4e41e8e702495c830659c513e2aa04","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011289999999999998, -0.0011649999999999994, -0.001169, -0.0006999999999999992, -0.003398, -0.000785000000000001, -0.006583, -0.014976], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8c4e41e8e702495c830659c513e2aa04","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5d103cc103e744ae976651c1fae7ad5f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.0000000000044695e-06, -0.001277000000000002, -0.0012650000000000022, -0.001297000000000003, -0.0007460000000000019, -0.003511000000000002, -0.0008580000000000011, -0.006427000000000002, -0.015725000000000003], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5d103cc103e744ae976651c1fae7ad5f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t162509821edb432988e49d065b1768e2","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, -9.999999999975306e-07, -0.0013379999999999972, -0.001336999999999998, -0.0013459999999999982, -0.000677999999999998, -0.003590999999999997, -0.0008479999999999981, -0.006425999999999998, -0.016005], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t162509821edb432988e49d065b1768e2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5158d2677c3047b1871037b4a0a26454","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.001340000000000001, -0.0013390000000000016, -0.0013460000000000017, -0.0007450000000000009, -0.0034930000000000013, -0.0009220000000000009, -0.006294000000000001, -0.015565], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5158d2677c3047b1871037b4a0a26454","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0c1d2b3efd154e069386cba8bb057b93","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013640000000000006, -0.0013769999999999998, -0.0013819999999999995, -0.000674000000000001, -0.003124, -0.0009160000000000001, -0.006836, -0.016128], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0c1d2b3efd154e069386cba8bb057b93","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3a7d40ef2b3f4b5dbfe6763c3deb579d","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, -0.0013399999999999992, -0.0013799999999999993, -0.0013869999999999993, -0.000678999999999999, -0.0035390000000000005, -0.0008319999999999994, -0.006813, -0.015815], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3a7d40ef2b3f4b5dbfe6763c3deb579d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb94c6219b2684b6ebf2926bf8e1e9815","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012780000000000014, -0.001289000000000002, -0.001294, -0.0005509999999999994, -0.003471, -0.0007519999999999992, -0.0068980000000000005, -0.014477], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb94c6219b2684b6ebf2926bf8e1e9815","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2e5346a3fda24eb0a68408dfc0387cb9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012469999999999998, -0.0012490000000000001, -0.001254, -0.0005839999999999995, -0.003549, -0.0006690000000000012, -0.0063820000000000005, -0.014291], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2e5346a3fda24eb0a68408dfc0387cb9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t05e1a55c6c174ecb9047de06cfb03cf4","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013220000000000003, -0.0013430000000000004, -0.0013490000000000012, -0.0006610000000000001, -0.003680000000000001, -0.0008740000000000015, -0.006549000000000001, -0.014909], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t05e1a55c6c174ecb9047de06cfb03cf4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbc65b539762943e9b42e2e5b6ab3ba8e","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0013609999999999994, -0.0013569999999999988, -0.0013670000000000002, -0.0006429999999999995, -0.0033959999999999997, -0.0007620000000000005, -0.006898, -0.015217], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbc65b539762943e9b42e2e5b6ab3ba8e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbbf56a208f514730b810ecf3cf16af7c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013109999999999997, -0.001301, -0.0013150000000000002, -0.0006040000000000004, -0.003306, -0.0008009999999999996, -0.006448000000000001, -0.015151000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbbf56a208f514730b810ecf3cf16af7c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t663073762e0b45b08aa8d47e552b069c","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012930000000000007, -0.0012930000000000007, -0.0013000000000000008, -0.0005880000000000017, -0.003077, -0.0006640000000000014, -0.006734, -0.014807], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t663073762e0b45b08aa8d47e552b069c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta7a84bf84b944f439482b3f027170a6b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0012239999999999994, -0.001229000000000001, -0.001243000000000001, -0.0006200000000000008, -0.0032130000000000006, -0.0007090000000000013, -0.006864, -0.014241], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta7a84bf84b944f439482b3f027170a6b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t37ba938855b6453992d3c0cbd6f67543","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0012180000000000003, -0.0012879999999999992, -0.0012899999999999995, -0.0006149999999999992, -0.0036769999999999997, -0.0007089999999999996, -0.007011999999999999, -0.014913], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t37ba938855b6453992d3c0cbd6f67543","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te926c937edb1433fb77bbb7a04860789","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012530000000000006, -0.0012970000000000013, -0.0012990000000000015, -0.0007170000000000024, -0.0032060000000000005, -0.0008120000000000002, -0.006809000000000001, -0.015005000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te926c937edb1433fb77bbb7a04860789","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t93abb7be3e674d06be2e77ec65a11f80","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0013130000000000017, -0.0013240000000000005, -0.0013260000000000008, -0.0007390000000000001, -0.002955000000000001, -0.0007559999999999997, -0.007383000000000001, -0.015019000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t93abb7be3e674d06be2e77ec65a11f80","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t75aa247023474b2ba7c38c68ed121803","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.0000000000044695e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.001400000000000002, -0.001406000000000001, -0.001408000000000003, -0.000682000000000002, -0.0029500000000000012, -0.0007650000000000018, -0.006706000000000002, -0.015831], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t75aa247023474b2ba7c38c68ed121803","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t85d1117ed8aa4f459e1b0a94052cbde1","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999975306e-07, -0.0014769999999999991, -0.0014769999999999991, -0.0014789999999999977, -0.0006449999999999997, -0.003480999999999998, -0.0009099999999999976, -0.006540999999999998, -0.016158], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t85d1117ed8aa4f459e1b0a94052cbde1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tba134459e4c34c059f0aeaa9c829dc01","vertex_data","graph vertex data",["x", "y"],[[-3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0015400000000000014, -0.0015420000000000017, -0.0015420000000000017, -0.0006510000000000023, -0.0031940000000000007, -0.0008760000000000018, -0.006530000000000001, -0.016427], [5.0, 8.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tba134459e4c34c059f0aeaa9c829dc01","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t29e71a07313247f3a433307b0d19b7e7","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -9.999999999992654e-07, -2.000000000002e-06, -0.0015110000000000002, -0.0015130000000000005, -0.0015130000000000005, -0.0006919999999999999, -0.002836, -0.0008059999999999994, -0.0065520000000000005, -0.015347000000000001], [5.0, 7.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t29e71a07313247f3a433307b0d19b7e7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb64378f44bc1494383ae10763a2f9d71","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.001466000000000002, -0.0014670000000000013, -0.0014680000000000006, -0.0007710000000000009, -0.003250000000000001, -0.0008830000000000018, -0.006735000000000001, -0.015258], [7.0, 8.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 5.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb64378f44bc1494383ae10763a2f9d71","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teef4e7133aaa4860844bae377a39c47e","vertex_data","graph vertex data",["x", "y"],[[-1.9999999999985307e-06, -1.9999999999985307e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.001540999999999999, -0.0015449999999999995, -0.0015469999999999998, -0.0008190000000000003, -0.0034979999999999994, -0.0010369999999999997, -0.0076159999999999995, -0.016104], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teef4e7133aaa4860844bae377a39c47e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0dfd86ae081e4d918d96f407692398ca","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0014009999999999995, -0.0014020000000000005, -0.0014070000000000003, -0.0008009999999999996, -0.0031409999999999997, -0.000876, -0.00643, -0.015355], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0dfd86ae081e4d918d96f407692398ca","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te425e5acbfe344f2be3ee05aa1cf37e9","vertex_data","graph vertex data",["x", "y"],[[-1.9999999999985307e-06, -1.9999999999985307e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.001377999999999999, -0.001384999999999999, -0.0013939999999999994, -0.0006669999999999992, -0.0034779999999999985, -0.0008619999999999982, -0.006695999999999999, -0.015503], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te425e5acbfe344f2be3ee05aa1cf37e9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdec147f8dd774f48ba8f39d0090aec2d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013299999999999996, -0.0013419999999999994, -0.0013480000000000002, -0.0006269999999999991, -0.003450999999999999, -0.0007759999999999989, -0.0073279999999999994, -0.015347], [7.0, 8.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdec147f8dd774f48ba8f39d0090aec2d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2c540427956849b6918c3f0a12daa031","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013430000000000004, -0.0013509999999999998, -0.0013550000000000003, -0.0006590000000000016, -0.0037470000000000003, -0.0007150000000000004, -0.0066560000000000005, -0.015433], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2c540427956849b6918c3f0a12daa031","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8e0453e8ec6544ca996e7a0b57c3c5b8","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -1.9999999999985307e-06, -1.9999999999985307e-06, -1.9999999999985307e-06, -9.999999999975306e-07, -0.0012829999999999994, -0.0013049999999999989, -0.0013059999999999981, -0.0006909999999999989, -0.0035139999999999998, -0.0007169999999999989, -0.006362999999999999, -0.015641], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8e0453e8ec6544ca996e7a0b57c3c5b8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf77fe31535814aada0c8570aab7140a0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0012619999999999992, -0.0012659999999999998, -0.0012700000000000003, -0.0006560000000000003, -0.003141999999999999, -0.0007169999999999989, -0.0068059999999999996, -0.014903], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf77fe31535814aada0c8570aab7140a0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t13cff71e63534155a2abce0fc26bddaf","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0013059999999999999, -0.0013089999999999994, -0.001321000000000001, -0.0006680000000000002, -0.003632999999999999, -0.0008229999999999991, -0.00703, -0.014992], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t13cff71e63534155a2abce0fc26bddaf","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tccc73f13e06f46519ddde65a490c36c7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012729999999999998, -0.0012779999999999996, -0.0012839999999999987, -0.0006870000000000001, -0.0033819999999999996, -0.0007369999999999998, -0.0067139999999999995, -0.014558], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tccc73f13e06f46519ddde65a490c36c7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tde797fdeed844ad182c2dfc02315e9b1","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013190000000000007, -0.0013220000000000003, -0.001327, -0.0007010000000000002, -0.0036970000000000006, -0.0007810000000000004, -0.007289, -0.015247], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tde797fdeed844ad182c2dfc02315e9b1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t221d2e25c6224508ba07c94be1ed5a5a","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013109999999999997, -0.0013109999999999997, -0.001321000000000001, -0.000725, -0.003353, -0.0008410000000000015, -0.006753, -0.015202], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t221d2e25c6224508ba07c94be1ed5a5a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0f0d22b0a2b24da6a012e3716159b4d7","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.0012460000000000006, -0.0012490000000000001, -0.0012540000000000016, -0.0006580000000000006, -0.0034430000000000016, -0.0006890000000000004, -0.006958000000000001, -0.014328], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0f0d22b0a2b24da6a012e3716159b4d7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc0d37af871f84fe097a2b29ec795c2f4","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.001216, -0.001217000000000001, -0.0012259999999999997, -0.0005970000000000003, -0.003913, -0.0006399999999999999, -0.00646, -0.014246], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc0d37af871f84fe097a2b29ec795c2f4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2a6d789a68f0413cace838188b77cd4a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013229999999999995, -0.001337999999999999, -0.001347000000000001, -0.0006549999999999993, -0.0032130000000000006, -0.000723999999999999, -0.007359, -0.015157], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2a6d789a68f0413cace838188b77cd4a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t50fda7996a1a471ab3edca15b02c6338","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.000000000001e-06, -0.0012060000000000005, -0.0012140000000000015, -0.0012190000000000013, -0.0005730000000000006, -0.0035650000000000005, -0.0006050000000000014, -0.006438000000000001, -0.013999000000000001], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t50fda7996a1a471ab3edca15b02c6338","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tba46bfc61a814cf7b9efd4763cb3a314","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.001254, -0.0012589999999999997, -0.001268, -0.0005819999999999992, -0.003549, -0.0006639999999999997, -0.0064399999999999995, -0.014244], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tba46bfc61a814cf7b9efd4763cb3a314","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t674ae1656ac14392aa398ed271d099d7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.000000000002e-06, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -0.0012900000000000012, -0.001294, -0.0012990000000000015, -0.0006610000000000019, -0.0036190000000000007, -0.0007640000000000008, -0.006925000000000001, -0.014373], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t674ae1656ac14392aa398ed271d099d7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tde8eb95cbd8d49619505b49427ed739f","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, -0.0012709999999999996, -0.001275, -0.0012790000000000006, -0.0005760000000000001, -0.0034920000000000003, -0.0006550000000000011, -0.00708, -0.014597], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tde8eb95cbd8d49619505b49427ed739f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tad297cb60f9a4152bb0e0cc2c8b8a895","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012219999999999991, -0.0012329999999999997, -0.0012359999999999993, -0.0005859999999999997, -0.0036489999999999995, -0.0006189999999999998, -0.006666, -0.014662], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tad297cb60f9a4152bb0e0cc2c8b8a895","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te8cdb1184bca4cb5aa525a7bcf798d1d","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0012570000000000012, -0.0012990000000000015, -0.001301, -0.0006069999999999999, -0.003734000000000001, -0.000678999999999999, -0.006928, -0.015184], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te8cdb1184bca4cb5aa525a7bcf798d1d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb0205b89e5ec4fb4a17ec0b72e5aeb35","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012340000000000007, -0.0012490000000000001, -0.0012510000000000004, -0.000589000000000001, -0.0035930000000000007, -0.000595, -0.007069, -0.014464], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb0205b89e5ec4fb4a17ec0b72e5aeb35","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te887f74bd53647e7af91e15e2dc870dd","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -0.0012110000000000003, -0.0012580000000000004, -0.0012600000000000007, -0.0005669999999999998, -0.0038639999999999994, -0.0007500000000000007, -0.006983, -0.014501], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te887f74bd53647e7af91e15e2dc870dd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc69da87dca7c473f8072420a7a898c26","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -0.0012770000000000004, -0.001287, -0.0012900000000000012, -0.0007360000000000005, -0.0034730000000000004, -0.0007830000000000007, -0.006273000000000001, -0.014793], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc69da87dca7c473f8072420a7a898c26","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta0a9859751884e1b9b3079ff476cd53c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0012810000000000009, -0.0013220000000000003, -0.0013220000000000003, -0.0007740000000000004, -0.0033100000000000004, -0.0007880000000000005, -0.006549000000000001, -0.014863000000000001], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta0a9859751884e1b9b3079ff476cd53c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t958a193cba52442abac645612d2cbfd2","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.0012480000000000008, -0.0012640000000000012, -0.0012640000000000012, -0.0007419999999999996, -0.0033110000000000014, -0.0007610000000000013, -0.006389000000000001, -0.014977], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t958a193cba52442abac645612d2cbfd2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2ed7f320a5bc404ca85eb53a4740fa14","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013619999999999986, -0.0013740000000000002, -0.0013749999999999995, -0.0008109999999999992, -0.003443999999999999, -0.0008230000000000008, -0.0066619999999999995, -0.015927], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2ed7f320a5bc404ca85eb53a4740fa14","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta0b5f26e1b2b4992aaff1ca254e3c85f","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0012840000000000004, -0.0012630000000000002, -0.0012840000000000004, -0.0007379999999999991, -0.0038200000000000005, -0.0007640000000000008, -0.006442, -0.014551999999999999], [5.0, 7.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta0b5f26e1b2b4992aaff1ca254e3c85f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te225b8861f7142a7a86af8c08e3647d3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013190000000000007, -0.001340000000000001, -0.0013430000000000004, -0.0007270000000000002, -0.003384, -0.0007980000000000001, -0.006746, -0.01564], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te225b8861f7142a7a86af8c08e3647d3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf2813c1ca62245f7907ba7a82c7cc81c","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.001328000000000001, -0.001303000000000002, -0.0013370000000000014, -0.0009240000000000012, -0.003256000000000002, -0.0009469999999999999, -0.006131000000000001, -0.01498], [5.0, 7.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf2813c1ca62245f7907ba7a82c7cc81c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
})();</script></div></div>


Finally, you can plot the tree onto a set of Toyplot axes for finer control and the ability to add things like axis labels. 


```python
## set up axes
canvas = toyplot.Canvas(width=500, height=350)
axes1 = canvas.cartesian(bounds=(50, 300, 50, 300))
axes2 = canvas.cartesian(bounds=(300, 500, 50, 300))

## add tree
trees.draw_cloudtree(
    axes=axes1,
    orient='right',
    use_edge_lengths=True,
    tip_labels=False,
    edge_style={
        'opacity': 0.025, 
        'stroke': '#262626'},
    );

## add tip labels
tre = trees.treelist[0]
axes2.text(
    np.zeros(len(tre)), 
    tre.verts[:len(tre), 1],
    tips[::-1],
    style={
        'text-anchor': 'start',
        '-toyplot-anchor-shift': '-90px',
        'fill': '#262626',
        },
    );

## axis styling
axes1.y.show = False
axes1.x.ticks.show = True
axes1.x.ticks.locator = toyplot.locator.Explicit(
    locations=np.linspace(0, -15, 5) / 1000.,
    labels=np.linspace(0, 15, 5),
    )
axes1.x.label.text = "Divergence time (substitutions/site x 10<sup>-3</sup>)"
axes2.show = False
```


<div class="toyplot" id="tdea88cd40ba847bf822df5135cb0d450" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="350.0px" id="tc868bc68ed9044afa7ec68adfd50d602" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 500.0 350.0" width="500.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t7348772f928641ef8e8a52fda9d73579"><clipPath id="tda7c207d1ca14d2d80d24f8f5bef71c9"><rect height="270.0" width="270.0" x="40.0" y="40.0"></rect></clipPath><g clip-path="url(#tda7c207d1ca14d2d80d24f8f5bef71c9)"><g class="toyplot-mark-Text" id="t82bb734a069e49219a93b6c57b905dd8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tef31469c718c41358873f8e289b2e424"><g class="toyplot-Edges"><path d="M 217.546213476 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.31425164 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.528324389 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.528324389 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.31425164 245.3125 L 282.528324389 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.660703637 191.6015625 L 249.31425164 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.574239714 137.890625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.648777579 132.03125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.64698867 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.763864043 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.763864043 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.64698867 89.0625 L 272.763864043 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.648777579 132.03125 L 270.64698867 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.574239714 137.890625 L 231.648777579 132.03125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.660703637 191.6015625 L 231.574239714 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.546213476 245.80078125 L 221.660703637 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(272.76386404293379, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(270.64698867024447, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(231.64877757901013, 132.03125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(282.52832438878949, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(231.5742397137746, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(249.31425163983303, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(221.66070363744785, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(217.54621347644601, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9b83d66408664c8c99e9bc69974dfadb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc3a65a94191941279efb6484689b4813"><g class="toyplot-Edges"><path d="M 220.602265951 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.204531902 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.866428145 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.866428145 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.204531902 245.3125 L 286.866428145 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.014907573 191.6015625 L 241.204531902 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.033989267 137.890625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.19797257 132.03125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.360166965 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.12045319 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.12045319 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.360166965 89.0625 L 274.12045319 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.19797257 132.03125 L 273.360166965 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 234.033989267 137.890625 L 234.19797257 132.03125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.014907573 191.6015625 L 234.033989267 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.602265951 245.80078125 L 225.014907573 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(274.12045319022059, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(273.36016696481812, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(234.19797257006559, 132.03125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(286.86642814549788, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(234.03398926654739, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(241.2045319022063, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(225.01490757304711, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(220.60226595110316, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3f6eaaa8aebe404590e3747867bbbcf3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf9234e7a3f324af1a61a3fd6a31bc9a7"><g class="toyplot-Edges"><path d="M 213.312462731 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.723911747 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.107334526 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.107334526 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.723911747 245.3125 L 285.107334526 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.067978533 191.6015625 L 243.723911747 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.742993441 137.890625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.847346452 132.03125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.974955277 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.1836613 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.1836613 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.974955277 89.0625 L 271.1836613 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.847346452 132.03125 L 270.974955277 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.742993441 137.890625 L 227.847346452 132.03125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.067978533 191.6015625 L 227.742993441 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.312462731 245.80078125 L 218.067978533 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(271.18366129994035, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(270.97495527728086, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(227.84734645199759, 132.03125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(285.10733452593922, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(227.74299344066785, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.72391174716756, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(218.06797853309482, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(213.31246273106734, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td01cc709ec114a36b5cb607652a26ff0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcdf7f5dc599e481fb055581ad300074d"><g class="toyplot-Edges"><path d="M 211.911150865 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.793679189 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.04293381 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.04293381 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.793679189 245.3125 L 289.04293381 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.218246869 191.6015625 L 247.793679189 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.116875373 137.890625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.459749553 132.03125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.527728086 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.98986285 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.98986285 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.527728086 89.0625 L 270.98986285 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.459749553 132.03125 L 270.527728086 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.116875373 137.890625 L 227.459749553 132.03125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 217.218246869 191.6015625 L 227.116875373 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.911150865 245.80078125 L 217.218246869 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(270.98986285032794, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(270.52772808586764, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(227.45974955277282, 132.03125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.04293381037564, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(227.11687537268929, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.79367918902801, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(217.21824686940965, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(211.91115086463921, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t12fbf35b0ead4c25bda01c449a5c135b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t76b3d2cbfae34772b326c82f3509f660"><g class="toyplot-Edges"><path d="M 212.969588551 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.499105546 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.310077519 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.310077519 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.499105546 245.3125 L 290.310077519 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.112701252 195.5078125 L 244.499105546 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.32438879 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.980322004 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.347644603 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.601073345 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.601073345 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.347644603 89.0625 L 271.601073345 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.980322004 116.40625 L 271.347644603 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.32438879 145.703125 L 228.980322004 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 218.112701252 195.5078125 L 228.32438879 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.969588551 247.75390625 L 218.112701252 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(271.60107334525935, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(271.34764460345855, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(228.98032200357781, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(290.31007751937983, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(228.32438878950506, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.49910554561717, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(218.11270125223612, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(212.96958855098387, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4e34e326dae54434ba5ac1df6f4ab54a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t87c98a8c91544b2d9e7459d71413446c"><g class="toyplot-Edges"><path d="M 207.722122838 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.244484198 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.339892665 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.339892665 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.244484198 245.3125 L 290.339892665 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.342277877 195.5078125 L 245.244484198 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.807394156 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.075730471 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.409660107 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.722719141 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.722719141 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.409660107 89.0625 L 269.722719141 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.075730471 116.40625 L 269.409660107 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 223.807394156 145.703125 L 224.075730471 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.342277877 195.5078125 L 223.807394156 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.722122838 247.75390625 L 213.342277877 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(269.72271914132381, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(269.4096601073345, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(224.07573047107928, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(290.339892665474, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(223.80739415623137, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.24448419797258, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(213.34227787716159, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(207.7221228384019, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4ed3184ac5eb46d39212ffc72200bc46"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te1fced60035d4c43a3a3cf6753adb0f1"><g class="toyplot-Edges"><path d="M 204.338103757 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.732856291 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.983303518 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.983303518 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.732856291 245.3125 L 288.983303518 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.750745379 195.5078125 L 248.732856291 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.64698867 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.153846154 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.097793679 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.887895051 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.887895051 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.097793679 89.0625 L 268.887895051 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 221.153846154 116.40625 L 268.097793679 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 220.64698867 145.703125 L 221.153846154 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.750745379 195.5078125 L 220.64698867 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.338103757 247.75390625 L 208.750745379 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(268.8878950506857, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(268.09779367918901, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(221.15384615384613, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.98330351818726, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(220.64698867024447, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(248.73285629099581, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(208.75074537865234, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(204.33810375670839, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc84e06969c664fdc9433906ce3d17885"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb7d2abb1bf494189934c507f0f415be7"><g class="toyplot-Edges"><path d="M 208.064997018 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.38163387 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.04293381 221.875 L 299.970184854 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.04293381 221.875 L 299.970184854 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.38163387 245.3125 L 289.04293381 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.567084079 195.5078125 L 255.38163387 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.80620155 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.970184854 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.020870602 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.423375075 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.423375075 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.020870602 89.0625 L 270.423375075 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.970184854 116.40625 L 270.020870602 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.80620155 145.703125 L 224.970184854 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 212.567084079 195.5078125 L 224.80620155 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.064997018 247.75390625 L 212.567084079 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.97018485390583, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.97018485390583, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(270.42337507453789, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(270.02087060226597, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(224.97018485390581, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(289.04293381037564, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(224.80620155038758, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(255.38163387000597, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(212.56708407871201, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(208.06499701848543, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0bd62f9480fa48f193ad99347e4fd729"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t928f5db8d5004d04810f307e8af8d507"><g class="toyplot-Edges"><path d="M 209.928443649 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.897435897 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.310077519 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.310077519 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.897435897 245.3125 L 290.310077519 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.221824687 195.5078125 L 260.897435897 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.012522361 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.25104353 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.781156828 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.98986285 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.98986285 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.781156828 89.0625 L 270.98986285 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.25104353 116.40625 L 270.781156828 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.012522361 145.703125 L 227.25104353 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 214.221824687 195.5078125 L 227.012522361 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 209.928443649 247.75390625 L 214.221824687 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(270.98986285032794, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(270.78115682766844, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(227.25104353011326, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(290.31007751937983, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(227.01252236135954, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(260.89743589743591, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(214.22182468694098, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(209.92844364937386, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t525d29f0e9dd4acd9a8d7fd0aac8cce8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0412bd48b3334363a825873e1b5119bc"><g class="toyplot-Edges"><path d="M 215.966010733 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.747167561 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.326177698 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.326177698 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.747167561 245.3125 L 289.326177698 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.454382826 195.5078125 L 261.747167561 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.6326774 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.990459153 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.972570066 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.136553369 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.136553369 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.972570066 89.0625 L 273.136553369 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.990459153 116.40625 L 272.972570066 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.6326774 145.703125 L 232.990459153 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 219.454382826 195.5078125 L 232.6326774 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 215.966010733 247.75390625 L 219.454382826 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(273.13655336911148, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(272.97257006559335, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(232.9904591532499, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(289.32617769827073, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(232.63267740011929, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.74716756112105, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(219.45438282647584, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(215.96601073345261, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t73c60fe0c6c547548213f1c65bcf94b9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfb916ae1445641708f1a4de09e241305"><g class="toyplot-Edges"><path d="M 207.215265355 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.669051878 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.833035182 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.833035182 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.669051878 245.3125 L 289.833035182 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.374478235 195.5078125 L 264.669051878 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.968992248 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.042337507 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.244484198 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.319022063 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.319022063 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.244484198 89.0625 L 270.319022063 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.042337507 116.40625 L 270.244484198 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.968992248 145.703125 L 227.042337507 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.374478235 195.5078125 L 225.968992248 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.215265355 247.75390625 L 211.374478235 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(270.31902206320814, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(270.2444841979725, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(227.04233750745377, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(289.83303518187239, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(225.96899224806202, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(264.6690518783542, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(211.37447823494335, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(207.21526535480024, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6b71cc04c26d41c29722abaaf528c75b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdf7c307c0ec5445e8d67646d2650ee76"><g class="toyplot-Edges"><path d="M 209.615384615 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 263.5509839 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.041741205 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.041741205 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 263.5509839 245.3125 L 290.041741205 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.744782349 195.5078125 L 263.5509839 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.786523554 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.008944544 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.034585569 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.109123435 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.109123435 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.034585569 89.0625 L 271.109123435 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.008944544 116.40625 L 271.034585569 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.786523554 145.703125 L 230.008944544 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.744782349 195.5078125 L 228.786523554 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 209.615384615 247.75390625 L 213.744782349 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(271.10912343470483, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(271.0345855694693, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(230.00894454382825, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(290.04174120453183, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(228.7865235539654, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(263.55098389982112, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(213.74478234943351, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(209.61538461538461, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2d83a518e2a44e4bad50a694b6566219"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t78214d74de734a4c925c5392a1974b1e"><g class="toyplot-Edges"><path d="M 204.01013715 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.942158617 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.179487179 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.179487179 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.942158617 245.3125 L 287.179487179 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.51222421 195.5078125 L 260.942158617 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.895646989 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.968992248 116.40625 L 299.970184854 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.200954085 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.260584377 65.625 L 299.970184854 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.260584377 65.625 L 299.970184854 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.200954085 89.0625 L 269.260584377 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.968992248 116.40625 L 269.200954085 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.895646989 145.703125 L 225.968992248 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.51222421 195.5078125 L 224.895646989 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.01013715 247.75390625 L 208.51222421 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.97018485390572, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.97018485390572, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.97018485390572, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(269.26058437686345, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(269.20095408467506, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(225.96899224806202, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(287.17948717948718, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(224.89564698867025, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(260.94215861657722, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(208.51222420989865, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(204.01013714967203, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3e696d4fec474b7f9725f05e3844668b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7e6b55f5093d4d0095ec0be54cf9b43b"><g class="toyplot-Edges"><path d="M 205.322003578 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.075730471 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.20810972 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.20810972 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.075730471 245.3125 L 288.20810972 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 210.509838998 195.5078125 L 249.075730471 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.416219439 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.638640429 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.81216458 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.931425164 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.931425164 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.81216458 89.0625 L 269.931425164 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 227.638640429 116.40625 L 269.81216458 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.416219439 145.703125 L 227.638640429 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 210.509838998 195.5078125 L 226.416219439 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.322003578 247.75390625 L 210.509838998 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(269.93142516398325, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(269.81216457960642, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(227.63864042933812, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.20810971973759, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(226.41621943947524, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(249.07573047107928, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(210.50983899821108, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(205.32200357781755, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t852a4df63d964afa8d49d28373467191"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3970b23e82d143849cbc0f76cda183ed"><g class="toyplot-Edges"><path d="M 207.841383423 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.307096005 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.743589744 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.743589744 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.307096005 245.3125 L 289.743589744 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.866428145 195.5078125 L 255.307096005 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.771615981 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.755515802 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.691711389 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.751341682 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.751341682 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.691711389 89.0625 L 270.751341682 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.755515802 116.40625 L 270.691711389 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.771615981 145.703125 L 229.755515802 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.866428145 195.5078125 L 228.771615981 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.841383423 247.75390625 L 211.866428145 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(270.75134168157422, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(270.69171138938577, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(229.75551580202742, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(289.74358974358972, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(228.77161598091828, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(255.30709600477041, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(211.86642814549791, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(207.84138342277876, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1a79b7f84542437b87e5b63dc2f67966"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t373d804ae8304805ba78309561776c9b"><g class="toyplot-Edges"><path d="M 201.37149672 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.198568873 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.789505069 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.789505069 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.198568873 245.3125 L 288.789505069 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.858676208 195.5078125 L 246.198568873 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.001192606 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.895646989 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.545020871 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.73881932 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.73881932 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.545020871 89.0625 L 268.73881932 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.895646989 116.40625 L 268.545020871 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 224.001192606 145.703125 L 224.895646989 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.858676208 195.5078125 L 224.001192606 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.37149672 247.75390625 L 205.858676208 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(268.73881932021465, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(268.54502087060223, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(224.89564698867025, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(288.78950506857484, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(224.00119260584376, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.19856887298744, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(205.85867620751338, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(201.37149672033394, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9cf058da301a404eb31ce664b4ab0d9c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4ee89187289c4231bd9b9e14cc51da2e"><g class="toyplot-Edges"><path d="M 203.205128205 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.044722719 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.235539654 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.235539654 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.044722719 245.3125 L 290.235539654 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.617769827 195.5078125 L 250.044722719 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.894454383 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.774001193 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.260584377 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.991055456 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.991055456 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.260584377 89.0625 L 269.991055456 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 226.774001193 116.40625 L 269.260584377 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 225.894454383 145.703125 L 226.774001193 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.617769827 195.5078125 L 225.894454383 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.205128205 247.75390625 L 207.617769827 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(269.99105545617175, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(269.26058437686345, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(226.77400119260588, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(290.2355396541443, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(225.89445438282647, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.04472271914133, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(207.61776982707215, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(203.20512820512823, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2968de597bb041968d84c2bcd1967e50"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tead707e3393d47c590f0ba6f148f7a60"><g class="toyplot-Edges"><path d="M 207.200357782 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.905187835 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.920095408 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.920095408 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.905187835 245.3125 L 291.920095408 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.702444842 195.5078125 L 241.905187835 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.69588551 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.769230769 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.796064401 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.019677996 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.019677996 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.796064401 89.0625 L 271.019677996 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.769230769 116.40625 L 270.796064401 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.69588551 145.703125 L 230.769230769 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.702444842 195.5078125 L 229.69588551 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.200357782 247.75390625 L 211.702444842 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(271.01967799642222, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(270.79606440071558, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(230.7692307692308, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(291.92009540846749, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(229.695885509839, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(241.90518783542041, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(211.70244484197971, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(207.20035778175315, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdd01d0053b0d4a08b3fb1ecaa849ed3e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t066465ffd8ab45e2b53f610efd4a2e99"><g class="toyplot-Edges"><path d="M 205.903398927 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.515205725 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.561121049 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.561121049 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.515205725 245.3125 L 292.561121049 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.210494931 195.5078125 L 243.515205725 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.861061419 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.84496124 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.244484198 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.676803816 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.676803816 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.244484198 89.0625 L 270.676803816 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.84496124 116.40625 L 270.244484198 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.861061419 145.703125 L 229.84496124 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.210494931 195.5078125 L 228.861061419 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.903398927 247.75390625 L 211.210494931 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(270.67680381633869, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(270.24448419797255, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(229.84496124031006, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(292.56112104949312, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(228.86106141920095, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.51520572450801, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(211.21049493142516, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(205.90339892665475, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0d60e21b96f34f209967b82aca8b2f5e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t366d0cbb6170418f8080c69b82665658"><g class="toyplot-Edges"><path d="M 206.305903399 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.451997615 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.025641026 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.025641026 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.451997615 245.3125 L 291.025641026 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.10614192 195.5078125 L 246.451997615 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.740608229 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.052474657 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.483005367 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.750149076 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.750149076 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.483005367 89.0625 L 271.750149076 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 231.052474657 116.40625 L 270.483005367 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.740608229 145.703125 L 231.052474657 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 211.10614192 195.5078125 L 229.740608229 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 206.305903399 247.75390625 L 211.10614192 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(271.75014907573041, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(270.48300536672627, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(231.05247465712583, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(291.02564102564105, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(229.74060822898031, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(246.45199761478827, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(211.10614192009541, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(206.3059033989266, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfeb24f7408414485a933f6b19985588e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2aca2e6e1105474fbd55365f1304a027"><g class="toyplot-Edges"><path d="M 203.413834228 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.407274896 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.71019678 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.71019678 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.407274896 245.3125 L 292.71019678 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.974358974 195.5078125 L 246.407274896 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.726893262 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.396541443 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.0816935 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.050685748 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.050685748 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.0816935 89.0625 L 270.050685748 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 230.396541443 116.40625 L 269.0816935 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 228.726893262 145.703125 L 230.396541443 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.974358974 195.5078125 L 228.726893262 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.413834228 247.75390625 L 208.974358974 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(270.05068574836014, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(269.08169350029812, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(230.39654144305311, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(292.71019677996418, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(228.72689326177701, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.40727489564696, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(208.97435897435895, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(203.4138342277877, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc33daa59d8764e04b93bd750fb86c5b9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t872969e88c4d46868751475e378efe6b"><g class="toyplot-Edges"><path d="M 199.731663685 247.75390625 L 299.970184854 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.967799642 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.308884914 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.308884914 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.967799642 245.3125 L 291.308884914 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.903398927 195.5078125 L 251.967799642 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.338103757 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.16935003 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.576028623 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.93261777 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.93261777 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.576028623 89.0625 L 268.93261777 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 233.16935003 116.40625 L 267.576028623 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 229.338103757 145.703125 L 233.16935003 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.903398927 195.5078125 L 229.338103757 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.731663685 247.75390625 L 205.903398927 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(268.93261776982706, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(267.57602862254021, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(233.16935002981515, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(291.30888491353608, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(229.33810375670836, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(251.96779964221824, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(205.90339892665475, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(199.73166368515206, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t18fa3f6540fb48248bb348c6b4c01d95"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9056b3b9ee104da5a7d789c8500a976b"><g class="toyplot-Edges"><path d="M 196.168753727 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.957662493 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.29397734 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.29397734 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.957662493 245.3125 L 291.29397734 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.041144902 195.5078125 L 247.957662493 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.148479428 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.204531902 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.023255814 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.261776983 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.261776983 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.023255814 89.0625 L 268.261776983 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.204531902 116.40625 L 268.023255814 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 238.148479428 145.703125 L 241.204531902 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.041144902 195.5078125 L 238.148479428 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.168753727 247.75390625 L 203.041144902 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(268.2617769827072, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(268.02325581395348, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(241.2045319022063, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(291.29397734048899, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(238.14847942754918, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(247.95766249254621, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(203.04114490161001, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(196.16875372689327, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1d224f2756ec40718a0ab48e1eecd6ea"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta1c36d5a0f7a40e9a5071ab1f7d12d1d"><g class="toyplot-Edges"><path d="M 190.921288014 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.460345856 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.95110316 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.95110316 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 239.460345856 245.3125 L 290.95110316 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.972570066 195.5078125 L 239.460345856 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.011926058 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.455575432 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.025641026 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.189624329 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.189624329 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.025641026 89.0625 L 266.189624329 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.455575432 116.40625 L 266.025641026 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.011926058 145.703125 L 243.455575432 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.972570066 195.5078125 L 240.011926058 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.921288014 247.75390625 L 197.972570066 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(266.18962432915924, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(266.02564102564105, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(243.45557543231959, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.95110316040541, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(240.01192605843767, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(239.46034585569467, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(197.97257006559329, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.92128801431124, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2aafe1081db24c7c99fc0bef2681fe19"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7601f47d4d174e538a9dbd11c32cbdef"><g class="toyplot-Edges"><path d="M 189.683959451 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.623136553 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.29397734 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.29397734 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 240.623136553 245.3125 L 291.29397734 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.735241503 195.5078125 L 240.623136553 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.752534287 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.109123435 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.80202743 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.921288014 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.921288014 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.80202743 89.0625 L 265.921288014 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.109123435 116.40625 L 265.80202743 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.752534287 145.703125 L 246.109123435 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.735241503 195.5078125 L 244.752534287 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.683959451 247.75390625 L 196.735241503 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(265.92128801431124, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(265.80202742993441, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.1091234347048, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(291.29397734048899, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(244.752534287418, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(240.62313655336911, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(196.73524150268335, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(189.68395945140131, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2cd8de17909b4a50b45f4b105ad9f467"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc7046f417b1d40b9802e9d5d3473fef1"><g class="toyplot-Edges"><path d="M 186.896243292 247.265625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.689326178 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.60822898 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.60822898 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.689326178 245.3125 L 290.60822898 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.663088849 194.53125 L 247.689326178 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.856887299 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.645796064 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.354800239 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.399522958 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.399522958 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.354800239 81.25 L 265.399522958 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.645796064 112.5 L 265.354800239 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.856887299 143.75 L 246.645796064 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.663088849 194.53125 L 244.856887299 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.896243292 247.265625 L 194.663088849 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(265.3995229576625, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(265.35480023852119, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.64579606440074, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(290.60822898032205, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.85688729874775, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(247.68932617769829, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(194.66308884913536, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.89624329159213, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t78c57133d11743d59fc20e2bf178d501"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t74c7320acbf245b799e7718db3fa3d81"><g class="toyplot-Edges"><path d="M 182.811568277 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.55515802 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.220632081 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.220632081 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.55515802 245.3125 L 290.220632081 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.936195587 193.5546875 L 247.55515802 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.381037567 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.49791294 108.59375 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.177101968 73.4375 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.221824687 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.221824687 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.177101968 73.4375 L 264.221824687 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.49791294 108.59375 L 264.177101968 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.381037567 141.796875 L 245.49791294 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.936195587 193.5546875 L 243.381037567 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.811568277 246.77734375 L 190.936195587 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(264.22182468694098, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(264.17710196779962, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.49791293977344, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(290.22063208109716, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(243.38103756708409, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(247.55515802027429, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.93619558735841, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(182.81156827668457, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t87a8057aa56940b38352c2dbe363cfb4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6f29673f5da646b19565178dac9cda48"><g class="toyplot-Edges"><path d="M 182.09600477 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.30411449 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.415623137 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.415623137 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.30411449 245.3125 L 289.415623137 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.623136553 193.5546875 L 245.30411449 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.020870602 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.809779368 108.59375 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.445438283 73.4375 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.505068575 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.505068575 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.445438283 73.4375 L 264.505068575 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.809779368 108.59375 L 264.445438283 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.020870602 141.796875 L 246.809779368 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.623136553 193.5546875 L 245.020870602 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.09600477 246.77734375 L 190.623136553 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(264.50506857483606, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(264.44543828264761, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(246.80977936791891, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.41562313655334, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.02087060226594, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.30411449016103, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.62313655336911, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.09600477042338, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4c3afbc63a5e4bd8a5feed6e5ce8f916"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta17ea1b61bcb4a939e8514c1daeacdd3"><g class="toyplot-Edges"><path d="M 182.319618366 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.890280262 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.190816935 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.190816935 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.890280262 245.3125 L 290.190816935 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.685152057 195.5078125 L 241.890280262 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.779964222 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.717948718 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.862850328 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.92248062 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.92248062 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.862850328 89.0625 L 264.92248062 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.717948718 116.40625 L 264.862850328 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.779964222 145.703125 L 248.717948718 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.685152057 195.5078125 L 246.779964222 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.319618366 247.75390625 L 188.685152057 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(264.92248062015506, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(264.86285032796661, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(248.71794871794873, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(290.19081693500294, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.77996422182468, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(241.89028026237332, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(188.68515205724509, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.31961836612999, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taf8d1903c7d740208906e47b2b783e94"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td369b0d633f84db9a05ff3c9040f8a89"><g class="toyplot-Edges"><path d="M 181.857483602 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.651759094 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.43053071 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.43053071 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.651759094 245.3125 L 289.43053071 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.429338104 195.5078125 L 241.651759094 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.986285033 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.44484198 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.654144305 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.713774597 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.713774597 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.654144305 89.0625 L 264.713774597 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.44484198 116.40625 L 264.654144305 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.986285033 145.703125 L 252.44484198 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.429338104 195.5078125 L 248.986285033 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.857483602 247.75390625 L 190.429338104 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(264.7137745974955, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(264.65414430530711, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.44484197972568, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(289.43053070960048, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(248.98628503279664, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(241.65175909361955, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.42933810375666, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.85748360166963, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8e252d363a824a10b71b37827b80c6ad"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tddd42aaa2cdd4bf0b21e9c2a99bc74ac"><g class="toyplot-Edges"><path d="M 180.172927847 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.707215265 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.727489565 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.727489565 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 232.707215265 245.3125 L 290.727489565 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.816935003 195.5078125 L 232.707215265 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.732856291 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 256.902206321 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 263.819320215 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.056648778 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.056648778 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 263.819320215 89.0625 L 265.056648778 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 256.902206321 116.40625 L 263.819320215 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.732856291 145.703125 L 256.902206321 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.816935003 195.5078125 L 248.732856291 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.172927847 247.75390625 L 190.816935003 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(265.05664877757903, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(263.81932021466912, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(256.90220632081099, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.72748956469883, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(248.73285629099581, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(232.70721526535479, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.8169350029815, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(180.17292784734644, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t950251669efa4c67baaa01238bc433e9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf7137f4b47ff44c3b0437a6fa6cb8750"><g class="toyplot-Edges"><path d="M 175.87954681 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.916517591 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.835420394 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.835420394 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.916517591 245.3125 L 287.835420394 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.387000596 195.5078125 L 244.916517591 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.533094812 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.913536076 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.490161002 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.669051878 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.669051878 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.490161002 89.0625 L 264.669051878 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.913536076 116.40625 L 264.490161002 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.533094812 145.703125 L 259.913536076 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.387000596 195.5078125 L 253.533094812 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.87954681 247.75390625 L 188.387000596 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(264.6690518783542, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(264.49016100178892, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(259.91353607632675, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(287.83542039355996, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(253.53309481216459, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.91651759093622, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(188.38700059630293, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(175.87954680977936, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taa550012f2884be086ee62f66521820f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0817ed1f8582439aafad69931903f691"><g class="toyplot-Edges"><path d="M 175.253428742 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.899224806 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.326177698 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.326177698 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.899224806 245.3125 L 289.326177698 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.952295766 195.5078125 L 246.899224806 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.901013715 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 263.685152057 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.639236732 89.0625 L 299.970184854 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.728682171 65.625 L 299.970184854 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.728682171 65.625 L 299.970184854 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.639236732 89.0625 L 264.728682171 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 263.685152057 116.40625 L 264.639236732 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.901013715 145.703125 L 263.685152057 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.952295766 195.5078125 L 257.901013715 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.253428742 247.75390625 L 189.952295766 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390572, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390572, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390572, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(264.72868217054264, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(264.63923673226003, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(263.68515205724509, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.32617769827073, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(257.90101371496718, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.89922480620154, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(189.95229576624928, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(175.25342874180083, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t43245551eb7340b69f666a0dd956dbab"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdce1387514a0425299157eef2d6362a0"><g class="toyplot-Edges"><path d="M 168.023255814 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.782349434 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.061419201 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.061419201 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.782349434 245.3125 L 286.061419201 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.732259988 195.5078125 L 244.782349434 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 258.646392367 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.256410256 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.717352415 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.686344663 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.686344663 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.717352415 89.0625 L 262.686344663 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.256410256 116.40625 L 261.717352415 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 258.646392367 145.703125 L 260.256410256 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.732259988 195.5078125 L 258.646392367 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.023255814 247.75390625 L 186.732259988 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(262.6863446630889, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(261.71735241502682, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(260.25641025641028, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(286.06141920095411, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(258.64639236732262, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.78234943351225, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.73225998807391, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(168.02325581395348, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t521c8b53b80e47b3b08a98b11a1515b4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfe1526a913624d0c948c2ebed367de3c"><g class="toyplot-Edges"><path d="M 162.149672033 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.735241503 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.372093023 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.372093023 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.735241503 245.3125 L 288.372093023 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.009540847 195.5078125 L 246.735241503 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.322003578 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.376863447 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.584376863 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.239117472 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.239117472 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.584376863 89.0625 L 262.239117472 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.376863447 116.40625 L 260.584376863 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.322003578 145.703125 L 259.376863447 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.009540847 195.5078125 L 255.322003578 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.149672033 247.75390625 L 192.009540847 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(262.23911747167563, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(260.58437686344661, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(259.37686344663092, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(288.37209302325573, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(255.32200357781753, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.73524150268338, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.00954084675013, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(162.14967203339296, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t529113191e1d484dad4c1cdce3065c62"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t04cc181aaa5449d997dd012572a1a147"><g class="toyplot-Edges"><path d="M 169.991055456 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.162790698 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.968395945 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.968395945 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.162790698 245.3125 L 288.968395945 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.760286225 195.5078125 L 251.162790698 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.203935599 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.538461538 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.090041741 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.147286822 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.147286822 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.090041741 89.0625 L 264.147286822 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.538461538 116.40625 L 262.090041741 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.203935599 145.703125 L 261.538461538 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.760286225 195.5078125 L 254.203935599 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.991055456 247.75390625 L 200.760286225 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(264.14728682170545, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(262.09004174120452, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(261.53846153846155, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(288.96839594514017, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(254.20393559928442, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.16279069767441, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(200.76028622540252, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.99105545617175, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t083231e080664fab96c3a74b6738f993"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="teda0399410c6463cba86c4d32b75a0a9"><g class="toyplot-Edges"><path d="M 161.508646392 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.684555754 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.849135361 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.849135361 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.684555754 245.3125 L 288.849135361 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.625521765 195.5078125 L 251.684555754 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 256.350626118 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.317233154 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.898628503 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.56946929 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.56946929 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.898628503 89.0625 L 260.56946929 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.317233154 116.40625 L 259.898628503 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 256.350626118 145.703125 L 259.317233154 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.625521765 195.5078125 L 256.350626118 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 161.508646392 247.75390625 L 188.625521765 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(260.56946929039952, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(259.89862850327967, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(259.31723315444248, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.84913536076328, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(256.35062611806796, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.68455575432321, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(188.62552176505667, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(161.50864639236735, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t95531b8db58f48448f52894156f3008c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t43080d2dff5d4e05a445fabf18c4df7b"><g class="toyplot-Edges"><path d="M 154.561717352 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.793679189 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.610614192 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.610614192 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.793679189 245.3125 L 288.610614192 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.171138939 195.5078125 L 247.793679189 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.039952296 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 258.870005963 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.54084675 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.958258795 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.958258795 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.54084675 89.0625 L 259.958258795 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 258.870005963 116.40625 L 259.54084675 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.039952296 145.703125 L 258.870005963 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.171138939 195.5078125 L 254.039952296 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.561717352 247.75390625 L 194.171138939 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(259.95825879546811, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(259.54084675014906, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(258.8700059630292, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.61061419200951, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(254.03995229576626, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(247.79367918902801, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(194.17113893858078, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(154.561717352415, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te55dd35166134e0dad477b002be197b0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t81bd041b529e4ece8bfe8107320154a8"><g class="toyplot-Edges"><path d="M 154.546809779 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.970781157 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.57960644 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.57960644 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.970781157 245.3125 L 289.57960644 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.744186047 195.5078125 L 261.970781157 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.546809779 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.598091831 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.000596303 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.358378056 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.358378056 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 262.000596303 89.0625 L 262.358378056 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.598091831 116.40625 L 262.000596303 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.546809779 145.703125 L 261.598091831 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.744186047 195.5078125 L 254.546809779 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.546809779 247.75390625 L 201.744186047 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(262.35837805605246, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(262.00059630292191, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.59809183064999, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(289.57960644007159, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(254.54680977936795, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(261.97078115682768, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(201.74418604651163, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(154.54680977936792, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb3c297fe15d44f5886e02c789cf5bcef"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t26775d667d824997aee919cd9b8b836e"><g class="toyplot-Edges"><path d="M 157.245080501 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.792486583 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.250447227 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.250447227 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.792486583 245.3125 L 290.250447227 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.248062016 195.5078125 L 273.792486583 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 258.064997018 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.877757901 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.952295766 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.80202743 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.80202743 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.952295766 89.0625 L 265.80202743 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.877757901 116.40625 L 264.952295766 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 258.064997018 145.703125 L 264.877757901 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.248062016 195.5078125 L 258.064997018 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.245080501 247.75390625 L 192.248062016 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(265.80202742993447, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(264.95229576624928, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(264.87775790101369, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.25044722719139, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(258.06499701848543, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(273.79248658318426, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.24806201550388, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(157.24508050089446, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1336ba8caec649dabef37c3aa0b7632b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4829ac3097cd4d4c89b9ce194d8a9cd3"><g class="toyplot-Edges"><path d="M 155.992844365 247.75390625 L 299.970184854 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.245676804 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.892665474 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.892665474 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 269.245676804 245.3125 L 289.892665474 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.935002982 195.5078125 L 269.245676804 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.376863447 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.011926058 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.324985092 89.0625 L 299.970184854 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.503875969 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.503875969 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.324985092 89.0625 L 265.503875969 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.011926058 116.40625 L 265.324985092 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.376863447 145.703125 L 265.011926058 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.935002982 195.5078125 L 259.376863447 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.992844365 247.75390625 L 191.935002982 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390583, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390583, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(265.50387596899225, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(265.32498509242703, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(265.01192605843772, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.89266547406083, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(259.37686344663092, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(269.24567680381631, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.93500298151463, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(155.99284436493741, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t147fb43625f54bf0af80f0786a0b0d9c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdbb68958457d4d3d805974f252ce4f94"><g class="toyplot-Edges"><path d="M 155.57543232 247.265625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.449612403 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.474060823 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.474060823 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.449612403 245.3125 L 290.474060823 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.907573047 194.53125 L 273.449612403 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.558139535 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.206917114 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.669051878 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.295169946 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.295169946 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.669051878 81.25 L 265.295169946 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 264.206917114 112.5 L 264.669051878 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.558139535 143.75 L 264.206917114 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.907573047 194.53125 L 257.558139535 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.57543232 247.265625 L 189.907573047 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(265.29516994633275, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(264.6690518783542, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(264.20691711389384, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(290.47406082289802, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(257.55813953488371, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(273.44961240310073, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(189.90757304710792, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(155.57543231961836, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td44d3a65e74d444aafe276dd4b15c39e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td105dfc631824372b4758f609d29acc3"><g class="toyplot-Edges"><path d="M 156.171735242 247.265625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.972570066 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.652951699 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.652951699 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.972570066 245.3125 L 290.652951699 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.055456172 194.53125 L 272.972570066 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.364341085 143.75 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.011926058 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.578413834 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.697674419 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.697674419 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.578413834 81.25 L 265.697674419 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.011926058 112.5 L 265.578413834 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.364341085 143.75 L 265.011926058 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.055456172 194.53125 L 257.364341085 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.171735242 247.265625 L 191.055456172 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(265.69767441860466, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(265.57841383422777, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(265.01192605843772, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(290.6529516994633, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(257.36434108527129, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(272.97257006559329, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.05545617173524, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(156.17173524150269, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t805d6055a9544e588fd0be508c32d93b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8a966ed13a2c4404b0202669de815d22"><g class="toyplot-Edges"><path d="M 159.421586166 247.265625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.013714967 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.040548599 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.040548599 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.013714967 245.3125 L 291.040548599 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.8980322 194.53125 L 276.013714967 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.673822302 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.127608825 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.664281455 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.813357185 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.813357185 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.664281455 81.25 L 268.813357185 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.127608825 112.5 L 268.664281455 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.673822302 143.75 L 268.127608825 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.8980322 194.53125 L 260.673822302 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 159.421586166 247.265625 L 197.8980322 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(268.81335718545023, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(268.66428145497912, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(268.12760882528323, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(291.04054859868808, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(260.67382230172927, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(276.01371496720333, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(197.89803220035776, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(159.4215861657722, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2f29afc3568042c58cfb8de9f13f903a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t95cfa1a418a441f9b912dcc394bc50af"><g class="toyplot-Edges"><path d="M 151.610017889 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.74895647 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.028026237 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.028026237 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.74895647 245.3125 L 289.028026237 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.978533095 195.5078125 L 272.74895647 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.949314252 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.128801431 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.486583184 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.501490757 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.501490757 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.486583184 89.0625 L 267.501490757 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.128801431 116.40625 L 267.486583184 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.949314252 145.703125 L 267.128801431 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.978533095 195.5078125 L 254.949314252 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.610017889 247.75390625 L 192.978533095 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(267.50149075730474, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(267.48658318425765, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(267.12880143112704, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(289.0280262373285, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(254.94931425163983, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(272.74895646988671, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.97853309481218, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(151.61001788908769, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t891845e403964d24b8211530f6896e9d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t636be2d99aab4d96a5d8daf6b514f4c3"><g class="toyplot-Edges"><path d="M 138.89385808 247.265625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.0 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.834227788 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.834227788 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.0 245.3125 L 288.834227788 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.92248062 194.53125 L 275.0 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 258.363148479 143.75 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.234347048 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.428145498 81.25 L 299.970184854 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.428145498 81.25 L 299.970184854 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.428145498 81.25 L 299.970184854 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.428145498 81.25 L 266.428145498 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.234347048 112.5 L 266.428145498 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 258.363148479 143.75 L 266.234347048 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.92248062 194.53125 L 258.363148479 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.89385808 247.265625 L 189.92248062 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(266.42814549791291, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(266.42814549791291, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(266.23434704830049, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.8342277877162, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(258.36314847942754, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(275.0, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(189.92248062015503, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.89385807990459, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4196c2fcc6fc42f7a4225ed15fcb68ea"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf12235f4747d4188bc5521ea78de1d67"><g class="toyplot-Edges"><path d="M 138.118664281 247.265625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.387596899 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.131186643 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.131186643 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.387596899 245.3125 L 290.131186643 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.997018485 194.53125 L 275.387596899 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.360763268 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.398330352 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.577221228 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.577221228 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.577221228 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.577221228 81.25 L 266.577221228 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.398330352 112.5 L 266.577221228 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 260.360763268 143.75 L 266.398330352 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.997018485 194.53125 L 260.360763268 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.118664281 247.265625 L 189.997018485 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(266.57722122838396, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(266.57722122838396, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(266.39833035181869, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.1311866428145, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(260.36076326774003, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(275.38759689922477, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(189.99701848539058, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(138.11866428145498, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6797ce6350ea427bbd4c60cc874796c9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb230cd2071fc48879a5e3697f2a2359b"><g class="toyplot-Edges"><path d="M 135.017889088 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.076923077 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.313655337 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.313655337 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.076923077 245.3125 L 287.313655337 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.999403697 193.5546875 L 273.076923077 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.732259988 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.936195587 108.59375 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.249254621 73.4375 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.29397734 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.29397734 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.249254621 73.4375 L 266.29397734 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 265.936195587 108.59375 L 266.249254621 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 261.732259988 141.796875 L 265.936195587 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.999403697 193.5546875 L 261.732259988 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.017889088 246.77734375 L 187.999403697 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(266.29397734048899, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(266.24925462134763, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(265.93619558735838, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(287.31365533691115, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(261.73225998807396, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(273.07692307692309, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.99940369707809, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(135.01788908765653, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t914f167b69a14c23a90c43c24073da8a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te7ecc66c508640d49f9e186d6af646f2"><g class="toyplot-Edges"><path d="M 130.605247466 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.894454383 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.612999404 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.612999404 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.894454383 245.3125 L 286.612999404 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.992248062 193.5546875 L 275.894454383 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.719737627 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.800834824 108.59375 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.949910555 73.4375 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.054263566 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.054263566 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.949910555 73.4375 L 267.054263566 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 266.800834824 108.59375 L 266.949910555 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.719737627 141.796875 L 266.800834824 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.992248062 193.5546875 L 259.719737627 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 130.605247466 246.77734375 L 193.992248062 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(267.05426356589146, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(266.94991055456177, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(266.80083482409066, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(286.61299940369713, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(259.71973762671439, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(275.8944543828265, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.99224806201551, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(130.60524746571261, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t122707525e1640aba90d12080139b24c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3a4b99f8af1c4a2da562fcd36aad62b1"><g class="toyplot-Edges"><path d="M 127.161598092 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.104353011 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.163387001 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.163387001 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.104353011 245.3125 L 288.163387001 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.61836613 193.5546875 L 275.104353011 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.158020274 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.993440668 108.59375 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.127608825 73.4375 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.455575432 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.455575432 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 268.127608825 73.4375 L 268.455575432 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 267.993440668 108.59375 L 268.127608825 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.158020274 141.796875 L 267.993440668 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.61836613 193.5546875 L 255.158020274 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 127.161598092 246.77734375 L 194.61836613 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(268.45557543231962, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(268.12760882528329, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(267.99344066785932, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.16338700059634, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(255.15802027429933, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(275.10435301132975, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(194.61836612999403, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(127.16159809183065, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta85b55aaf49341959716f4098c84cd0a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4c2b63cf13c749b780d73a49a7a8ba6c"><g class="toyplot-Edges"><path d="M 128.398926655 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.116875373 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.355992844 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.355992844 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.116875373 245.3125 L 289.355992844 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.566487776 193.5546875 L 277.116875373 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.392367323 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.035778175 108.59375 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.15503876 73.4375 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.333929636 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.333929636 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.15503876 73.4375 L 270.333929636 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.035778175 108.59375 L 270.15503876 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.392367323 141.796875 L 270.035778175 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.566487776 193.5546875 L 246.392367323 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.398926655 246.77734375 L 200.566487776 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(270.33392963625522, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(270.15503875968994, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(270.03577817531306, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(289.35599284436495, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.39236732259988, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(277.11687537268926, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(200.56648777579008, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(128.39892665474059, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t895c13f785204cedbda25a5f980bcf04"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2d34c7189158428c8c4c6cd4f586e588"><g class="toyplot-Edges"><path d="M 129.531902206 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.135957066 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.580799046 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.580799046 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.135957066 245.3125 L 288.580799046 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.821109123 193.5546875 L 286.135957066 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.5307096 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.361359571 108.59375 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.495527728 73.4375 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.55515802 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.55515802 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.495527728 73.4375 L 272.55515802 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.361359571 108.59375 L 272.495527728 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.5307096 141.796875 L 272.361359571 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.821109123 193.5546875 L 255.5307096 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 129.531902206 246.77734375 L 199.821109123 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(272.55515802027429, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(272.49552772808585, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(272.36135957066188, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(288.58079904591528, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(255.53070960047702, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(286.13595706618963, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(199.82110912343472, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(129.53190220632081, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t914d47ebd65344e9a2f30e65d8ca4e22"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb4e0ce3612d24e2f9b3ed05367aa661c"><g class="toyplot-Edges"><path d="M 124.209898629 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.961836613 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.936195587 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.936195587 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.961836613 245.3125 L 290.936195587 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.491949911 195.5078125 L 281.961836613 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.319618366 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.331544425 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.391174717 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.495527728 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.495527728 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.391174717 89.0625 L 272.495527728 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.331544425 116.40625 L 272.391174717 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.319618366 145.703125 L 272.331544425 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.491949911 195.5078125 L 257.319618366 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 124.209898629 247.75390625 L 200.491949911 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(272.49552772808585, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(272.39117471675615, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(272.33154442456771, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(290.93619558735838, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(257.31961836612999, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(281.96183661299938, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(200.49194991055455, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(124.20989862850327, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t973a6e9da27041cda8f52fbdf06f54a9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9923816b6ae844e9bdf72e49ffc4d410"><g class="toyplot-Edges"><path d="M 115.652951699 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.369111509 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.503875969 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.503875969 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.369111509 245.3125 L 290.503875969 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.072152654 193.5546875 L 278.369111509 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.042337507 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.124031008 108.59375 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.168753727 73.4375 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.645796064 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.645796064 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.168753727 73.4375 L 271.645796064 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.124031008 108.59375 L 271.168753727 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.042337507 141.796875 L 271.124031008 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.072152654 193.5546875 L 252.042337507 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 115.652951699 246.77734375 L 202.072152654 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(271.64579606440077, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(271.16875372689327, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(271.12403100775191, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(290.50387596899225, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(252.04233750745379, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(278.36911150864643, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(202.07215265354799, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(115.65295169946333, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5ebc6b58544243559222c6d8c27a1a6d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6e927434d50a4e3f898b5ae338ba52e6"><g class="toyplot-Edges"><path d="M 128.398926655 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.186642815 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.115086464 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.115086464 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.186642815 245.3125 L 291.115086464 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.252236136 193.5546875 L 281.186642815 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.37149672 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.762671437 108.59375 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.77757901 73.4375 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.986285033 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.986285033 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.77757901 73.4375 L 273.986285033 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.762671437 108.59375 L 273.77757901 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.37149672 141.796875 L 273.762671437 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.252236136 193.5546875 L 251.37149672 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.398926655 246.77734375 L 201.252236136 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(273.98628503279667, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(273.77757901013712, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(273.76267143708998, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(291.11508646392366, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(251.37149672033391, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.18664281454977, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(201.25223613595702, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(128.39892665474059, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3cf91c6b485849f8842826c8dad298af"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t06a183041c7446b591602d915d97b025"><g class="toyplot-Edges"><path d="M 116.279069767 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.489564699 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.175909362 221.875 L 299.970184854 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.175909362 221.875 L 299.970184854 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.489564699 245.3125 L 290.175909362 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.894454383 190.625 L 277.489564699 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.516994633 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.420989863 96.875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.420989863 96.875 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.40608229 96.875 L 272.420989863 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.704233751 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.704233751 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.40608229 96.875 L 272.704233751 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.516994633 135.9375 L 272.40608229 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.894454383 190.625 L 254.516994633 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 116.279069767 245.3125 L 200.894454383 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.97018485390572, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.97018485390572, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(272.70423375074535, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(272.42098986285032, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(272.40608228980318, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.17590936195592, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(254.51699463327373, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(277.48956469886701, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(200.89445438282644, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(116.27906976744187, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb616c9b6eb3d46e7867ed5fea8131467"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1d48c90d0b1f4bb1b812355f95cfad13"><g class="toyplot-Edges"><path d="M 98.5092426953 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.15921288 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.416815742 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.416815742 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.15921288 245.3125 L 288.416815742 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.871794872 190.625 L 279.15921288 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.083482409 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.557543232 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.557543232 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.15503876 96.875 L 270.557543232 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.259391771 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.259391771 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.15503876 96.875 L 270.259391771 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.083482409 135.9375 L 270.15503876 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.871794872 190.625 L 255.083482409 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 98.5092426953 245.3125 L 194.871794872 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(270.25939177101964, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(270.5575432319618, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(270.15503875968994, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(288.41681574239715, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(255.08348240906378, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(279.15921288014312, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(194.87179487179489, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(98.509242695289203, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2c19cd4e08fd4dd0b54f614cb1832b43"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2290760c6b4f473fbe6e7e3f3ff204cc"><g class="toyplot-Edges"><path d="M 99.060822898 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.380441264 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.072748956 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.072748956 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.380441264 245.3125 L 289.072748956 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.510435301 190.625 L 281.380441264 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.874776386 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.361359571 96.875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.361359571 96.875 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.466905188 96.875 L 272.361359571 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.630888491 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.630888491 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.466905188 96.875 L 271.630888491 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.874776386 135.9375 L 271.466905188 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.510435301 190.625 L 254.874776386 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 99.060822898 245.3125 L 197.510435301 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(271.63088849135357, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(272.36135957066188, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(271.46690518783538, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(289.07274895646992, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(254.87477638640428, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.38044126416219, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(197.51043530113299, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(99.060822898032214, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb960002b7b4a48adbbaee1eb8db1c4a6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tff5799a7c4e14882a6cd57363d6421b6"><g class="toyplot-Edges"><path d="M 98.4496124031 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.930828861 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.131186643 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.131186643 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.930828861 245.3125 L 290.131186643 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.086463924 190.625 L 282.930828861 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.730471079 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.258199165 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.258199165 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.109123435 96.875 L 271.258199165 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.1836613 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.1836613 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.109123435 96.875 L 271.1836613 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.730471079 135.9375 L 271.109123435 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.086463924 190.625 L 250.730471079 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 98.4496124031 245.3125 L 190.086463924 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(271.18366129994035, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(271.25819916517582, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(271.10912343470477, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(290.1311866428145, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.73047107930827, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(282.93082886106146, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.08646392367322, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(98.449612403100772, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta43a57350ee140c49924c0c3adf47265"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7950f61c5b5e48f1ba640e372a1f252a"><g class="toyplot-Edges"><path d="M 101.02862254 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.848539058 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.60822898 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.60822898 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.848539058 245.3125 L 290.60822898 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.985092427 190.625 L 276.848539058 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.311866428 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.615980918 96.875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.615980918 96.875 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.556350626 96.875 L 271.615980918 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.645796064 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.645796064 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.556350626 96.875 L 271.645796064 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.311866428 135.9375 L 271.556350626 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.985092427 190.625 L 251.311866428 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 101.02862254 245.3125 L 199.985092427 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(271.64579606440077, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(271.61598091830649, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(271.5563506261181, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(290.60822898032205, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.31186642814549, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(276.84853905784138, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(199.98509242695289, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(101.02862254025047, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td4aa938c29c24cccb89680bdcb3b06c6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t187aa0c28eca48d9a9cfa97bafb4deba"><g class="toyplot-Edges"><path d="M 91.3237924866 245.80078125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.977936792 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.742397138 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.742397138 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.977936792 245.3125 L 290.742397138 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.540250447 191.6015625 L 280.977936792 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.311866428 137.890625 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.736434109 100.78125 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.781156828 89.0625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.825879547 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.825879547 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.781156828 89.0625 L 270.825879547 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 270.736434109 100.78125 L 270.781156828 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.311866428 137.890625 L 270.736434109 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.540250447 191.6015625 L 251.311866428 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 91.3237924866 245.80078125 L 197.540250447 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(270.82587954680974, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(270.78115682766844, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(270.73643410852713, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(290.74239713774597, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.31186642814549, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.97793679189027, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(197.54025044722718, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(91.323792486583187, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t94df9862971940ae8117068aa5d74167"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te3fafeccdafe4034bbd66a846da2384c"><g class="toyplot-Edges"><path d="M 89.862850328 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.036374478 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.009540847 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.009540847 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.036374478 245.3125 L 292.009540847 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.899821109 191.6015625 L 282.036374478 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.022063208 137.890625 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.286821705 100.78125 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.316636852 89.0625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.420989863 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.420989863 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.316636852 89.0625 L 272.420989863 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.286821705 100.78125 L 272.316636852 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.022063208 137.890625 L 272.286821705 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.899821109 191.6015625 L 244.022063208 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 89.862850328 245.80078125 L 208.899821109 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(272.42098986285026, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(272.31663685152057, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(272.28682170542635, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(292.0095408467501, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(244.0220632081097, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(282.0363744782349, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(208.89982110912342, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(89.862850327966584, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7b45e4ba9c944653a11ce82d3b71a76d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te1bb52a9b891471d82068b6085b6ac73"><g class="toyplot-Edges"><path d="M 87.32856291 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.897435897 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.069171139 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.069171139 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.897435897 245.3125 L 292.069171139 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.614788312 190.625 L 285.897435897 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.86940966 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.032200358 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.032200358 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.002385212 96.875 L 273.032200358 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.181276088 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.181276088 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.002385212 96.875 L 273.181276088 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.86940966 135.9375 L 273.002385212 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.614788312 190.625 L 246.86940966 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 87.32856291 245.3125 L 197.614788312 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(273.18127608825284, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(273.03220035778173, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(273.00238521168751, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(292.06917113893854, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(246.86940966010732, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(285.89743589743586, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(197.61478831246274, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(87.328562909958251, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcf43a508ea824842998859388b5cd77c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t23113960f8db4212abfe8868c9117096"><g class="toyplot-Edges"><path d="M 88.6404293381 244.82421875 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.722122838 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.14490161 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.14490161 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.722122838 245.3125 L 291.14490161 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.225998807 189.6484375 L 282.722122838 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.985092427 133.984375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.21228384 92.96875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.257006559 104.6875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.346451998 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.346451998 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.257006559 104.6875 L 272.346451998 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.21228384 92.96875 L 272.257006559 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.985092427 133.984375 L 272.21228384 92.96875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.225998807 189.6484375 L 249.985092427 133.984375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.6404293381 244.82421875 L 198.225998807 189.6484375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(272.34645199761479, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(272.25700655933213, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(272.21228384019082, 92.96875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(291.14490161001794, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(249.98509242695289, 133.984375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(282.7221228384019, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.22599880739415, 189.6484375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(88.640429338103758, 244.82421875)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfb0ff4b5d6d042d697a45e82eb8260b1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t10879776d3ca49e4ac3dbd3dea9082ef"><g class="toyplot-Edges"><path d="M 97.465712582 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.675014908 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.085271318 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.085271318 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.675014908 245.3125 L 291.085271318 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.968992248 190.625 L 284.675014908 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.428741801 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.404889684 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.404889684 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.389982111 96.875 L 273.404889684 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.822301729 96.875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.822301729 96.875 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.389982111 96.875 L 273.822301729 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.428741801 135.9375 L 273.389982111 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.968992248 190.625 L 253.428741801 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 97.465712582 245.3125 L 200.968992248 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(273.82230172927848, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(273.40488968395948, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(273.38998211091234, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(291.08527131782944, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.42874180083481, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(284.67501490757303, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(200.96899224806202, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.465712581991639, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t494bdb3ecd9e45a699e7acb163086cca"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td63a932c47d84384b34eb35a64943ceb"><g class="toyplot-Edges"><path d="M 95.3041144902 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.41025641 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.787119857 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.787119857 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.41025641 245.3125 L 290.787119857 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.459749553 190.625 L 281.41025641 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.145497913 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.360166965 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.360166965 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.778771616 96.875 L 273.360166965 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.808586762 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.808586762 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.778771616 96.875 L 272.808586762 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.145497913 135.9375 L 272.778771616 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.459749553 190.625 L 253.145497913 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 95.3041144902 245.3125 L 202.459749553 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(272.80858676207515, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(273.36016696481812, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(272.77877161598087, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(290.78711985688733, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.14549791293979, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.41025641025641, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(202.45974955277282, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(95.304114490160998, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf846f3a41d0a48f381c0ce4aaa10208d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t64e20f879e9f4737afb03e9bbc2f37cc"><g class="toyplot-Edges"><path d="M 90.831842576 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.914728682 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.323792487 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.323792487 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.914728682 245.3125 L 291.323792487 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.929039952 191.6015625 L 283.914728682 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.985092427 137.890625 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.033392964 100.78125 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.107930829 89.0625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.346451998 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.346451998 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.107930829 89.0625 L 272.346451998 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.033392964 100.78125 L 272.107930829 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.985092427 137.890625 L 272.033392964 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.929039952 191.6015625 L 249.985092427 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 90.831842576 245.80078125 L 196.929039952 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(272.34645199761479, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(272.10793082886107, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(272.03339296362554, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(291.32379248658322, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(249.98509242695289, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(283.91472868217056, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(196.92903995229577, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(90.83184257602862, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t12cb6d6984a6486389f6a93076d1482d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2a1b0a25b9014da9b8026095ef7eab33"><g class="toyplot-Edges"><path d="M 95.0506857484 244.82421875 L 299.970184854 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.631484794 245.3125 L 299.970184854 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.129994037 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.129994037 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.631484794 245.3125 L 291.129994037 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.710793083 189.6484375 L 283.631484794 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.490757305 133.984375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.06320811 92.96875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.078115683 104.6875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.435897436 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.435897436 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.078115683 104.6875 L 272.435897436 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.06320811 92.96875 L 272.078115683 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.490757305 133.984375 L 272.06320811 92.96875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.710793083 189.6484375 L 251.490757305 133.984375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 95.0506857484 244.82421875 L 204.710793083 189.6484375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.97018485390572, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.97018485390572, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(272.43589743589746, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(272.07811568276685, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(272.06320810971977, 92.96875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(291.1299940369708, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.4907573047108, 133.984375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(283.63148479427548, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(204.71079308288611, 189.6484375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(95.050685748360166, 244.82421875)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4d77a1e1757347278de006a62c8fbc80"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td01504f1b1974abf86b54d3eff75fce4"><g class="toyplot-Edges"><path d="M 88.282647585 245.80078125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.41025641 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.457960644 221.875 L 299.970184854 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.457960644 221.875 L 299.970184854 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.41025641 245.3125 L 291.457960644 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.069767442 191.6015625 L 281.41025641 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.774001193 137.890625 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.273106738 100.78125 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.33273703 89.0625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.407274896 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.407274896 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.33273703 89.0625 L 271.407274896 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.273106738 100.78125 L 271.33273703 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.774001193 137.890625 L 271.273106738 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.069767442 191.6015625 L 251.774001193 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.282647585 245.80078125 L 204.069767442 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.97018485390572, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.97018485390572, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(271.40727489564699, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(271.33273703041147, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(271.27310673822302, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(291.45796064400713, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.77400119260585, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(281.41025641025641, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(204.06976744186045, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(88.282647584973176, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t02bf0f830e674f9e826b54820b5efdab"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t93465f4e19464e4c8f4338b4d9e4551a"><g class="toyplot-Edges"><path d="M 90.2951699463 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.421586166 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.99582588 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.99582588 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.421586166 245.3125 L 290.99582588 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.560524747 190.625 L 284.421586166 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.543231962 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.689326178 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.689326178 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.659511032 96.875 L 272.689326178 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.927847346 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.927847346 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.659511032 96.875 L 272.927847346 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.543231962 135.9375 L 272.659511032 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.560524747 190.625 L 257.543231962 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 90.2951699463 245.3125 L 205.560524747 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(272.92784734645198, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(272.68932617769826, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(272.6595110316041, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(290.99582587954683, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(257.54323196183663, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(284.42158616577228, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(205.56052474657128, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(90.295169946332749, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9d91f9cbc65e42aea84fb89d169594a3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6827922b63a24c87a8e389b989331b6e"><g class="toyplot-Edges"><path d="M 75.9838998211 243.359375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.240310078 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.548598688 221.875 L 299.970184854 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.548598688 221.875 L 299.970184854 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.240310078 245.3125 L 290.548598688 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.945140131 186.71875 L 286.240310078 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.263565891 128.125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.660703637 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.72033393 112.5 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.765056649 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.765056649 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.72033393 112.5 L 271.765056649 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.660703637 81.25 L 271.72033393 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.263565891 128.125 L 271.660703637 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.945140131 186.71875 L 254.263565891 128.125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.9838998211 243.359375 L 195.945140131 186.71875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.97018485390572, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.97018485390572, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(271.76505664877754, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(271.7203339296363, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(271.66070363744785, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.5485986881335, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(254.26356589147287, 128.125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(286.24031007751938, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(195.94514013118663, 186.71875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(75.983899821109119, 243.359375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t14e91026c7aa4b7cbaf6f4723ba1f682"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1d674514431a417999d01d6c70a02d0e"><g class="toyplot-Edges"><path d="M 78.4585569469 243.359375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.76326774 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.697674419 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.697674419 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.76326774 245.3125 L 290.697674419 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.016100179 186.71875 L 285.76326774 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 256.216457961 128.125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.943947525 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.988670244 112.5 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.048300537 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.048300537 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.988670244 112.5 L 272.048300537 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.943947525 81.25 L 271.988670244 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 256.216457961 128.125 L 271.943947525 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.016100179 186.71875 L 256.216457961 128.125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.4585569469 243.359375 L 199.016100179 186.71875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(272.04830053667263, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(271.98867024448418, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(271.94394752534288, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.69767441860461, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(256.21645796064399, 128.125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(285.763267740012, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(199.01610017889087, 186.71875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(78.458556946929022, 243.359375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t68c541b82f2948a496ec9f42dc2578f2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9c34265c561a48a79d57b699e48cabed"><g class="toyplot-Edges"><path d="M 66.0107334526 243.359375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.574239714 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.683959451 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.683959451 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.574239714 245.3125 L 289.683959451 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.339296363 186.71875 L 281.574239714 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.132975552 128.125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.481812761 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.481812761 112.5 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.630888491 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.630888491 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.481812761 112.5 L 271.630888491 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 271.481812761 81.25 L 271.481812761 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.132975552 128.125 L 271.481812761 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.339296363 186.71875 L 251.132975552 128.125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.0107334526 243.359375 L 203.339296363 186.71875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(271.63088849135357, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(271.48181276088252, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(271.48181276088252, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.68395945140128, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(251.13297555158019, 128.125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.5742397137746, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(203.33929636255215, 186.71875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(66.010733452593897, 243.359375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0b34efce7e8c40b2ad6d1ffda7a09902"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8761e3db53534d0dbb7a99162c0bdaa9"><g class="toyplot-Edges"><path d="M 81.4698867024 243.359375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.903398927 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.95110316 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.95110316 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.903398927 245.3125 L 290.95110316 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.871794872 186.71875 L 280.903398927 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.506857484 128.125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.242098986 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.257006559 112.5 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.480620155 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.480620155 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.257006559 112.5 L 272.480620155 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.242098986 81.25 L 272.257006559 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.506857484 128.125 L 272.242098986 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.871794872 186.71875 L 250.506857484 128.125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 81.4698867024 243.359375 L 194.871794872 186.71875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(272.48062015503876, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(272.25700655933213, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(272.24209898628499, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(290.95110316040552, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(250.50685748360166, 128.125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.9033989266548, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(194.87179487179489, 186.71875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(81.469886702444853, 243.359375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td1ad1358de764098975db4943827c79a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3c3692924e3f493f9c5e8b9ebfc35aae"><g class="toyplot-Edges"><path d="M 90.0119260584 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.868813357 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.741204532 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.741204532 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.868813357 245.3125 L 291.741204532 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.166368515 190.625 L 284.868813357 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.591532499 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.895646989 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.955277281 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.029815146 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.029815146 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.955277281 81.25 L 275.029815146 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.895646989 96.875 L 274.955277281 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.591532499 135.9375 L 274.895646989 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.166368515 190.625 L 254.591532499 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 90.0119260584 245.3125 L 198.166368515 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(275.02981514609417, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(274.95527728085864, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(274.89564698867025, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(291.74120453190216, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(254.59153249850925, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(284.86881335718539, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.16636851520573, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(90.011926058437666, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6121a9da49ff4530914d4c570285c502"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdc15ac7aba5f4ccd8a22dca95df04080"><g class="toyplot-Edges"><path d="M 95.0805008945 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.538461538 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.174716756 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.174716756 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.538461538 245.3125 L 291.174716756 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.217054264 190.625 L 286.538461538 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.298151461 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.596302922 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.670840787 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.730471079 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.730471079 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.670840787 81.25 L 275.730471079 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.596302922 96.875 L 275.670840787 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.298151461 135.9375 L 275.596302922 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.217054264 190.625 L 250.298151461 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 95.0805008945 245.3125 L 193.217054264 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(275.7304710793083, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(275.6708407871198, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(275.59630292188433, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(291.1747167561121, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(250.29815146094217, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(286.53846153846149, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(193.21705426356587, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(95.08050089445436, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbbef31a580bd43688202a939bc259683"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8d42be882b724ce38f420e3e831b4f2e"><g class="toyplot-Edges"><path d="M 93.4704830054 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.909958259 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.548598688 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.548598688 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.909958259 245.3125 L 290.548598688 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.391174717 193.5546875 L 287.909958259 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.722719141 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.118067979 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.177698271 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.22242099 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.22242099 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.177698271 104.6875 L 276.22242099 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.118067979 108.59375 L 276.177698271 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.722719141 141.796875 L 276.118067979 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.391174717 193.5546875 L 244.722719141 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 93.4704830054 246.77734375 L 197.391174717 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(276.22242098986283, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(276.17769827072152, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(276.11806797853308, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(290.5485986881335, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.72271914132378, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(287.90995825879548, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(197.3911747167561, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(93.470483005366731, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7837eb11d4ad40fb8d7f297ffed45e08"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6a614ebb9903460abc363491bfe7f6f3"><g class="toyplot-Edges"><path d="M 85.6589147287 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.313655337 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.04293381 221.875 L 299.970184854 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.04293381 221.875 L 299.970184854 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.313655337 245.3125 L 289.04293381 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.277280859 190.625 L 287.313655337 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.347644603 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.14907573 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.238521169 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.253428742 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.253428742 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.238521169 81.25 L 275.253428742 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.14907573 96.875 L 275.238521169 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.347644603 135.9375 L 275.14907573 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.277280859 190.625 L 246.347644603 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 85.6589147287 245.3125 L 205.277280859 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(275.2534287418008, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(275.23852116875372, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(275.14907573047105, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(289.04293381037564, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(246.34764460345855, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(287.31365533691121, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(205.27728085867619, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(85.658914728682163, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t594685aeff734c8c9eaa078877f88344"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc874c9175f7d48b4b1a954de12f8cff3"><g class="toyplot-Edges"><path d="M 74.6273106738 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.778175313 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.547406082 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.547406082 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.778175313 245.3125 L 291.547406082 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.775193798 193.5546875 L 285.778175313 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.561717352 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.479427549 108.59375 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.956469887 104.6875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.97137746 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.97137746 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.956469887 104.6875 L 273.97137746 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.479427549 108.59375 L 273.956469887 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.561717352 141.796875 L 273.479427549 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.775193798 193.5546875 L 254.561717352 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.6273106738 246.77734375 L 200.775193798 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695292, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(273.97137745974959, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(273.95646988670245, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(273.47942754919501, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(291.5474060822898, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(254.56171735241503, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(285.77817531305902, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(200.77519379844966, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(74.627310673822308, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf7e9e0e160224c1ab1b0d35ce1d3806a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5c416bbc109944bfa70280827e38d615"><g class="toyplot-Edges"><path d="M 64.0429338104 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.332140727 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.712581992 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.712581992 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.332140727 245.3125 L 290.712581992 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.459749553 193.5546875 L 284.332140727 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.510435301 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.987477639 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.121645796 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.225998807 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.225998807 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.121645796 104.6875 L 273.225998807 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 272.987477639 108.59375 L 273.121645796 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.510435301 141.796875 L 272.987477639 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.459749553 193.5546875 L 247.510435301 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.0429338104 246.77734375 L 202.459749553 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.99999999999994, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(273.22599880739415, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(273.12164579606434, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(272.98747763864043, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.71258199165175, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(247.51043530113296, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(284.33214072748956, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(202.45974955277279, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(64.042933810375644, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfa564b80982842d98ab64be63c9cdca8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t587ac096004e475aa345909eed7f0842"><g class="toyplot-Edges"><path d="M 76.9379844961 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.583184258 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.368515206 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.368515206 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.583184258 245.3125 L 291.368515206 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.957662493 193.5546875 L 286.583184258 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.283243888 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.462134764 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.551580203 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.715563506 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.715563506 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.551580203 104.6875 L 275.715563506 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.462134764 108.59375 L 275.551580203 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.283243888 141.796875 L 275.462134764 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.957662493 193.5546875 L 250.283243888 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.9379844961 246.77734375 L 197.957662493 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(275.71556350626122, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(275.55158020274303, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(275.4621347644603, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(291.36851520572452, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.28324388789505, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(286.58318425760285, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(197.95766249254621, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(76.937984496124017, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te53a161a3b624ef3800de49c85519afa"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbc361bb341ae4a1190f81e64bf9e766a"><g class="toyplot-Edges"><path d="M 66.443053071 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.496124031 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.370900417 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.370900417 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.496124031 245.3125 L 289.370900417 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.709600477 193.5546875 L 284.496124031 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.839594514 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.493142516 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.642218247 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.80620155 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.80620155 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.642218247 104.6875 L 274.80620155 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.493142516 108.59375 L 274.642218247 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.839594514 141.796875 L 274.493142516 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.709600477 193.5546875 L 246.839594514 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.443053071 246.77734375 L 205.709600477 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(274.80620155038758, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(274.64221824686939, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(274.49314251639834, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(289.37090041741197, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.83959451401313, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(284.49612403100775, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(205.70960047704233, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(66.443053070960048, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8b43968d6a804a80b317c24a2b21a72a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc70cf5a9913a44dd8674fd7c3528f202"><g class="toyplot-Edges"><path d="M 62.0602265951 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.568276685 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.77340489 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.77340489 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.568276685 245.3125 L 289.77340489 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.207513417 193.5546875 L 286.568276685 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.847346452 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.208706023 108.59375 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.283243888 104.6875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.432319618 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.432319618 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.283243888 104.6875 L 275.432319618 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.208706023 108.59375 L 275.283243888 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.847346452 141.796875 L 275.208706023 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.207513417 193.5546875 L 252.847346452 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.0602265951 246.77734375 L 201.207513417 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695292, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695292, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695292, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695292, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695292, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695292, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(275.43231961836608, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(275.28324388789503, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(275.20870602265956, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(289.77340488968395, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.84734645199762, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(286.56827668455577, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(201.20751341681574, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(62.060226595110329, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6ff741467e6c48d393b7d67bdf242c3e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta704a397581a496ba7c658ce50dccba1"><g class="toyplot-Edges"><path d="M 51.3267740012 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.841383423 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.061419201 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.061419201 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.841383423 245.3125 L 286.061419201 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.072152654 193.5546875 L 282.841383423 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.629695886 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.09183065 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.330351819 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.360166965 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.360166965 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.330351819 104.6875 L 273.360166965 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.09183065 108.59375 L 273.330351819 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.629695886 141.796875 L 273.09183065 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.072152654 193.5546875 L 247.629695886 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 51.3267740012 246.77734375 L 202.072152654 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(273.36016696481806, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(273.3303518187239, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(273.09183064997018, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(286.06141920095405, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.62969588550982, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(282.84138342277873, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(202.07215265354796, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(51.326774001192597, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t63c1abe2a7e1441f8bb393f599028a6f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6d6e79cbdfb54cd3877589b1b4949c6a"><g class="toyplot-Edges"><path d="M 50.0 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.66129994 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.416815742 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.416815742 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.66129994 245.3125 L 288.416815742 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.158020274 193.5546875 L 283.66129994 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.277280859 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.345259392 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.479427549 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.299344067 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.299344067 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.479427549 104.6875 L 274.299344067 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 273.345259392 108.59375 L 273.479427549 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.277280859 141.796875 L 273.345259392 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.158020274 193.5546875 L 255.277280859 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 246.77734375 L 205.158020274 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(274.29934406678592, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(273.47942754919501, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(273.34525939177104, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.41681574239715, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(255.27728085867622, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(283.6612999403697, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(205.15802027429936, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(50.0, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t536ff76ce192466299e98ee17bd728a1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8b723ef030544f63a491928aa98e47d9"><g class="toyplot-Edges"><path d="M 59.0936195587 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.927251044 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.655336911 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.655336911 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.927251044 245.3125 L 288.655336911 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.180083482 193.5546875 L 285.927251044 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.700655933 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.045915325 108.59375 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.209898629 104.6875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.029815146 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.029815146 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.209898629 104.6875 L 275.029815146 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.045915325 108.59375 L 274.209898629 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.700655933 141.796875 L 274.045915325 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.180083482 193.5546875 L 250.700655933 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.0936195587 246.77734375 L 199.180083482 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(275.02981514609422, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(274.20989862850331, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(274.04591532498512, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.65533691115087, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(250.70065593321408, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(285.92725104353008, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(199.18008348240909, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(59.093619558735831, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t21f2510127274d2fa57a11e097f872a2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdadc05be6756454a94881ff977fcaf93"><g class="toyplot-Edges"><path d="M 70.0208706023 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.343470483 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.519976148 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.519976148 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.343470483 245.3125 L 289.519976148 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.841979726 193.5546875 L 287.343470483 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.03875969 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.612403101 108.59375 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.746571258 104.6875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.088252832 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.088252832 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.746571258 104.6875 L 276.088252832 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.612403101 108.59375 L 274.746571258 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.03875969 141.796875 L 274.612403101 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.841979726 193.5546875 L 255.03875969 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.0208706023 246.77734375 L 194.841979726 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(276.08825283243891, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(274.7465712581992, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(274.61240310077517, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(289.51997614788314, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(255.0387596899225, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(287.34347048300538, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(194.84197972570067, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(70.020870602265958, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdb9806c711974abf918e14c99533292a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7226c5a00f274b369e4af9557bfbae69"><g class="toyplot-Edges"><path d="M 68.2617769827 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.911150865 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.088849135 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.088849135 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.911150865 245.3125 L 288.088849135 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.382826476 193.5546875 L 286.911150865 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.35301133 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.731663685 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.836016696 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.90816935 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.90816935 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.836016696 104.6875 L 276.90816935 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 274.731663685 108.59375 L 274.836016696 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.35301133 141.796875 L 274.731663685 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.382826476 193.5546875 L 254.35301133 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.2617769827 246.77734375 L 204.382826476 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(276.90816935002982, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(274.83601669648186, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(274.73166368515211, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(288.08884913536076, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(254.35301132975553, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(286.91115086463924, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(204.38282647584975, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(68.261776982707218, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb85bf087d8744c57a214423701ca7869"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2dccb5d6631d4603b30ed778b1599514"><g class="toyplot-Edges"><path d="M 72.4209898629 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.598091831 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.163387001 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.163387001 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.598091831 245.3125 L 288.163387001 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.255813953 193.5546875 L 286.598091831 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.387596899 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.387596899 108.59375 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.909361956 104.6875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.116875373 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.116875373 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.909361956 104.6875 L 277.116875373 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 275.387596899 108.59375 L 275.909361956 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.387596899 141.796875 L 275.387596899 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.255813953 193.5546875 L 250.387596899 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.4209898629 246.77734375 L 198.255813953 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(277.11687537268926, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(275.90936195587358, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(275.38759689922477, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(288.16338700059629, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.3875968992248, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(286.59809183064999, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.25581395348837, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(72.420989862850305, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbe3615c5499147509d04a75d58f13f7d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t962316ec78fa4fc2b5fab5604fb154b6"><g class="toyplot-Edges"><path d="M 81.7233154442 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.793082886 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.431723315 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.431723315 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.793082886 245.3125 L 288.431723315 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.634466309 193.5546875 L 285.793082886 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.858676208 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.729278473 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.131782946 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.889683959 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.889683959 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.131782946 104.6875 L 279.889683959 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.729278473 108.59375 L 277.131782946 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.858676208 141.796875 L 276.729278473 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.634466309 193.5546875 L 255.858676208 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 81.7233154442 246.77734375 L 193.634466309 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(279.88968395945142, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(277.1317829457364, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(276.72927847346449, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.43172331544429, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(255.85867620751341, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(285.79308288610611, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.6344663088849, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(81.723315444245671, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t469fadeb141a42bb9ae8f147f6f3642a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdeac59903ed045a98e388a3e791c63fc"><g class="toyplot-Edges"><path d="M 74.2695289207 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.045319022 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.418008348 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.418008348 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.045319022 245.3125 L 287.418008348 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.0816935 193.5546875 L 287.045319022 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.212880143 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.431127013 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.818723912 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.713178295 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.713178295 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.818723912 104.6875 L 277.713178295 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.431127013 108.59375 L 276.818723912 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 259.212880143 141.796875 L 276.431127013 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.0816935 193.5546875 L 259.212880143 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.2695289207 246.77734375 L 194.0816935 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(277.71317829457365, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(276.81872391174716, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(276.43112701252232, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(287.41800834824096, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(259.21288014311273, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(287.04531902206315, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(194.08169350029817, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(74.269528920691698, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t98ae539b5fb544bd8c63ce986468129b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t45c9955f974a43f5a7c33faf6a484a5e"><g class="toyplot-Edges"><path d="M 73.6135957066 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.762075134 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.537268933 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.537268933 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.762075134 245.3125 L 287.537268933 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.376267144 193.5546875 L 286.762075134 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.237328563 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.475849732 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.729278473 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.981514609 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.981514609 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.729278473 104.6875 L 277.981514609 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.475849732 108.59375 L 276.729278473 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.237328563 141.796875 L 276.475849732 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.376267144 193.5546875 L 251.237328563 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.6135957066 246.77734375 L 197.376267144 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(277.98151460942154, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(276.72927847346449, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(276.47584973166363, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(287.53726893261768, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.23732856290991, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(286.76207513416819, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(197.37626714370899, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(73.613595706618952, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t67139230b57147768e4fe30ea3b6c32b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t29522b904d4a46a5b4c7b301494f6039"><g class="toyplot-Edges"><path d="M 72.3166368515 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.942158617 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.834227788 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.834227788 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.942158617 245.3125 L 288.834227788 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.779964222 190.625 L 285.942158617 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.943947525 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.083482409 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.083482409 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.878354204 96.875 L 280.083482409 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.997614788 128.125 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.997614788 128.125 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.878354204 96.875 L 276.997614788 128.125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.943947525 135.9375 L 276.878354204 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.779964222 190.625 L 246.943947525 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.3166368515 245.3125 L 196.779964222 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(276.99761478831243, 128.125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.08348240906378, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(276.87835420393554, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.8342277877162, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.94394752534288, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(285.94215861657722, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(196.77996422182466, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(72.316636851520542, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3b71d0dcbd6b4a66adcd8670cdc74cca"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9e83eb08111a4286ba44b4602e5fc92b"><g class="toyplot-Edges"><path d="M 80.5008944544 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.581991652 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.192009541 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.192009541 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.581991652 245.3125 L 289.192009541 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.022063208 195.5078125 L 287.581991652 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.513416816 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.801431127 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.861061419 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.796660704 65.625 L 299.970184854 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.796660704 65.625 L 299.970184854 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.861061419 89.0625 L 282.796660704 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.801431127 116.40625 L 278.861061419 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.513416816 145.703125 L 278.801431127 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.022063208 195.5078125 L 257.513416816 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.5008944544 247.75390625 L 194.022063208 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(282.79666070363749, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(278.86106141920095, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(278.80143112701251, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(289.1920095408467, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(257.51341681574235, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(287.5819916517591, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(194.0220632081097, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(80.500894454382802, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t623619b5010343409de15709878e6812"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ted526229a5934d15b001c6550db0d094"><g class="toyplot-Edges"><path d="M 80.1729278473 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.984496124 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.041741205 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.041741205 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.984496124 245.3125 L 290.041741205 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.522957662 195.5078125 L 287.984496124 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.567680382 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.084675015 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.15921288 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.511031604 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.511031604 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.15921288 89.0625 L 284.511031604 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.084675015 116.40625 L 279.15921288 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.567680382 145.703125 L 279.084675015 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.522957662 195.5078125 L 249.567680382 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.1729278473 247.75390625 L 199.522957662 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(284.51103160405489, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.15921288014312, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.08467501490759, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.04174120453189, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(249.56768038163389, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(287.98449612403101, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(199.52295766249256, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(80.172927847346472, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t937ac72ad4e146a8b56838b353436dd0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t92678b9308e245439fbf5022696eb7ca"><g class="toyplot-Edges"><path d="M 79.6362552177 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.01431127 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.833035182 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.833035182 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.01431127 245.3125 L 289.833035182 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.122838402 195.5078125 L 288.01431127 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.053667263 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.741800835 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.831246273 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.994036971 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.994036971 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.831246273 89.0625 L 279.994036971 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.741800835 116.40625 L 278.831246273 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.053667263 145.703125 L 278.741800835 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.122838402 195.5078125 L 255.053667263 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.6362552177 247.75390625 L 197.122838402 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.99403697078117, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(278.83124627310673, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(278.74180083482412, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(289.83303518187245, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(255.05366726296961, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(288.01431127012523, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(197.12283840190818, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(79.636255217650572, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9bdf05f7439e4fc0ba0b931af90288eb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t98857e6cb54b4d88982333571d7c9670"><g class="toyplot-Edges"><path d="M 68.7835420394 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.793082886 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.701252236 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.701252236 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.793082886 245.3125 L 287.701252236 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.828264758 195.5078125 L 285.793082886 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.03875969 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.385211688 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.549194991 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.085867621 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.085867621 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.549194991 89.0625 L 278.085867621 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.385211688 116.40625 L 277.549194991 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.03875969 145.703125 L 277.385211688 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.828264758 195.5078125 L 255.03875969 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.7835420394 247.75390625 L 193.828264758 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(278.0858676207514, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(277.54919499105546, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(277.38521168753732, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(287.70125223613599, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(255.0387596899225, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(285.79308288610616, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.82826475849731, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(68.783542039356007, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t071055e93e6d4b66b3bf2c883cec11ca"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te4f5c4df9a554fbfa3605413d819f32a"><g class="toyplot-Edges"><path d="M 78.9505068575 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.32856291 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.326177698 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.326177698 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.32856291 245.3125 L 289.326177698 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.892069171 195.5078125 L 287.32856291 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.827072153 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.189028026 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.323196184 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.053667263 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.053667263 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.323196184 89.0625 L 280.053667263 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.189028026 116.40625 L 279.323196184 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.827072153 145.703125 L 279.189028026 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.892069171 195.5078125 L 244.827072153 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.9505068575 247.75390625 L 202.892069171 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.05366726296961, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(279.32319618366125, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(279.18902802623728, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(289.32617769827073, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(244.82707215265353, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(287.32856290995824, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(202.89206917113893, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(78.950506857483589, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbe3a2781b0e54b66b9c71073f27ee0dc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc61b25fc0d684e51bfd0e64a0ace82c0"><g class="toyplot-Edges"><path d="M 75.1937984496 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.568276685 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.178294574 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.178294574 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.568276685 245.3125 L 288.178294574 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.629695886 195.5078125 L 286.568276685 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.075730471 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.041144902 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.32438879 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.890876565 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.890876565 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.32438879 89.0625 L 278.890876565 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.041144902 116.40625 L 278.32438879 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.075730471 145.703125 L 278.041144902 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.629695886 195.5078125 L 249.075730471 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.1937984496 247.75390625 L 197.629695886 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(278.89087656529517, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(278.32438878950506, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(278.04114490161004, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(288.17829457364337, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(249.07573047107931, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(286.56827668455577, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(197.62969588550982, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(75.193798449612402, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3ca4946db70a4409bcca9567c55af175"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1bc58487056947bfb70218c23fe52fa1"><g class="toyplot-Edges"><path d="M 85.6440071556 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.552176506 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.880143113 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.880143113 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.552176506 245.3125 L 287.880143113 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.178890877 195.5078125 L 287.552176506 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.679189028 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.15921288 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.576624925 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.560524747 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.560524747 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.576624925 89.0625 L 280.560524747 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.15921288 116.40625 L 279.576624925 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.679189028 145.703125 L 279.15921288 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.178890877 195.5078125 L 243.679189028 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 85.6440071556 247.75390625 L 200.178890877 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.56052474657128, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(279.57662492546217, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(279.15921288014312, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(287.88014311270121, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(243.67918902802623, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(287.55217650566487, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(200.17889087656528, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(85.64400715563508, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t639fc22884d445c8a7320eeea44bcf43"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te767726972a64696bbafba02b50bcdd5"><g class="toyplot-Edges"><path d="M 89.9522957662 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.611806798 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.118664281 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.118664281 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.611806798 245.3125 L 288.118664281 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.535480024 195.5078125 L 287.611806798 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.880739416 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.503279666 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.980322004 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.621347645 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.621347645 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.980322004 89.0625 L 279.621347645 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.503279666 116.40625 L 278.980322004 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.880739416 145.703125 L 278.503279666 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.535480024 195.5078125 L 249.880739416 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 89.9522957662 247.75390625 L 201.535480024 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.62134764460342, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(278.98032200357778, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(278.50327966607034, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.11866428145504, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(249.88073941562311, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(287.61180679785332, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(201.53548002385213, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(89.95229576624925, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1b1d5be7b9544a3a9adb8d0d97cfa1fb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t101f460a200f40bb9045a0a361e5d5f2"><g class="toyplot-Edges"><path d="M 80.2176505665 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.47763864 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.67143709 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.67143709 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.47763864 245.3125 L 287.67143709 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.186046512 195.5078125 L 287.47763864 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.960047704 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.90816935 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.280858676 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.504472272 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.504472272 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.280858676 89.0625 L 277.504472272 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.90816935 116.40625 L 277.280858676 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.960047704 145.703125 L 276.90816935 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.186046512 195.5078125 L 245.960047704 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.2176505665 247.75390625 L 194.186046512 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695292, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695292, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695292, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(277.50447227191415, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(277.28085867620752, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(276.90816935002988, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(287.67143709004171, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.96004770423374, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(287.47763864042935, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(194.18604651162792, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(80.217650566487791, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7c28c14c1d234e878f1f9f5d792b1b82"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbf4fdb32c94c41429f7d0b0f775acbdf"><g class="toyplot-Edges"><path d="M 77.0870602266 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.581991652 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.223017293 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.223017293 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.581991652 245.3125 L 288.223017293 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.042337507 195.5078125 L 287.581991652 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.119260584 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.653548002 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.906976744 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.950506857 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.950506857 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.906976744 89.0625 L 278.950506857 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.653548002 116.40625 L 277.906976744 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.119260584 145.703125 L 277.653548002 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.042337507 195.5078125 L 250.119260584 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.0870602266 247.75390625 L 202.042337507 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(278.95050685748356, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(277.90697674418607, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(277.65354800238521, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.22301729278473, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(250.11926058437689, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(287.5819916517591, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(202.04233750745379, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(77.087060226595099, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t57a99fba143045f3ba7629b8903294a5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc60db1a5ede04062a1f7944fd9897f83"><g class="toyplot-Edges"><path d="M 76.3118664281 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.118664281 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.221824687 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.221824687 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.118664281 245.3125 L 289.221824687 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.368515206 195.5078125 L 288.118664281 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.506857484 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.608825283 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.996422182 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.50208706 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.50208706 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.996422182 89.0625 L 279.50208706 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.608825283 116.40625 L 277.996422182 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.506857484 145.703125 L 277.608825283 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.368515206 195.5078125 L 250.506857484 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.3118664281 247.75390625 L 191.368515206 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.50208706022653, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(277.99642218246868, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(277.60882528324385, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(289.22182468694092, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(250.50685748360166, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(288.11866428145504, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.36851520572449, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(76.311866428145493, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5aa03a39f0604311b1749ddb3e5a3546"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t69bef147e4c3470a80c5ba9c34b60211"><g class="toyplot-Edges"><path d="M 74.2695289207 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.760882528 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.834227788 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.834227788 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.760882528 245.3125 L 288.834227788 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.875372689 195.5078125 L 287.760882528 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.327966607 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.518187239 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.801431127 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.022659511 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.022659511 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.801431127 89.0625 L 281.022659511 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.518187239 116.40625 L 278.801431127 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.327966607 145.703125 L 278.518187239 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.875372689 195.5078125 L 250.327966607 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.2695289207 247.75390625 L 191.875372689 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.02265951103158, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(278.80143112701251, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(278.51818723911754, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(288.8342277877162, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.32796660703639, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(287.76088252832443, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.87537268932621, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(74.269528920691727, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta420198d0f1c4cda96e9974d72a4a1cb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tae673ab56fd142ebb9772edb6a8f2475"><g class="toyplot-Edges"><path d="M 72.9874776386 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.745974955 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.789505069 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.789505069 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.745974955 245.3125 L 288.789505069 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.27549195 195.5078125 L 287.745974955 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.011329756 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.489564699 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.13059034 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.84496124 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.84496124 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.13059034 89.0625 L 279.84496124 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.489564699 116.40625 L 278.13059034 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.011329756 145.703125 L 277.489564699 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.27549195 195.5078125 L 253.011329756 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.9874776386 247.75390625 L 194.27549195 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(279.84496124031006, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(278.13059033989259, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(277.48956469886696, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.78950506857478, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.01132975551582, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(287.74597495527723, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(194.27549194991053, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(72.987477638640428, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta3673f03cc8240bdb4ac294c17dbd906"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t443a8b3a025e4c2ab37dd82457c55cc3"><g class="toyplot-Edges"><path d="M 71.8545020871 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.790697674 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.849135361 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.849135361 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.790697674 245.3125 L 288.849135361 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.442456768 195.5078125 L 287.790697674 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.834824091 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.355396541 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.996422182 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.412641622 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.412641622 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.996422182 89.0625 L 279.412641622 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.355396541 116.40625 L 277.996422182 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.834824091 145.703125 L 277.355396541 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.442456768 195.5078125 L 250.834824091 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.8545020871 247.75390625 L 204.442456768 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(279.41264162194398, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(277.99642218246868, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(277.3553965414431, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(288.84913536076328, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.83482409063805, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(287.7906976744186, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(204.44245676803817, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(71.854502087060212, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1dabf17c53964d0ebd7162112a2da153"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6e64cdca5dc54e59813da90e0b1b746a"><g class="toyplot-Edges"><path d="M 70.3786523554 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.13476446 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.327370304 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.327370304 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.13476446 245.3125 L 288.327370304 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.55515802 195.5078125 L 287.13476446 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.005963029 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.192605844 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.877161598 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.025044723 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.025044723 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.877161598 89.0625 L 279.025044723 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.192605844 116.40625 L 277.877161598 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.005963029 145.703125 L 276.192605844 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.55515802 195.5078125 L 245.005963029 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.3786523554 247.75390625 L 197.55515802 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(279.0250447227192, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(277.87716159809185, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(276.19260584376866, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(288.32737030411454, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.00596302921883, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(287.13476446034588, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(197.55515802027429, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(70.37865235539654, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te37c2ad1331c4bf2ac42c0514b01439d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tef6090e48c0442c2a1118a89ae316701"><g class="toyplot-Edges"><path d="M 83.1991651759 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.387000596 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.864042934 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.864042934 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.387000596 245.3125 L 288.864042934 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.379248658 195.5078125 L 288.387000596 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.690518784 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.680977937 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.307096005 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.560524747 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.560524747 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.307096005 89.0625 L 280.560524747 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.680977937 116.40625 L 280.307096005 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.690518784 145.703125 L 279.680977937 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.379248658 195.5078125 L 246.690518784 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 83.1991651759 247.75390625 L 207.379248658 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.56052474657128, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.30709600477041, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.68097793679192, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.86404293381031, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(246.69051878354205, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.38700059630287, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(207.37924865831843, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(83.199165175909357, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7ce085e55c8f443bb892fc36d1f3ed82"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t88374a8570e34205bce50b68af5799cf"><g class="toyplot-Edges"><path d="M 85.9421586166 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.923673226 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.072748956 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.072748956 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.923673226 245.3125 L 289.072748956 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.861061419 195.5078125 L 288.923673226 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.462134764 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.172927847 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.799045915 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.320810972 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.320810972 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.799045915 89.0625 L 281.320810972 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.172927847 116.40625 L 280.799045915 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.462134764 145.703125 L 280.172927847 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.861061419 195.5078125 L 250.462134764 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 85.9421586166 247.75390625 L 203.861061419 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.32081097197374, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.799045915325, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.17292784734644, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(289.07274895646987, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(250.46213476446036, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.92367322599881, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(203.86106141920095, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(85.942158616577217, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t791a1b8546314b7aa4fcda9dc3ef59b7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t20d31f42ccf748029a503b2ca73bb03e"><g class="toyplot-Edges"><path d="M 72.3315444246 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.790697674 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.342277877 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.342277877 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.790697674 245.3125 L 288.342277877 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.060822898 195.5078125 L 287.790697674 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.552772809 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.861061419 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.680977937 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.336911151 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.336911151 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.680977937 89.0625 L 280.336911151 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.861061419 116.40625 L 279.680977937 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.552772809 145.703125 L 278.861061419 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.060822898 195.5078125 L 249.552772809 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.3315444246 247.75390625 L 199.060822898 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.33691115086464, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.68097793679186, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(278.86106141920095, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.34227787716162, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(249.55277280858672, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(287.7906976744186, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(199.06082289803217, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(72.331544424567682, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfc319821178148c0ae29c1cd7c515be0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t43985e65a64449bfa7077c293fd2c347"><g class="toyplot-Edges"><path d="M 73.1961836613 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.744782349 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.295169946 221.875 L 299.970184854 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.295169946 221.875 L 299.970184854 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.744782349 245.3125 L 290.295169946 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.836016696 195.5078125 L 288.744782349 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.972570066 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.979129398 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.754323196 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.663685152 65.625 L 299.970184854 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.663685152 65.625 L 299.970184854 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.754323196 89.0625 L 281.663685152 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.979129398 116.40625 L 280.754323196 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.972570066 145.703125 L 279.979129398 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.836016696 195.5078125 L 247.972570066 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.1961836613 247.75390625 L 199.836016696 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.97018485390572, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.97018485390572, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.97018485390572, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.97018485390572, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.66368515205721, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(280.75432319618369, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.97912939773403, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.29516994633269, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(247.97257006559332, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(288.74478234943348, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(199.83601669648181, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(73.196183661299926, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2acdf716df7c40559bb5e2b8bb06c60d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tef6843701a4446b3b0826c4f5e4d4648"><g class="toyplot-Edges"><path d="M 79.442456768 247.75390625 L 299.970184854 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.564698867 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.833035182 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.833035182 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.564698867 245.3125 L 289.833035182 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.583780561 195.5078125 L 289.564698867 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.668455575 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.052474657 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.618962433 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.51222421 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.51222421 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.618962433 89.0625 L 283.51222421 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.052474657 116.40625 L 281.618962433 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.668455575 145.703125 L 281.052474657 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.583780561 195.5078125 L 252.668455575 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.442456768 247.75390625 L 198.583780561 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390572, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(283.51222420989865, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.61896243291596, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.05247465712586, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.83303518187239, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.66845557543235, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.56469886702445, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.58378056052473, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(79.442456768038156, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1d5011eb1f3f4fe0a23129a29bf53ab2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf1455f8119624eaea8c2988e2da6f084"><g class="toyplot-Edges"><path d="M 72.3911747168 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.774597496 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.849135361 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.849135361 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.774597496 245.3125 L 288.849135361 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.383422779 195.5078125 L 288.774597496 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.370304114 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.217650566 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.948121646 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.60405486 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.60405486 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.948121646 89.0625 L 281.60405486 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.217650566 116.40625 L 280.948121646 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.370304114 145.703125 L 280.217650566 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.383422779 195.5078125 L 252.370304114 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.3911747168 247.75390625 L 191.383422779 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.60405485986882, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.94812164579605, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.21765056648775, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.84913536076328, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.37030411449018, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.77459749552776, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.38342277877163, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(72.391174716756097, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t54398191a92a4debb9962c1e169c83e8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t03325a9f6bd04f958ab9e1036c47afeb"><g class="toyplot-Edges"><path d="M 78.7119856887 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.296362552 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.355992844 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.355992844 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.296362552 245.3125 L 289.355992844 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.752534287 195.5078125 L 289.296362552 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.935599284 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.276088253 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.842576029 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.407871199 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.407871199 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.842576029 89.0625 L 283.407871199 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.276088253 116.40625 L 281.842576029 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.935599284 145.703125 L 281.276088253 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.752534287 195.5078125 L 253.935599284 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.7119856887 247.75390625 L 194.752534287 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(283.4078711985689, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(281.84257602862255, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(281.27608825283244, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(289.35599284436495, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.93559928443651, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(289.2963625521765, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(194.752534287418, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(78.711985688729897, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t47a9d1656dc4477eb42619b6ec9f0403"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tad3145dae4f445088c34f0b26d06cf55"><g class="toyplot-Edges"><path d="M 70.6469886702 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.01431127 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.205724508 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.205724508 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.01431127 245.3125 L 290.205724508 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.799642218 195.5078125 L 288.01431127 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.12045319 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.843768634 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.827668456 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.961836613 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.961836613 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.827668456 89.0625 L 281.961836613 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.843768634 116.40625 L 281.827668456 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.12045319 145.703125 L 280.843768634 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.799642218 195.5078125 L 249.12045319 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.6469886702 247.75390625 L 192.799642218 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(281.96183661299938, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(281.82766845557541, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.8437686344663, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(290.20572450805008, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(249.12045319022064, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(288.01431127012523, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.79964221824687, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(70.646988670244497, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf20b6ee87ea04797825883f1fa805325"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t98f8cbaf0b4c451a83a7da23886ce2ca"><g class="toyplot-Edges"><path d="M 71.8545020871 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.026833631 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.682766846 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.682766846 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.026833631 245.3125 L 290.682766846 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.731663685 195.5078125 L 290.026833631 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.093023256 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.171735242 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.693500298 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.797853309 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.797853309 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.693500298 89.0625 L 281.797853309 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.171735242 116.40625 L 281.693500298 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.093023256 145.703125 L 281.171735242 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.731663685 195.5078125 L 247.093023256 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.8545020871 247.75390625 L 199.731663685 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(281.79785330948124, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(281.69350029815143, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(281.17173524150263, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(290.68276684555758, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(247.09302325581396, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(290.02683363148475, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(199.73166368515203, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(71.854502087060212, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6372ac5e0d974a9cb12e29765b4b264f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3a9b36d1ee834aaa83fd5a786a3a0ce5"><g class="toyplot-Edges"><path d="M 75.2087060227 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.429338104 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.831842576 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.831842576 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.429338104 245.3125 L 290.831842576 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.699463327 195.5078125 L 290.429338104 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.358974359 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.276088253 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.633870006 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.723315444 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.723315444 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.633870006 89.0625 L 281.723315444 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.276088253 116.40625 L 281.633870006 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.358974359 145.703125 L 281.276088253 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.699463327 195.5078125 L 249.358974359 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.2087060227 247.75390625 L 201.699463327 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.72331544424571, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.63387000596299, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.27608825283244, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(290.83184257602863, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(249.35897435897436, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(290.42933810375666, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(201.69946332737032, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(75.208706022659499, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t76db07c2c0a9442581007611fc4161e6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6f9a329abd0c469bbb9a12560e7d9c57"><g class="toyplot-Edges"><path d="M 58.0053667263 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.044126416 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.011926058 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.011926058 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.044126416 245.3125 L 290.011926058 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.443649374 195.5078125 L 288.044126416 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.799642218 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.083482409 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.411449016 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.843768634 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.843768634 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.411449016 89.0625 L 280.843768634 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.083482409 116.40625 L 280.411449016 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.799642218 145.703125 L 280.083482409 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.443649374 195.5078125 L 242.799642218 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.0053667263 247.75390625 L 203.443649374 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.8437686344663, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.41144901610022, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.08348240906378, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.01192605843772, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(242.79964221824687, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.04412641621946, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(203.44364937388195, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(58.005366726296941, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9a841ff3833d4f469f85c6b41207ce2e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf5db8c0382f04970aa6d42dcf6bbc0fc"><g class="toyplot-Edges"><path d="M 55.6499701849 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.076326774 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.221824687 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.221824687 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.076326774 245.3125 L 289.221824687 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.837209302 195.5078125 L 286.076326774 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.728085868 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.606440072 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.785330948 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.098389982 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.098389982 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.785330948 89.0625 L 280.098389982 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.606440072 116.40625 L 279.785330948 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.728085868 145.703125 L 279.606440072 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.837209302 195.5078125 L 252.728085868 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.6499701849 247.75390625 L 198.837209302 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.99999999999994, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(280.09838998211092, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.78533094812161, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.60644007155634, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(289.22182468694092, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(252.72808586762073, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(286.07632677400119, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.83720930232556, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(55.649970184853871, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcaa72a1fbc11443783778a9d071e2dfb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf115431470f2443fa8a551fc3ca45756"><g class="toyplot-Edges"><path d="M 54.5020870602 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.122242099 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.519976148 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.519976148 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.122242099 245.3125 L 289.519976148 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.099582588 195.5078125 L 285.122242099 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.511627907 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.69588551 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.755515802 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.053667263 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.053667263 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.755515802 89.0625 L 280.053667263 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.69588551 116.40625 L 279.755515802 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.511627907 145.703125 L 279.69588551 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.099582588 195.5078125 L 246.511627907 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 54.5020870602 247.75390625 L 204.099582588 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.05366726296961, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(279.75551580202745, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(279.695885509839, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.51997614788314, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.51162790697674, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(285.12224209898631, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(204.0995825879547, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(54.5020870602266, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf62b299bee324a56b37c8e4c242e4083"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6ec416f0381a466fbb3f72b9f83f3b9f"><g class="toyplot-Edges"><path d="M 60.4800238521 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.940966011 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.998211091 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.998211091 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.940966011 245.3125 L 288.998211091 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.930232558 195.5078125 L 286.940966011 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.629695886 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.427549195 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.531902206 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.963029219 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.963029219 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.531902206 89.0625 L 280.963029219 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.427549195 116.40625 L 279.531902206 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.629695886 145.703125 L 279.427549195 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.930232558 195.5078125 L 247.629695886 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.4800238521 247.75390625 L 195.930232558 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.96302921884313, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(279.53190220632081, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(279.42754919499106, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.99821109123434, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(247.62969588550982, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(286.9409660107334, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(195.93023255813955, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(60.480023852116858, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc63d261b581e4fc09c43c33be3504261"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t073e58c5921b4c43b3612c08ad0f1d17"><g class="toyplot-Edges"><path d="M 58.6911150865 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.98568873 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.712581992 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.712581992 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.98568873 245.3125 L 290.712581992 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.098389982 195.5078125 L 286.98568873 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.503279666 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.831246273 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.935599284 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.725700656 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.725700656 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.935599284 89.0625 L 279.725700656 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.831246273 116.40625 L 278.935599284 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.503279666 145.703125 L 278.831246273 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.098389982 195.5078125 L 253.503279666 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.6911150865 247.75390625 L 205.098389982 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(279.72570065593322, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(278.93559928443653, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(278.83124627310673, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(290.71258199165175, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.50327966607034, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(286.98568872987477, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(205.09838998211092, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(58.691115086463931, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5938745e50094ca197b829ac495c5d27"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0fe1633507bb4dbab117825e2b44b781"><g class="toyplot-Edges"><path d="M 65.3697078116 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.224209899 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.639236732 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.639236732 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.224209899 245.3125 L 289.639236732 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.483005367 195.5078125 L 287.224209899 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.296958855 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.562909958 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.66726297 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.262373286 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.262373286 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.66726297 89.0625 L 280.262373286 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.562909958 116.40625 L 278.66726297 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.296958855 145.703125 L 278.562909958 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.483005367 195.5078125 L 251.296958855 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.3697078116 247.75390625 L 195.483005367 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.26237328562911, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(278.66726296958853, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(278.56290995825879, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.63923673225997, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(251.29695885509838, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(287.22420989862849, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(195.4830053667263, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(65.36970781156829, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t893a7494932d4163bdb455b7d3bb4cbe"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t415ed255548d4a40ba00cfe2bb8a3c4d"><g class="toyplot-Edges"><path d="M 77.2659511032 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.973166369 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.905187835 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.905187835 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.973166369 245.3125 L 291.905187835 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.516994633 195.5078125 L 284.973166369 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.605843769 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.69588551 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.815146094 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.09600477 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.09600477 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.815146094 89.0625 L 282.09600477 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.69588551 116.40625 L 279.815146094 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.605843769 145.703125 L 279.69588551 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.516994633 195.5078125 L 242.605843769 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.2659511032 247.75390625 L 204.516994633 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(282.09600477042341, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.81514609421589, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.695885509839, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(291.90518783542041, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(242.60584376863449, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(284.97316636851519, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(204.5169946332737, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(77.265951103160418, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb18eef0a99ed4819befa671c5e0d5df3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t99b658e35ab047459a2dcbd192a6b982"><g class="toyplot-Edges"><path d="M 82.5432319618 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.86523554 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.397137746 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.397137746 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.86523554 245.3125 L 292.397137746 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.53667263 195.5078125 L 287.86523554 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.225998807 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.57543232 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.72450805 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.648777579 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.648777579 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.72450805 89.0625 L 281.648777579 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.57543232 116.40625 L 280.72450805 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.225998807 145.703125 L 280.57543232 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.53667263 195.5078125 L 248.225998807 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.5432319618 247.75390625 L 200.53667263 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.64877757901007, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.72450805008941, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.57543231961836, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(292.39713774597493, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(248.22599880739412, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(287.86523553965407, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(200.53667262969586, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(82.543231961836597, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t44f2215cc481497da88eb8a197539904"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t55f5adfdf05343d4b07b91bd6c6df455"><g class="toyplot-Edges"><path d="M 76.4907573047 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.432915921 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.740011926 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 292.740011926 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.432915921 245.3125 L 292.740011926 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.199165176 195.5078125 L 287.432915921 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.242098986 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.201550388 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.425163983 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.170542636 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.170542636 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.425163983 89.0625 L 282.170542636 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.201550388 116.40625 L 281.425163983 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.242098986 145.703125 L 281.201550388 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.199165176 195.5078125 L 247.242098986 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.4907573047 247.75390625 L 208.199165176 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(282.17054263565888, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.42516398330355, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.20155038759691, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(292.7400119260584, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(247.24209898628504, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(287.43291592128804, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(208.19916517590934, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(76.490757304710769, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t112890d1b4244801b16c0f5c2204a5bb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf101a2ea44e44eb6804b35957d10f53f"><g class="toyplot-Edges"><path d="M 82.4537865236 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.57960644 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.891472868 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.891472868 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.57960644 245.3125 L 290.891472868 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.813357185 195.5078125 L 289.57960644 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.165175909 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.469886702 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.574239714 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.601669648 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.601669648 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.574239714 89.0625 L 283.601669648 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.469886702 116.40625 L 281.574239714 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.165175909 145.703125 L 281.469886702 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.813357185 195.5078125 L 249.165175909 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.4537865236 247.75390625 L 193.813357185 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(283.60166964818126, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.5742397137746, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.4698867024448, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.89147286821702, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(249.16517590936195, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(289.57960644007153, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.8133571854502, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(82.45378652355393, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0ff10dfea4064807a6c1243090cff086"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t23951550188243d9959a42174b636897"><g class="toyplot-Edges"><path d="M 80.4412641622 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.266547406 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.250447227 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.250447227 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.266547406 245.3125 L 290.250447227 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.49791294 195.5078125 L 289.266547406 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.619558736 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.782945736 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.842576029 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.662492546 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.662492546 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.842576029 89.0625 L 282.662492546 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.782945736 116.40625 L 281.842576029 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.619558736 145.703125 L 281.782945736 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.49791294 195.5078125 L 243.619558736 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.4412641622 247.75390625 L 195.49791294 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(282.66249254621346, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.84257602862255, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.7829457364341, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(290.25044722719139, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(243.61955873583781, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.26654740608228, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(195.49791293977339, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(80.441264162194372, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc4c6149ee78b47ecb10602311eeac9a9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5fe6660ce5f443b090007c9c996bf181"><g class="toyplot-Edges"><path d="M 72.5402504472 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.133571855 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.861657722 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.861657722 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.133571855 245.3125 L 290.861657722 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.018485391 190.625 L 288.133571855 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.970184854 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.528324389 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.528324389 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.022659511 96.875 L 282.528324389 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.082289803 128.125 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.082289803 128.125 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.022659511 96.875 L 281.082289803 128.125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.970184854 135.9375 L 281.022659511 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.018485391 190.625 L 249.970184854 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.5402504472 245.3125 L 197.018485391 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.08228980322002, 128.125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(282.52832438878949, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.02265951103158, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(290.86165772212286, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(249.97018485390575, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.13357185450207, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(197.01848539057841, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(72.54025044722718, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t39acd662d91643aca29c3985f87164f8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0940c24e785c4c948f9cb8d0d270c97a"><g class="toyplot-Edges"><path d="M 68.1872391175 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.224209899 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.431723315 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.431723315 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.224209899 245.3125 L 288.431723315 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.169946333 193.5546875 L 287.224209899 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.729278473 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.590339893 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.709600477 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.663685152 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.663685152 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.709600477 104.6875 L 281.663685152 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.590339893 108.59375 L 280.709600477 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.729278473 141.796875 L 280.590339893 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.169946333 193.5546875 L 251.729278473 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.1872391175 246.77734375 L 195.169946333 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(281.66368515205721, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(280.70960047704233, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(280.5903398926655, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(288.43172331544429, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.72927847346452, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(287.22420989862849, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(195.16994633273703, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(68.187239117471677, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t33a500bc73ea4a72801e3bba1fedc5d5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t45b271ac8b634925aa3760de0bb886e8"><g class="toyplot-Edges"><path d="M 87.8205128205 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.072748956 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.803220036 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.803220036 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.072748956 245.3125 L 289.803220036 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.066189624 195.5078125 L 289.072748956 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.981514609 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.468694097 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.558139535 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.422778772 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.422778772 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.558139535 89.0625 L 283.422778772 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.468694097 116.40625 L 282.558139535 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.981514609 145.703125 L 282.468694097 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 207.066189624 195.5078125 L 252.981514609 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 87.8205128205 247.75390625 L 207.066189624 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(283.42277877161598, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(282.55813953488371, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(282.46869409660104, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.80322003577811, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(252.98151460942154, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.07274895646981, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(207.06618962432916, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(87.820512820512818, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td2356ec774b042d6b7c497c7f8f151c3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb2adab3dfa704a58a1362490de7df0ad"><g class="toyplot-Edges"><path d="M 79.3082886106 247.75390625 L 299.970184854 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.506261181 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.998211091 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.998211091 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.506261181 245.3125 L 288.998211091 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.864042934 195.5078125 L 288.506261181 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.80620155 145.703125 L 299.970184854 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.933214073 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.06738223 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.110912343 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.110912343 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.06738223 89.0625 L 282.110912343 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.933214073 116.40625 L 281.06738223 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.80620155 145.703125 L 280.933214073 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.864042934 195.5078125 L 249.80620155 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.3082886106 247.75390625 L 188.864042934 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.97018485390572, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.97018485390572, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(282.11091234347049, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(281.06738223017294, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.93321407274897, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.99821109123434, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(249.80620155038758, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.50626118067981, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(188.8640429338104, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(79.308288610614198, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t45851362d5b8459b94709862c33dc66b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="teaacf1dd5f8444818c223503466ece16"><g class="toyplot-Edges"><path d="M 80.4114490161 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.685152057 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.728682171 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.728682171 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.685152057 245.3125 L 289.728682171 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.895646989 195.5078125 L 288.685152057 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.089445438 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.678592725 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.75313059 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.274895647 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.274895647 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.75313059 89.0625 L 282.274895647 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.678592725 116.40625 L 281.75313059 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.089445438 145.703125 L 281.678592725 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.895646989 195.5078125 L 250.089445438 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.4114490161 247.75390625 L 199.895646989 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(282.27489564698868, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.75313059033988, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.67859272510429, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(289.72868217054258, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(250.08944543828264, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.68515205724503, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(199.89564698867025, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(80.411449016100178, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcf37d7a69890446b86539daa1f3784a6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tebc2e0b178e243eb96ce6a48337da5c7"><g class="toyplot-Edges"><path d="M 71.7501490757 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.774597496 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.624329159 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.624329159 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.774597496 245.3125 L 289.624329159 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.141323792 195.5078125 L 288.774597496 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.85092427 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.037567084 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.097197376 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.648777579 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.648777579 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.097197376 89.0625 L 281.648777579 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.037567084 116.40625 L 281.097197376 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.85092427 145.703125 L 281.037567084 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.141323792 195.5078125 L 249.85092427 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.7501490757 247.75390625 L 194.141323792 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.64877757901007, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.0971973762671, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.03756708407866, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(289.62432915921283, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(249.85092426952889, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.77459749552776, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(194.14132379248656, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(71.750149075730448, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t53d3256ace4b4d79bbe015a790bf011a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf1113171570b4b23b808789d04c37539"><g class="toyplot-Edges"><path d="M 77.0870602266 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.461538462 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.698867024 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.698867024 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.461538462 245.3125 L 289.698867024 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.941562314 195.5078125 L 288.461538462 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.763864043 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.484794275 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.589147287 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.051282051 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.051282051 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.589147287 89.0625 L 282.051282051 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.484794275 116.40625 L 281.589147287 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.763864043 145.703125 L 281.484794275 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.941562314 195.5078125 L 247.763864043 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.0870602266 247.75390625 L 198.941562314 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(282.05128205128204, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.58914728682174, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.48479427549194, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(289.69886702444836, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(247.76386404293382, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(288.46153846153845, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.94156231365534, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(77.087060226595099, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbfc9bb4b38104460920b64e6f3b04f53"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta84efb7a3fdf43bab2048524c6263a1e"><g class="toyplot-Edges"><path d="M 82.4686940966 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.804412642 245.3125 L 299.970184854 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.280262373 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.280262373 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.804412642 245.3125 L 290.280262373 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.295766249 195.5078125 L 288.804412642 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.145497913 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.28980322 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.438878951 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.587954681 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.587954681 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.438878951 89.0625 L 282.587954681 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.28980322 116.40625 L 282.438878951 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.145497913 145.703125 L 282.28980322 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.295766249 195.5078125 L 253.145497913 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.4686940966 247.75390625 L 202.295766249 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390572, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(282.58795468097793, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(282.43887895050688, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(282.28980322003576, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(290.28026237328561, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(253.14549791293979, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(288.80441264162192, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(202.29576624925463, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(82.46869409660107, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6d3512119bd54d8392aa96d3c6c7c0eb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf2c48138103341ceb52be3ed704442aa"><g class="toyplot-Edges"><path d="M 79.9791293977 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.595706619 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.548598688 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.548598688 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.595706619 245.3125 L 290.548598688 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.587358378 195.5078125 L 288.595706619 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.668455575 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.125819917 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.274895647 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.423971377 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.423971377 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.274895647 89.0625 L 282.423971377 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.125819917 116.40625 L 282.274895647 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.668455575 145.703125 L 282.125819917 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.587358378 195.5078125 L 252.668455575 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.9791293977 247.75390625 L 195.587358378 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(282.42397137745979, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(282.27489564698868, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(282.12581991651763, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(290.5485986881335, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(252.66845557543235, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.59570661896237, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(195.58735837805608, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(79.979129397734056, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7c1219fef2cb4fd89ab0afebe74be5d9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td9f515ebdfa648529be4e94d9bce4f0a"><g class="toyplot-Edges"><path d="M 82.6624925462 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.790697674 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.341085271 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.341085271 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.790697674 245.3125 L 289.341085271 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.624925462 195.5078125 L 287.790697674 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.168753727 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.379248658 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.438878951 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.692307692 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.692307692 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.438878951 89.0625 L 282.692307692 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.379248658 116.40625 L 282.438878951 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.168753727 145.703125 L 282.379248658 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.624925462 195.5078125 L 246.168753727 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.6624925462 247.75390625 L 201.624925462 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(282.69230769230768, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(282.43887895050688, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(282.37924865831843, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(289.34108527131781, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(246.16875372689324, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(287.7906976744186, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(201.62492546213477, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(82.662492546213485, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta753d394f8fa48a7888b5fa90a21f0f3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t04f99ce6f86e4773a5149628ea51fe1b"><g class="toyplot-Edges"><path d="M 88.938580799 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.505068575 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.788312463 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.788312463 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.505068575 245.3125 L 289.788312463 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.568872987 195.5078125 L 289.505068575 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.929039952 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.154442457 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.303518187 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.51222421 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.51222421 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.303518187 89.0625 L 283.51222421 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.154442457 116.40625 L 283.303518187 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.929039952 145.703125 L 283.154442457 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.568872987 195.5078125 L 246.929039952 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.938580799 247.75390625 L 198.568872987 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(283.51222420989865, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(283.30351818723909, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(283.15444245676804, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.78831246273114, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(246.9290399522958, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.50506857483606, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.56887298747762, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(88.938580799045909, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfcf192cf50ae4059a2a7eb4d8c5d37fb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t54c00daf250d48eba0c03e2e4ae0db6f"><g class="toyplot-Edges"><path d="M 75.4472271914 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.505068575 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.146094216 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.146094216 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.505068575 245.3125 L 290.146094216 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.357781753 195.5078125 L 289.505068575 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.893261777 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.438878951 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.647584973 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.901013715 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.901013715 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.647584973 89.0625 L 282.901013715 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.438878951 116.40625 L 282.647584973 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.893261777 145.703125 L 282.438878951 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.357781753 195.5078125 L 251.893261777 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.4472271914 247.75390625 L 200.357781753 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(282.90101371496718, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(282.64758497316637, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(282.43887895050688, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(290.14609421586164, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(251.89326177698271, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(289.50506857483606, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(200.35778175313058, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(75.447227191413248, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf820c91d5a25426a8806a1ad6e5bd40f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1b2a9194eb6b4c5490fe4dcafb6ef53a"><g class="toyplot-Edges"><path d="M 75.954084675 247.75390625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.669051878 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.728682171 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.728682171 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.669051878 245.3125 L 289.728682171 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.190220632 195.5078125 L 289.669051878 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.506857484 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.558139535 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.737030411 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.064997018 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.064997018 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.737030411 89.0625 L 283.064997018 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.558139535 116.40625 L 282.737030411 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.506857484 145.703125 L 282.558139535 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.190220632 195.5078125 L 250.506857484 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.954084675 247.75390625 L 203.190220632 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(283.06499701848543, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(282.73703041144904, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(282.55813953488376, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(289.72868217054258, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(250.50685748360166, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(289.66905187835425, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(203.19022063208109, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(75.954084675014926, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8cef68bf515c4e80b72deeb90de62bdd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta3fae4ed8bbd4a5ab590054dae1f040b"><g class="toyplot-Edges"><path d="M 73.5092426953 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.148479428 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.086463924 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.086463924 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.148479428 245.3125 L 290.086463924 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.189028026 195.5078125 L 288.148479428 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.449612403 145.703125 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.051282051 116.40625 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.185450209 89.0625 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.573047108 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.573047108 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.185450209 89.0625 L 282.573047108 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.051282051 116.40625 L 282.185450209 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.449612403 145.703125 L 282.051282051 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.189028026 195.5078125 L 248.449612403 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.5092426953 247.75390625 L 204.189028026 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(282.57304710793079, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(282.18545020870602, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(282.05128205128204, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.08646392367325, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(248.44961240310079, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.1484794275492, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(204.18902802623731, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(73.509242695289217, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcd754d5d838d496496936686a09a8444"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t012539a827ef4719bfafde3c24b8e41c"><g class="toyplot-Edges"><path d="M 61.4192009541 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.060226595 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.624329159 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.624329159 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.060226595 245.3125 L 289.624329159 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.50208706 195.5078125 L 287.060226595 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.716756112 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.110912343 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.185450209 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.319618366 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.319618366 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.185450209 89.0625 L 282.319618366 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.110912343 116.40625 L 282.185450209 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.716756112 145.703125 L 282.110912343 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.50208706 195.5078125 L 249.716756112 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.4192009541 247.75390625 L 204.50208706 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(282.31961836612999, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(282.18545020870602, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(282.11091234347049, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(289.62432915921289, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(249.71675611210492, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(287.06022659511029, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(204.50208706022659, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(61.419200954084666, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t40a90cf212eb45da85b767fe59917f63"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t339f2a1a909d4aa49b0d77ffdf05b14f"><g class="toyplot-Edges"><path d="M 62.2540250447 247.265625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.326177698 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.414430531 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.414430531 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.326177698 245.3125 L 290.414430531 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.709600477 194.53125 L 289.326177698 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.84078712 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.932021467 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.961836613 81.25 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.09600477 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.09600477 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.961836613 81.25 L 282.09600477 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.932021467 112.5 L 281.961836613 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.84078712 143.75 L 281.932021467 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.709600477 194.53125 L 245.84078712 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.2540250447 247.265625 L 205.709600477 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(282.09600477042335, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.96183661299938, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.93202146690521, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(290.41443053070958, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(245.84078711985688, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.32617769827073, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(205.70960047704233, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(62.254025044722717, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc8aa7ae4c3e64d2cab0f850975fdc7b9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta5aed95d77634be6921576059e6e80e3"><g class="toyplot-Edges"><path d="M 53.9206917114 247.265625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.029218843 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.624329159 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.624329159 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.029218843 245.3125 L 289.624329159 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 206.454979129 194.53125 L 288.029218843 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.252236136 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.693500298 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.708407871 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.857483602 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.857483602 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.708407871 81.25 L 281.857483602 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.693500298 112.5 L 281.708407871 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.252236136 143.75 L 281.693500298 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 206.454979129 194.53125 L 251.252236136 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 53.9206917114 247.265625 L 206.454979129 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.85748360166963, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.70840787119857, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.69350029815143, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(289.62432915921283, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(251.25223613595702, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.02921884317226, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(206.45497912939771, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(53.920691711389381, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbb27993229cc4baa98c03797419c8b79"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t781121d5c8394d1ca515103ff89d9de4"><g class="toyplot-Edges"><path d="M 63.8938580799 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.118664281 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.952295766 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.952295766 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.118664281 245.3125 L 289.952295766 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.148479428 190.625 L 288.118664281 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.078115683 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.125819917 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.125819917 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.110912343 96.875 L 282.125819917 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.200357782 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.200357782 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.110912343 96.875 L 282.200357782 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.078115683 135.9375 L 282.110912343 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 213.148479428 190.625 L 247.078115683 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.8938580799 245.3125 L 213.148479428 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.99999999999994, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.99999999999994, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.99999999999994, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.99999999999994, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.99999999999994, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(282.2003577817531, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(282.12581991651757, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(282.11091234347049, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(289.95229576624922, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(247.07811568276685, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(288.11866428145498, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(213.14847942754918, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(63.893858079904575, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td782188e471b42598de22c918c61512a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tbd1a0d5ead3a490cb12abea3d5ae294b"><g class="toyplot-Edges"><path d="M 60.0178890877 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.760882528 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.372093023 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.372093023 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.760882528 245.3125 L 288.372093023 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.137745975 190.625 L 287.760882528 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.433512224 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.754323196 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.754323196 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.72450805 96.875 L 280.754323196 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.350626118 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.350626118 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.72450805 96.875 L 281.350626118 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.433512224 135.9375 L 280.72450805 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.137745975 190.625 L 249.433512224 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.0178890877 245.3125 L 197.137745975 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(281.35062611806791, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.75432319618363, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.72450805008941, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(288.37209302325573, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(249.43351222420986, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(287.76088252832437, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(197.13774597495524, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(60.017889087656513, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf8df2b726ab349448e793eac029e3e3d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc896ad0500cf4dd0bb7c51370f06d66e"><g class="toyplot-Edges"><path d="M 64.7435897436 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.596899225 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.580799046 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.580799046 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.596899225 245.3125 L 288.580799046 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.894454383 190.625 L 287.596899225 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.309481216 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.38163387 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.38163387 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.351818724 96.875 L 280.38163387 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.471079308 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.471079308 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.351818724 96.875 L 280.471079308 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.309481216 135.9375 L 280.351818724 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.894454383 190.625 L 253.309481216 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.7435897436 245.3125 L 200.894454383 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695292, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695292, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695292, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.47107930828861, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.38163387000594, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.35181872391172, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.58079904591534, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.30948121645795, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(287.59689922480618, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(200.89445438282647, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(64.743589743589752, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td575f9765f944a69b546b671c4dd1a53"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4ae017cb284c4d43b56311c1f199e5a9"><g class="toyplot-Edges"><path d="M 79.5169946333 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.163387001 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.834227788 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.834227788 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.163387001 245.3125 L 288.834227788 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.524150268 190.625 L 288.163387001 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.031007752 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.991651759 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.021466905 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.6326774 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.6326774 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.021466905 112.5 L 282.6326774 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.991651759 96.875 L 282.021466905 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.031007752 135.9375 L 281.991651759 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.524150268 190.625 L 249.031007752 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.5169946333 245.3125 L 198.524150268 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(282.63267740011929, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(282.02146690518782, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.9916517590936, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.8342277877162, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(249.03100775193798, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.16338700059634, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.52415026833631, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(79.516994633273697, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8e616fe638ba4989b74530f269352fab"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t04655a33c4a34641a89c89096391c1d6"><g class="toyplot-Edges"><path d="M 76.7441860465 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.297555158 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.564698867 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.564698867 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.297555158 245.3125 L 289.564698867 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.863446631 190.625 L 288.297555158 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.344066786 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.573047108 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.6326774 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.16935003 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 283.16935003 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.6326774 112.5 L 283.16935003 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.573047108 96.875 L 282.6326774 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.344066786 135.9375 L 282.573047108 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 201.863446631 190.625 L 249.344066786 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.7441860465 245.3125 L 201.863446631 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(283.16935002981518, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(282.63267740011923, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(282.57304710793085, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(289.56469886702445, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(249.34406678592725, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.29755515802026, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(201.86344663088849, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(76.744186046511629, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7fd9134b38bd4c80b524c63e1d5c8152"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfcf472b591df49fea48d444ad6fb7b29"><g class="toyplot-Edges"><path d="M 65.5784138342 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.209302326 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.878950507 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.878950507 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.209302326 245.3125 L 288.878950507 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.189028026 190.625 L 287.209302326 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.659511032 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.141920095 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.141920095 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.664877758 96.875 L 281.141920095 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.963029219 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.963029219 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.664877758 96.875 L 280.963029219 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.659511032 135.9375 L 280.664877758 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.189028026 190.625 L 247.659511032 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.5784138342 245.3125 L 204.189028026 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.9850924269528, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(280.96302921884319, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.14192009540847, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(280.66487775790097, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(288.87895050685739, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(247.65951103160404, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(287.20930232558135, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(204.18902802623728, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(65.578413834227746, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t62b7870e85b649d7952ccee7865feb42"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc8b185f4881245259d9b7ae4a58ef762"><g class="toyplot-Edges"><path d="M 61.404293381 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.358378056 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.892665474 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.892665474 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.358378056 245.3125 L 289.892665474 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.203935599 190.625 L 287.358378056 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.466905188 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.068574836 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.068574836 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.934406679 96.875 L 280.068574836 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.053667263 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.053667263 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.934406679 96.875 L 280.053667263 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.466905188 135.9375 L 279.934406679 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.203935599 190.625 L 246.466905188 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.404293381 245.3125 L 204.203935599 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.05366726296967, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.06857483601675, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(279.93440667859278, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.89266547406083, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(246.46690518783547, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(287.35837805605252, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(204.20393559928448, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(61.40429338103759, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7f6361cc4fbf41b5ba784d0840e1e585"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te403baed17924ddf8e42d7b9702d54a5"><g class="toyplot-Edges"><path d="M 67.9636255218 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.255217651 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.89385808 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.89385808 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.255217651 245.3125 L 288.89385808 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 206.171735242 190.625 L 286.255217651 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.927847346 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.03875969 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.03875969 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.934406679 96.875 L 280.03875969 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.023852117 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.023852117 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.934406679 96.875 L 280.023852117 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.927847346 135.9375 L 279.934406679 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 206.171735242 190.625 L 247.927847346 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.9636255218 245.3125 L 206.171735242 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.02385211687539, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.03875968992247, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(279.93440667859272, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.89385807990453, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(247.92784734645198, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(286.25521765056652, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(206.17173524150266, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.963625521765039, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6789c67be32a4863aae4743b8b436dc9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tffd7531ee35345bfb9c55ad0b51193dc"><g class="toyplot-Edges"><path d="M 59.5706618962 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.344663089 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.952295766 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.952295766 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.344663089 245.3125 L 289.952295766 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.09183065 190.625 L 286.344663089 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.428741801 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.472271914 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.472271914 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.397734049 96.875 L 279.472271914 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.666070364 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.666070364 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.397734049 96.875 L 279.666070364 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.428741801 135.9375 L 279.397734049 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.09183065 190.625 L 253.428741801 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.5706618962 245.3125 L 198.09183065 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(279.66607036374478, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(279.47227191413236, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(279.39773404889689, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(289.95229576624922, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(253.42874180083481, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(286.34466308884913, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.09183064997021, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(59.570661896243294, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf4952ad408b447218f808307300b55d1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6c68b917b1af4327b176544bc00c962d"><g class="toyplot-Edges"><path d="M 64.23673226 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.596899225 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.877757901 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.877757901 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.596899225 245.3125 L 289.877757901 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.43470483 190.625 L 287.596899225 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.242098986 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.427549195 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.427549195 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.323196184 96.875 L 279.427549195 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.023852117 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.023852117 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.323196184 96.875 L 280.023852117 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.242098986 135.9375 L 279.323196184 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.43470483 190.625 L 247.242098986 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.23673226 245.3125 L 198.43470483 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695292, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695292, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695292, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.02385211687539, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(279.42754919499106, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(279.32319618366131, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.87775790101369, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.24209898628504, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(287.59689922480618, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.43470483005368, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(64.236732259988088, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdeb5e93b48a14f28a7034df504759d05"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1e29f5accf0d45e58b522edcc90d95bb"><g class="toyplot-Edges"><path d="M 84.183064997 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.789505069 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.785927251 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.785927251 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.789505069 245.3125 L 291.785927251 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.167561121 190.625 L 288.789505069 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.255813953 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.784138342 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.784138342 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.709600477 96.875 L 280.784138342 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.948121646 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.948121646 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.709600477 96.875 L 280.948121646 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.255813953 135.9375 L 280.709600477 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.167561121 190.625 L 248.255813953 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 84.183064997 245.3125 L 197.167561121 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.94812164579605, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.78413834227786, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.70960047704233, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(291.78592725104352, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(248.25581395348837, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.78950506857484, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(197.16756112104949, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(84.183064997018477, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t30eacb46abcf4c85bc48a9b3f76735f9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t64d19abb08aa4ddb94e8a65b016ae902"><g class="toyplot-Edges"><path d="M 86.9558735838 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.026833631 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.29397734 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.29397734 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.026833631 245.3125 L 291.29397734 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.859868813 190.625 L 290.026833631 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.093023256 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.380441264 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.380441264 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.305903399 96.875 L 281.380441264 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.41025641 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.41025641 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.305903399 96.875 L 281.41025641 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.093023256 135.9375 L 281.305903399 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.859868813 190.625 L 247.093023256 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 86.9558735838 245.3125 L 204.859868813 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.41025641025641, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.38044126416219, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.3059033989266, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(291.29397734048899, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(247.09302325581396, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(290.02683363148475, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(204.85986881335717, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(86.955873583780573, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t36d8d5f57df44f16b48f5adca42537a2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="teed6e8de2d3b4cd590b417a3412aec18"><g class="toyplot-Edges"><path d="M 77.7429934407 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.970781157 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.146094216 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.146094216 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.970781157 245.3125 L 290.146094216 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.370304114 190.625 L 286.970781157 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.140131187 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.979129398 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.979129398 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.889683959 96.875 L 279.979129398 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.292188432 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.292188432 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.889683959 96.875 L 280.292188432 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.140131187 135.9375 L 279.889683959 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.370304114 190.625 L 245.140131187 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.7429934407 245.3125 L 202.370304114 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.29218843172328, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.97912939773403, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.88968395945142, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.14609421586164, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(245.1401311866428, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(286.97078115682768, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(202.37030411449015, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(77.742993440667846, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tded9ac3710a24482ade763d329b1d45b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf137fb03d77c472ca330c0ac06104fff"><g class="toyplot-Edges"><path d="M 73.1514609422 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.640429338 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.414430531 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.414430531 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.640429338 245.3125 L 290.414430531 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.167561121 190.625 L 288.640429338 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.373881932 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.770423375 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.770423375 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.621347645 96.875 L 279.770423375 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.710793083 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.710793083 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.621347645 96.875 L 279.710793083 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.373881932 135.9375 L 279.621347645 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.167561121 190.625 L 249.373881932 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.1514609422 245.3125 L 197.167561121 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.71079308288614, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.77042337507453, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.62134764460342, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.41443053070964, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(249.37388193202145, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(288.64042933810379, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(197.16756112104952, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(73.151460942158621, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t262fd8f8fb4e4bab87f97c549eb39b7d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te44834836ada4dedb505c444ff0fe969"><g class="toyplot-Edges"><path d="M 74.1353607633 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.059033989 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.99582588 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.99582588 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.059033989 245.3125 L 290.99582588 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.875968992 190.625 L 288.059033989 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.715563506 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.605247466 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.605247466 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.396541443 96.875 L 280.605247466 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.456171735 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.456171735 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.396541443 96.875 L 280.456171735 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.715563506 135.9375 L 280.396541443 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.875968992 190.625 L 250.715563506 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.1353607633 245.3125 L 203.875968992 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.45617173524153, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.60524746571264, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.39654144305308, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(290.99582587954683, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(250.71556350626116, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(288.05903398926654, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(203.87596899224806, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(74.135360763267727, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t91b52c091df749928a7ca57d919ccbfc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfaf9004d70884efc85fb1d755512e7a3"><g class="toyplot-Edges"><path d="M 79.2635658915 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.101371497 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.234347048 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.234347048 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.101371497 245.3125 L 291.234347048 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.612403101 190.625 L 290.101371497 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.129397734 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.72450805 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.72450805 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.620155039 96.875 L 280.72450805 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.72450805 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.72450805 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.620155039 96.875 L 280.72450805 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 254.129397734 135.9375 L 280.620155039 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.612403101 190.625 L 254.129397734 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.2635658915 245.3125 L 199.612403101 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.72450805008941, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.72450805008941, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.62015503875972, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(291.23434704830049, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(254.12939773404889, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(290.10137149672033, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(199.6124031007752, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(79.263565891472865, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tea619bae8f264aff96a4bda7ed5cdbc5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t132e0233e66b4f81968967566c1d0b06"><g class="toyplot-Edges"><path d="M 87.7012522361 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.43053071 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.757304711 221.875 L 299.970184854 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.757304711 221.875 L 299.970184854 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.43053071 245.3125 L 290.757304711 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.674418605 190.625 L 289.43053071 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.1019678 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.678592725 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.678592725 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.469886702 96.875 L 281.678592725 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.75313059 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.75313059 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.469886702 96.875 L 281.75313059 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.1019678 135.9375 L 281.469886702 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 197.674418605 190.625 L 252.1019678 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 87.7012522361 245.3125 L 197.674418605 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.97018485390572, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.97018485390572, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(281.75313059033988, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(281.67859272510429, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(281.4698867024448, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(290.75730471079305, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(252.10196779964221, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(289.43053070960048, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(197.67441860465118, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(87.701252236135957, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t42e61251f43a4754b1f27cdab3e2effa"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t07d906612ae148b19a817728f88147c8"><g class="toyplot-Edges"><path d="M 77.6833631485 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.43053071 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.831842576 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.831842576 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.43053071 245.3125 L 290.831842576 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.468097794 190.625 L 289.43053071 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.184853906 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.799045915 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.799045915 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.769230769 96.875 L 280.799045915 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.842576029 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.842576029 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.769230769 96.875 L 281.842576029 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.184853906 135.9375 L 280.769230769 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.468097794 190.625 L 245.184853906 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.6833631485 245.3125 L 195.468097794 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(281.84257602862255, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.79904591532494, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.76923076923083, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(290.83184257602869, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(245.18485390578411, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.43053070960048, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(195.46809779367919, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(77.683363148479444, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t572b37bec7634ee4bd65bf92ca4a9da2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7f76a77efa014910a93f6260ea9fff28"><g class="toyplot-Edges"><path d="M 76.3118664281 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.895050686 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.311270125 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.311270125 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.895050686 245.3125 L 289.311270125 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.494335122 190.625 L 287.895050686 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.206320811 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.664877758 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.664877758 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.635062612 96.875 L 280.664877758 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.320810972 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.320810972 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.635062612 96.875 L 281.320810972 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.206320811 135.9375 L 280.635062612 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.494335122 190.625 L 252.206320811 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.3118664281 245.3125 L 198.494335122 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(281.32081097197374, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.66487775790097, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.6350626118068, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(289.31127012522359, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(252.20632081097199, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(287.89505068574834, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.49433512224209, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(76.311866428145493, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="teee805bb6ba24a17828e8e01d38a84c3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t89ff0431c966480bae3cee4ad71989c7"><g class="toyplot-Edges"><path d="M 76.1031604055 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.729874776 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.983303518 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.983303518 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.729874776 245.3125 L 288.983303518 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.937388193 190.625 L 288.729874776 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.948121646 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.23255814 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.262373286 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.426356589 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.426356589 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.262373286 112.5 L 280.426356589 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.23255814 96.875 L 280.262373286 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 255.948121646 135.9375 L 280.23255814 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.937388193 190.625 L 255.948121646 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.1031604055 245.3125 L 189.937388193 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.42635658914725, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.26237328562911, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.23255813953489, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.98330351818726, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(255.94812164579602, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.7298747763864, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(189.93738819320214, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(76.103160405485966, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t21c102b23f1041c29c0f03afbc4bdfbb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t683fa832454a466794108d023c0cd49a"><g class="toyplot-Edges"><path d="M 63.9982110912 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.595706619 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.833035182 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.833035182 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.595706619 245.3125 L 289.833035182 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.029815146 190.625 L 288.595706619 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 256.022659511 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.039952296 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.039952296 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.01013715 96.875 L 279.039952296 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.129397734 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.129397734 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.01013715 96.875 L 279.129397734 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 256.022659511 135.9375 L 279.01013715 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.029815146 190.625 L 256.022659511 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.9982110912 245.3125 L 200.029815146 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.9850924269528, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.12939773404889, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.03995229576623, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.010137149672, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(289.83303518187239, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(256.02265951103158, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.59570661896237, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(200.02981514609417, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(63.998211091234324, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t83d8e3b94708460899a62217bd444068"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0dc16c269eae4e9a9db0cdd89f2bc81f"><g class="toyplot-Edges"><path d="M 59.1234347048 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.434108527 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.384615385 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.384615385 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.434108527 245.3125 L 290.384615385 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.489564699 190.625 L 286.434108527 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.106738223 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.981514609 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.981514609 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.951699463 96.875 L 277.981514609 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.981514609 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.981514609 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.951699463 96.875 L 277.981514609 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.106738223 135.9375 L 277.951699463 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.489564699 190.625 L 248.106738223 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.1234347048 245.3125 L 202.489564699 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695292, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695292, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695292, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695292, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695292, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(277.98151460942159, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(277.98151460942159, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(277.95169946332737, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.38461538461536, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(248.10673822301732, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(286.43410852713185, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(202.48956469886704, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(59.123434704830075, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t06eee56959fe4f4cab8585dbee447709"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb26db005bf484c2ba11d8339f93a55f9"><g class="toyplot-Edges"><path d="M 55.1132975552 244.82421875 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.940966011 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.295169946 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.295169946 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.940966011 245.3125 L 290.295169946 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.653548002 189.6484375 L 286.940966011 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.385211688 133.984375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.012522361 92.96875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.012522361 104.6875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.042337507 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.042337507 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.012522361 104.6875 L 277.042337507 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.012522361 92.96875 L 277.012522361 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.385211688 133.984375 L 277.012522361 92.96875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.653548002 189.6484375 L 252.385211688 133.984375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.1132975552 244.82421875 L 202.653548002 189.6484375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.99999999999994, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.99999999999994, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.99999999999994, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.99999999999994, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.99999999999994, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(277.04233750745374, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(277.01252236135952, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(277.01252236135952, 92.96875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(290.29516994633269, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.38521168753726, 133.984375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(286.9409660107334, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(202.65354800238518, 189.6484375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(55.113297555158013, 244.82421875)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5d6f878e57cd431ea0a225a19ced7ce4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t47a132f5483f4525acb01b991bc2ac12"><g class="toyplot-Edges"><path d="M 71.213476446 245.3125 L 299.970184854 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.984496124 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.683959451 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.683959451 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.984496124 245.3125 L 289.683959451 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.325581395 190.625 L 287.984496124 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.722122838 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.44484198 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.44484198 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.474657126 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.474657126 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.44484198 81.25 L 277.474657126 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.44484198 96.875 L 277.44484198 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 257.722122838 135.9375 L 277.44484198 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.325581395 190.625 L 257.722122838 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.213476446 245.3125 L 202.325581395 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(277.47465712581987, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(277.44484197972565, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(277.44484197972565, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(289.68395945140134, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(257.7221228384019, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(287.98449612403101, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(202.32558139534882, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(71.213476446034576, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t825888b31d6840fabf37f5cb35011e98"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tba63c95537a94ea3a6c3a413452960e6"><g class="toyplot-Edges"><path d="M 72.5402504472 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.836612999 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.506261181 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.506261181 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.836612999 245.3125 L 288.506261181 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.597495528 190.625 L 286.836612999 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.550387597 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.13059034 128.125 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.13059034 128.125 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.115682767 96.875 L 278.13059034 128.125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.145497913 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.145497913 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 278.115682767 96.875 L 278.145497913 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.550387597 135.9375 L 278.115682767 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.597495528 190.625 L 251.550387597 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.5402504472 245.3125 L 199.597495528 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(278.14549791293973, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(278.13059033989259, 128.125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(278.11568276684551, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(288.50626118067981, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(251.55038759689924, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(286.83661299940371, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(199.59749552772806, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(72.54025044722718, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta97329a2f5f744dd81b20a8eeb7683c0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td35e3851d63843b1ad514fef0f4dd3fb"><g class="toyplot-Edges"><path d="M 59.9284436494 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.54084675 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.790697674 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.790697674 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 284.54084675 245.3125 L 287.790697674 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.463923673 190.625 L 284.54084675 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.853309481 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.937984496 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.967799642 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.027429934 112.5 L 299.970184854 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 277.027429934 112.5 L 299.970184854 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.967799642 81.25 L 277.027429934 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 276.937984496 96.875 L 276.967799642 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.853309481 135.9375 L 276.937984496 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.463923673 190.625 L 247.853309481 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.9284436494 245.3125 L 186.463923673 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.97018485390583, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.97018485390583, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(277.02742993440671, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(276.96779964221821, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(276.93798449612399, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(287.7906976744186, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(247.85330948121648, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(284.54084675014906, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.46392367322602, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(59.928443649373882, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t48257e0927a644e1a6408b605f6d89bd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcf320384815a40a094727ac9b16fd976"><g class="toyplot-Edges"><path d="M 71.0942158617 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.940966011 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.059033989 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.059033989 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.940966011 245.3125 L 288.059033989 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.144305307 190.625 L 286.940966011 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.175313059 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.025044723 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.099582588 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.114490161 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.114490161 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.099582588 81.25 L 279.114490161 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.025044723 96.875 L 279.099582588 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.175313059 135.9375 L 279.025044723 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.144305307 190.625 L 253.175313059 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.0942158617 245.3125 L 204.144305307 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.11449016100175, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.09958258795473, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.02504472271914, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.05903398926654, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(253.17531305903398, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(286.9409660107334, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(204.144305307096, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(71.094215861657716, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5b016e9cfe234b708029923116312e73"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc979562535ed4908943ebfe6ee3b85bf"><g class="toyplot-Edges"><path d="M 68.8878950507 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.149672033 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.056648778 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.056648778 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.149672033 245.3125 L 290.056648778 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.178890877 190.625 L 287.149672033 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.151460942 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.218843172 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.35301133 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.457364341 112.5 L 299.970184854 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.457364341 112.5 L 299.970184854 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.35301133 81.25 L 279.457364341 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.218843172 96.875 L 279.35301133 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.151460942 135.9375 L 279.218843172 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.178890877 190.625 L 248.151460942 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.8878950507 245.3125 L 200.178890877 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390583, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390583, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(279.45736434108528, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(279.35301132975553, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(279.21884317233156, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(290.05664877757897, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(248.15146094215862, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(287.14967203339302, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(200.1788908765653, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(68.887895050685756, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tae79a8b6b3d8445c89438c1cea8e3aaf"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc76afac84519403e9980843aa84ec3d9"><g class="toyplot-Edges"><path d="M 71.213476446 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.431723315 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.652951699 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.652951699 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.431723315 245.3125 L 290.652951699 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.757304711 193.5546875 L 288.431723315 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.553965414 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.904591532 108.59375 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.994036971 104.6875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.172927847 65.625 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.172927847 65.625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.994036971 104.6875 L 280.172927847 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.904591532 108.59375 L 279.994036971 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.553965414 141.796875 L 279.904591532 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.757304711 193.5546875 L 248.553965414 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.213476446 246.77734375 L 190.757304711 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.17292784734644, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.99403697078117, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.9045915324985, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.65295169946336, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(248.55396541443054, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.43172331544429, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.75730471079308, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(71.213476446034591, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taf88c8ffa1514298973a81f306830896"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdd83d51adaca4049876dd932beeb9e81"><g class="toyplot-Edges"><path d="M 69.931425164 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.341085271 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.175909362 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.175909362 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.341085271 245.3125 L 290.175909362 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.775193798 191.6015625 L 289.341085271 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.141323792 137.890625 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.800238521 100.78125 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.859868813 89.0625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.979129398 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.979129398 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.859868813 89.0625 L 279.979129398 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.800238521 100.78125 L 279.859868813 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.141323792 137.890625 L 279.800238521 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.775193798 191.6015625 L 244.141323792 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.931425164 245.80078125 L 200.775193798 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.97912939773403, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.8598688133572, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(279.80023852116869, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.17590936195592, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(244.14132379248659, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(289.34108527131781, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(200.77519379844964, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(69.931425163983306, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tac6f3eb50c8545e89bacfdda23a3009b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8afa645d72b24328a8648a52ae18a036"><g class="toyplot-Edges"><path d="M 66.8306499702 245.80078125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.311270125 245.3125 L 299.970184854 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.698867024 221.875 L 299.970184854 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.698867024 221.875 L 299.970184854 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.311270125 245.3125 L 289.698867024 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.143112701 191.6015625 L 289.311270125 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.614788312 137.890625 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.5307096 100.78125 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.545617174 89.0625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.873583781 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.873583781 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.545617174 89.0625 L 280.873583781 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.5307096 100.78125 L 280.545617174 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.614788312 137.890625 L 280.5307096 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 205.143112701 191.6015625 L 247.614788312 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.8306499702 245.80078125 L 205.143112701 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390583, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390583, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.97018485390583, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695292, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.87358378056052, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.54561717352419, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.53070960047705, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.69886702444842, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(247.61478831246274, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.31127012522364, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(205.14311270125225, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(66.830649970184879, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t146aa5845cf742cd90e7aad4d7e83d86"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te1f74e2ca4774192bc45c77389fb9984"><g class="toyplot-Edges"><path d="M 77.832438879 245.80078125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.311270125 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.220632081 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.220632081 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.311270125 245.3125 L 290.220632081 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.539057841 191.6015625 L 289.311270125 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.160405486 137.890625 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.06738223 100.78125 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.127012522 89.0625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.186642815 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.186642815 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.127012522 89.0625 L 281.186642815 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.06738223 100.78125 L 281.127012522 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 253.160405486 137.890625 L 281.06738223 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 198.539057841 191.6015625 L 253.160405486 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 77.832438879 245.80078125 L 198.539057841 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.18664281454983, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.12701252236133, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.06738223017294, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(290.22063208109716, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(253.1604054859869, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(289.31127012522364, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.53905784138342, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(77.832438878950512, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t32b5822391894bf29d3b57b0a58bd3f5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t854ae12e29334dd7b4fc84df6cb0489d"><g class="toyplot-Edges"><path d="M 76.5056648778 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.731067382 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.041741205 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.041741205 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.731067382 245.3125 L 290.041741205 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.199761479 191.6015625 L 287.731067382 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.84078712 137.890625 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.307096005 100.78125 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.485986881 89.0625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.5307096 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.5307096 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.485986881 89.0625 L 280.5307096 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.307096005 100.78125 L 280.485986881 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.84078712 137.890625 L 280.307096005 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.199761479 191.6015625 L 245.84078712 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.5056648778 245.80078125 L 195.199761479 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(280.53070960047705, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(280.48598688133569, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(280.30709600477036, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(290.04174120453183, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(245.84078711985691, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(287.73106738223021, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(195.19976147883125, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(76.505664877757908, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td4aa702bb002428eb670ef34b85e10ac"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6a898793dfe549578e94250e9a04d98c"><g class="toyplot-Edges"><path d="M 82.9755515802 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.013118664 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.758497317 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.758497317 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.013118664 245.3125 L 289.758497317 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.910554562 191.6015625 L 289.013118664 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.582587955 137.890625 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.858676208 100.78125 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.948121646 89.0625 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.022659511 96.875 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.022659511 96.875 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.948121646 89.0625 L 281.022659511 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.858676208 100.78125 L 280.948121646 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.582587955 137.890625 L 280.858676208 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.910554562 191.6015625 L 249.582587955 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.9755515802 245.80078125 L 199.910554562 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(281.02265951103158, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.94812164579611, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.85867620751344, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.75849731663686, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(249.58258795468097, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(289.01311866428148, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(199.91055456171736, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(82.975551580202747, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taabcc11659b54d05bdee5676ac70e147"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2b493165bf91437a8bb9583a8c6b751c"><g class="toyplot-Edges"><path d="M 72.7042337507 245.80078125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.35718545 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.549791294 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.549791294 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.35718545 245.3125 L 289.549791294 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.33870006 191.6015625 L 288.35718545 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.886702445 137.890625 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.217650566 100.78125 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.292188432 89.0625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.336911151 96.875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.336911151 96.875 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.292188432 89.0625 L 280.336911151 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.217650566 100.78125 L 280.292188432 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.886702445 137.890625 L 280.217650566 100.78125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.33870006 191.6015625 L 244.886702445 137.890625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.7042337507 245.80078125 L 191.33870006 191.6015625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.33691115086464, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.29218843172328, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.21765056648775, 100.78125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(289.54979129397731, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(244.88670244484197, 137.890625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(288.3571854502087, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.33870005963027, 191.6015625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(72.704233750745388, 245.80078125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tde2c1008148c4609a5517550bc4c9979"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t10ed08090f714e49903984f8f576dad6"><g class="toyplot-Edges"><path d="M 73.3750745379 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.462731067 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.192009541 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.192009541 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.462731067 245.3125 L 289.192009541 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.329159213 193.5546875 L 287.462731067 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.014907573 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.307096005 108.59375 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.456171735 104.6875 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.456171735 65.625 L 299.970184854 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.456171735 65.625 L 299.970184854 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.456171735 104.6875 L 280.456171735 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.307096005 108.59375 L 280.456171735 104.6875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.014907573 141.796875 L 280.307096005 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.329159213 193.5546875 L 250.014907573 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.3750745379 246.77734375 L 199.329159213 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.97018485390572, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.45617173524153, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.45617173524153, 104.6875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.30709600477036, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(289.1920095408467, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(250.01490757304711, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(287.46273106738221, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(199.32915921288014, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(73.375074537865231, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te713ece04c08450193b9045470e76418"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4cc3b401ca6641a79ea86b1b8f56405c"><g class="toyplot-Edges"><path d="M 86.404293381 247.75390625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.728682171 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.190816935 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.190816935 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.728682171 245.3125 L 290.190816935 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.273106738 195.5078125 L 289.728682171 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.673225999 145.703125 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.305903399 116.40625 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.380441264 89.0625 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.425163983 65.625 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.425163983 65.625 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.380441264 89.0625 L 281.425163983 65.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.305903399 116.40625 L 281.380441264 89.0625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.673225999 145.703125 L 281.305903399 116.40625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.273106738 195.5078125 L 248.673225999 145.703125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 86.404293381 247.75390625 L 196.273106738 195.5078125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.42516398330355, 65.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.38044126416219, 89.0625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.30590339892666, 116.40625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.19081693500294, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(248.67322599880737, 145.703125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(289.72868217054258, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(196.27310673822302, 195.5078125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(86.404293381037547, 247.75390625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta9a7135f1c9140f09281cc4f61b0bd4b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te368256baf24474396b9924b3b9b8e0c"><g class="toyplot-Edges"><path d="M 87.6267143709 247.265625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.45915325 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.100178891 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.100178891 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.45915325 245.3125 L 291.100178891 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.697078116 194.53125 L 290.45915325 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.666666667 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.723315444 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.857483602 81.25 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.872391175 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.872391175 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.857483602 81.25 L 281.872391175 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.723315444 112.5 L 281.857483602 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 241.666666667 143.75 L 281.723315444 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.697078116 194.53125 L 241.666666667 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 87.6267143709 247.265625 L 203.697078116 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.87239117471677, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.85748360166963, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.72331544424571, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(291.10017889087658, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(241.66666666666669, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(290.45915324985089, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(203.69707811568276, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(87.62671437090043, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t52f23005212a4ec48b411ce8549a2b82"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t89f6414e40f941f08d6f789d9c85b6c2"><g class="toyplot-Edges"><path d="M 74.045915325 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.206917114 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.235539654 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.235539654 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.206917114 245.3125 L 290.235539654 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.295169946 193.5546875 L 289.206917114 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.1019678 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.919499106 108.59375 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.053667263 73.4375 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.277280859 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.277280859 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.053667263 73.4375 L 280.277280859 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.919499106 108.59375 L 280.053667263 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 252.1019678 141.796875 L 279.919499106 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.295169946 193.5546875 L 252.1019678 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.045915325 246.77734375 L 190.295169946 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.27728085867625, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(280.05366726296961, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(279.91949910554564, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(290.2355396541443, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(252.10196779964221, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(289.20691711389389, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.29516994633275, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(74.045915324985089, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t861ee548d4d54ff897d3f13c682f2545"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te9b4eb1810654a59a2bd43c37420d515"><g class="toyplot-Edges"><path d="M 91.3088849135 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.980918306 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.457960644 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.457960644 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.980918306 245.3125 L 291.457960644 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.025044723 193.5546875 L 290.980918306 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.854502087 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.827668456 108.59375 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.902206321 73.4375 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.021466905 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 282.021466905 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.902206321 73.4375 L 282.021466905 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.827668456 108.59375 L 281.902206321 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.854502087 141.796875 L 281.827668456 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.025044723 193.5546875 L 246.854502087 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 91.3088849135 246.77734375 L 204.025044723 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(282.02146690518782, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.90220632081099, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(281.82766845557541, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(291.45796064400713, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(246.85450208706021, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(290.98091830649969, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(204.02504472271914, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(91.308884913536062, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7fda7e67c40642bcbdcb0ff945e95371"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t08383958abc6409d8e8bdf9cc4591a63"><g class="toyplot-Edges"><path d="M 87.656529517 246.77734375 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.101371497 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.323792487 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.323792487 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.101371497 245.3125 L 291.323792487 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.995229577 193.5546875 L 290.101371497 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.093023256 141.796875 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.097197376 108.59375 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.231365534 73.4375 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.305903399 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.305903399 96.875 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.231365534 73.4375 L 281.305903399 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.097197376 108.59375 L 281.231365534 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.093023256 141.796875 L 281.097197376 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.995229577 193.5546875 L 247.093023256 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 87.656529517 246.77734375 L 203.995229577 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(281.3059033989266, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(281.23136553369113, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(281.09719737626716, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(291.32379248658322, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(247.09302325581396, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(290.10137149672039, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(203.99522957662492, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(87.656529516994638, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0a75ae9d061f4a4e87e5ed667da8830d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td663b1c090b84a5f8b72cef1010638ea"><g class="toyplot-Edges"><path d="M 85.7334525939 246.77734375 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.610614192 245.3125 L 299.970184854 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.146094216 221.875 L 299.970184854 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.146094216 221.875 L 299.970184854 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.610614192 245.3125 L 290.146094216 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.765056649 193.5546875 L 288.610614192 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.049493143 141.796875 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.635062612 108.59375 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.709600477 73.4375 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.769230769 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.769230769 96.875 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.709600477 73.4375 L 280.769230769 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.635062612 108.59375 L 280.709600477 73.4375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.049493143 141.796875 L 280.635062612 108.59375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.765056649 193.5546875 L 246.049493143 141.796875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 85.7334525939 246.77734375 L 196.765056649 193.5546875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.97018485390572, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.97018485390572, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.97018485390572, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.76923076923077, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.70960047704233, 73.4375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(280.6350626118068, 108.59375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(290.14609421586164, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(246.04949314251638, 141.796875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(288.61061419200951, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(196.76505664877757, 193.5546875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(85.733452593917718, 246.77734375)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7f03c15f470b4cb28ac35dcb2d47a0bc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6cb0e1a7c3ab40249f705080331e3641"><g class="toyplot-Edges"><path d="M 82.3941562314 247.265625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.235539654 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.413237925 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.413237925 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.235539654 245.3125 L 291.413237925 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.454382826 194.53125 L 290.235539654 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.942754919 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.933214073 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.992844365 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.052474657 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.052474657 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.992844365 81.25 L 281.052474657 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.933214073 112.5 L 280.992844365 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 247.942754919 143.75 L 280.933214073 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.454382826 194.53125 L 247.942754919 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 82.3941562314 247.265625 L 194.454382826 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(281.05247465712586, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.99284436493735, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(280.93321407274897, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(291.41323792486583, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(247.94275491949909, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(290.23553965414425, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(194.45438282647584, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(82.394156231365528, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t854667823c22444bba4f02fc817dcc6d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9510e02513cb4dff833eaa6c93891692"><g class="toyplot-Edges"><path d="M 81.4251639833 247.265625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.772212284 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.264162194 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.264162194 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.772212284 245.3125 L 291.264162194 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.626118068 194.53125 L 290.772212284 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.602265951 143.75 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.574239714 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.618962433 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.782945736 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.782945736 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.618962433 81.25 L 281.782945736 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.574239714 112.5 L 281.618962433 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 245.602265951 143.75 L 281.574239714 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.626118068 194.53125 L 245.602265951 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 81.4251639833 247.265625 L 200.626118068 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.78294573643416, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.61896243291596, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.5742397137746, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(291.26416219439477, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(245.60226595110316, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(290.77221228384013, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(200.62611806797855, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(81.42516398330352, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4899ea99d0074712b176311605a4b782"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6e5e47b669124e629968cc7e4b489ce6"><g class="toyplot-Edges"><path d="M 73.6434108527 247.265625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.877757901 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.95110316 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 290.95110316 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.877757901 245.3125 L 290.95110316 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.72033393 194.53125 L 289.877757901 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.335122242 143.75 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.605247466 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.635062612 81.25 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.26118068 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.26118068 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.635062612 81.25 L 281.26118068 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.605247466 112.5 L 280.635062612 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 244.335122242 143.75 L 280.605247466 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 196.72033393 194.53125 L 244.335122242 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.6434108527 247.265625 L 196.72033393 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(281.26118067978535, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.6350626118068, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.60524746571264, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(290.95110316040552, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(244.335122242099, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(289.87775790101369, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(196.72033392963627, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(73.643410852713188, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0cf8f29c42664bcdbfa2547c6637483a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3b9b9899f01b438cb488831d25759096"><g class="toyplot-Edges"><path d="M 84.3768634466 247.265625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.129994037 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.219439475 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.219439475 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.129994037 245.3125 L 291.219439475 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.61836613 194.53125 L 291.129994037 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.437090042 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.350626118 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.380441264 81.25 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.60405486 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.60405486 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.380441264 81.25 L 281.60405486 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.350626118 112.5 L 281.380441264 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 246.437090042 143.75 L 281.350626118 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.61836613 194.53125 L 246.437090042 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 84.3768634466 247.265625 L 194.61836613 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.60405485986882, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.38044126416219, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(281.35062611806796, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(291.21943947525341, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(246.43709004174121, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(291.1299940369708, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(194.61836612999403, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(84.376863446630892, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3a823228c0f849eea816f7997d7d65f4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t027fa6a852184e83abb504944ee96135"><g class="toyplot-Edges"><path d="M 83.8252832439 247.265625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.819320215 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.547406082 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 291.547406082 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.819320215 245.3125 L 291.547406082 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.900417412 194.53125 L 288.819320215 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.397137746 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.216457961 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.246273107 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.94692904 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.94692904 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.246273107 81.25 L 281.94692904 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.216457961 112.5 L 281.246273107 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 242.397137746 143.75 L 281.216457961 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 195.900417412 194.53125 L 242.397137746 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 83.8252832439 247.265625 L 195.900417412 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.94692903995229, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.24627310673822, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(281.21645796064399, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(291.5474060822898, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(242.39713774597499, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(288.81932021466906, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(195.90041741204533, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(83.825283243887895, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1472dd5bbaed475bbd592ff8acf45f5c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tffa11d8cecb441e899b3dcc9c0f7972b"><g class="toyplot-Edges"><path d="M 79.4722719141 247.265625 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.327370304 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.028026237 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.028026237 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.327370304 245.3125 L 289.028026237 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 206.484794275 194.53125 L 288.327370304 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.225998807 143.75 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.769230769 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.813953488 81.25 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.963029219 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.963029219 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.813953488 81.25 L 280.963029219 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.769230769 112.5 L 280.813953488 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.225998807 143.75 L 280.769230769 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 206.484794275 194.53125 L 248.225998807 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.4722719141 247.265625 L 206.484794275 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.96302921884313, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.81395348837208, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(280.76923076923077, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(289.0280262373285, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(248.22599880739412, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(288.32737030411454, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(206.48479427549196, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(79.472271914132364, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta6988cd63ffd453c9a8fa67bca4faf9e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t91945cea74e646f9b5d464a8c5092296"><g class="toyplot-Edges"><path d="M 78.4287418008 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.252832439 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.461538462 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.461538462 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.252832439 245.3125 L 288.461538462 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.370304114 190.625 L 288.252832439 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.655933214 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.292188432 96.875 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.292188432 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.903398927 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.903398927 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.292188432 112.5 L 280.903398927 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.292188432 96.875 L 280.292188432 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.655933214 135.9375 L 280.292188432 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 202.370304114 190.625 L 250.655933214 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.4287418008 245.3125 L 202.370304114 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(280.90339892665475, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(280.29218843172328, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(280.29218843172328, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(288.46153846153845, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(250.65593321407275, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(288.25283243887895, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(202.37030411449015, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(78.428741800834814, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5ccda06e06704cd3b68230fbce9e78f2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t03947fe21907431894222b3a1f097b56"><g class="toyplot-Edges"><path d="M 76.7292784735 247.265625 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.655336911 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.938580799 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.938580799 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.655336911 245.3125 L 288.938580799 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.755515802 194.53125 L 288.655336911 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.641025641 143.75 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.156827668 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.156827668 81.25 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.395348837 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.395348837 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.156827668 81.25 L 281.395348837 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.156827668 112.5 L 281.156827668 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 250.641025641 143.75 L 281.156827668 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 204.755515802 194.53125 L 250.641025641 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.7292784735 247.265625 L 204.755515802 194.53125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(281.39534883720933, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(281.15682766845555, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(281.15682766845555, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(288.93858079904595, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(250.64102564102564, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(288.65533691115087, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(204.75551580202742, 194.53125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(76.729278473464518, 247.265625)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t57d0001d05e54db0b5dcd69185f73c5e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2659d1f9598740459380458786511dd4"><g class="toyplot-Edges"><path d="M 62.5670840787 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.731067382 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.909958259 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.909958259 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 287.731067382 245.3125 L 287.909958259 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.68574836 190.625 L 287.731067382 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.658318426 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.50208706 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.516994633 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.69588551 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.69588551 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.516994633 112.5 L 279.69588551 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.50208706 96.875 L 279.516994633 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 248.658318426 135.9375 L 279.50208706 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 200.68574836 190.625 L 248.658318426 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.5670840787 245.3125 L 200.68574836 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695292, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695292, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695292, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695292, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.695885509839, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.51699463327373, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(279.50208706022659, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(287.90995825879548, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(248.65831842576029, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(287.73106738223015, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(200.68574836016697, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(62.567084078711986, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4eb24d35a26a47269667a4611bdcc3cd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t062ad5b0e7a14f58993df8c1e998302f"><g class="toyplot-Edges"><path d="M 83.0649970185 245.3125 L 299.985092427 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.610614192 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.998211091 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.998211091 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.610614192 245.3125 L 288.998211091 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.965414431 190.625 L 288.610614192 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.05307096 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.171735242 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 281.171735242 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.858676208 96.875 L 281.171735242 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.858676208 112.5 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.858676208 112.5 L 299.985092427 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.858676208 96.875 L 280.858676208 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 243.05307096 135.9375 L 280.858676208 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 203.965414431 190.625 L 243.05307096 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 83.0649970185 245.3125 L 203.965414431 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(299.98509242695286, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.85867620751338, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(281.17173524150263, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(280.85867620751338, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.99821109123434, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(243.05307096004771, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(288.61061419200951, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(203.96541443053073, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(83.0649970184854, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6bdedfc015314fc9833a71066c3748ce"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfaa2d7d321ba4e16b3e390cfb15731aa"><g class="toyplot-Edges"><path d="M 66.8455575432 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.103756708 245.3125 L 300.0 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.162194395 221.875 L 299.985092427 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 289.162194395 221.875 L 299.985092427 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 288.103756708 245.3125 L 289.162194395 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.433512224 190.625 L 288.103756708 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.552772809 135.9375 L 300.0 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.979129398 96.875 L 299.985092427 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.023852117 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.336911151 81.25 L 300.0 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.336911151 81.25 L 300.0 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.023852117 112.5 L 280.336911151 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 279.979129398 96.875 L 280.023852117 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 249.552772809 135.9375 L 279.979129398 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 199.433512224 190.625 L 249.552772809 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.8455575432 245.3125 L 199.433512224 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(299.98509242695286, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.33691115086464, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(280.02385211687539, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(279.97912939773403, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(289.16219439475259, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(249.55277280858675, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(288.10375670840784, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(199.43351222420989, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(66.845557543231948, 245.3125)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta49a4d9b80634dca89ea82cd906937d4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5fbc0d2cc4094915af59b3abcace8e0e"><g class="toyplot-Edges"><path d="M 76.6845557543 245.3125 L 300.0 300.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.882528324 245.3125 L 299.985092427 268.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.225402504 221.875 L 300.0 237.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 286.225402504 221.875 L 300.0 206.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 285.882528324 245.3125 L 286.225402504 221.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.601669648 190.625 L 285.882528324 245.3125" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.460942159 135.9375 L 299.985092427 175.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.57543232 81.25 L 299.985092427 50.0" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.57543232 81.25 L 299.985092427 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.068574836 96.875 L 280.57543232 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.202742993 112.5 L 300.0 81.25" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.202742993 112.5 L 300.0 143.75" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 280.068574836 96.875 L 280.202742993 112.5" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 251.460942159 135.9375 L 280.068574836 96.875" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 208.601669648 190.625 L 251.460942159 135.9375" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.6845557543 245.3125 L 208.601669648 190.625" style="fill:none;opacity:0.025;stroke:rgb(14.9%,14.9%,14.9%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 143.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 50.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 175.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 206.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 237.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(299.98509242695286, 268.75)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(300.0, 300.0)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(280.20274299344067, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(280.57543231961836, 81.25)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(280.06857483601669, 96.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(286.22540250447224, 221.875)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(251.46094215861655, 135.9375)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(285.88252832438877, 245.3125)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(208.60166964818126, 190.625)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(76.684555754323199, 245.3125)"><circle r="0.0"></circle></g></g></g></g><g class="toyplot-coordinates-Axis" id="tee40aaa8aa0d4553a0fae55d7a44a324" transform="translate(50.0,300.0)translate(0,10.0)"><line style="" x1="0" x2="250.0" y1="0" y2="0"></line><g><line style="" x1="250.0" x2="250.0" y1="0" y2="-5"></line><line style="" x1="194.09660107334525" x2="194.09660107334525" y1="0" y2="-5"></line><line style="" x1="138.19320214669054" x2="138.19320214669054" y1="0" y2="-5"></line><line style="" x1="82.2898032200358" x2="82.2898032200358" y1="0" y2="-5"></line><line style="" x1="26.386404293381048" x2="26.386404293381048" y1="0" y2="-5"></line></g><g><g transform="translate(250.0,6)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:10.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-6.95" y="8.555">0.0</text></g><g transform="translate(194.09660107334525,6)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:10.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-9.73" y="8.555">3.75</text></g><g transform="translate(138.19320214669054,6)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:10.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-6.95" y="8.555">7.5</text></g><g transform="translate(82.2898032200358,6)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:10.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-12.51" y="8.555">11.25</text></g><g transform="translate(26.386404293381048,6)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:10.0px;font-weight:normal;stroke:none;vertical-align:baseline;white-space:pre" x="-9.73" y="8.555">15.0</text></g></g><g transform="translate(125.0,22)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:bold;stroke:none;vertical-align:baseline;white-space:pre" x="-118.7658" y="10.266">Divergence time (substitutions/site x 10</text><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:8.4px;font-weight:bold;stroke:none;vertical-align:baseline;white-space:pre" x="107.3022" y="7.746">-3</text><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:bold;stroke:none;vertical-align:baseline;white-space:pre" x="114.7698" y="10.266">)</text></g><g class="toyplot-coordinates-Axis-coordinates" style="visibility:hidden" transform=""><line style="stroke:rgb(43.9%,50.2%,56.5%);stroke-opacity:1.0;stroke-width:1.0" x1="0" x2="0" y1="-3.0" y2="4.5"></line><text style="alignment-baseline:alphabetic;fill:rgb(43.9%,50.2%,56.5%);fill-opacity:1.0;font-size:10px;font-weight:normal;stroke:none;text-anchor:middle" x="0" y="-6"></text></g></g></g><g class="toyplot-coordinates-Cartesian" id="t7ec0bf9718254d8a903d0ba57b5fabd8"><clipPath id="t99cd5c6f61904337808d1c7248f2ba95"><rect height="270.0" width="220.0" x="290.0" y="40.0"></rect></clipPath><g clip-path="url(#t99cd5c6f61904337808d1c7248f2ba95)"><g class="toyplot-mark-Text" id="tf8bf0656d3c74084a56fb98ba3236f24"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(400.0,56.807866868381225)"><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="-90.0" y="3.066">P. rex lipskyana</text></g><g class="toyplot-Datum" transform="translate(400.0,86.355900151285923)"><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="-90.0" y="3.066">P. rex rex</text></g><g class="toyplot-Datum" transform="translate(400.0,115.90393343419063)"><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="-90.0" y="3.066">P. rex rockii</text></g><g class="toyplot-Datum" transform="translate(400.0,175.0)"><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="-90.0" y="3.066">P. thamnophila tham.</text></g><g class="toyplot-Datum" transform="translate(400.0,145.4519667170953)"><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="-90.0" y="3.066">P. thamnophila cup.</text></g><g class="toyplot-Datum" transform="translate(400.0,204.54803328290467)"><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="-90.0" y="3.066">P. superba</text></g><g class="toyplot-Datum" transform="translate(400.0,234.09606656580942)"><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="-90.0" y="3.066">P. cyathophylla</text></g><g class="toyplot-Datum" transform="translate(400.0,263.64409984871406)"><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="-90.0" y="3.066">P. cyathophylloides</text></g><g class="toyplot-Datum" transform="translate(400.0,293.19213313161879)"><text style="fill:rgb(14.9%,14.9%,14.9%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-style:italic;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="-90.0" y="3.066">P. przewalskii</text></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "tdea88cd40ba847bf822df5135cb0d450";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "tc868bc68ed9044afa7ec68adfd50d602";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
modules["toyplot.coordinates.Axis"] = (
        function(canvas)
        {
            function sign(x)
            {
                return x < 0 ? -1 : x > 0 ? 1 : 0;
            }

            function mix(a, b, amount)
            {
                return ((1.0 - amount) * a) + (amount * b);
            }

            function log(x, base)
            {
                return Math.log(Math.abs(x)) / Math.log(base);
            }

            function in_range(a, x, b)
            {
                var left = Math.min(a, b);
                var right = Math.max(a, b);
                return left <= x && x <= right;
            }

            function inside(range, projection)
            {
                for(var i = 0; i != projection.length; ++i)
                {
                    var segment = projection[i];
                    if(in_range(segment.range.min, range, segment.range.max))
                        return true;
                }
                return false;
            }

            function to_domain(range, projection)
            {
                for(var i = 0; i != projection.length; ++i)
                {
                    var segment = projection[i];
                    if(in_range(segment.range.bounds.min, range, segment.range.bounds.max))
                    {
                        if(segment.scale == "linear")
                        {
                            var amount = (range - segment.range.min) / (segment.range.max - segment.range.min);
                            return mix(segment.domain.min, segment.domain.max, amount)
                        }
                        else if(segment.scale[0] == "log")
                        {
                            var amount = (range - segment.range.min) / (segment.range.max - segment.range.min);
                            var base = segment.scale[1];
                            return sign(segment.domain.min) * Math.pow(base, mix(log(segment.domain.min, base), log(segment.domain.max, base), amount));
                        }
                    }
                }
            }

            var axes = {};

            function display_coordinates(e)
            {
                var current = canvas.createSVGPoint();
                current.x = e.clientX;
                current.y = e.clientY;

                for(var axis_id in axes)
                {
                    var axis = document.querySelector("#" + axis_id);
                    var coordinates = axis.querySelector(".toyplot-coordinates-Axis-coordinates");
                    if(coordinates)
                    {
                        var projection = axes[axis_id];
                        var local = current.matrixTransform(axis.getScreenCTM().inverse());
                        if(inside(local.x, projection))
                        {
                            var domain = to_domain(local.x, projection);
                            coordinates.style.visibility = "visible";
                            coordinates.setAttribute("transform", "translate(" + local.x + ")");
                            var text = coordinates.querySelector("text");
                            text.textContent = domain.toFixed(2);
                        }
                        else
                        {
                            coordinates.style.visibility= "hidden";
                        }
                    }
                }
            }

            canvas.addEventListener("click", display_coordinates);

            var module = {};
            module.show_coordinates = function(axis_id, projection)
            {
                axes[axis_id] = projection;
            }

            return module;
        })(modules["toyplot/canvas"]);
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tef31469c718c41358873f8e289b2e424","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -0.0018270000000000005, -0.0019690000000000003, -0.0045850000000000005, -0.0011720000000000003, -0.00459, -0.0034000000000000002, -0.005255, -0.005531], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tef31469c718c41358873f8e289b2e424","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc3a65a94191941279efb6484689b4813","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -0.001736000000000001, -0.0017870000000000008, -0.004414000000000001, -0.0008810000000000007, -0.004425000000000001, -0.003944000000000001, -0.005030000000000001, -0.005326000000000001], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc3a65a94191941279efb6484689b4813","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf9234e7a3f324af1a61a3fd6a31bc9a7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -0.0019330000000000007, -0.0019470000000000008, -0.0048400000000000006, -0.0009990000000000008, -0.004847000000000001, -0.0037750000000000006, -0.005496000000000001, -0.005815000000000001], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf9234e7a3f324af1a61a3fd6a31bc9a7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcdf7f5dc599e481fb055581ad300074d","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000018675e-06, -1.0000000000018675e-06, -1.0000000000018675e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, -0.0019459999999999998, -0.0019770000000000005, -0.0048660000000000005, -0.0007350000000000004, -0.004889, -0.0035020000000000003, -0.005553000000000001, -0.005909], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcdf7f5dc599e481fb055581ad300074d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t76b3d2cbfae34772b326c82f3509f660","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -0.0019050000000000004, -0.001922, -0.004764000000000001, -0.0006500000000000004, -0.004808000000000001, -0.003723, -0.0054930000000000005, -0.005838], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t76b3d2cbfae34772b326c82f3509f660","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t87c98a8c91544b2d9e7459d71413446c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0020310000000000007, -0.002052000000000001, -0.005093, -0.000648000000000001, -0.005111, -0.003673, -0.0058130000000000005, -0.00619], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t87c98a8c91544b2d9e7459d71413446c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1fced60035d4c43a3a3cf6753adb0f1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -0.0020870000000000003, -0.0021400000000000004, -0.005289000000000001, -0.0007390000000000009, -0.005323000000000001, -0.003439000000000001, -0.006121000000000001, -0.006417000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1fced60035d4c43a3a3cf6753adb0f1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb7d2abb1bf494189934c507f0f415be7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -1.999999999999398e-06, -1.999999999999398e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.0019839999999999997, -0.0020109999999999998, -0.005032999999999999, -0.0007349999999999995, -0.005044, -0.0029929999999999996, -0.0058649999999999996, -0.006167], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb7d2abb1bf494189934c507f0f415be7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t928f5db8d5004d04810f307e8af8d507","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.0019460000000000007, -0.001960000000000001, -0.004880000000000001, -0.0006500000000000004, -0.004896, -0.0026230000000000003, -0.0057540000000000004, -0.0060420000000000005], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t928f5db8d5004d04810f307e8af8d507","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0412bd48b3334363a825873e1b5119bc","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -1.0000000000001327e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0018019999999999998, -0.0018129999999999995, -0.004495, -0.0007159999999999996, -0.004519, -0.0025659999999999997, -0.005403, -0.005637], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0412bd48b3334363a825873e1b5119bc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfb916ae1445641708f1a4de09e241305","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -0.0019910000000000006, -0.0019960000000000004, -0.004894000000000001, -0.0006820000000000003, -0.004966, -0.00237, -0.005945000000000001, -0.006224], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfb916ae1445641708f1a4de09e241305","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdf7c307c0ec5445e8d67646d2650ee76","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0019379999999999996, -0.0019429999999999994, -0.0046949999999999995, -0.0006680000000000002, -0.004777, -0.002445, -0.0057859999999999995, -0.006063], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdf7c307c0ec5445e8d67646d2650ee76","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t78214d74de734a4c925c5392a1974b1e","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.0000000000001327e-06, -2.0000000000002655e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -0.0020620000000000005, -0.002066, -0.004966, -0.0008599999999999997, -0.005038000000000001, -0.00262, -0.006137, -0.006439], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t78214d74de734a4c925c5392a1974b1e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7e6b55f5093d4d0095ec0be54cf9b43b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -0.0020170000000000006, -0.0020250000000000008, -0.004854000000000001, -0.0007910000000000009, -0.004936000000000001, -0.0034160000000000006, -0.0060030000000000005, -0.006351000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7e6b55f5093d4d0095ec0be54cf9b43b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3970b23e82d143849cbc0f76cda183ed","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.001962, -0.0019660000000000007, -0.004712000000000001, -0.0006880000000000011, -0.004778000000000001, -0.002998000000000001, -0.005912000000000001, -0.006182000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3970b23e82d143849cbc0f76cda183ed","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t373d804ae8304805ba78309561776c9b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.673617379884035e-19, 0.0, -0.002097, -0.00211, -0.005038000000000001, -0.0007520000000000001, -0.005098, -0.0036090000000000002, -0.006315, -0.006616], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t373d804ae8304805ba78309561776c9b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4ee89187289c4231bd9b9e14cc51da2e","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002012999999999999, -0.0020619999999999996, -0.004912, -0.0006549999999999993, -0.004971, -0.003351, -0.006196999999999999, -0.006493], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4ee89187289c4231bd9b9e14cc51da2e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tead707e3393d47c590f0ba6f148f7a60","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -1.0000000000001327e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0019439999999999995, -0.001959, -0.004644, -0.0005419999999999991, -0.004716, -0.0038969999999999994, -0.0059229999999999994, -0.006225], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tead707e3393d47c590f0ba6f148f7a60","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t066465ffd8ab45e2b53f610efd4a2e99","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -1.0000000000001327e-06, -0.001967, -0.0019959999999999995, -0.004706, -0.0004989999999999994, -0.004772, -0.003789, -0.0059559999999999995, -0.006312], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t066465ffd8ab45e2b53f610efd4a2e99","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t366d0cbb6170418f8080c69b82665658","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.0000000000018675e-06, -0.0018950000000000009, -0.001980000000000001, -0.0046250000000000015, -0.0006020000000000018, -0.004713000000000002, -0.0035920000000000014, -0.005963000000000001, -0.0062850000000000015], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t366d0cbb6170418f8080c69b82665658","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2aca2e6e1105474fbd55365f1304a027","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -1.0000000000001327e-06, 0.0, -0.0020090000000000004, -0.0020740000000000003, -0.004669, -0.0004889999999999999, -0.0047810000000000005, -0.003595, -0.006106, -0.006479], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2aca2e6e1105474fbd55365f1304a027","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t872969e88c4d46868751475e378efe6b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -2.0000000000002655e-06, -0.002084, -0.002175, -0.004483, -0.0005830000000000002, -0.00474, -0.0032220000000000005, -0.006312, -0.006726], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t872969e88c4d46868751475e378efe6b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9056b3b9ee104da5a7d789c8500a976b","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -8.673617379884035e-19, -8.673617379884035e-19, -0.0021290000000000007, -0.002145000000000001, -0.003944000000000001, -0.0005840000000000012, -0.004149000000000001, -0.0034910000000000006, -0.006504000000000001, -0.006965000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9056b3b9ee104da5a7d789c8500a976b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta1c36d5a0f7a40e9a5071ab1f7d12d1d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -1.734723475976807e-18, -0.002268000000000001, -0.0022790000000000015, -0.0037930000000000017, -0.0006070000000000016, -0.0040240000000000015, -0.004061000000000002, -0.006844000000000001, -0.0073170000000000015], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta1c36d5a0f7a40e9a5071ab1f7d12d1d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7601f47d4d174e538a9dbd11c32cbdef","vertex_data","graph vertex data",["x", "y"],[[-8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, 0.0, 0.0, -8.673617379884035e-19, -0.0022860000000000016, -0.002294000000000001, -0.0036150000000000015, -0.0005840000000000012, -0.0037060000000000014, -0.003983000000000001, -0.006927000000000001, -0.007400000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7601f47d4d174e538a9dbd11c32cbdef","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc7046f417b1d40b9802e9d5d3473fef1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.002321, -0.0023239999999999997, -0.0035789999999999997, -0.0006300000000000004, -0.003699, -0.003509, -0.007066, -0.007587], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc7046f417b1d40b9802e9d5d3473fef1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t74c7320acbf245b799e7718db3fa3d81","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0023999999999999994, -0.0024029999999999998, -0.0036559999999999995, -0.0006559999999999995, -0.003798, -0.0035179999999999994, -0.007316, -0.007861], [7.0, 6.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t74c7320acbf245b799e7718db3fa3d81","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6f29673f5da646b19565178dac9cda48","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0023809999999999994, -0.002385, -0.003568, -0.0007100000000000006, -0.0036879999999999994, -0.0036689999999999995, -0.007337, -0.007909], [7.0, 6.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6f29673f5da646b19565178dac9cda48","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta17ea1b61bcb4a939e8514c1daeacdd3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002353, -0.0023569999999999997, -0.0034399999999999995, -0.0006579999999999997, -0.0035700000000000003, -0.0038979999999999996, -0.007467, -0.007894], [7.0, 8.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta17ea1b61bcb4a939e8514c1daeacdd3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td369b0d633f84db9a05ff3c9040f8a89","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.734723475976807e-18, -0.002367000000000002, -0.0023710000000000016, -0.003190000000000001, -0.0007090000000000022, -0.0034220000000000014, -0.003914000000000002, -0.0073500000000000015, -0.007925000000000001], [7.0, 8.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td369b0d633f84db9a05ff3c9040f8a89","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tddd42aaa2cdd4bf0b21e9c2a99bc74ac","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0023439999999999997, -0.0024269999999999995, -0.0028909999999999995, -0.0006220000000000002, -0.003439, -0.004514, -0.007324, -0.008038], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tddd42aaa2cdd4bf0b21e9c2a99bc74ac","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf7137f4b47ff44c3b0437a6fa6cb8750","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0023699999999999997, -0.0023819999999999996, -0.0026889999999999996, -0.0008159999999999999, -0.003117, -0.0036950000000000004, -0.007487, -0.008326], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf7137f4b47ff44c3b0437a6fa6cb8750","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0817ed1f8582439aafad69931903f691","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002366, -0.002372, -0.002436, -0.0007160000000000005, -0.002824, -0.003562000000000001, -0.0073820000000000005, -0.008368], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0817ed1f8582439aafad69931903f691","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdce1387514a0425299157eef2d6362a0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.002502999999999999, -0.002568, -0.002666, -0.0009349999999999983, -0.0027739999999999996, -0.003704, -0.007598, -0.008853], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdce1387514a0425299157eef2d6362a0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfe1526a913624d0c948c2ebed367de3c","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0025330000000000005, -0.0026440000000000005, -0.002725, -0.0007800000000000012, -0.0029969999999999997, -0.003573, -0.0072440000000000004, -0.009247], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfe1526a913624d0c948c2ebed367de3c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t04cc181aaa5449d997dd012572a1a147","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -0.002404999999999999, -0.0025429999999999993, -0.00258, -0.0007399999999999993, -0.003072, -0.0032759999999999994, -0.006657, -0.008721], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t04cc181aaa5449d997dd012572a1a147","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teda0399410c6463cba86c4d32b75a0a9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.002644999999999999, -0.002689999999999999, -0.002728999999999999, -0.0007480000000000004, -0.002927999999999999, -0.003240999999999999, -0.007470999999999999, -0.00929], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teda0399410c6463cba86c4d32b75a0a9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t43080d2dff5d4e05a445fabf18c4df7b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.002686000000000001, -0.002714000000000001, -0.002759000000000001, -0.0007640000000000008, -0.0030830000000000007, -0.0035020000000000008, -0.007099000000000001, -0.009756], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t43080d2dff5d4e05a445fabf18c4df7b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t81bd041b529e4ece8bfe8107320154a8","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0025249999999999995, -0.002548999999999999, -0.002576, -0.000699, -0.0030489999999999996, -0.0025509999999999994, -0.006591, -0.009757], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t81bd041b529e4ece8bfe8107320154a8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t26775d667d824997aee919cd9b8b836e","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002293999999999999, -0.0023510000000000007, -0.0023560000000000005, -0.0006540000000000001, -0.0028129999999999995, -0.0017579999999999991, -0.007228, -0.009576], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t26775d667d824997aee919cd9b8b836e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4829ac3097cd4d4c89b9ce194d8a9cd3","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -1.9999999999985307e-06, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, -9.999999999992654e-07, -1.9999999999985307e-06, -0.0023139999999999983, -0.002325999999999998, -0.0023469999999999984, -0.000677999999999998, -0.0027249999999999983, -0.002062999999999999, -0.0072489999999999985, -0.009659999999999998], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4829ac3097cd4d4c89b9ce194d8a9cd3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdbb68958457d4d3d805974f252ce4f94","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.002328, -0.0023700000000000006, -0.0024010000000000004, -0.0006390000000000007, -0.0028470000000000006, -0.0017810000000000013, -0.007385000000000001, -0.009688], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdbb68958457d4d3d805974f252ce4f94","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td105dfc631824372b4758f609d29acc3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.002301000000000001, -0.0023090000000000003, -0.002347, -0.0006270000000000008, -0.0028600000000000006, -0.0018130000000000004, -0.007308, -0.009648], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td105dfc631824372b4758f609d29acc3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8a966ed13a2c4404b0202669de815d22","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002092, -0.0021020000000000006, -0.002138000000000001, -0.0006010000000000008, -0.0026380000000000006, -0.001609000000000001, -0.006849000000000001, -0.009430000000000001], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8a966ed13a2c4404b0202669de815d22","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95cfa1a418a441f9b912dcc394bc50af","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, 0.0, -0.0021799999999999996, -0.002180999999999999, -0.0022049999999999986, -0.0007359999999999988, -0.0030219999999999986, -0.0018279999999999998, -0.007179, -0.009954], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95cfa1a418a441f9b912dcc394bc50af","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t636be2d99aab4d96a5d8daf6b514f4c3","vertex_data","graph vertex data",["x", "y"],[[-2.000000000002e-06, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.0022520000000000005, -0.0022520000000000005, -0.0022650000000000014, -0.0007489999999999997, -0.0027930000000000003, -0.0016770000000000014, -0.007384000000000001, -0.010807], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t636be2d99aab4d96a5d8daf6b514f4c3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf12235f4747d4188bc5521ea78de1d67","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.734723475976807e-18, 0.0, -0.002242000000000001, -0.002242000000000001, -0.002254000000000001, -0.0006620000000000011, -0.002659, -0.0016510000000000014, -0.007379, -0.010859], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf12235f4747d4188bc5521ea78de1d67","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb230cd2071fc48879a5e3697f2a2359b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.002261000000000001, -0.0022640000000000004, -0.0022850000000000006, -0.0008510000000000011, -0.002567, -0.0018060000000000003, -0.007513000000000001, -0.011067], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb230cd2071fc48879a5e3697f2a2359b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te7ecc66c508640d49f9e186d6af646f2","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -0.0022099999999999984, -0.0022169999999999985, -0.002227, -0.0008979999999999995, -0.0027019999999999995, -0.0016169999999999986, -0.007110999999999998, -0.011362999999999998], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te7ecc66c508640d49f9e186d6af646f2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3a4b99f8af1c4a2da562fcd36aad62b1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002116, -0.0021379999999999993, -0.0021469999999999996, -0.0007939999999999996, -0.0030080000000000003, -0.0016699999999999996, -0.007069, -0.011594], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3a4b99f8af1c4a2da562fcd36aad62b1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4c2b63cf13c749b780d73a49a7a8ba6c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0019900000000000004, -0.0020020000000000003, -0.0020100000000000014, -0.0007140000000000011, -0.0035960000000000002, -0.0015350000000000016, -0.006670000000000001, -0.011511], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4c2b63cf13c749b780d73a49a7a8ba6c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2d34c7189158428c8c4c6cd4f586e588","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0018410000000000024, -0.0018450000000000012, -0.0018540000000000015, -0.0007660000000000011, -0.0029830000000000013, -0.0009300000000000003, -0.006720000000000001, -0.011435], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2d34c7189158428c8c4c6cd4f586e588","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb4e0ce3612d24e2f9b3ed05367aa661c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0018449999999999994, -0.0018519999999999995, -0.001856, -0.0006080000000000009, -0.002863000000000001, -0.0012099999999999993, -0.006675, -0.011792], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb4e0ce3612d24e2f9b3ed05367aa661c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9923816b6ae844e9bdf72e49ffc4d410","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0019019999999999992, -0.001934, -0.0019369999999999995, -0.0006370000000000004, -0.0032169999999999994, -0.0014509999999999992, -0.006569, -0.012366], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9923816b6ae844e9bdf72e49ffc4d410","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e927434d50a4e3f898b5ae338ba52e6","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001745, -0.0017590000000000001, -0.0017600000000000011, -0.000596000000000001, -0.003262000000000001, -0.001262000000000001, -0.0066240000000000005, -0.011511], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e927434d50a4e3f898b5ae338ba52e6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t06a183041c7446b591602d915d97b025","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, 0.0, -0.001831000000000001, -0.0018499999999999992, -0.0018510000000000002, -0.0006589999999999999, -0.003051, -0.0015099999999999992, -0.006648, -0.012324], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t06a183041c7446b591602d915d97b025","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1d48c90d0b1f4bb1b812355f95cfad13","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0019950000000000002, -0.001975000000000001, -0.0020020000000000003, -0.0007769999999999999, -0.003013, -0.001398, -0.007052, -0.013516], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1d48c90d0b1f4bb1b812355f95cfad13","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2290760c6b4f473fbe6e7e3f3ff204cc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -0.0019030000000000002, -0.0018539999999999997, -0.0019140000000000008, -0.0007329999999999993, -0.003027, -0.0012490000000000001, -0.006875, -0.013479], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2290760c6b4f473fbe6e7e3f3ff204cc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tff5799a7c4e14882a6cd57363d6421b6","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, -0.0019330000000000007, -0.0019280000000000026, -0.0019380000000000022, -0.0006620000000000011, -0.0033050000000000024, -0.0011450000000000002, -0.007373000000000001, -0.01352], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tff5799a7c4e14882a6cd57363d6421b6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7950f61c5b5e48f1ba640e372a1f252a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0019019999999999992, -0.0019039999999999994, -0.001908, -0.0006300000000000004, -0.003266, -0.0015530000000000006, -0.006709, -0.013347], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7950f61c5b5e48f1ba640e372a1f252a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t187aa0c28eca48d9a9cfa97bafb4deba","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0019570000000000004, -0.00196, -0.0019629999999999995, -0.000621, -0.003266, -0.0012759999999999994, -0.006873, -0.013998], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t187aa0c28eca48d9a9cfa97bafb4deba","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te3fafeccdafe4034bbd66a846da2384c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.001850000000000001, -0.001857000000000001, -0.0018589999999999995, -0.000536, -0.0037549999999999997, -0.0012050000000000012, -0.006111, -0.014096000000000001], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te3fafeccdafe4034bbd66a846da2384c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1bb52a9b891471d82068b6085b6ac73","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.0017990000000000003, -0.0018090000000000016, -0.0018110000000000001, -0.0005320000000000012, -0.003564000000000001, -0.0009460000000000007, -0.006868000000000001, -0.014266000000000001], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1bb52a9b891471d82068b6085b6ac73","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t23113960f8db4212abfe8868c9117096","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.001854999999999999, -0.0018609999999999998, -0.001864000000000001, -0.000593999999999999, -0.0033550000000000003, -0.0011590000000000003, -0.006827, -0.014178], [8.0, 5.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t23113960f8db4212abfe8868c9117096","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t10879776d3ca49e4ac3dbd3dea9082ef","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.0017560000000000006, -0.0017840000000000009, -0.0017850000000000019, -0.0005980000000000013, -0.003124, -0.0010280000000000011, -0.0066430000000000005, -0.013586], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t10879776d3ca49e4ac3dbd3dea9082ef","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td63a932c47d84384b34eb35a64943ceb","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -0.0018239999999999992, -0.0017870000000000004, -0.0018260000000000012, -0.0006180000000000005, -0.003143, -0.0012469999999999998, -0.006543, -0.013731], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td63a932c47d84384b34eb35a64943ceb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t64e20f879e9f4737afb03e9bbc2f37cc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0018550000000000007, -0.0018709999999999994, -0.001876000000000001, -0.0005820000000000009, -0.0033550000000000003, -0.001079, -0.006914, -0.014031], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t64e20f879e9f4737afb03e9bbc2f37cc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2a1b0a25b9014da9b8026095ef7eab33","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -0.001849, -0.0018729999999999997, -0.0018740000000000007, -0.000595, -0.003254, -0.001098, -0.006392, -0.013748], [8.0, 5.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2a1b0a25b9014da9b8026095ef7eab33","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td01504f1b1974abf86b54d3eff75fce4","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0019179999999999996, -0.0019229999999999994, -0.001927, -0.0005730000000000006, -0.003235, -0.0012469999999999998, -0.006435, -0.014202], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td01504f1b1974abf86b54d3eff75fce4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t93465f4e19464e4c8f4338b4d9e4551a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0018159999999999982, -0.0018320000000000003, -0.0018339999999999988, -0.0006040000000000004, -0.002848, -0.001044999999999999, -0.0063349999999999995, -0.014067], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t93465f4e19464e4c8f4338b4d9e4551a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6827922b63a24c87a8e389b989331b6e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, -1.000000000001e-06, -0.0018939999999999999, -0.0018970000000000011, -0.001901, -0.0006340000000000009, -0.0030679999999999995, -0.0009230000000000002, -0.00698, -0.015027], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6827922b63a24c87a8e389b989331b6e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1d674514431a417999d01d6c70a02d0e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -0.001875, -0.0018790000000000005, -0.001882, -0.0006240000000000013, -0.0029370000000000004, -0.0009549999999999993, -0.0067740000000000005, -0.014861000000000001], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1d674514431a417999d01d6c70a02d0e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9c34265c561a48a79d57b699e48cabed","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001903000000000002, -0.0019130000000000015, -0.0019130000000000015, -0.0006920000000000016, -0.0032780000000000014, -0.001236000000000001, -0.006484000000000002, -0.015696], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9c34265c561a48a79d57b699e48cabed","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8761e3db53534d0dbb7a99162c0bdaa9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0018459999999999987, -0.0018609999999999998, -0.0018620000000000008, -0.0006069999999999999, -0.00332, -0.0012809999999999992, -0.007052, -0.014659], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8761e3db53534d0dbb7a99162c0bdaa9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3c3692924e3f493f9c5e8b9ebfc35aae","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0016750000000000011, -0.001680000000000001, -0.0016840000000000015, -0.0005540000000000024, -0.003046, -0.001015000000000002, -0.006831000000000001, -0.014086000000000001], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3c3692924e3f493f9c5e8b9ebfc35aae","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdc15ac7aba5f4ccd8a22dca95df04080","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.001628000000000001, -0.0016320000000000015, -0.0016370000000000013, -0.0005920000000000022, -0.003334, -0.000903000000000001, -0.007163000000000001, -0.013746000000000001], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdc15ac7aba5f4ccd8a22dca95df04080","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8d42be882b724ce38f420e3e831b4f2e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001595000000000001, -0.0015980000000000005, -0.001602000000000001, -0.0006340000000000009, -0.0037080000000000012, -0.000811000000000001, -0.006883, -0.013854], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8d42be882b724ce38f420e3e831b4f2e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a614ebb9903460abc363491bfe7f6f3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, -1.000000000001e-06, -0.00166, -0.001661000000000001, -0.001667, -0.0007350000000000013, -0.0035989999999999998, -0.0008509999999999993, -0.006354, -0.014378], [5.0, 7.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a614ebb9903460abc363491bfe7f6f3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc874c9175f7d48b4b1a954de12f8cff3","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999975306e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0017459999999999976, -0.0017469999999999986, -0.0017789999999999993, -0.0005669999999999981, -0.0030479999999999986, -0.000954, -0.006655999999999999, -0.015118], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc874c9175f7d48b4b1a954de12f8cff3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c416bbc109944bfa70280827e38d615","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.469446951953614e-18, -0.0017960000000000025, -0.0018030000000000025, -0.0018120000000000011, -0.000623000000000002, -0.0035210000000000016, -0.0010510000000000016, -0.006543000000000002, -0.015828000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c416bbc109944bfa70280827e38d615","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t587ac096004e475aa345909eed7f0842","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0016290000000000002, -0.0016400000000000008, -0.001646, -0.0005789999999999997, -0.003335000000000001, -0.0009000000000000015, -0.006845, -0.014963], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t587ac096004e475aa345909eed7f0842","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbc361bb341ae4a1190f81e64bf9e766a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0016900000000000005, -0.0017010000000000011, -0.0017110000000000007, -0.0007130000000000018, -0.0035659999999999997, -0.001040000000000001, -0.006325000000000001, -0.015667], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbc361bb341ae4a1190f81e64bf9e766a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc70cf5a9913a44dd8674fd7c3528f202","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -1.000000000001e-06, -0.0016480000000000002, -0.0016579999999999998, -0.0016629999999999995, -0.0006859999999999991, -0.003162999999999999, -0.000900999999999999, -0.006626999999999999, -0.015961], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc70cf5a9913a44dd8674fd7c3528f202","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta704a397581a496ba7c658ce50dccba1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -0.0017870000000000021, -0.0017890000000000024, -0.001805000000000001, -0.0009350000000000018, -0.0035130000000000022, -0.0011510000000000027, -0.006569000000000002, -0.016681], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta704a397581a496ba7c658ce50dccba1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6d6e79cbdfb54cd3877589b1b4949c6a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0017239999999999998, -0.0017789999999999993, -0.0017879999999999997, -0.0007769999999999999, -0.002999999999999999, -0.0010959999999999998, -0.006362, -0.01677], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6d6e79cbdfb54cd3877589b1b4949c6a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8b723ef030544f63a491928aa98e47d9","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0016749999999999994, -0.0017300000000000006, -0.0017409999999999995, -0.0007609999999999995, -0.003307000000000001, -0.0009440000000000004, -0.006763, -0.01616], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8b723ef030544f63a491928aa98e47d9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdadc05be6756454a94881ff977fcaf93","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0016039999999999995, -0.0016939999999999993, -0.0017029999999999997, -0.0007029999999999988, -0.0030159999999999996, -0.0008489999999999991, -0.0070539999999999995, -0.015427], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdadc05be6756454a94881ff977fcaf93","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7226c5a00f274b369e4af9557bfbae69","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -0.001549, -0.0016879999999999985, -0.0016949999999999986, -0.0007989999999999994, -0.0030619999999999988, -0.0008780000000000003, -0.0064139999999999996, -0.015545], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7226c5a00f274b369e4af9557bfbae69","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2dccb5d6631d4603b30ed778b1599514","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0015350000000000016, -0.0016160000000000011, -0.0016510000000000014, -0.0007940000000000013, -0.003328000000000001, -0.0008990000000000005, -0.006825000000000001, -0.015266000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2dccb5d6631d4603b30ed778b1599514","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t962316ec78fa4fc2b5fab5604fb154b6","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0013490000000000012, -0.0015340000000000006, -0.0015610000000000016, -0.0007760000000000006, -0.002961, -0.0009530000000000007, -0.007135000000000001, -0.014642], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t962316ec78fa4fc2b5fab5604fb154b6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdeac59903ed045a98e388a3e791c63fc","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0014950000000000015, -0.0015550000000000008, -0.0015810000000000008, -0.0008439999999999993, -0.0027360000000000006, -0.000869, -0.007105, -0.015142000000000001], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdeac59903ed045a98e388a3e791c63fc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t45c9955f974a43f5a7c33faf6a484a5e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -0.0014770000000000009, -0.0015610000000000016, -0.0015780000000000013, -0.0008360000000000017, -0.0032710000000000013, -0.0008880000000000016, -0.006884000000000001, -0.015186000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t45c9955f974a43f5a7c33faf6a484a5e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t29522b904d4a46a5b4c7b301494f6039","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.001543000000000001, -0.0013360000000000021, -0.001551000000000002, -0.0007490000000000014, -0.0035590000000000014, -0.0009430000000000011, -0.006924000000000001, -0.015273000000000002], [5.0, 6.0, 8.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 5.5, 7.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t29522b904d4a46a5b4c7b301494f6039","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9e83eb08111a4286ba44b4602e5fc92b","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0011540000000000005, -0.0014180000000000009, -0.0014220000000000014, -0.000725, -0.002850000000000002, -0.0008330000000000004, -0.007109000000000001, -0.014724000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9e83eb08111a4286ba44b4602e5fc92b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ted526229a5934d15b001c6550db0d094","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0010389999999999983, -0.001398, -0.0014029999999999997, -0.0006679999999999985, -0.003382999999999999, -0.0008059999999999994, -0.0067399999999999995, -0.014745999999999999], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ted526229a5934d15b001c6550db0d094","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t92678b9308e245439fbf5022696eb7ca","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013419999999999994, -0.0014199999999999994, -0.0014260000000000002, -0.0006819999999999986, -0.0030149999999999986, -0.0008039999999999992, -0.006900999999999999, -0.014782], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t92678b9308e245439fbf5022696eb7ca","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t98857e6cb54b4d88982333571d7c9670","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001469999999999999, -0.0015060000000000004, -0.0015169999999999993, -0.0008249999999999993, -0.0030159999999999996, -0.000952999999999999, -0.007122, -0.01551], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t98857e6cb54b4d88982333571d7c9670","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te4f5c4df9a554fbfa3605413d819f32a","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013380000000000006, -0.001387000000000001, -0.0013960000000000014, -0.0007160000000000014, -0.003701000000000001, -0.0008500000000000001, -0.006514000000000001, -0.014828000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te4f5c4df9a554fbfa3605413d819f32a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc61b25fc0d684e51bfd0e64a0ace82c0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -0.0014160000000000006, -0.0014540000000000004, -0.0014729999999999986, -0.0007930000000000003, -0.003415999999999999, -0.000900999999999999, -0.006867, -0.01508], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc61b25fc0d684e51bfd0e64a0ace82c0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1bc58487056947bfb70218c23fe52fa1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0013039999999999996, -0.0013699999999999997, -0.001398, -0.0008129999999999995, -0.003778, -0.0008349999999999989, -0.006696, -0.014379], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1bc58487056947bfb70218c23fe52fa1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te767726972a64696bbafba02b50bcdd5","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0013670000000000002, -0.0014099999999999998, -0.0014420000000000006, -0.0007970000000000008, -0.0033620000000000004, -0.0008310000000000001, -0.006605, -0.01409], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te767726972a64696bbafba02b50bcdd5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t101f460a200f40bb9045a0a361e5d5f2","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.001509, -0.0015239999999999993, -0.0015489999999999983, -0.0008269999999999996, -0.0036249999999999998, -0.0008400000000000005, -0.007097999999999999, -0.014743], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t101f460a200f40bb9045a0a361e5d5f2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbf4fdb32c94c41429f7d0b0f775acbdf","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.001412, -0.0014820000000000007, -0.0014990000000000003, -0.0007900000000000008, -0.003346, -0.0008330000000000004, -0.0065710000000000005, -0.014953000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbf4fdb32c94c41429f7d0b0f775acbdf","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc60db1a5ede04062a1f7944fd9897f83","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013750000000000012, -0.0014760000000000016, -0.0015019999999999999, -0.0007230000000000014, -0.00332, -0.0007970000000000008, -0.007287000000000001, -0.015005000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc60db1a5ede04062a1f7944fd9897f83","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t69bef147e4c3470a80c5ba9c34b60211","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012729999999999998, -0.0014219999999999997, -0.0014409999999999978, -0.0007489999999999997, -0.003331999999999998, -0.0008209999999999988, -0.007252999999999999, -0.015142], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t69bef147e4c3470a80c5ba9c34b60211","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tae673ab56fd142ebb9772edb6a8f2475","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0013520000000000008, -0.0014670000000000013, -0.001510000000000001, -0.0007520000000000009, -0.0031520000000000003, -0.0008220000000000015, -0.007092000000000001, -0.015228], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tae673ab56fd142ebb9772edb6a8f2475","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t443a8b3a025e4c2ab37dd82457c55cc3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.0013810000000000003, -0.0014760000000000016, -0.0015189999999999995, -0.0007480000000000021, -0.0032980000000000006, -0.0008190000000000003, -0.006410000000000001, -0.015304000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t443a8b3a025e4c2ab37dd82457c55cc3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e64cdca5dc54e59813da90e0b1b746a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0014069999999999985, -0.0014839999999999992, -0.0015969999999999995, -0.000782999999999999, -0.0036889999999999996, -0.0008629999999999992, -0.006872, -0.015403], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e64cdca5dc54e59813da90e0b1b746a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tef6090e48c0442c2a1118a89ae316701","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013039999999999996, -0.0013209999999999993, -0.0013629999999999996, -0.0007470000000000011, -0.0035759999999999993, -0.0007790000000000002, -0.006213, -0.014543], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tef6090e48c0442c2a1118a89ae316701","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t88374a8570e34205bce50b68af5799cf","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0012530000000000006, -0.001288000000000001, -0.0013299999999999996, -0.000733000000000001, -0.0033229999999999996, -0.0007430000000000006, -0.006449, -0.014359], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t88374a8570e34205bce50b68af5799cf","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t20d31f42ccf748029a503b2ca73bb03e","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013190000000000007, -0.0013630000000000014, -0.0014180000000000009, -0.0007820000000000014, -0.0033840000000000016, -0.0008190000000000003, -0.006771000000000001, -0.015272], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t20d31f42ccf748029a503b2ca73bb03e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t43985e65a64449bfa7077c293fd2c347","vertex_data","graph vertex data",["x", "y"],[[-2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.001230000000000002, -0.0012910000000000005, -0.0013430000000000004, -0.0006510000000000023, -0.00349, -0.0007550000000000022, -0.006719000000000001, -0.015214000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t43985e65a64449bfa7077c293fd2c347","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tef6843701a4446b3b0826c4f5e4d4648","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -0.0011059999999999993, -0.0012329999999999997, -0.0012709999999999996, -0.0006820000000000003, -0.003174999999999999, -0.000700000000000001, -0.006803, -0.014795], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tef6843701a4446b3b0826c4f5e4d4648","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf1455f8119624eaea8c2988e2da6f084","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012340000000000007, -0.0012780000000000014, -0.0013270000000000018, -0.0007480000000000021, -0.003195, -0.0007530000000000002, -0.007286000000000001, -0.015268], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf1455f8119624eaea8c2988e2da6f084","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t03325a9f6bd04f958ab9e1036c47afeb","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0011129999999999994, -0.0012180000000000003, -0.0012560000000000002, -0.0007139999999999994, -0.003089999999999999, -0.0007179999999999999, -0.0070599999999999994, -0.014844], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t03325a9f6bd04f958ab9e1036c47afeb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tad3145dae4f445088c34f0b26d06cf55","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012099999999999993, -0.0012189999999999996, -0.0012849999999999997, -0.0006569999999999996, -0.0034129999999999994, -0.0008039999999999992, -0.0071909999999999995, -0.015385], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tad3145dae4f445088c34f0b26d06cf55","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t98f8cbaf0b4c451a83a7da23886ce2ca","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0012210000000000016, -0.0012280000000000017, -0.0012630000000000002, -0.0006250000000000006, -0.003549, -0.0006690000000000012, -0.006726000000000001, -0.015304000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t98f8cbaf0b4c451a83a7da23886ce2ca","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3a9b36d1ee834aaa83fd5a786a3a0ce5","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0012259999999999997, -0.0012320000000000005, -0.0012560000000000002, -0.000615000000000001, -0.0033970000000000007, -0.0006420000000000019, -0.006594000000000001, -0.015079], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3a9b36d1ee834aaa83fd5a786a3a0ce5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6f9a329abd0c469bbb9a12560e7d9c57","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012849999999999997, -0.0013139999999999992, -0.0013360000000000004, -0.0006700000000000005, -0.003837, -0.0008020000000000006, -0.006477, -0.016233], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6f9a329abd0c469bbb9a12560e7d9c57","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf5db8c0382f04970aa6d42dcf6bbc0fc","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -3.469446951953614e-18, -0.0013350000000000029, -0.001356000000000003, -0.0013680000000000012, -0.0007230000000000014, -0.003171000000000002, -0.0009340000000000008, -0.006786000000000002, -0.016391000000000003], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf5db8c0382f04970aa6d42dcf6bbc0fc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf115431470f2443fa8a551fc3ca45756","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, -0.001337999999999999, -0.0013579999999999998, -0.0013619999999999986, -0.0007029999999999988, -0.003587999999999999, -0.0009979999999999989, -0.0064329999999999995, -0.016468], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf115431470f2443fa8a551fc3ca45756","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6ec416f0381a466fbb3f72b9f83f3b9f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012770000000000004, -0.001373000000000001, -0.001380000000000001, -0.0007380000000000008, -0.0035130000000000005, -0.0008760000000000018, -0.006981000000000001, -0.016067], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6ec416f0381a466fbb3f72b9f83f3b9f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t073e58c5921b4c43b3612c08ad0f1d17","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.00136, -0.001413000000000001, -0.0014200000000000011, -0.0006230000000000003, -0.0031190000000000002, -0.0008730000000000005, -0.006366, -0.016187], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t073e58c5921b4c43b3612c08ad0f1d17","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0fe1633507bb4dbab117825e2b44b781","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013240000000000005, -0.001431, -0.001438, -0.0006950000000000012, -0.003266999999999999, -0.0008570000000000001, -0.007011, -0.015739], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0fe1633507bb4dbab117825e2b44b781","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t415ed255548d4a40ba00cfe2bb8a3c4d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.001200999999999999, -0.0013539999999999993, -0.0013619999999999986, -0.0005429999999999983, -0.0038499999999999993, -0.0010079999999999985, -0.006404999999999999, -0.014941], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t415ed255548d4a40ba00cfe2bb8a3c4d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t99b658e35ab047459a2dcbd192a6b982","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012310000000000012, -0.0012930000000000007, -0.0013030000000000003, -0.00051, -0.0034730000000000004, -0.0008140000000000005, -0.006672000000000001, -0.014587000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t99b658e35ab047459a2dcbd192a6b982","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t55f5adfdf05343d4b07b91bd6c6df455","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0011960000000000009, -0.0012460000000000006, -0.001261, -0.0004869999999999996, -0.0035390000000000005, -0.000843, -0.006158, -0.014993000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t55f5adfdf05343d4b07b91bd6c6df455","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf101a2ea44e44eb6804b35957d10f53f","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.0011000000000000003, -0.001236000000000001, -0.001243000000000001, -0.0006110000000000004, -0.0034100000000000016, -0.0006990000000000017, -0.007123000000000002, -0.014593000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf101a2ea44e44eb6804b35957d10f53f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t23951550188243d9959a42174b636897","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -0.0011630000000000008, -0.0012180000000000003, -0.0012220000000000009, -0.0006540000000000018, -0.0037820000000000006, -0.0007200000000000019, -0.0070100000000000015, -0.014728000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t23951550188243d9959a42174b636897","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5fe6660ce5f443b090007c9c996bf181","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.001269000000000001, -0.0011720000000000012, -0.0012729999999999998, -0.0006130000000000007, -0.0033560000000000013, -0.0007960000000000016, -0.006908000000000001, -0.015258], [5.0, 6.0, 8.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 5.5, 7.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5fe6660ce5f443b090007c9c996bf181","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0940c24e785c4c948f9cb8d0d270c97a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012300000000000002, -0.001294, -0.0013019999999999993, -0.0007760000000000006, -0.0032379999999999996, -0.0008570000000000001, -0.007032, -0.01555], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0940c24e785c4c948f9cb8d0d270c97a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t45b271ac8b634925aa3760de0bb886e8","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.0000000000027348e-06, -1.0000000000027348e-06, -1.734723475976807e-18, 0.0, -0.0011120000000000019, -0.0011700000000000026, -0.0011760000000000017, -0.0006840000000000023, -0.0031540000000000023, -0.0007330000000000027, -0.006234000000000002, -0.014233], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t45b271ac8b634925aa3760de0bb886e8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb2adab3dfa704a58a1362490de7df0ad","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -0.0011999999999999997, -0.0012700000000000003, -0.0012790000000000006, -0.0007380000000000008, -0.003367, -0.0007709999999999991, -0.007455, -0.014804], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb2adab3dfa704a58a1362490de7df0ad","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teaacf1dd5f8444818c223503466ece16","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011890000000000008, -0.0012240000000000011, -0.001229000000000001, -0.0006890000000000004, -0.0033480000000000003, -0.0007589999999999993, -0.0067150000000000005, -0.01473], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teaacf1dd5f8444818c223503466ece16","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tebc2e0b178e243eb96ce6a48337da5c7","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0012310000000000012, -0.0012680000000000018, -0.0012720000000000023, -0.0006960000000000022, -0.0033640000000000024, -0.0007530000000000002, -0.007101000000000001, -0.015311000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tebc2e0b178e243eb96ce6a48337da5c7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf1113171570b4b23b808789d04c37539","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012040000000000002, -0.001235, -0.001242, -0.0006910000000000006, -0.003504, -0.0007740000000000004, -0.006779, -0.014953000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf1113171570b4b23b808789d04c37539","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta84efb7a3fdf43bab2048524c6263a1e","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.000000000002e-06, -1.000000000001e-06, -0.0011680000000000006, -0.0011780000000000002, -0.0011880000000000016, -0.0006519999999999998, -0.003143, -0.0007510000000000017, -0.006554000000000001, -0.014592], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta84efb7a3fdf43bab2048524c6263a1e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf2c48138103341ceb52be3ed704442aa","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011789999999999995, -0.0011890000000000008, -0.0011990000000000004, -0.0006340000000000009, -0.003174999999999999, -0.0007650000000000001, -0.007004, -0.014759], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf2c48138103341ceb52be3ed704442aa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td9f515ebdfa648529be4e94d9bce4f0a","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0011610000000000006, -0.0011780000000000002, -0.0011820000000000008, -0.0007150000000000004, -0.0036110000000000014, -0.0008190000000000003, -0.006599000000000001, -0.014579], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td9f515ebdfa648529be4e94d9bce4f0a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t04f99ce6f86e4773a5149628ea51fe1b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0011059999999999993, -0.0011199999999999995, -0.001129999999999999, -0.0006849999999999998, -0.0035600000000000007, -0.0007039999999999998, -0.006804, -0.014158], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t04f99ce6f86e4773a5149628ea51fe1b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t54c00daf250d48eba0c03e2e4ae0db6f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0011470000000000004, -0.001164, -0.0011780000000000002, -0.0006610000000000019, -0.0032270000000000007, -0.0007039999999999998, -0.006684000000000001, -0.015063], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t54c00daf250d48eba0c03e2e4ae0db6f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1b2a9194eb6b4c5490fe4dcafb6ef53a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0011359999999999999, -0.0011579999999999993, -0.0011699999999999992, -0.0006890000000000004, -0.00332, -0.0006930000000000009, -0.006494, -0.015028999999999999], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1b2a9194eb6b4c5490fe4dcafb6ef53a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta3fae4ed8bbd4a5ab590054dae1f040b","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, 0.0, -0.0011690000000000016, -0.0011949999999999999, -0.0012040000000000002, -0.0006650000000000007, -0.003458000000000001, -0.0007950000000000006, -0.006427, -0.015193], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta3fae4ed8bbd4a5ab590054dae1f040b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t012539a827ef4719bfafde3c24b8e41c","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0011859999999999996, -0.0011949999999999999, -0.0011999999999999997, -0.0006959999999999987, -0.003373000000000001, -0.0008680000000000007, -0.006406, -0.016004], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t012539a827ef4719bfafde3c24b8e41c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t339f2a1a909d4aa49b0d77ffdf05b14f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012010000000000007, -0.001210000000000001, -0.0012120000000000013, -0.0006430000000000012, -0.003633000000000001, -0.0007160000000000014, -0.006325000000000001, -0.015948], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t339f2a1a909d4aa49b0d77ffdf05b14f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta5aed95d77634be6921576059e6e80e3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001217000000000001, -0.0012270000000000007, -0.0012280000000000017, -0.0006960000000000022, -0.003270000000000002, -0.0008030000000000016, -0.006275000000000001, -0.016507], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta5aed95d77634be6921576059e6e80e3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t781121d5c8394d1ca515103ff89d9de4","vertex_data","graph vertex data",["x", "y"],[[-3.469446951953614e-18, -3.469446951953614e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, 0.0, -0.0011940000000000006, -0.0011990000000000021, -0.0012000000000000014, -0.000674000000000001, -0.003550000000000001, -0.0007970000000000026, -0.005826000000000001, -0.015838], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t781121d5c8394d1ca515103ff89d9de4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbd1a0d5ead3a490cb12abea3d5ae294b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0012510000000000021, -0.0012910000000000022, -0.0012930000000000025, -0.0007800000000000012, -0.0033920000000000027, -0.0008210000000000023, -0.006900000000000002, -0.016098], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tbd1a0d5ead3a490cb12abea3d5ae294b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc896ad0500cf4dd0bb7c51370f06d66e","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999975306e-07, 0.0, -0.0013099999999999987, -0.0013159999999999995, -0.0013179999999999997, -0.0007659999999999993, -0.0031319999999999994, -0.0008319999999999994, -0.006647999999999999, -0.015781], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc896ad0500cf4dd0bb7c51370f06d66e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4ae017cb284c4d43b56311c1f199e5a9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.001165000000000001, -0.0012060000000000005, -0.0012080000000000007, -0.0007489999999999997, -0.003419, -0.0007939999999999996, -0.0068070000000000006, -0.014790000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4ae017cb284c4d43b56311c1f199e5a9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t04655a33c4a34641a89c89096391c1d6","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011289999999999998, -0.0011649999999999994, -0.001169, -0.0006999999999999992, -0.003398, -0.000785000000000001, -0.006583, -0.014976], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t04655a33c4a34641a89c89096391c1d6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfcf472b591df49fea48d444ad6fb7b29","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.0000000000044695e-06, -0.001277000000000002, -0.0012650000000000022, -0.001297000000000003, -0.0007460000000000019, -0.003511000000000002, -0.0008580000000000011, -0.006427000000000002, -0.015725000000000003], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfcf472b591df49fea48d444ad6fb7b29","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc8b185f4881245259d9b7ae4a58ef762","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, -9.999999999975306e-07, -0.0013379999999999972, -0.001336999999999998, -0.0013459999999999982, -0.000677999999999998, -0.003590999999999997, -0.0008479999999999981, -0.006425999999999998, -0.016005], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc8b185f4881245259d9b7ae4a58ef762","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te403baed17924ddf8e42d7b9702d54a5","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.001340000000000001, -0.0013390000000000016, -0.0013460000000000017, -0.0007450000000000009, -0.0034930000000000013, -0.0009220000000000009, -0.006294000000000001, -0.015565], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te403baed17924ddf8e42d7b9702d54a5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tffd7531ee35345bfb9c55ad0b51193dc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013640000000000006, -0.0013769999999999998, -0.0013819999999999995, -0.000674000000000001, -0.003124, -0.0009160000000000001, -0.006836, -0.016128], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tffd7531ee35345bfb9c55ad0b51193dc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6c68b917b1af4327b176544bc00c962d","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, -0.0013399999999999992, -0.0013799999999999993, -0.0013869999999999993, -0.000678999999999999, -0.0035390000000000005, -0.0008319999999999994, -0.006813, -0.015815], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6c68b917b1af4327b176544bc00c962d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1e29f5accf0d45e58b522edcc90d95bb","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012780000000000014, -0.001289000000000002, -0.001294, -0.0005509999999999994, -0.003471, -0.0007519999999999992, -0.0068980000000000005, -0.014477], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1e29f5accf0d45e58b522edcc90d95bb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t64d19abb08aa4ddb94e8a65b016ae902","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012469999999999998, -0.0012490000000000001, -0.001254, -0.0005839999999999995, -0.003549, -0.0006690000000000012, -0.0063820000000000005, -0.014291], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t64d19abb08aa4ddb94e8a65b016ae902","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teed6e8de2d3b4cd590b417a3412aec18","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013220000000000003, -0.0013430000000000004, -0.0013490000000000012, -0.0006610000000000001, -0.003680000000000001, -0.0008740000000000015, -0.006549000000000001, -0.014909], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teed6e8de2d3b4cd590b417a3412aec18","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf137fb03d77c472ca330c0ac06104fff","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0013609999999999994, -0.0013569999999999988, -0.0013670000000000002, -0.0006429999999999995, -0.0033959999999999997, -0.0007620000000000005, -0.006898, -0.015217], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf137fb03d77c472ca330c0ac06104fff","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te44834836ada4dedb505c444ff0fe969","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013109999999999997, -0.001301, -0.0013150000000000002, -0.0006040000000000004, -0.003306, -0.0008009999999999996, -0.006448000000000001, -0.015151000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te44834836ada4dedb505c444ff0fe969","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfaf9004d70884efc85fb1d755512e7a3","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012930000000000007, -0.0012930000000000007, -0.0013000000000000008, -0.0005880000000000017, -0.003077, -0.0006640000000000014, -0.006734, -0.014807], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfaf9004d70884efc85fb1d755512e7a3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t132e0233e66b4f81968967566c1d0b06","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0012239999999999994, -0.001229000000000001, -0.001243000000000001, -0.0006200000000000008, -0.0032130000000000006, -0.0007090000000000013, -0.006864, -0.014241], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t132e0233e66b4f81968967566c1d0b06","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t07d906612ae148b19a817728f88147c8","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0012180000000000003, -0.0012879999999999992, -0.0012899999999999995, -0.0006149999999999992, -0.0036769999999999997, -0.0007089999999999996, -0.007011999999999999, -0.014913], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t07d906612ae148b19a817728f88147c8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7f76a77efa014910a93f6260ea9fff28","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012530000000000006, -0.0012970000000000013, -0.0012990000000000015, -0.0007170000000000024, -0.0032060000000000005, -0.0008120000000000002, -0.006809000000000001, -0.015005000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7f76a77efa014910a93f6260ea9fff28","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89ff0431c966480bae3cee4ad71989c7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0013130000000000017, -0.0013240000000000005, -0.0013260000000000008, -0.0007390000000000001, -0.002955000000000001, -0.0007559999999999997, -0.007383000000000001, -0.015019000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89ff0431c966480bae3cee4ad71989c7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t683fa832454a466794108d023c0cd49a","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.0000000000044695e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.001400000000000002, -0.001406000000000001, -0.001408000000000003, -0.000682000000000002, -0.0029500000000000012, -0.0007650000000000018, -0.006706000000000002, -0.015831], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t683fa832454a466794108d023c0cd49a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0dc16c269eae4e9a9db0cdd89f2bc81f","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999975306e-07, -0.0014769999999999991, -0.0014769999999999991, -0.0014789999999999977, -0.0006449999999999997, -0.003480999999999998, -0.0009099999999999976, -0.006540999999999998, -0.016158], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0dc16c269eae4e9a9db0cdd89f2bc81f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb26db005bf484c2ba11d8339f93a55f9","vertex_data","graph vertex data",["x", "y"],[[-3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0015400000000000014, -0.0015420000000000017, -0.0015420000000000017, -0.0006510000000000023, -0.0031940000000000007, -0.0008760000000000018, -0.006530000000000001, -0.016427], [5.0, 8.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb26db005bf484c2ba11d8339f93a55f9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t47a132f5483f4525acb01b991bc2ac12","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -9.999999999992654e-07, -2.000000000002e-06, -0.0015110000000000002, -0.0015130000000000005, -0.0015130000000000005, -0.0006919999999999999, -0.002836, -0.0008059999999999994, -0.0065520000000000005, -0.015347000000000001], [5.0, 7.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t47a132f5483f4525acb01b991bc2ac12","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tba63c95537a94ea3a6c3a413452960e6","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.001466000000000002, -0.0014670000000000013, -0.0014680000000000006, -0.0007710000000000009, -0.003250000000000001, -0.0008830000000000018, -0.006735000000000001, -0.015258], [7.0, 8.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 5.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tba63c95537a94ea3a6c3a413452960e6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td35e3851d63843b1ad514fef0f4dd3fb","vertex_data","graph vertex data",["x", "y"],[[-1.9999999999985307e-06, -1.9999999999985307e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.001540999999999999, -0.0015449999999999995, -0.0015469999999999998, -0.0008190000000000003, -0.0034979999999999994, -0.0010369999999999997, -0.0076159999999999995, -0.016104], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td35e3851d63843b1ad514fef0f4dd3fb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcf320384815a40a094727ac9b16fd976","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0014009999999999995, -0.0014020000000000005, -0.0014070000000000003, -0.0008009999999999996, -0.0031409999999999997, -0.000876, -0.00643, -0.015355], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcf320384815a40a094727ac9b16fd976","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc979562535ed4908943ebfe6ee3b85bf","vertex_data","graph vertex data",["x", "y"],[[-1.9999999999985307e-06, -1.9999999999985307e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.001377999999999999, -0.001384999999999999, -0.0013939999999999994, -0.0006669999999999992, -0.0034779999999999985, -0.0008619999999999982, -0.006695999999999999, -0.015503], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc979562535ed4908943ebfe6ee3b85bf","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc76afac84519403e9980843aa84ec3d9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013299999999999996, -0.0013419999999999994, -0.0013480000000000002, -0.0006269999999999991, -0.003450999999999999, -0.0007759999999999989, -0.0073279999999999994, -0.015347], [7.0, 8.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc76afac84519403e9980843aa84ec3d9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd83d51adaca4049876dd932beeb9e81","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013430000000000004, -0.0013509999999999998, -0.0013550000000000003, -0.0006590000000000016, -0.0037470000000000003, -0.0007150000000000004, -0.0066560000000000005, -0.015433], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd83d51adaca4049876dd932beeb9e81","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8afa645d72b24328a8648a52ae18a036","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -1.9999999999985307e-06, -1.9999999999985307e-06, -1.9999999999985307e-06, -9.999999999975306e-07, -0.0012829999999999994, -0.0013049999999999989, -0.0013059999999999981, -0.0006909999999999989, -0.0035139999999999998, -0.0007169999999999989, -0.006362999999999999, -0.015641], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8afa645d72b24328a8648a52ae18a036","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1f74e2ca4774192bc45c77389fb9984","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0012619999999999992, -0.0012659999999999998, -0.0012700000000000003, -0.0006560000000000003, -0.003141999999999999, -0.0007169999999999989, -0.0068059999999999996, -0.014903], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te1f74e2ca4774192bc45c77389fb9984","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t854ae12e29334dd7b4fc84df6cb0489d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0013059999999999999, -0.0013089999999999994, -0.001321000000000001, -0.0006680000000000002, -0.003632999999999999, -0.0008229999999999991, -0.00703, -0.014992], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t854ae12e29334dd7b4fc84df6cb0489d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a898793dfe549578e94250e9a04d98c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012729999999999998, -0.0012779999999999996, -0.0012839999999999987, -0.0006870000000000001, -0.0033819999999999996, -0.0007369999999999998, -0.0067139999999999995, -0.014558], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a898793dfe549578e94250e9a04d98c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2b493165bf91437a8bb9583a8c6b751c","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013190000000000007, -0.0013220000000000003, -0.001327, -0.0007010000000000002, -0.0036970000000000006, -0.0007810000000000004, -0.007289, -0.015247], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2b493165bf91437a8bb9583a8c6b751c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t10ed08090f714e49903984f8f576dad6","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013109999999999997, -0.0013109999999999997, -0.001321000000000001, -0.000725, -0.003353, -0.0008410000000000015, -0.006753, -0.015202], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t10ed08090f714e49903984f8f576dad6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4cc3b401ca6641a79ea86b1b8f56405c","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.0012460000000000006, -0.0012490000000000001, -0.0012540000000000016, -0.0006580000000000006, -0.0034430000000000016, -0.0006890000000000004, -0.006958000000000001, -0.014328], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4cc3b401ca6641a79ea86b1b8f56405c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te368256baf24474396b9924b3b9b8e0c","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.001216, -0.001217000000000001, -0.0012259999999999997, -0.0005970000000000003, -0.003913, -0.0006399999999999999, -0.00646, -0.014246], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te368256baf24474396b9924b3b9b8e0c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89f6414e40f941f08d6f789d9c85b6c2","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013229999999999995, -0.001337999999999999, -0.001347000000000001, -0.0006549999999999993, -0.0032130000000000006, -0.000723999999999999, -0.007359, -0.015157], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t89f6414e40f941f08d6f789d9c85b6c2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te9b4eb1810654a59a2bd43c37420d515","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.000000000001e-06, -0.0012060000000000005, -0.0012140000000000015, -0.0012190000000000013, -0.0005730000000000006, -0.0035650000000000005, -0.0006050000000000014, -0.006438000000000001, -0.013999000000000001], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te9b4eb1810654a59a2bd43c37420d515","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t08383958abc6409d8e8bdf9cc4591a63","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.001254, -0.0012589999999999997, -0.001268, -0.0005819999999999992, -0.003549, -0.0006639999999999997, -0.0064399999999999995, -0.014244], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t08383958abc6409d8e8bdf9cc4591a63","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td663b1c090b84a5f8b72cef1010638ea","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.000000000002e-06, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -0.0012900000000000012, -0.001294, -0.0012990000000000015, -0.0006610000000000019, -0.0036190000000000007, -0.0007640000000000008, -0.006925000000000001, -0.014373], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td663b1c090b84a5f8b72cef1010638ea","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6cb0e1a7c3ab40249f705080331e3641","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, -0.0012709999999999996, -0.001275, -0.0012790000000000006, -0.0005760000000000001, -0.0034920000000000003, -0.0006550000000000011, -0.00708, -0.014597], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6cb0e1a7c3ab40249f705080331e3641","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9510e02513cb4dff833eaa6c93891692","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012219999999999991, -0.0012329999999999997, -0.0012359999999999993, -0.0005859999999999997, -0.0036489999999999995, -0.0006189999999999998, -0.006666, -0.014662], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9510e02513cb4dff833eaa6c93891692","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e5e47b669124e629968cc7e4b489ce6","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0012570000000000012, -0.0012990000000000015, -0.001301, -0.0006069999999999999, -0.003734000000000001, -0.000678999999999999, -0.006928, -0.015184], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e5e47b669124e629968cc7e4b489ce6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3b9b9899f01b438cb488831d25759096","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012340000000000007, -0.0012490000000000001, -0.0012510000000000004, -0.000589000000000001, -0.0035930000000000007, -0.000595, -0.007069, -0.014464], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3b9b9899f01b438cb488831d25759096","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t027fa6a852184e83abb504944ee96135","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -0.0012110000000000003, -0.0012580000000000004, -0.0012600000000000007, -0.0005669999999999998, -0.0038639999999999994, -0.0007500000000000007, -0.006983, -0.014501], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t027fa6a852184e83abb504944ee96135","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tffa11d8cecb441e899b3dcc9c0f7972b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -0.0012770000000000004, -0.001287, -0.0012900000000000012, -0.0007360000000000005, -0.0034730000000000004, -0.0007830000000000007, -0.006273000000000001, -0.014793], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tffa11d8cecb441e899b3dcc9c0f7972b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t91945cea74e646f9b5d464a8c5092296","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0012810000000000009, -0.0013220000000000003, -0.0013220000000000003, -0.0007740000000000004, -0.0033100000000000004, -0.0007880000000000005, -0.006549000000000001, -0.014863000000000001], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t91945cea74e646f9b5d464a8c5092296","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t03947fe21907431894222b3a1f097b56","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.0012480000000000008, -0.0012640000000000012, -0.0012640000000000012, -0.0007419999999999996, -0.0033110000000000014, -0.0007610000000000013, -0.006389000000000001, -0.014977], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t03947fe21907431894222b3a1f097b56","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2659d1f9598740459380458786511dd4","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013619999999999986, -0.0013740000000000002, -0.0013749999999999995, -0.0008109999999999992, -0.003443999999999999, -0.0008230000000000008, -0.0066619999999999995, -0.015927], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2659d1f9598740459380458786511dd4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t062ad5b0e7a14f58993df8c1e998302f","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0012840000000000004, -0.0012630000000000002, -0.0012840000000000004, -0.0007379999999999991, -0.0038200000000000005, -0.0007640000000000008, -0.006442, -0.014551999999999999], [5.0, 7.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t062ad5b0e7a14f58993df8c1e998302f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfaa2d7d321ba4e16b3e390cfb15731aa","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013190000000000007, -0.001340000000000001, -0.0013430000000000004, -0.0007270000000000002, -0.003384, -0.0007980000000000001, -0.006746, -0.01564], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfaa2d7d321ba4e16b3e390cfb15731aa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5fbc0d2cc4094915af59b3abcace8e0e","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.001328000000000001, -0.001303000000000002, -0.0013370000000000014, -0.0009240000000000012, -0.003256000000000002, -0.0009469999999999999, -0.006131000000000001, -0.01498], [5.0, 7.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5fbc0d2cc4094915af59b3abcace8e0e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(axis, axis_id, projection)
        {
            axis.show_coordinates(axis_id, projection);
        })(modules["toyplot.coordinates.Axis"],"tee40aaa8aa0d4553a0fae55d7a44a324",[{"domain": {"bounds": {"max": Infinity, "min": -Infinity}, "max": 0.0, "min": -0.01677}, "range": {"bounds": {"max": Infinity, "min": -Infinity}, "max": 250.0, "min": 0.0}, "scale": "linear"}]);
})();</script></div></div>


#### Save the plots



```python
toyplot.html.render(canvas, "cloud-test.html")
import toyplot.svg
toyplot.svg.render(canvas, "cloud-test.svg")
```

### Attributes of the Multitree object
Below I list all of the attributes of a multitree object. In a notebook you can use tab-completion to see of all of these. 


```python
## draws a cloudtree (returns (canvas, axes))
## with options similar to draw()
canvas, axes = trees.draw_cloudtree(orient='right');
```


<div class="toyplot" id="t5aba26c279e840d5b7744f5b016c8add" style="text-align:center"><svg class="toyplot-canvas-Canvas" height="225.0px" id="t493499ef62de4bc5bb57012ed1d381bc" preserveAspectRatio="xMidYMid meet" style="background-color:transparent;fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:Helvetica;font-size:12px;opacity:1.0;stroke:rgb(16.1%,15.3%,14.1%);stroke-opacity:1.0;stroke-width:1.0" viewBox="0 0 275.0 225.0" width="275.0px" xmlns="http://www.w3.org/2000/svg" xmlns:toyplot="http://www.sandia.gov/toyplot" xmlns:xlink="http://www.w3.org/1999/xlink"><g class="toyplot-coordinates-Cartesian" id="t7e5785216bbb4ef89da12ef4655aea1b"><clipPath id="tf5e85f140e8a42ebb3484a63d4e0f06d"><rect height="225.0" width="275.0" x="0.0" y="0.0"></rect></clipPath><g clip-path="url(#tf5e85f140e8a42ebb3484a63d4e0f06d)"><g class="toyplot-mark-Text" id="t222670b455dc4061a80ad387824dd3d5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t52aa31c1e5b44694a1a55de2e38438b0"><g class="toyplot-Edges"><path d="M 149.466963667 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.326657552 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.04481709 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.04481709 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.326657552 144.024614419 L 188.04481709 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.909608206 119.943311738 L 168.326657552 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.794965518 95.8620090567 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.839216325 93.2349578551 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.991238476 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.247961391 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.247961391 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.991238476 73.9699157102 L 182.247961391 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.839216325 93.2349578551 L 180.991238476 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.794965518 95.8620090567 L 157.839216325 93.2349578551" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.909608206 119.943311738 L 157.794965518 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.466963667 144.243535352 L 151.909608206 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(182.24796139097523, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.99123847606398, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.83921632530505, 93.234957855093256)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(188.04481709003758, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(157.79496551844198, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.32665755185297, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(151.90960820565348, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(149.46696366681192, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t62ef045655a44f3ab53079046f3c9c46"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6fefcfad67fe47f29cd47a00cf23b82c"><g class="toyplot-Edges"><path d="M 151.281246748 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.512169765 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.620214049 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.620214049 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.512169765 144.024614419 L 190.620214049 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.900894514 119.943311738 L 163.512169765 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 159.255242145 95.8620090567 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 159.35259392 93.2349578551 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.053326076 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.053326076 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 73.9699157102 L 183.053326076 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 159.35259392 93.2349578551 L 182.601967846 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 159.255242145 95.8620090567 L 159.35259392 93.2349578551" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.900894514 119.943311738 L 159.255242145 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.281246748 144.243535352 L 153.900894514 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.05332607588312, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.60196784587981, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(159.35259392002209, 93.234957855093256)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.62021404946836, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(159.25524214492333, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(163.51216976515079, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(153.90089451449171, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(151.28124674819787, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbcef469751834a369b1f02ac613e0f40"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t989ab78f06b742c6b5bf755c732df236"><g class="toyplot-Edges"><path d="M 146.953517837 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.007847037 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.575895007 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.575895007 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.007847037 144.024614419 L 189.575895007 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.776719315 119.943311738 L 165.007847037 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.520474046 95.8620090567 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.582425175 93.2349578551 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.185942026 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.309844285 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.309844285 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.185942026 73.9699157102 L 181.309844285 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.582425175 93.2349578551 L 181.185942026 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.520474046 95.8620090567 L 155.582425175 93.2349578551" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.776719315 119.943311738 L 155.520474046 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.953517837 144.243535352 L 149.776719315 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.30984428547811, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.1859420262615, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(155.58242517528839, 93.234957855093256)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(189.57589500749987, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(155.52047404568012, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(165.00784703712262, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(149.77671931485344, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(146.95351783698948, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t49840927bbe94731ad3f9f98e2dd8d5e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf0a8d18d957b45038d95e70f366539fb"><g class="toyplot-Edges"><path d="M 146.121602668 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.423941092 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.423941092 144.024614419 L 191.91233761 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.272260117 119.943311738 L 167.423941092 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.148767268 95.8620090567 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.35232098 93.2349578551 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.920437185 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.194792188 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.194792188 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.920437185 73.9699157102 L 181.194792188 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.35232098 93.2349578551 L 180.920437185 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.148767268 95.8620090567 L 155.35232098 93.2349578551" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.272260117 119.943311738 L 155.148767268 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.121602668 144.243535352 L 149.272260117 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.19479218763414, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(180.9204371850831, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(155.35232097960042, 93.234957855093256)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.91233760987006, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(155.1487672680303, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(167.4239410918463, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(149.2722601166144, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(146.12160266796371, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t01b187b7c7ad405e87aa357d7df7245f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf2187f860df4440bab92b6e570060b08"><g class="toyplot-Edges"><path d="M 146.749964125 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.468055428 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.664601327 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.664601327 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.468055428 144.024614419 L 192.664601327 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.803269799 121.694679206 L 165.468055428 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.865630339 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.25503744 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.407196061 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.557648804 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.557648804 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.407196061 73.9699157102 L 181.557648804 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.25503744 86.2294879842 L 181.407196061 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.865630339 99.3647439921 L 156.25503744 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 149.803269799 121.694679206 L 155.865630339 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.749964125 145.119219086 L 149.803269799 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.55764880391132, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.40719606057689, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(156.25503743960709, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.66460132654225, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(155.86563033921206, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(165.46805542849856, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(149.80326979897126, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(146.74996412541935, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tce91503888f94d62848005deb01cc0d2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb450ce834a544ec3b32ab5604a2fb535"><g class="toyplot-Edges"><path d="M 143.634707322 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.910563497 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.682301649 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.682301649 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.910563497 144.024614419 L 192.682301649 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.97121816 121.694679206 L 165.910563497 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.184031443 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.343334348 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.256675082 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.442528471 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.442528471 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.256675082 73.9699157102 L 180.442528471 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.343334348 86.2294879842 L 180.256675082 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.184031443 99.3647439921 L 153.343334348 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.97121816 121.694679206 L 153.184031443 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.634707322 145.119219086 L 146.97121816 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.44252847096192, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.25667508213701, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(153.34333434801698, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.68230164928747, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(153.18403144330992, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(165.91056349712926, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(146.97121815973469, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(143.63470732225912, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9e08dcc2371d4a528acb566b0b00f5af"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9e5daa44288749cfb2ca50f0eb29ea8f"><g class="toyplot-Edges"><path d="M 141.625720691 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.981501258 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.876936964 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.876936964 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.981501258 144.024614419 L 191.876936964 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.245368457 121.694679206 L 167.981501258 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.307797232 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.608702719 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.477860881 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.946919434 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.946919434 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.477860881 73.9699157102 L 179.946919434 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.608702719 86.2294879842 L 179.477860881 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 151.307797232 99.3647439921 L 151.608702719 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.245368457 121.694679206 L 151.307797232 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.625720691 145.119219086 L 144.245368457 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.94691943409555, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.47786088134697, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(151.6087027189846, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.87693696437958, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(151.30779723231569, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.981501258321, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(144.24536845696952, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(141.62572069067568, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9a90dcf4c8b5448392ea6fff18079cc8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4399cf4722cd40f0854feacb2a98f78a"><g class="toyplot-Edges"><path d="M 143.838261034 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.928673231 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 133.516409613 L 198.399505896 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 133.516409613 L 198.399505896 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.928673231 144.024614419 L 191.91233761 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.511009768 121.694679206 L 171.928673231 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.776992255 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.87434403 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.619531698 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.858486055 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.858486055 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.619531698 73.9699157102 L 180.858486055 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.87434403 86.2294879842 L 180.619531698 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.776992255 99.3647439921 L 153.87434403 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.511009768 121.694679206 L 153.776992255 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.838261034 145.119219086 L 146.511009768 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599633, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599633, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(180.85848605547477, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(180.61953169841422, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(153.87434403037383, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.91233760987006, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(153.7769922552751, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(171.928673230507, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(146.51100976835878, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(143.83826103382927, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3e57db77a9ac4f868ea1379ad1dedf65"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t57ebccbfe0e4491c869d8d40d7fd0384"><g class="toyplot-Edges"><path d="M 144.944531205 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.203232938 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.664601327 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.664601327 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.203232938 144.024614419 L 192.664601327 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 147.493377681 121.694679206 L 175.203232938 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.086816138 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.22841872 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.070889928 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.194792188 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.194792188 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.070889928 73.9699157102 L 181.194792188 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.22841872 86.2294879842 L 181.070889928 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.086816138 99.3647439921 L 155.22841872 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 147.493377681 121.694679206 L 155.086816138 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.944531205 145.119219086 L 147.493377681 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.19479218763414, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.07088992841753, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(155.22841872038384, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.66460132654225, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(155.08681613842197, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(175.20323293837424, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(147.49337768071894, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(144.94453120540604, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdcf437f54d2f46c7a018a981d889553c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2679d76b34ed443da830d4630a919aad"><g class="toyplot-Edges"><path d="M 148.528846561 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.707692137 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.707692137 144.024614419 L 192.080490676 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 150.599784323 121.694679206 L 175.707692137 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.423326976 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.635730849 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.37186365 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.469215425 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.469215425 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.37186365 73.9699157102 L 182.469215425 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.635730849 86.2294879842 L 182.37186365 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.423326976 99.3647439921 L 158.635730849 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 150.599784323 121.694679206 L 158.423326976 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 148.528846561 145.119219086 L 150.599784323 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.4692154252906, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.37186365019187, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(158.63573084884035, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.0804906759497, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(158.4233269758976, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(175.7076921366133, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(150.59978432250657, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(148.52884656131482, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1816d47fbe654ddaab8f74fe60fa09b8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5c04ee1d2eac4d19ac3025f884a7b4c0"><g class="toyplot-Edges"><path d="M 143.333801836 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 144.024614419 L 192.381396163 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.802996859 121.694679206 L 177.442323766 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.467304842 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.104516461 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.752284119 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.796534926 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.796534926 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.752284119 73.9699157102 L 180.796534926 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.104516461 86.2294879842 L 180.752284119 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.467304842 99.3647439921 L 155.104516461 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.802996859 121.694679206 L 154.467304842 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.333801836 145.119219086 L 145.802996859 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.7965349258665, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.75228411900343, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(155.10451646116724, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.38139616261856, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(154.46730484233902, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.44232376564568, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(145.80299685854962, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(143.33380183559024, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t581f051cb0df4e24b3585728dd530e89"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdf2f39ecb15a4bfba0595d3e7a710bb6"><g class="toyplot-Edges"><path d="M 144.758677817 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.778561663 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.778561663 144.024614419 L 192.505298422 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 147.210172517 121.694679206 L 176.778561663 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.139985342 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.865698574 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.221342672 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.265593479 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.265593479 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.221342672 73.9699157102 L 181.265593479 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.865698574 86.2294879842 L 181.221342672 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.139985342 99.3647439921 L 156.865698574 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 147.210172517 121.694679206 L 156.139985342 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.758677817 145.119219086 L 147.210172517 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.26559347861505, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.22134267175196, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(156.86569857431749, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.50529842183516, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(156.13998534176309, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(176.77856166269962, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(147.2101725167953, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(144.75867781658113, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3449551b444d452d862ea4a3fab8c7bf"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t33fcb132a61b43bfa163fcd55dd3269a"><g class="toyplot-Edges"><path d="M 141.43101714 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.229783422 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.806067438 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.806067438 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.229783422 144.024614419 L 190.806067438 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.103765875 121.694679206 L 175.229783422 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.830093224 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.467304842 86.2294879842 L 198.399505896 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.132772823 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.168173468 63.4617109039 L 198.399505896 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.168173468 63.4617109039 L 198.399505896 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.132772823 73.9699157102 L 180.168173468 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.467304842 86.2294879842 L 180.132772823 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.830093224 99.3647439921 L 154.467304842 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.103765875 121.694679206 L 153.830093224 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.43101714 145.119219086 L 144.103765875 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.16817346841088, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.1327728229204, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(154.46730484233902, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(190.80606743829327, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(153.83009322351077, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(175.22978342249212, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(144.1037658750077, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.43101714047816, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8d0254cc04d84f1d9032d4393834d88b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t41fc181587734eed99e73da108cede90"><g class="toyplot-Edges"><path d="M 142.209831341 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.18505497 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.416728573 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.416728573 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.18505497 144.024614419 L 191.416728573 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.289687499 121.694679206 L 168.18505497 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.732809684 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.458522916 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.495629439 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.56643073 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.56643073 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.495629439 73.9699157102 L 180.56643073 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 155.458522916 86.2294879842 L 180.495629439 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.732809684 99.3647439921 L 155.458522916 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.289687499 121.694679206 L 154.732809684 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.209831341 145.119219086 L 145.289687499 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.56643073017852, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(180.49562943919759, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(155.45852291607179, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.41672857300364, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(154.73280968351742, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.18505496989113, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(145.28968749893798, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(142.2098313412682, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t569ccfd0002947ee8a7de68c6bc4e715"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t21fbb93fda994175b089a87fb19df6e7"><g class="toyplot-Edges"><path d="M 143.705508613 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.884422424 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.328295194 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.328295194 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.884422424 144.024614419 L 192.328295194 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.095052184 121.694679206 L 171.884422424 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.13113518 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.715245831 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.01778896 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.053189606 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.053189606 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.01778896 73.9699157102 L 181.053189606 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.715245831 86.2294879842 L 181.01778896 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.13113518 99.3647439921 L 156.715245831 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.095052184 121.694679206 L 156.13113518 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.705508613 145.119219086 L 146.095052184 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.05318960567232, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.01778896018186, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(156.71524583098301, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.32829519438289, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(156.13113518039049, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.88442242364394, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(146.09505218384587, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(143.70550861324003, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf8eefc06fa414cf0b459170cc03e56c0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdd921c04c783475398a0c7dfa155f6ed"><g class="toyplot-Edges"><path d="M 139.864538578 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.476973825 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.476973825 144.024614419 L 191.761884867 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.528437151 121.694679206 L 166.476973825 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.299083541 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.830093224 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.743365723 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.85841782 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.85841782 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.743365723 73.9699157102 L 179.85841782 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.830093224 86.2294879842 L 179.743365723 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 153.299083541 99.3647439921 L 153.830093224 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.528437151 121.694679206 L 153.299083541 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.864538578 145.119219086 L 142.528437151 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(179.85841782036937, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(179.7433657225254, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(153.83009322351077, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.76188486653561, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(153.29908354115392, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(166.47697382497657, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(142.52843715068232, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(139.86453857752542, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te1955b7e095d4f30ac8b1f930ff2fd6c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t42c4e169a7354be09437f44a81ed21b7"><g class="toyplot-Edges"><path d="M 140.953108426 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.760315459 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.760315459 144.024614419 L 192.62035052 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.572756193 121.694679206 L 168.760315459 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.423054035 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.945213556 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.168173468 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.601831376 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.601831376 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.168173468 73.9699157102 L 180.601831376 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.945213556 86.2294879842 L 180.168173468 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 154.423054035 99.3647439921 L 154.945213556 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.572756193 121.694679206 L 154.423054035 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.953108426 145.119219086 L 143.572756193 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.60183137566901, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.16817346841088, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(154.94521355646017, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.62035051967919, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(154.42305403547593, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.76031545911107, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(143.57275619265084, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(140.95310842635701, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te6532f6b88fa4cdbb34edc2dbfa0998a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tca1d2b27413c4b5aaede2bc3cabf3b90"><g class="toyplot-Edges"><path d="M 143.324951674 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.92812735 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.620418755 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.620418755 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.92812735 144.024614419 L 193.620418755 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.997700409 121.694679206 L 163.92812735 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.679845185 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.317056804 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.07974009 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.21249251 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.21249251 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.07974009 73.9699157102 L 181.21249251 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.317056804 86.2294879842 L 181.07974009 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.679845185 99.3647439921 L 157.317056804 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.997700409 121.694679206 L 156.679845185 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.324951674 145.119219086 L 145.997700409 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.21249251037938, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.07974008979016, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(157.31705680432083, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.62041875478459, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(156.67984518549258, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(163.92812734966367, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(145.99770040874714, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(143.32495167421763, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4b07f47d828d4b17bc47c8dc9773cf8a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf7118d8149644b8f97574a40126d9965"><g class="toyplot-Edges"><path d="M 142.554987635 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.883944778 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.000975694 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.000975694 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.883944778 144.024614419 L 194.000975694 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.705645083 121.694679206 L 164.883944778 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.184236149 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.768346799 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.752284119 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.008938799 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.008938799 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.752284119 73.9699157102 L 181.008938799 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.768346799 86.2294879842 L 180.752284119 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.184236149 99.3647439921 L 156.768346799 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.705645083 121.694679206 L 156.184236149 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.554987635 145.119219086 L 145.705645083 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.00893879880925, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.75228411900343, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(156.76834679921873, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(194.00097569380699, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(156.18423614862616, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(164.88394477790601, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(145.70564508345086, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(142.55498763480017, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb79178ca5c4c43278b64dbd09ccccb13"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tffc653747caf4eda91cd80f502deb3fe"><g class="toyplot-Edges"><path d="M 142.793941992 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.627426568 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.089409072 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.089409072 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.627426568 144.024614419 L 193.089409072 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.643693954 121.694679206 L 166.627426568 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.70639567 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.48520987 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.893886701 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.646150418 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.646150418 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.893886701 73.9699157102 L 181.646150418 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.48520987 86.2294879842 L 180.893886701 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.70639567 99.3647439921 L 157.48520987 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 145.643693954 121.694679206 L 156.70639567 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.793941992 145.119219086 L 145.643693954 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.64615041763744, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(180.89388670096525, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(157.48520987040047, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(193.08940907242774, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(156.7063956696104, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(166.62742656831102, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(145.64369395384256, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(142.79394199186075, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1bc11eb8c2c2448db96d1cb3038b0312"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc2569b6c0f8f4d6fbdb08c3b208b2e59"><g class="toyplot-Edges"><path d="M 141.077010686 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.600876084 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.089477308 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.089477308 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.600876084 144.024614419 L 194.089477308 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.378120878 121.694679206 L 166.600876084 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.104584696 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.09580277 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.061971532 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.637232021 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.637232021 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.061971532 73.9699157102 L 180.637232021 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 157.09580277 86.2294879842 L 180.061971532 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.104584696 99.3647439921 L 157.09580277 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.378120878 121.694679206 L 156.104584696 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.077010686 145.119219086 L 144.378120878 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.63723202115943, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(180.06197153193949, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(157.09580277000546, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(194.08947730753314, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(156.10458469627264, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(166.60087608419315, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(144.37812087755873, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.07701068557361, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t29e93ecdb7664dfdb0a2c1f55302f7f5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2cb7038c66c3404eb7af9b529bd44d8a"><g class="toyplot-Edges"><path d="M 138.891020827 145.119219086 L 198.399505896 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.901986276 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.257562139 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.257562139 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.901986276 144.024614419 L 193.257562139 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.554987635 121.694679206 L 169.901986276 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.467441313 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.741932785 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.168105233 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.973469918 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.973469918 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.168105233 73.9699157102 L 179.973469918 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.741932785 86.2294879842 L 179.168105233 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 156.467441313 99.3647439921 L 158.741932785 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.554987635 121.694679206 L 156.467441313 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.891020827 145.119219086 L 142.554987635 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(179.97346991821337, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(179.16810523330548, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(158.74193278531172, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.25756213850741, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(156.46744131254982, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.90198627617832, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(142.55498763480017, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.89102082653787, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdafdb6bf29d64829abd945387c710f63"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td5867096d3b54acfb96892d6d6e37cef"><g class="toyplot-Edges"><path d="M 136.775832258 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.521292867 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.521292867 144.024614419 L 193.248711977 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.855756651 121.694679206 L 167.521292867 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 161.697886684 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.512169765 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.433610074 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.575212656 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.575212656 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.433610074 73.9699157102 L 179.575212656 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.512169765 86.2294879842 L 179.433610074 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 161.697886684 99.3647439921 L 163.512169765 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.855756651 121.694679206 L 161.697886684 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.775832258 145.119219086 L 140.855756651 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.57521265644573, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(179.43361007448391, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(163.51216976515079, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.2487119771348, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(161.69788668376489, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.52129286694506, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.85575665125822, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(136.77583225848304, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf25fd7ed83684855bd59674d51091cf5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t86e3604794a642a38d488d4299d02bea"><g class="toyplot-Edges"><path d="M 133.660575455 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.476700885 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.476700885 144.024614419 L 193.045158266 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.846701785 121.694679206 L 162.476700885 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.804156855 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.848544132 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.247688451 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.345040226 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.345040226 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.247688451 73.9699157102 L 178.345040226 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.848544132 86.2294879842 L 178.247688451 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 162.804156855 99.3647439921 L 164.848544132 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.846701785 121.694679206 L 162.804156855 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.660575455 145.119219086 L 137.846701785 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.34504022565235, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.24768845055357, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(164.84854413241555, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.04515826556465, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(162.80415685534163, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(162.47670088455493, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(137.84670178456938, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(133.66057545532283, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8fa919fe22734d82961c1e6f7281c328"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6de88a4bf7f24f529211fdc279571bf2"><g class="toyplot-Edges"><path d="M 132.926012061 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.167013472 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.167013472 144.024614419 L 193.248711977 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.112138391 121.694679206 L 163.167013472 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.618508172 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.423872857 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.11493603 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.185737321 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.185737321 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.11493603 73.9699157102 L 178.185737321 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.423872857 86.2294879842 L 178.11493603 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.618508172 99.3647439921 L 166.423872857 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.112138391 121.694679206 L 165.618508172 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.926012061 145.119219086 L 137.112138391 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.18573732094529, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.11493602996435, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.4238728567409, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.2487119771348, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(165.61850817183301, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(163.16701347161884, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.11213839064237, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(132.92601206139582, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4aa276a1e54f493da704847b31535b09"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcf81e12199684abda75fb0bb52b3fca4"><g class="toyplot-Edges"><path d="M 131.271031885 144.900298153 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.361989962 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.841604554 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.841604554 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.361989962 144.024614419 L 192.841604554 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.88196596 121.256837339 L 167.361989962 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.680459301 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.742478666 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.849431189 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.875981673 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.875981673 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.849431189 70.4671807747 L 177.875981673 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.742478666 84.4781205165 L 177.849431189 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.680459301 98.4890602582 L 166.742478666 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.88196596 121.256837339 L 165.680459301 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.271031885 144.900298153 L 135.88196596 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.87598167290378, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.84943118878596, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(166.74247866615502, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.84160455399456, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(165.68045930144129, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(167.36198996223803, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(135.88196595984903, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(131.27103188471696, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9dfb6ee361bb4643b4dbb48ae044cad9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9daffcd106ff410391aeed898c33f3ef"><g class="toyplot-Edges"><path d="M 128.846087669 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.28233851 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.611500358 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.611500358 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.28233851 144.024614419 L 192.611500358 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.669425617 120.818995472 L 167.28233851 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.804293326 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.06101624 82.7267530488 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.15026844 66.9644458393 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.176818924 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.176818924 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.15026844 66.9644458393 L 177.176818924 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.06101624 82.7267530488 L 177.15026844 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.804293326 97.6133765244 L 166.06101624 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.669425617 120.818995472 L 164.804293326 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.846087669 144.681377219 L 133.669425617 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.17681892446726, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.15026844034944, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.06101624046372, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.61150035830656, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(164.80429332555252, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(167.28233850988448, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(133.66942561669543, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(128.84608766862064, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td304d1f766604c42aa9b837f1209ec01"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb07ea5f9c05f4ef385bda6d76844c01e"><g class="toyplot-Edges"><path d="M 128.421279923 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.945964143 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.133591644 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.133591644 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.945964143 144.024614419 L 192.133591644 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.483572228 120.818995472 L 165.945964143 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.777811077 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.839830441 82.7267530488 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.309571345 66.9644458393 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.344971991 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.344971991 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.309571345 66.9644458393 L 177.344971991 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.839830441 82.7267530488 L 177.309571345 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.777811077 97.6133765244 L 166.839830441 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.483572228 120.818995472 L 165.777811077 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.421279923 144.681377219 L 133.483572228 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(177.34497199054692, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(177.30957134505647, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(166.83983044125378, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.13359164418537, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(165.77781107654008, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(165.94596414261974, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(133.48357222787052, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(128.42127992273518, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdbf3ac0a118a4c06a841c66177cc2e4e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8849c004139c43139dbe1591cc50bfc0"><g class="toyplot-Edges"><path d="M 128.554032343 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.919277188 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.593800036 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.593800036 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.919277188 144.024614419 L 192.593800036 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.333051249 121.694679206 L 163.919277188 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.822130119 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.972651097 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.557375863 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.592776509 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.592776509 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.557375863 73.9699157102 L 177.592776509 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.972651097 86.2294879842 L 177.557375863 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.822130119 99.3647439921 L 167.972651097 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.333051249 121.694679206 L 166.822130119 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.554032343 145.119219086 L 132.333051249 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(177.59277650898011, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(177.55737586348968, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.9726510969484, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.59380003556137, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(166.82213011850854, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(163.91927718829109, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(132.33305124943067, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(128.55403234332437, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9d55d83bc74944c0ade537f860839496"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1f5787067c704b40ba01f99b0523904d"><g class="toyplot-Edges"><path d="M 128.279677341 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.777674606 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.777674606 144.024614419 L 192.142441806 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.36852013 121.694679206 L 163.777674606 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.131954002 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.18519144 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.433473604 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.46887425 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.46887425 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.433473604 73.9699157102 L 177.46887425 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.18519144 86.2294879842 L 177.433473604 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.131954002 99.3647439921 L 170.18519144 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.36852013 121.694679206 L 168.131954002 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 128.279677341 145.119219086 L 133.36852013 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(177.4688742497635, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(177.43347360427305, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(170.18519144010196, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.14244180555801, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.13195400165546, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(163.77767460632921, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(133.36852013002652, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(128.27967734077333, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb5cbf067e02f46b0868e2d68cdc7e851"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdce309a51b0446889cf2b1b98eae05d5"><g class="toyplot-Edges"><path d="M 127.279609106 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.467577783 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.912405845 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.912405845 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 158.467577783 144.024614419 L 192.912405845 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.598624326 121.694679206 L 158.467577783 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.981501258 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.831389691 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.937864567 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.672427961 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.672427961 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.937864567 73.9699157102 L 177.672427961 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.831389691 86.2294879842 L 176.937864567 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.981501258 99.3647439921 L 172.831389691 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.598624326 121.694679206 L 167.981501258 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 127.279609106 145.119219086 L 133.598624326 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(177.67242796133365, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(176.93786456740668, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(172.83138969051365, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.91240584497544, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.981501258321, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(158.46757778276066, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(133.59862432571452, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(127.27960910566793, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6e42a3304743405fa354c4f4800100b0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5c36bbcc713d4de3ac2e49eb63925c5a"><g class="toyplot-Edges"><path d="M 124.73076263 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.715859947 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.195474539 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.195474539 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.715859947 144.024614419 L 191.195474539 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.156048022 121.694679206 L 165.715859947 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.83125322 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.619122288 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.336121829 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.336121829 73.9699157102 L 177.442323766 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.619122288 86.2294879842 L 177.336121829 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.83125322 99.3647439921 L 174.619122288 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.156048022 121.694679206 L 170.83125322 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 124.73076263 145.119219086 L 132.156048022 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.44232376564568, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.33612182917435, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(174.61912228778172, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.1954745386883, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(170.83125322030284, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(165.71585994693174, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(132.15604802197839, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(124.73076263035502, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tba4a68d826a34a128206d6240a9f1549"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t506fe1fe8c6c4728bbb5efe5537a333d"><g class="toyplot-Edges"><path d="M 124.359055853 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.892931409 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.892931409 144.024614419 L 192.080490676 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.085314966 121.694679206 L 166.892931409 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.424350502 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.858213115 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.424623443 73.9699157102 L 198.399505896 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.477724411 63.4617109039 L 198.399505896 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.477724411 63.4617109039 L 198.399505896 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.424623443 73.9699157102 L 177.477724411 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.858213115 86.2294879842 L 177.424623443 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.424350502 99.3647439921 L 176.858213115 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.085314966 121.694679206 L 173.424350502 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 124.359055853 145.119219086 L 133.085314966 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.47772441113614, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.42462344290047, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(176.85821311505313, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.0804906759497, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(173.4243505024788, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.89293140948945, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(133.08531496610289, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(124.35905585270521, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0e0e06b88b484ff69547bdee0c4a9e88"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t22ef0063c2cc4dbe802da172eb7ca58c"><g class="toyplot-Edges"><path d="M 120.066727587 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.636208495 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.142305335 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.142305335 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.636208495 144.024614419 L 190.142305335 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.17368011 121.694679206 L 165.636208495 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.866858571 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.822675999 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.689991814 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.265252303 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.265252303 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.689991814 73.9699157102 L 176.265252303 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.822675999 86.2294879842 L 175.689991814 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.866858571 99.3647439921 L 174.822675999 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.17368011 121.694679206 L 173.866858571 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 120.066727587 145.119219086 L 131.17368011 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(176.265252303088, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(175.68999181386803, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(174.82267599935187, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.14230533534717, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(173.8668585711095, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(165.63620849457823, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(131.1736801096182, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(120.0667275869873, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdc9e428a7e5445f68cc89ae4c0359397"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t168f8a0dc03e41c697bf5bac67b83c90"><g class="toyplot-Edges"><path d="M 116.579764006 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.795579634 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.514080348 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.514080348 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.795579634 144.024614419 L 191.514080348 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.306637236 121.694679206 L 166.795579634 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.893272585 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.300516478 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.01737955 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.999747462 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.999747462 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.01737955 73.9699157102 L 175.999747462 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.300516478 86.2294879842 L 175.01737955 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.893272585 99.3647439921 L 174.300516478 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.306637236 121.694679206 L 171.893272585 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 116.579764006 145.119219086 L 134.306637236 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(175.99974746190955, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(175.01737954954936, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(174.30051647836763, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.51408034810237, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(171.89327258501652, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.79557963439072, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(134.30663723552368, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(116.57976400617724, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t91d5e8e1da3c431a8e4464ac1a5fc140"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t92bbfb6b32ed413a902f154d5b1e6ec5"><g class="toyplot-Edges"><path d="M 121.234948888 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.424077562 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.868086803 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.868086803 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.424077562 144.024614419 L 191.868086803 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.501681961 121.694679206 L 169.424077562 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.229510482 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.583789877 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.911245848 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.132568118 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.132568118 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.911245848 73.9699157102 L 177.132568118 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.583789877 86.2294879842 L 175.911245848 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.229510482 99.3647439921 L 175.583789877 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.501681961 121.694679206 L 171.229510482 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 121.234948888 145.119219086 L 139.501681961 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(177.13256811760422, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(175.91124584818343, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(175.5837898773967, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.86808680300697, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(171.22951048207048, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.42407756205714, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(139.50168196124827, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(121.23494888817238, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0f6cbccf9fba43d881d408afdf285ce1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc0259d6a4f7242ff9a13d5afa69d8e12"><g class="toyplot-Edges"><path d="M 116.199207067 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.73383321 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.73383321 144.024614419 L 191.797285512 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.297650604 121.694679206 L 169.73383321 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.50393372 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.265115833 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.610272126 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.008529388 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.008529388 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.610272126 73.9699157102 L 175.008529388 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.265115833 86.2294879842 L 174.610272126 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.50393372 99.3647439921 L 174.265115833 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.297650604 121.694679206 L 172.50393372 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 116.199207067 145.119219086 L 132.297650604 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(175.00852938817678, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(174.61027212640914, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(174.26511583287717, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.79728551202606, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(172.50393371972692, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(169.73383321009865, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(132.29765060394024, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(116.19920706715484, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf09d3a48c553497f90536446f0c22d21"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="taa53c18d71b54367b593d3c21c750cce"><g class="toyplot-Edges"><path d="M 112.075031868 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.423941092 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.423941092 144.024614419 L 191.65568293 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.589910635 121.694679206 L 167.423941092 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.132158707 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.999610992 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.397868253 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.645672772 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.645672772 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.397868253 73.9699157102 L 174.645672772 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.999610992 86.2294879842 L 174.397868253 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.132158707 99.3647439921 L 173.999610992 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.589910635 121.694679206 L 171.132158707 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 112.075031868 145.119219086 L 135.589910635 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(174.64567277189954, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(174.39786825346633, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(173.99961099169872, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.65568293006422, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(171.13215870697169, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(167.4239410918463, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(135.58991063455272, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(112.07503186751657, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7cb83828537f4471913e713ac2b41889"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t43e8d8e428564310b55526226e95cf6a"><g class="toyplot-Edges"><path d="M 112.066181706 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.840444557 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.230943419 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.230943419 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.840444557 144.024614419 L 192.230943419 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.085792612 121.694679206 L 175.840444557 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.433064194 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.619190523 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.85814488 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.070548753 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 176.070548753 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.85814488 73.9699157102 L 176.070548753 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.619190523 86.2294879842 L 175.85814488 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.433064194 99.3647439921 L 175.619190523 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.085792612 121.694679206 L 171.433064194 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 112.066181706 145.119219086 L 140.085792612 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(176.07054875289049, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(175.85814487994773, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(175.61919052288712, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.23094341928419, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.4330641936406, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(175.84044455720252, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.08579261184082, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(112.06618170614396, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf3f8e125af704a74adc98da4066f24fc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t08865226b9584bdaaff11ab901823cf4"><g class="toyplot-Edges"><path d="M 113.668060915 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.858622526 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.629200681 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.629200681 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.858622526 144.024614419 L 192.629200681 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.448239817 121.694679206 L 182.858622526 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.521702278 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.566226025 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.610476832 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.11493603 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.11493603 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.610476832 73.9699157102 L 178.11493603 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.566226025 86.2294879842 L 177.610476832 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.521702278 99.3647439921 L 177.566226025 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.448239817 121.694679206 L 173.521702278 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 113.668060915 145.119219086 L 134.448239817 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.11493602996438, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.61047683172535, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(177.56622602486229, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.62920068105177, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(173.52170227757756, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.85862252568563, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(134.4482398174855, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(113.66806091458717, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t011320db2fc64eda809c70b02f7ec316"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tca0312ece1434e4dbddf24b09976db1d"><g class="toyplot-Edges"><path d="M 112.924647359 145.119219086 L 198.399505896 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.159323307 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.416796808 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.416796808 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.159323307 144.024614419 L 192.416796808 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.262386429 121.694679206 L 180.159323307 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.300516478 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.645877477 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.831730866 73.9699157102 L 198.399505896 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.937932803 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.937932803 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.831730866 73.9699157102 L 177.937932803 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.645877477 86.2294879842 L 177.831730866 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.300516478 99.3647439921 L 177.645877477 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.262386429 121.694679206 L 174.300516478 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 112.924647359 145.119219086 L 134.262386429 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.93793280251211, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.83173086604074, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(177.64587747721583, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.41679680810904, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(174.30051647836763, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.15932330703828, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(134.26238642866062, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(112.92464735928758, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t88e06c3cdde84d46841037e662d1bd25"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb1fc1dc028e4437fac1d2ae840fdce2b"><g class="toyplot-Edges"><path d="M 112.676842841 144.900298153 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.655068814 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.761953102 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.761953102 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.655068814 144.024614419 L 192.761953102 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.058764482 121.256837339 L 182.655068814 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.220796791 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.167968763 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.814030543 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.814030543 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.442323766 70.4671807747 L 177.814030543 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.167968763 84.4781205165 L 177.442323766 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.220796791 98.4890602582 L 177.167968763 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.058764482 121.256837339 L 173.220796791 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 112.676842841 144.900298153 L 133.058764482 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.8140305432955, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.44232376564568, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(177.16796876309465, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.76195310164101, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(173.22079679090865, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.65506881411548, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(133.05876448198507, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(112.67684284085436, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8c2289d008b645508ed755b30a2a3457"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9c7a7c3fe7e441bf99129436d1505908"><g class="toyplot-Edges"><path d="M 113.030849296 144.900298153 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.37186365 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.868155038 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.868155038 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.37186365 144.024614419 L 192.868155038 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.740226908 121.256837339 L 182.37186365 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.105744693 98.4890602582 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.645877477 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.982183609 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.0529849 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.0529849 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.982183609 70.4671807747 L 178.0529849 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 177.645877477 84.4781205165 L 177.982183609 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.105744693 98.4890602582 L 177.645877477 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.740226908 121.256837339 L 173.105744693 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 113.030849296 144.900298153 L 133.740226908 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(178.05298490035608, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.98218360937517, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(177.64587747721581, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.86815503811235, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(173.10574469306468, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(182.37186365019184, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(133.74022690767634, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(113.03084929575893, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3c8a52f6aa6044a69f778599a44e351a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t987b5f95aa414e4b9c502812795a5286"><g class="toyplot-Edges"><path d="M 114.960184475 144.900298153 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.17729657 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.098259234 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.098259234 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.17729657 144.024614419 L 193.098259234 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.802450978 121.256837339 L 184.17729657 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.070480518 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.495561204 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.814167014 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.902668627 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.902668627 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.814167014 70.4671807747 L 179.902668627 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.495561204 84.4781205165 L 179.814167014 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.070480518 98.4890602582 L 179.495561204 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.802450978 121.256837339 L 175.070480518 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 114.960184475 144.900298153 L 137.802450978 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(179.90266862723243, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(179.81416701350631, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(179.49556120409218, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(193.09825923380035, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(175.07048051778503, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.17729657020513, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.80245097770631, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(114.96018447498884, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1d1977d1409f469cb3a73a76d6f6633d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfbea634a29f1436d93b47782901ba95b"><g class="toyplot-Edges"><path d="M 110.322699916 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.23911123 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.903487448 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.903487448 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.23911123 144.024614419 L 191.903487448 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.881897725 121.694679206 L 182.23911123 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.672018551 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.902600392 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.115004265 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.123854426 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.123854426 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.115004265 73.9699157102 L 179.123854426 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.902600392 86.2294879842 L 179.115004265 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.672018551 99.3647439921 L 178.902600392 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.881897725 121.694679206 L 171.672018551 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 110.322699916 145.119219086 L 134.881897725 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(179.12385442644239, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(179.11500426506979, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(178.90260039212706, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.90348744849743, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(171.67201855070118, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.23911122960263, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(134.8818977247436, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(110.32269991573898, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb284c821f680440ebe24cb77e66bbdb5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te5c2875e4e9547dca208997be3b47dc0"><g class="toyplot-Edges"><path d="M 102.773512265 144.900298153 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.575485597 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.575485597 144.024614419 L 191.788435351 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.067614643 121.256837339 L 183.575485597 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.698705505 98.4890602582 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.37159071 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.486642808 70.4671807747 L 198.399505896 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.486642808 70.4671807747 L 198.399505896 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.486642808 70.4671807747 L 198.399505896 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.486642808 70.4671807747 L 178.486642808 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.37159071 84.4781205165 L 178.486642808 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.698705505 98.4890602582 L 178.37159071 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.067614643 121.256837339 L 173.698705505 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 102.773512265 144.900298153 L 133.067614643 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(178.48664280761417, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(178.48664280761417, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(178.37159070977017, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.78843535065346, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(173.69870550502984, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.57548559686737, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(133.06761464335764, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(102.77351226489897, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5d379e39de1a4f379308f84e7fd9b656"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t13697a115db842b88787b59887be3774"><g class="toyplot-Edges"><path d="M 102.313303874 144.900298153 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.805589793 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.55839939 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.55839939 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.805589793 144.024614419 L 192.55839939 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.11186545 121.256837339 L 183.805589793 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.884627129 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.468942485 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.575144421 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.575144421 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.575144421 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.575144421 70.4671807747 L 178.575144421 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.468942485 84.4781205165 L 178.575144421 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.884627129 98.4890602582 L 178.468942485 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.11186545 121.256837339 L 174.884627129 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 102.313303874 144.900298153 L 133.11186545 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.5751444213403, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.5751444213403, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(178.46894248486896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.55839939007086, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(174.88462712896015, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(183.80558979255537, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(133.11186545022073, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(102.31330387352303, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t224da68dbadd4eb2a5b60e6a0da754ec"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t22730598bf3d4f46a26066f7337bf4b0"><g class="toyplot-Edges"><path d="M 100.472470308 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.43381478 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.885718891 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.885718891 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.43381478 144.024614419 L 190.885718891 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.925943826 120.818995472 L 182.43381478 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.698841975 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.194587482 82.7267530488 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.380440871 66.9644458393 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.406991355 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.406991355 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.380440871 66.9644458393 L 178.406991355 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.194587482 82.7267530488 L 178.380440871 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 175.698841975 97.6133765244 L 178.194587482 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.925943826 120.818995472 L 175.698841975 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 100.472470308 144.681377219 L 131.925943826 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.40699135526063, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.38044087114281, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(178.1945874823179, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.88571889064676, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(175.69884197524067, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.43381477980012, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(131.92594382629042, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(100.47247030801927, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc6e4ab568c61408e94d1f3b537b32a73"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="teddad98b97c34cc28c0b10b5248ca99c"><g class="toyplot-Edges"><path d="M 97.8528225417 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.106495279 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.469761306 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.469761306 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.106495279 144.024614419 L 190.469761306 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.483708698 120.818995472 L 184.106495279 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.50407019 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.707896842 82.7267530488 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.796398456 66.9644458393 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.858349585 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.858349585 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.796398456 66.9644458393 L 178.858349585 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 178.707896842 82.7267530488 L 178.796398456 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.50407019 97.6133765244 L 178.707896842 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.483708698 120.818995472 L 174.50407019 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 97.8528225417 144.681377219 L 135.483708698 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.85834958526397, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.79639845565566, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(178.70789684192954, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.4697613061339, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(174.50407018993775, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.10649527922425, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(135.48370869808136, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(97.852822541725459, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfce4f139d64d49b7a546c5efb1d564a8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t38bd2ab0605146ce89ac860eb92a659e"><g class="toyplot-Edges"><path d="M 95.8084352647 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.637436726 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.637436726 144.024614419 L 191.390178089 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.855415476 120.818995472 L 183.637436726 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.79592081 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.415909752 82.7267530488 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.495561204 66.9644458393 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.690264754 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.690264754 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.495561204 66.9644458393 L 179.690264754 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 179.415909752 82.7267530488 L 179.495561204 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.79592081 97.6133765244 L 179.415909752 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.855415476 120.818995472 L 171.79592081 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 95.8084352647 144.681377219 L 135.855415476 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(179.6902647542897, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(179.49556120409218, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(179.4159097517387, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.39017808888582, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(171.79592080991779, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.6374367264757, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(135.85541547573118, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(95.808435264651536, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td86b61d4f50946e6a023ac6ff58ffb79"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tec17f82c662f45edb0c9aae6e72cfefe"><g class="toyplot-Edges"><path d="M 96.5429986586 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.832208512 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.098190999 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.098190999 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.832208512 144.024614419 L 192.098190999 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.386629863 120.818995472 L 184.832208512 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.592025923 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.62838186 82.7267530488 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.699183151 66.9644458393 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.805385087 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.805385087 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.699183151 66.9644458393 L 180.805385087 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.62838186 82.7267530488 L 180.699183151 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.592025923 97.6133765244 L 180.62838186 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.386629863 120.818995472 L 166.592025923 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 96.5429986586 144.681377219 L 139.386629863 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.8053850872391, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.69918315076771, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(180.62838185978683, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.09819099869495, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.59202592282057, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(184.83220851177859, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(139.38662986340424, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(96.542998658578512, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2a9c64a3075248cda5fc13cd591a4104"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6710a25e5ae947c48f3b6486d693757f"><g class="toyplot-Edges"><path d="M 97.2156109229 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.186556142 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.637982607 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.637982607 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.186556142 144.024614419 L 191.637982607 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.944121795 120.818995472 L 190.186556142 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.017174844 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.009007034 82.7267530488 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.088658486 66.9644458393 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.124059132 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.124059132 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.088658486 66.9644458393 L 182.124059132 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.009007034 82.7267530488 L 182.088658486 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.017174844 97.6133765244 L 182.009007034 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.944121795 120.818995472 L 172.017174844 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 97.2156109229 144.681377219 L 138.944121795 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.1240591317586, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.08865848626817, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.00900703391463, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.63798260731897, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(172.01717484423312, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.18655614221026, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(138.94412179477354, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(97.215610922897199, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td7ccb65d5b8c4ebdabb312d314dde79e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t440be00d7ad54e80a90b1304fbb5d8a9"><g class="toyplot-Edges"><path d="M 94.0561033129 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.036308104 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.036308104 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 144.024614419 L 193.036308104 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.342379057 121.694679206 L 187.708510958 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.079194209 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.991306711 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.026707357 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.088658486 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.088658486 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.026707357 73.9699157102 L 182.088658486 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.991306711 86.2294879842 L 182.026707357 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.079194209 99.3647439921 L 181.991306711 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.342379057 121.694679206 L 173.079194209 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 94.0561033129 145.119219086 L 139.342379057 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.0886584862682, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.02670735665987, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.99130671116941, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.03630810419205, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(173.07919420894683, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.70851095787827, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.34237905654118, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(94.056103312873915, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5242236fd7044101a94ab0ac4fdb5cf9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t62dfe980cbca45ed9ed8538539c9adf6"><g class="toyplot-Edges"><path d="M 88.976110685 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.575622067 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.779653424 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.779653424 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.575622067 144.024614419 L 192.779653424 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.280496162 120.818995472 L 185.575622067 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.946237083 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.27444364 82.7267530488 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.300994124 66.9644458393 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.584199288 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.584199288 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.300994124 66.9644458393 L 181.584199288 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.27444364 82.7267530488 L 181.300994124 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.946237083 97.6133765244 L 181.27444364 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.280496162 120.818995472 L 169.946237083 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 88.976110685 144.681377219 L 140.280496162 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.58419928802917, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.3009941241055, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.27444363998768, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.77965342438623, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.94623708304138, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(185.57562206707823, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(140.2804961620383, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(88.976110684993301, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcca94632b10c43f0b7bd2fe64d5f33eb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3c5c7f58c1634d368b3e51b5dd3ae9ca"><g class="toyplot-Edges"><path d="M 96.5429986586 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.248302567 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.142510041 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.142510041 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.248302567 144.024614419 L 193.142510041 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.793737287 120.818995472 L 187.248302567 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.547979821 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.840922203 82.7267530488 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.849772364 66.9644458393 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.973674624 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.973674624 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.849772364 66.9644458393 L 182.973674624 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.840922203 82.7267530488 L 182.849772364 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.547979821 97.6133765244 L 182.840922203 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.793737287 120.818995472 L 169.547979821 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 96.5429986586 144.681377219 L 139.793737287 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.9736746235296, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.849772364313, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.84092220294036, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.14251004066344, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(169.54797982127371, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.2483025665023, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(139.79373728654451, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(96.542998658578512, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7602d7b3d4354af1a60cd0b11a7601c2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t65d08aff28284857999824c89b700daa"><g class="toyplot-Edges"><path d="M 89.3478174626 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.053462546 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.584949874 133.516409613 L 198.399505896 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.584949874 133.516409613 L 198.399505896 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.053462546 144.024614419 L 192.584949874 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.581333414 119.505469871 L 185.053462546 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.415363871 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.044407679 77.4726506456 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.044407679 77.4726506456 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.035557518 77.4726506456 L 182.044407679 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.212560745 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.212560745 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.035557518 77.4726506456 L 182.212560745 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.415363871 94.9863253228 L 182.035557518 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.581333414 119.505469871 L 171.415363871 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 89.3478174626 144.024614419 L 139.581333414 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.21256074548478, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.04440767940511, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.03555751803248, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.58494987418874, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(171.41536387089536, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.05346254609398, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(139.58133341360175, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(89.347817462643107, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td0891c1bfa0043d1aa2ccc4f47954f79"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tecebaed64d38483ca09eee3254d18cd4"><g class="toyplot-Edges"><path d="M 78.7984251065 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.540630832 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.540630832 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 144.024614419 L 191.540630832 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.005868219 119.505469871 L 186.04468062 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.751670003 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.938137508 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.938137508 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.699183151 77.4726506456 L 180.938137508 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.76113428 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.76113428 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 180.699183151 77.4726506456 L 180.76113428 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.751670003 94.9863253228 L 180.699183151 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.005868219 119.505469871 L 171.751670003 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.7984251065 144.024614419 L 136.005868219 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.76113428037604, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.93813750782832, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(180.69918315076771, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.54063083222024, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(171.7516700030547, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.04468061982678, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(136.00586821906563, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(78.798425106486889, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t063dc41613e14216a364b520403079ec"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8e5426d586b847d588e477cb54e27009"><g class="toyplot-Edges"><path d="M 79.1258810773 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 144.024614419 L 191.930037933 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.572346782 119.505469871 L 187.363354664 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.627767744 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.009007034 77.4726506456 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.009007034 77.4726506456 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.477997352 77.4726506456 L 182.009007034 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.575349127 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.575349127 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.477997352 77.4726506456 L 181.575349127 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.627767744 94.9863253228 L 181.477997352 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.572346782 119.505469871 L 171.627767744 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 79.1258810773 144.024614419 L 137.572346782 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.57534912665656, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.00900703391466, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.47799735155778, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.93003793261528, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(171.62776774383812, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.36335466434628, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(137.57234678201834, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(79.125881077273618, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t232da3b5d5be48fca5755e38e43d8eab"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tac719de240784b4f967bbf72a6cdc442"><g class="toyplot-Edges"><path d="M 78.763024461 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.283771447 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.55839939 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.55839939 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.283771447 144.024614419 L 192.55839939 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.164966418 119.505469871 L 188.283771447 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.167422882 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.354095092 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.354095092 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.265593479 77.4726506456 L 181.354095092 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.309844285 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.309844285 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.265593479 77.4726506456 L 181.309844285 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.167422882 94.9863253228 L 181.265593479 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.164966418 119.505469871 L 169.167422882 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.763024461 144.024614419 L 133.164966418 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.30984428547811, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.35409509234117, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.26559347861505, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.55839939007086, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.16742288225132, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.28377144709819, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(133.1649664184564, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(78.763024460996419, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9b997c8d5f5c46efb4ed0b7df37993ea"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6a0b2ec66b1b4903aec613ab62b315ea"><g class="toyplot-Edges"><path d="M 80.2941023785 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.672905607 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.841604554 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.841604554 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.672905607 144.024614419 L 192.841604554 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.04147357 119.505469871 L 184.672905607 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.512579176 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.566498965 77.4726506456 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.566498965 77.4726506456 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.53109832 77.4726506456 L 181.566498965 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.584199288 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.584199288 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.53109832 77.4726506456 L 181.584199288 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.512579176 94.9863253228 L 181.53109832 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.04147357 119.505469871 L 169.512579176 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 80.2941023785 144.024614419 L 139.04147357 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.58419928802917, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.56649896528396, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.5310983197935, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.84160455399456, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.51257917578329, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.67290560707156, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(139.0414735698723, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(80.294102378458703, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbb2d8da159b1472aa5d78ce74c00f391"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t84e2187f6e68463ca75769704f9f9870"><g class="toyplot-Edges"><path d="M 74.5326473249 144.243535352 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.124400307 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.921256006 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.921256006 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.124400307 144.024614419 L 192.921256006 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.590047105 119.943311738 L 187.124400307 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.512579176 95.8620090567 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.044339444 79.2240181133 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.070889928 73.9699157102 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.097440413 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.097440413 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.070889928 73.9699157102 L 181.097440413 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.044339444 79.2240181133 L 181.070889928 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.512579176 95.8620090567 L 181.044339444 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.590047105 119.943311738 L 169.512579176 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.5326473249 144.243535352 L 137.590047105 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.09744041253538, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.07088992841753, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.04433944429971, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.92125600634807, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(169.51257917578329, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.1244003072857, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(137.59004710476356, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(74.532647324886796, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t952291e3cd574caf9684bee735b682eb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb7cf8188cdb34079b96f8efecdca53f5"><g class="toyplot-Edges"><path d="M 73.6653315104 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.752761765 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.673519723 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.673519723 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.752761765 144.024614419 L 193.673519723 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.333870071 119.943311738 L 187.752761765 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.184850265 95.8620090567 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.964756227 79.2240181133 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.98245655 73.9699157102 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.044407679 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.044407679 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.98245655 73.9699157102 L 182.044407679 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.964756227 79.2240181133 L 181.98245655 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.184850265 95.8620090567 L 181.964756227 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.333870071 119.943311738 L 165.184850265 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.6653315104 144.243535352 L 144.333870071 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(182.04440767940508, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.98245654979681, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(181.96475622705159, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.67351972302026, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(165.18485026457489, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.75276176474134, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(144.33387007069567, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(73.665331510370592, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tdba5e65a9c5e493e9ec11a52f29cea09"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3ee6b2fd665d41dbbec46d6d253fcbfc"><g class="toyplot-Edges"><path d="M 72.160804077 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.04495356 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.708920369 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.708920369 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.04495356 144.024614419 L 193.708920369 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.634297912 119.505469871 L 190.04495356 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.875231087 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.407264296 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.407264296 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.389563973 77.4726506456 L 182.407264296 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.495765909 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.495765909 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.389563973 77.4726506456 L 182.495765909 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.875231087 94.9863253228 L 182.389563973 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.634297912 119.505469871 L 166.875231087 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.160804077 144.024614419 L 137.634297912 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.49576590940845, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.40726429568227, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.38956397293708, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.70892036851072, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(166.87523108674421, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.04495356024839, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(137.63429791162665, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(72.160804077026157, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t438d0a9ec06d441cb6397ef3a262d823"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t71c993dba6fe48d692b600c3b82e6e80"><g class="toyplot-Edges"><path d="M 72.9396182778 143.805693485 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.159869188 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.160210363 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.160210363 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.159869188 144.024614419 L 193.160210363 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.997154528 119.067628004 L 188.159869188 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.724914814 94.110641589 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.92050542 75.7212831779 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.947055904 80.9753855811 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.000156873 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.000156873 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.947055904 80.9753855811 L 182.000156873 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.92050542 75.7212831779 L 181.947055904 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.724914814 94.110641589 L 181.92050542 75.7212831779" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.997154528 119.067628004 L 168.724914814 94.110641589" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.9396182778 143.805693485 L 137.997154528 119.067628004" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.00015687254205, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.94705590430635, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.92050542018848, 75.721283177905292)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.16021036340868, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(168.72491481362061, 94.11064158895266)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(188.15986918788158, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(137.99715452790383, 119.06762800394549)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(72.939618277816237, 143.80569348547345)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t74cf3cf4bbeb43d4b15a56425ee36827"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7181849e5aa2461e89afa16b1b21fe7e"><g class="toyplot-Edges"><path d="M 78.1789138104 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.319240328 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.124809718 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.124809718 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.319240328 144.024614419 L 193.124809718 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.62558422 119.505469871 L 189.319240328 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.769302091 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.62851833 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.62851833 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.619668169 77.4726506456 L 182.62851833 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.876322848 77.4726506456 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.876322848 77.4726506456 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.619668169 77.4726506456 L 182.876322848 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.769302091 94.9863253228 L 182.619668169 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.62558422 119.505469871 L 170.769302091 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 78.1789138104 144.024614419 L 139.62558422 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(182.87632284843087, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(182.62851832999766, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(182.61966816862503, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.1248097179182, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.76930209069451, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(189.31924032769405, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(139.62558422046484, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(78.17891381040387, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf05af9a8a51e4f12851eff7e6d0217bc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4e5c42b795654338857bb79ed19ff431"><g class="toyplot-Edges"><path d="M 76.8956404114 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.94780649 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.94780649 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 144.024614419 L 192.94780649 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.510600358 119.505469871 L 187.381054987 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.601149025 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.256811552 77.4726506456 L 182.601967846 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.274511875 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.274511875 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.256811552 77.4726506456 L 182.274511875 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.601149025 94.9863253228 L 182.256811552 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.510600358 119.505469871 L 170.601149025 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.8956404114 144.024614419 L 140.510600358 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.27451187509308, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.60196784587981, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.25681155234784, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.94780649046589, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.60114902461484, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.38105498709152, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(140.51060035772628, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(76.895640411374814, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb86a19e915364db2a08a8e55a17c9d72"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t82fcd47712204648ad7504c871db2679"><g class="toyplot-Edges"><path d="M 74.2405919996 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.867882098 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.2664123 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.2664123 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.867882098 144.024614419 L 193.2664123 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.227190488 119.943311738 L 188.867882098 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.724914814 95.8620090567 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.814303484 79.2240181133 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.858554291 73.9699157102 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.000156873 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.000156873 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.858554291 73.9699157102 L 182.000156873 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.814303484 79.2240181133 L 181.858554291 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.724914814 95.8620090567 L 181.814303484 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.227190488 119.943311738 L 168.724914814 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.2405919996 144.243535352 L 137.227190488 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(182.00015687254202, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.85855429058023, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(181.81430348371714, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(193.26641229988002, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(168.72491481362061, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.86788209769071, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.22719048848637, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(74.240591999590521, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t71243cf58796491ebded97da204d5af3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t24890861000d458e8def31fa614cf915"><g class="toyplot-Edges"><path d="M 76.745187668 143.805693485 L 198.399505896 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.699729032 144.024614419 L 198.399505896 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.151360202 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.151360202 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.699729032 144.024614419 L 193.151360202 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.846974725 119.067628004 L 188.699729032 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.618781112 94.110641589 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.832003806 75.7212831779 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.840853968 80.9753855811 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.053257841 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.053257841 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.840853968 80.9753855811 L 182.053257841 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.832003806 75.7212831779 L 181.840853968 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.618781112 94.110641589 L 181.832003806 75.7212831779" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.846974725 119.067628004 L 169.618781112 94.110641589" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.745187668 143.805693485 L 141.846974725 119.067628004" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.05325784077772, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.84085396783499, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(181.83200380646235, 75.721283177905292)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(193.15136020203605, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.61878111225468, 94.11064158895266)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.69972903161101, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(141.84697472499104, 119.06762800394549)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(76.745187668040359, 143.80569348547345)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td34af88692114b8baa575cdb8deebce0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5f07d728d3534427997a6132b1239b38"><g class="toyplot-Edges"><path d="M 72.7272144049 144.243535352 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.346063752 133.516409613 L 198.399505896 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.346063752 133.516409613 L 198.399505896 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 144.024614419 L 193.346063752 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.466417786 119.943311738 L 187.381054987 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.786934178 95.8620090567 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.362945254 79.2240181133 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.398345899 73.9699157102 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.442596706 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.442596706 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.398345899 73.9699157102 L 181.442596706 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.362945254 79.2240181133 L 181.398345899 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.786934178 95.8620090567 L 181.362945254 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.466417786 119.943311738 L 169.786934178 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.7272144049 144.243535352 L 141.466417786 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.44259670606735, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.39834589920426, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(181.3629452537138, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.34606375223353, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(169.78693417833432, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.38105498709152, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.46641778596862, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(72.727214404873479, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf2de2dc4bedd40e7af30bf4f9a50aa2d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t437cea7291c942c994362cbfeb724fb4"><g class="toyplot-Edges"><path d="M 73.9219861902 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.168787584 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.07170875 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.07170875 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.168787584 144.024614419 L 193.07170875 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.351433923 119.505469871 L 189.168787584 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.21194663 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.203710584 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.203710584 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.186010261 77.4726506456 L 182.203710584 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.345313166 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.345313166 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.186010261 77.4726506456 L 182.345313166 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.21194663 94.9863253228 L 182.186010261 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.351433923 119.505469871 L 173.21194663 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.9219861902 144.024614419 L 142.351433923 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(182.34531316607399, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(182.20371058411217, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(182.18601026136693, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.0717087496825, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(173.21194662953604, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(189.16878758435965, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(142.35143392323005, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(73.921986190176426, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t49e5bff3b5804340a132052ec86898dd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t95f54d698faf45d6af0fc14cd317076d"><g class="toyplot-Edges"><path d="M 65.4258312725 143.148930685 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.248507272 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 133.516409613 L 198.399505896 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 133.516409613 L 198.399505896 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.248507272 144.024614419 L 192.806203909 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.643079838 117.754102403 L 190.248507272 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.264911128 91.4835903874 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.593049449 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.628450095 84.4781205165 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.655000579 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.655000579 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.628450095 84.4781205165 L 181.655000579 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.593049449 70.4671807747 L 181.628450095 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.264911128 91.4835903874 L 181.593049449 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.643079838 117.754102403 L 171.264911128 91.4835903874" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.4258312725 143.148930685 L 136.643079838 117.754102403" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.39950589599627, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.39950589599627, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.65500057901008, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.6284500948922, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(181.59304944940178, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.80620390850407, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.26491112756094, 91.483590387374448)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.24850727181854, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(136.64307983789382, 117.75410240315637)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(65.425831272466695, 143.14893068507888)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t097883dbcee14a1797bcb40bd5277b08"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t732d935cff1d4737b613097dbee96b4b"><g class="toyplot-Edges"><path d="M 66.8949580603 143.148930685 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.965302108 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.894705522 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.894705522 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.965302108 144.024614419 L 192.894705522 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.466213081 117.754102403 L 189.965302108 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.424282267 91.4835903874 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.761202515 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.787753 84.4781205165 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.823153645 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.823153645 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.787753 84.4781205165 L 181.823153645 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.761202515 70.4671807747 L 181.787753 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.424282267 91.4835903874 L 181.761202515 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.466213081 117.754102403 L 172.424282267 91.4835903874" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.8949580603 143.148930685 L 138.466213081 117.754102403" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.82315364508977, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.78775299959926, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(181.76120251548144, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.89470552223023, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(172.42428226737337, 91.483590387374448)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(189.96530210789493, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(138.46621308065238, 117.75410240315637)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(66.894958060320661, 143.14893068507888)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5baf26f01b4347faa5f62cd6f13fd5d4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdba7fc56b3c34abcad40aad2ea2544a2"><g class="toyplot-Edges"><path d="M 59.5050733142 143.148930685 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.292894549 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.292894549 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 144.024614419 L 192.292894549 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.032759879 117.754102403 L 187.478406762 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.406377239 91.4835903874 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.486847513 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.486847513 84.4781205165 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.575349127 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.575349127 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.486847513 84.4781205165 L 181.575349127 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.486847513 70.4671807747 L 181.486847513 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.406377239 91.4835903874 L 181.486847513 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.032759879 117.754102403 L 169.406377239 91.4835903874" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.5050733142 143.148930685 L 141.032759879 117.754102403" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.57534912665653, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.48684751293038, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(181.48684751293038, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.29289454889243, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(169.40637723931189, 91.483590387374448)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.4784067621903, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(141.03275987871049, 117.75410240315637)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(59.505073314187726, 143.14893068507888)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcd4ee85b64114978a93e0f12f9c7add9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7e8fcef8fae6413e857054e39199bede"><g class="toyplot-Edges"><path d="M 68.6826906576 143.148930685 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.0801495 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.0801495 144.024614419 L 193.045158266 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.005868219 117.754102403 L 187.0801495 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 91.4835903874 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.938205743 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.947055904 84.4781205165 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.079808325 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.079808325 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.947055904 84.4781205165 L 182.079808325 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 181.938205743 70.4671807747 L 181.947055904 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 91.4835903874 L 181.938205743 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.005868219 117.754102403 L 169.034670462 91.4835903874" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.6826906576 143.148930685 L 136.005868219 117.754102403" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(182.07980832489557, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.94705590430635, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(181.93820574293375, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.04515826556468, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(169.0346704616621, 91.483590387374448)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.08014950042264, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(136.00586821906563, 117.75410240315637)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(68.682690657588751, 143.14893068507888)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t69d4363099fe4dbcb5e00c6f98afe03e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t705d9545d860439c9d8de7d3255650d0"><g class="toyplot-Edges"><path d="M 73.7538331241 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.434292426 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.514216818 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.514216818 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.434292426 144.024614419 L 193.514216818 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.961753882 119.505469871 L 189.434292426 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.459614678 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.513534467 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.548935113 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.59318592 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.59318592 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.548935113 70.4671807747 L 183.59318592 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.513534467 77.4726506456 L 183.548935113 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.459614678 94.9863253228 L 183.513534467 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.961753882 119.505469871 L 171.459614678 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.7538331241 144.024614419 L 137.961753882 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.59318591961261, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.54893511274955, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.51353446725906, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(193.5142168183132, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(171.45961467775842, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(189.43429242553802, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.96175388241335, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(73.75383312409673, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5eea1a46b828488aac0577600aca3d4a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdc15e8585c2e49f388d4bc266c0e91b8"><g class="toyplot-Edges"><path d="M 76.7628879908 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.425510499 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.177910686 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.177910686 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.425510499 144.024614419 L 193.177910686 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.023500307 119.505469871 L 190.425510499 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.910768202 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.929492052 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.973742859 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.009143504 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.009143504 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.973742859 70.4671807747 L 184.009143504 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.929492052 77.4726506456 L 183.973742859 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.910768202 94.9863253228 L 183.929492052 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.023500307 119.505469871 L 168.910768202 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 76.7628879908 144.024614419 L 135.023500307 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.00914350412546, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(183.97374285863501, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(183.92949205177192, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(193.17791068615387, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(168.9107682024455, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.42551049927084, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(135.02350030670542, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(76.762887990785586, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5d9c22882a114a6cac6faab00e12127c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf3272f54be694e5ca00b78e81d98f579"><g class="toyplot-Edges"><path d="M 75.8070705625 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.239725346 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.239725346 144.024614419 L 192.806203909 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.501545491 120.818995472 L 191.239725346 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.600807849 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.2392477 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.274648345 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.301198829 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.301198829 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.274648345 80.9753855811 L 184.301198829 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.2392477 82.7267530488 L 184.274648345 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.600807849 97.6133765244 L 184.2392477 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.501545491 120.818995472 L 165.600807849 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 75.8070705625 144.681377219 L 137.501545491 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.30119882942174, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.27464834530392, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.23924769981346, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.80620390850407, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(165.60080784908777, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.23972534555136, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(137.50154549103743, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(75.807070562543259, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tad3cb738f6dd4601be2f952dab3471aa"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tafa2034f6ec94846bdef595e7da1d185"><g class="toyplot-Edges"><path d="M 71.1695860033 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.885718891 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 133.516409613 L 198.399505896 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.91233761 133.516409613 L 198.399505896 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.885718891 144.024614419 L 191.91233761 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.183280857 119.505469871 L 190.885718891 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.565475439 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.663987211 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.717088179 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.72593834 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.72593834 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.717088179 70.4671807747 L 183.72593834 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.663987211 77.4726506456 L 183.717088179 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.565475439 94.9863253228 L 183.663987211 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.183280857 119.505469871 L 166.565475439 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.1695860033 144.024614419 L 142.183280857 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.72593834020182, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.71708817882921, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.66398721059352, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.91233760987006, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(166.56547543870272, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.88571889064681, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(142.18328085715038, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(71.169586003293361, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te46c7053b09d4bc0b35d8f4fbde9b0ec"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf3e180ccf5fe44979338e51b57d85356"><g class="toyplot-Edges"><path d="M 64.6204665876 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.974152269 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.39916472 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.39916472 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.974152269 144.024614419 L 193.39916472 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.510532123 120.818995472 L 189.974152269 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.441914355 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.672769137 82.7267530488 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.955974301 80.9753855811 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.964824462 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.964824462 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.955974301 80.9753855811 L 182.964824462 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.672769137 82.7267530488 L 182.955974301 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.441914355 97.6133765244 L 182.672769137 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.510532123 120.818995472 L 171.441914355 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.6204665876 144.681377219 L 139.510532123 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.96482446215703, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.95597430078439, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(182.67276913686072, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.39916472046926, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.44191435501321, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(189.97415226926751, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(139.51053212262087, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(64.620466587558809, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4bb58a6fa7e3406bb129921065b4f6e9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf11c0abcb98549e3be28a2ef35629499"><g class="toyplot-Edges"><path d="M 58.336852013 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.115686616 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.903555684 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.903555684 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.115686616 144.024614419 L 192.903555684 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.510600358 120.818995472 L 189.115686616 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.255788026 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.380713812 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.460365264 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.522316394 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.522316394 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.460365264 80.9753855811 L 182.522316394 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.380713812 82.7267530488 L 182.460365264 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.255788026 97.6133765244 L 182.380713812 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.510600358 120.818995472 L 167.255788026 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.336852013 144.681377219 L 140.510600358 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874151, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.52231639352624, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.46036526391796, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(182.38071381156445, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.9035556836028, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.25578802576661, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(189.1156866161239, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(140.51060035772625, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(58.336852013002641, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbf4b66cd7d2d4d97b36f764c2979353b"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t554f48df981443c18fe31b64f68c3c44"><g class="toyplot-Edges"><path d="M 65.9922416003 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.452060983 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.292962784 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.292962784 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.452060983 144.024614419 L 193.292962784 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.837851623 120.818995472 L 190.452060983 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.901918041 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.849840599 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.902941568 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.000293343 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.000293343 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.902941568 80.9753855811 L 184.000293343 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.849840599 82.7267530488 L 183.902941568 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.901918041 97.6133765244 L 183.849840599 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.837851623 120.818995472 L 168.901918041 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.9922416003 144.681377219 L 137.837851623 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.00029334275288, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(183.9029415676541, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(183.84984059941843, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.29296278399787, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.90191804107286, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.45206098338866, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(137.83785162319677, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(65.992241600314003, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t33167dc5170a463fa7337cf394cfb8c8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf4bcdff385314cc7bf1dcb8d44bedaea"><g class="toyplot-Edges"><path d="M 59.761727994 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.213038391 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.10704116 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.10704116 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.213038391 144.024614419 L 192.10704116 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.439935537 120.818995472 L 189.213038391 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.857530764 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.27458011 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.363081724 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.460433499 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.460433499 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.363081724 80.9753855811 L 183.460433499 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.27458011 82.7267530488 L 183.363081724 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.857530764 97.6133765244 L 183.27458011 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.439935537 120.818995472 L 166.857530764 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.761727994 144.681377219 L 142.439935537 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.4604334990234, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.36308172392461, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(183.27458011019849, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.10704116006752, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(166.85753076399899, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(189.21303839122271, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(142.4399355369562, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(59.761727993993553, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t60e320785096444ea7582ec650670791"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfd27016321114f8f86c16b8c3b87fd88"><g class="toyplot-Edges"><path d="M 57.1597805504 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.443210822 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.345995517 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.345995517 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.443210822 144.024614419 L 192.345995517 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.767186802 120.818995472 L 190.443210822 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.424145797 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.699387856 82.7267530488 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.743638663 80.9753855811 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.832140277 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.832140277 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.743638663 80.9753855811 L 183.832140277 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.699387856 82.7267530488 L 183.743638663 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.424145797 97.6133765244 L 183.699387856 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.767186802 120.818995472 L 170.424145797 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 57.1597805504 144.681377219 L 139.767186802 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736896, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.83214027667321, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.74363866294706, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(183.699387856084, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.34599551712816, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(170.42414579716257, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.44321082201608, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(139.76718680242669, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(57.159780550444957, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf243a4b3e1d84b0fb00c2385f8b8fafa"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8bc28881f28242298008b715d011da5a"><g class="toyplot-Edges"><path d="M 50.7876643622 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.230670479 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.142305335 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.142305335 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.230670479 144.024614419 L 190.142305335 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.280496162 120.818995472 L 188.230670479 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.326589317 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.442664941 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.584267523 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.601967846 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.584267523 80.9753855811 L 182.601967846 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.442664941 82.7267530488 L 182.584267523 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.326589317 97.6133765244 L 182.442664941 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.280496162 120.818995472 L 167.326589317 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.7876643622 144.681377219 L 140.280496162 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.60196784587978, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.58426752313457, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(182.44266494117272, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.14230533534717, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(167.32658931674754, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.23067047886249, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(140.28049616203828, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(50.787664362162658, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3765f51bcb6947d2bb0acfd6538cf776"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t25d7adc901954c04a9797fef3998210b"><g class="toyplot-Edges"><path d="M 50.0 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.717429354 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.540630832 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.540630832 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.717429354 144.024614419 L 191.540630832 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.112479566 120.818995472 L 188.717429354 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.866722101 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.593117685 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.672769137 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.159528012 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.159528012 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.672769137 80.9753855811 L 183.159528012 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 182.593117685 82.7267530488 L 182.672769137 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.866722101 97.6133765244 L 182.593117685 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.112479566 120.818995472 L 171.866722101 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 50.0 144.681377219 L 142.112479566 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(183.15952801235451, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.67276913686072, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(182.59311768450718, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.54063083222024, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(171.8667221008987, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(188.71742935435628, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(142.11247956616947, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(50.0, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t030630b01cca47698d1b29ed528c3958"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t35adad9f02234314aa8ad303337624aa"><g class="toyplot-Edges"><path d="M 55.3985984373 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.062653883 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.682233414 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.682233414 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.062653883 144.024614419 L 191.682233414 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.563564856 120.818995472 L 190.062653883 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.14972256 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.009075269 82.7267530488 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.106427044 80.9753855811 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.59318592 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.59318592 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.106427044 80.9753855811 L 183.59318592 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.009075269 82.7267530488 L 183.106427044 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.14972256 97.6133765244 L 183.009075269 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.563564856 120.818995472 L 169.14972256 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.3985984373 144.681377219 L 138.563564856 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.59318591961264, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.10642704411882, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(183.00907526902006, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.68223341418209, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.14972255950607, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.06265388299366, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.56356485575114, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(55.398598437294709, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tff8227db7d2f41e68f3a11f998d90bcd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2f16cf3419a24ef48fad7776f62bd4db"><g class="toyplot-Edges"><path d="M 61.8857667234 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.903419213 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.195542774 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.195542774 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.903419213 144.024614419 L 192.195542774 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.988167896 120.818995472 L 190.903419213 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.725119519 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.345381401 82.7267530488 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.425032854 80.9753855811 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.221547377 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.221547377 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.425032854 80.9753855811 L 184.221547377 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.345381401 82.7267530488 L 183.425032854 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.725119519 97.6133765244 L 183.345381401 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.988167896 120.818995472 L 171.725119519 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.8857667234 144.681377219 L 135.988167896 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(184.22154737706822, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(183.42503285353297, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(183.34538140117942, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.19554277379373, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(171.72511951893685, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.90341921339203, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(135.98816789632036, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(61.885766723420986, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t70ad076d72e342bc9ae8cff260a85c7f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t564cc720543e4875ac1db2f37fe47836"><g class="toyplot-Edges"><path d="M 60.8414476815 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.646764534 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.345927282 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.345927282 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.646764534 144.024614419 L 191.345927282 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.652271175 120.818995472 L 190.646764534 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.318012096 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.416182692 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.478133822 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.708306253 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.708306253 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.478133822 80.9753855811 L 184.708306253 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.416182692 82.7267530488 L 183.478133822 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.318012096 97.6133765244 L 183.416182692 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.652271175 120.818995472 L 171.318012096 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.8414476815 144.681377219 L 141.652271175 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(184.70830625256201, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(183.47813382176864, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(183.41618269216033, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.34592728202273, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(171.3180120957966, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.64676453358618, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(141.65227117479353, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(60.8414476814525, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t25bafd890ccf4a0bad9388dcb7ae258e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t94b9abf90c48495bac152600c5de43d7"><g class="toyplot-Edges"><path d="M 63.3106427044 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.460911145 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.460911145 144.024614419 L 191.390178089 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.014854851 120.818995472 L 190.460911145 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.963869171 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.805589793 82.7267530488 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.115345441 80.9753855811 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.832208512 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.832208512 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.115345441 80.9753855811 L 184.832208512 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 183.805589793 82.7267530488 L 184.115345441 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.963869171 97.6133765244 L 183.805589793 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.014854851 120.818995472 L 168.963869171 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.3106427044 144.681377219 L 138.014854851 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.83220851177859, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.11534544059685, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(183.80558979255537, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.39017808888576, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.96386917068119, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.4609111447613, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(138.01485485064904, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(63.310642704411876, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t66bbb81992f64292a4992ac6d5af90a2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t583f49e67a3446efa6696f4bc3bea945"><g class="toyplot-Edges"><path d="M 68.8331434009 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.983002431 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.983002431 144.024614419 L 191.549480994 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.271304825 120.818995472 L 189.983002431 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.211878394 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.602104316 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.841058673 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.478338527 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.478338527 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.841058673 80.9753855811 L 186.478338527 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.602104316 82.7267530488 L 184.841058673 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.211878394 97.6133765244 L 184.602104316 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.271304825 120.818995472 L 172.211878394 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.8331434009 144.681377219 L 135.271304825 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.47833852708484, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(184.84105867315122, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(184.60210431609062, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.54948099359288, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(172.21187839443064, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(189.98300243064011, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(135.27130482513863, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(68.833143400923191, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t22ea21f3421241099d50bb899d2c84a7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb97c29ddede0462abdd9c56915ecdf0e"><g class="toyplot-Edges"><path d="M 64.4080627146 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.726415986 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.94767002 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.94767002 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.726415986 144.024614419 L 190.94767002 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.536809666 120.818995472 L 190.726415986 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.203164703 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.425101089 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.655205284 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.186214967 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.186214967 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.655205284 80.9753855811 L 185.186214967 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.425101089 82.7267530488 L 184.655205284 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 174.203164703 97.6133765244 L 184.425101089 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.536809666 120.818995472 L 174.203164703 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.4080627146 144.681377219 L 135.536809666 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.18621496668317, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(184.65520528432631, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(184.42510108863834, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.94767002025509, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(174.20316470326884, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.7264159859397, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(135.53680966631705, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(64.408062714616051, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t38b96d686e8a4b56bc8f962172085d0e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9aec7bde68a7422ead7171c0b10d73dd"><g class="toyplot-Edges"><path d="M 64.0186556142 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.55826292 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.018471311 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.018471311 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.55826292 144.024614419 L 191.018471311 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.49269533 120.818995472 L 190.55826292 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.468328369 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.451651573 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.602104316 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.602104316 80.9753855811 L 185.345517871 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.451651573 82.7267530488 L 184.602104316 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.468328369 97.6133765244 L 184.451651573 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.49269533 120.818995472 L 169.468328369 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.0186556142 144.681377219 L 137.49269533 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.34551787139023, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.60210431609062, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.45165157275619, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.01847131123594, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.4683283689202, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.55826291986006, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.4926953296648, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(64.018655614221018, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0e5228c0b73042bbbc4ae8453c0a985f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9f8e577d7d1c4740996d25d9ba538e73"><g class="toyplot-Edges"><path d="M 63.2486915748 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.071504044 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.071504044 144.024614419 L 191.788435351 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.138688875 119.505469871 L 190.071504044 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.919481894 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.593390625 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.593390625 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.69060593 77.4726506456 L 186.593390625 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.761407221 91.4835903874 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.761407221 91.4835903874 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.69060593 77.4726506456 L 184.761407221 91.4835903874" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.919481894 94.9863253228 L 184.69060593 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.138688875 119.505469871 L 166.919481894 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.2486915748 144.024614419 L 137.138688875 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.76140722079771, 91.483590387374448)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.59339062492884, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(184.69060592981677, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.78843535065346, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(166.9194818936073, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(190.07150404436626, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(137.13868887476022, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(63.248691574803573, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb2c1ef3ef36849828bffe3c871483e97"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t09e4766b5b4c442f83d0b89ae06c388b"><g class="toyplot-Edges"><path d="M 68.1074301684 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.045021795 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.000839224 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.000839224 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.045021795 144.024614419 L 192.000839224 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.501409021 121.694679206 L 191.045021795 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.194246307 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.832276747 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.867677392 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.204119995 63.4617109039 L 198.399505896 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.204119995 63.4617109039 L 198.399505896 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.867677392 73.9699157102 L 188.204119995 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.832276747 86.2294879842 L 185.867677392 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.194246307 99.3647439921 L 185.832276747 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.501409021 121.694679206 L 173.194246307 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.1074301684 145.119219086 L 135.501409021 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.20411999474464, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(185.86767739237447, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(185.83227674688402, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.00083922359619, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(173.1942463067908, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.04502179535382, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(135.5014090208266, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(68.107430168368808, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t80fef742825d41b6b62a75bfd489daf8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t15dedcb4b2d34ea5821e66905488d6b5"><g class="toyplot-Edges"><path d="M 67.9127266182 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.283976152 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.283976152 144.024614419 L 192.505298422 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.767118567 121.694679206 L 191.283976152 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.477110295 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.000429813 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.221888553 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.221888553 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 73.9699157102 L 189.221888553 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.000429813 86.2294879842 L 186.04468062 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.477110295 99.3647439921 L 186.000429813 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.767118567 121.694679206 L 168.477110295 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.9127266182 145.119219086 L 138.767118567 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(189.22188855259532, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.04468061982678, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.00042981296372, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.50529842183522, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.47711029518743, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.2839761524144, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(138.76711856732126, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(67.91272661817132, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9e90d8da4d534dadbc945a35de8ecf71"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t97d112388bd44cfbb9e78f6ec13a37ba"><g class="toyplot-Edges"><path d="M 67.5941208088 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.301676475 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.301676475 144.024614419 L 192.381396163 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.342242586 121.694679206 L 191.301676475 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.73396968 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.796876101 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.84997707 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.540289657 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.540289657 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.84997707 73.9699157102 L 186.540289657 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.796876101 86.2294879842 L 185.84997707 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.73396968 99.3647439921 L 185.796876101 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.342242586 121.694679206 L 171.73396968 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.5941208088 145.119219086 L 137.342242586 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.54028965669318, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.84997706962929, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.79687610139356, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.38139616261861, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(171.73396968030946, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.30167647515967, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(137.34224258633037, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(67.594120808757197, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5df3ed0fd5c64b2eb260404de57855e8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta99a52eb92bf4a8681eeec78dc0388f6"><g class="toyplot-Edges"><path d="M 61.1512033295 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.983002431 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.115823086 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.115823086 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.983002431 144.024614419 L 191.115823086 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.386356923 121.694679206 L 189.983002431 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.725119519 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.991511416 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.088863192 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.407469001 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.407469001 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.088863192 73.9699157102 L 185.407469001 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.991511416 86.2294879842 L 185.088863192 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.725119519 99.3647439921 L 184.991511416 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.386356923 121.694679206 L 171.725119519 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.1512033295 145.119219086 L 135.386356923 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(185.40746900099856, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(185.08886319158444, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.99151141648568, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.11582308633476, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(171.72511951893685, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(189.98300243064011, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(135.3863569229826, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(61.151203329494003, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf55ae083c9d04910858d87d58a34e521"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1c95a80e3222467984db5647792c7571"><g class="toyplot-Edges"><path d="M 67.1870133856 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.894569052 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.894569052 144.024614419 L 192.080490676 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.767255038 121.694679206 L 190.894569052 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.662758979 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.062380943 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.142032395 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.142032395 73.9699157102 L 186.575690302 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.062380943 86.2294879842 L 186.142032395 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.662758979 99.3647439921 L 186.062380943 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.767255038 121.694679206 L 165.662758979 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.1870133856 145.119219086 L 140.767255038 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.57569030218363, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.14203239492554, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.06238094257199, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.0804906759497, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(165.66275897869608, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.89456905201939, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(140.7672550375321, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.187013385616922, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0062722e7bf348f0bf4a26d3b2b7eabb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t84d394e45e5f449cacdceacd82a0e170"><g class="toyplot-Edges"><path d="M 64.9567727197 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.443210822 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.39902825 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.39902825 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.443210822 144.024614419 L 191.39902825 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.643148073 121.694679206 L 190.443210822 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.18505497 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.380918517 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.549071583 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.885377715 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.885377715 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.549071583 73.9699157102 L 185.885377715 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.380918517 86.2294879842 L 185.549071583 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.18505497 99.3647439921 L 185.380918517 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.643148073 121.694679206 L 168.18505497 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.9567727197 145.119219086 L 137.643148073 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.88537771511972, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.54907158296035, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.38091851688071, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.3990282502584, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(168.18505496989115, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.44321082201608, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.64314807299925, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(64.956772719718145, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te42ea2626ae8480899b06449f0f477bb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta0cda425581d44a4a80c81c65a4be650"><g class="toyplot-Edges"><path d="M 71.1607358419 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.027321473 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.222025023 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.222025023 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.027321473 144.024614419 L 191.222025023 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.156525668 121.694679206 L 191.027321473 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.981296553 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.292485138 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.876595789 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.876595789 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.292485138 73.9699157102 L 186.876595789 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.04468062 86.2294879842 L 186.292485138 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.981296553 99.3647439921 L 186.04468062 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.156525668 121.694679206 L 164.981296553 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.1607358419 145.119219086 L 139.156525668 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.87659578885248, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.29248513825999, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.04468061982678, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.22202502280612, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(164.98129655300477, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.02732147260863, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(139.15652566771629, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(71.160735841920769, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3be196c474c74e899327ddeef581189e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1e585d7200f44fef9afde593fd568708"><g class="toyplot-Edges"><path d="M 73.7184324786 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.062722118 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.062722118 144.024614419 L 191.363627605 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.961890353 121.694679206 L 191.062722118 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.662963684 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.655273519 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.938478683 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.319035622 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.319035622 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.938478683 73.9699157102 L 186.319035622 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.655273519 86.2294879842 L 185.938478683 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.662963684 99.3647439921 L 185.655273519 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.961890353 121.694679206 L 168.662963684 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.7184324786 145.119219086 L 139.961890353 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.31903562237781, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(185.93847868335541, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(185.65527351943174, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.36362760476797, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(168.66296368401231, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.06272211809909, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.96189035262421, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(73.718432478606275, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td7aef5de71984b2c9839a13d234e36ee"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6e175e2764474743b6038741cf6e3fe3"><g class="toyplot-Edges"><path d="M 67.9392771023 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.983070666 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.098122764 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.098122764 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.983070666 144.024614419 L 191.098122764 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.598760796 121.694679206 L 190.983070666 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.335371243 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.708306253 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.929560287 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.062312707 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.062312707 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.929560287 73.9699157102 L 185.062312707 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.708306253 86.2294879842 L 184.929560287 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.335371243 99.3647439921 L 184.708306253 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.598760796 121.694679206 L 166.335371243 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.9392771023 145.119219086 L 135.598760796 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736896, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(185.06231270746659, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(184.9295602868774, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(184.70830625256204, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.09812276358952, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(166.33537124301475, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.98307066574554, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(135.59876079592536, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(67.939277102289168, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5f0e9cb0447848a3b27d78b61a69e966"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td9ddec6e10c54e2a800af794c92be927"><g class="toyplot-Edges"><path d="M 66.080743214 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.045021795 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.425578734 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.425578734 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.045021795 144.024614419 L 191.425578734 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.262795839 121.694679206 L 191.045021795 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.804566266 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.150814321 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.301267065 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.920778361 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.920778361 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.301267065 73.9699157102 L 185.920778361 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.150814321 86.2294879842 L 185.301267065 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.804566266 99.3647439921 L 185.150814321 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.262795839 121.694679206 L 168.804566266 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.080743214 145.119219086 L 140.262795839 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.92077836061017, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.30126706452717, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.15081432119271, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.42557873437627, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.80456626597416, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.04502179535382, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.26279583929306, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(66.080743214040154, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td0feb5961983469fb9f4e2f766378c5c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td2a135a33ee14b67a205d4631e3b872b"><g class="toyplot-Edges"><path d="M 65.6205348227 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.018539546 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.018539546 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 144.024614419 L 192.018539546 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.926080297 121.694679206 L 191.363627605 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.124263837 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.354368033 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.248234331 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.248234331 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.354368033 73.9699157102 L 186.248234331 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.124263837 86.2294879842 L 185.354368033 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 99.3647439921 L 185.124263837 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.926080297 121.694679206 L 169.034670462 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.6205348227 145.119219086 L 133.926080297 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.2482343313969, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.35436803276284, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.12426383707489, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.0185395463414, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(169.0346704616621, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.36362760476797, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(133.92608029650123, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(65.620534822664212, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8759b198a0154f7bb486370922c0d753"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8aa4230eb4f64c66bb45337dcb57f6c4"><g class="toyplot-Edges"><path d="M 64.4080627146 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.151223732 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.151223732 144.024614419 L 191.788435351 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.226985783 121.694679206 L 191.151223732 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.928468525 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.664123681 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.832276747 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.832276747 73.9699157102 L 187.150950791 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.664123681 86.2294879842 L 185.832276747 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.928468525 99.3647439921 L 185.664123681 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.226985783 121.694679206 L 168.928468525 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.4080627146 145.119219086 L 134.226985783 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.15095079140355, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(185.83227674688402, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(185.66412368080435, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.78843535065346, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(168.92846852519077, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.15122373182524, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(134.22698578317016, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(64.408062714616065, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6dcec97e6eec427a88537dc74aef0585"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1c990d7818c9436aa86e5b49af23ef75"><g class="toyplot-Edges"><path d="M 63.6469488366 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.14237357 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.14237357 144.024614419 L 191.761884867 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.651861764 121.694679206 L 191.14237357 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.521497572 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.053462546 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.434019485 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.451788043 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.451788043 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.434019485 73.9699157102 L 186.451788043 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.053462546 86.2294879842 L 185.434019485 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.521497572 99.3647439921 L 185.053462546 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.651861764 121.694679206 L 170.521497572 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.6469488366 145.119219086 L 135.651861764 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.45178804296702, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.43401948511638, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.05346254609398, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.76188486653558, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.5214975722613, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.14237357045255, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(135.65186176416103, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(63.646948836571227, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfaa38a5594f4403daa07b6d2c9a42afa"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf052cd2bdb58401ba8486a919dcdf18d"><g class="toyplot-Edges"><path d="M 62.9743365723 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 144.024614419 L 191.797285512 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.68767182 121.694679206 L 191.168924055 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.229374012 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.973811094 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.354368033 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.195133363 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.195133363 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.354368033 73.9699157102 L 186.195133363 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.973811094 86.2294879842 L 185.354368033 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.229374012 99.3647439921 L 184.973811094 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.68767182 121.694679206 L 169.229374012 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.9743365723 145.119219086 L 141.68767182 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.1951333631612, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.35436803276284, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(184.97381109374044, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.79728551202604, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.22937401185962, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.16892405457043, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(141.68767182028398, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(62.974336572252533, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t4b9772dfb99b4d28baa9c22091db1ddb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8ecc70ddae454c4f9089997ecadf25bb"><g class="toyplot-Edges"><path d="M 62.0981705964 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.779516954 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.487529864 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.487529864 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.779516954 144.024614419 L 191.487529864 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.598897266 121.694679206 L 190.779516954 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.768960915 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.283498507 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.283566742 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.965029167 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.965029167 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.283566742 73.9699157102 L 185.965029167 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.283498507 86.2294879842 L 185.283566742 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.768960915 99.3647439921 L 184.283498507 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.598897266 121.694679206 L 165.768960915 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.0981705964 145.119219086 L 137.598897266 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.96502916747323, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.28356674178195, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.28349850667655, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.48752986398455, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(165.76896091516744, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.77951695417542, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.59889726613619, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(62.09817059636373, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta179c136b2fb4285a52037a0d7375129"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t95d44d0defbe42e1a4d98833f8c62e5c"><g class="toyplot-Edges"><path d="M 69.7093093768 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.522930509 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.806135673 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.806135673 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.522930509 144.024614419 L 191.806135673 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.431153611 121.694679206 L 191.522930509 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.76902915 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.354436268 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.876595789 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.876595789 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 73.9699157102 L 186.876595789 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.354436268 86.2294879842 L 186.726143046 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.76902915 99.3647439921 L 186.354436268 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.431153611 121.694679206 L 166.76902915 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.7093093768 145.119219086 L 143.431153611 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.87659578885248, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.72614304551806, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.35443626786827, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.80613567339864, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(166.76902915027284, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.522930509475, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(143.43115361068899, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(69.709309376812016, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t32a923b0e38841b9ad94b2409e1ac6c5"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t48fcae728fdc41f89e51e60ad4e85beb"><g class="toyplot-Edges"><path d="M 71.3377390694 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.841536319 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.841536319 144.024614419 L 191.930037933 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.342515527 121.694679206 L 191.841536319 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.008119978 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.646491593 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.018198371 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.327954019 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.327954019 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.018198371 73.9699157102 L 187.327954019 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.646491593 86.2294879842 L 187.018198371 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.008119978 99.3647439921 L 186.646491593 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.342515527 121.694679206 L 169.008119978 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.3377390694 145.119219086 L 141.342515527 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.32795401885585, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.01819837081433, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.64649159316454, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.93003793261525, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.00811997754428, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.84153631888913, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(141.34251552675201, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(71.337739069373043, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td1b208f84bc64adcadc2919da4fa6b0d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdf37e856a6d741289c642e06048e7dc2"><g class="toyplot-Edges"><path d="M 63.2575417362 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.496380025 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.496380025 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 144.024614419 L 191.496380025 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.492763565 121.694679206 L 191.168924055 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.468260134 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.867677392 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.354436268 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.354436268 73.9699157102 L 186.743843368 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.867677392 86.2294879842 L 186.354436268 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.468260134 99.3647439921 L 185.867677392 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.492763565 121.694679206 L 168.468260134 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.2575417362 145.119219086 L 138.492763565 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.7438433682633, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.35443626786827, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.86767739237447, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.49638002535715, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.46826013381477, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.16892405457043, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(138.4927635647702, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(63.257541736176194, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t13da580e226d42c0841fbdb4176c5dcf"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8320b58e20104a4f9a63c386bf68c03f"><g class="toyplot-Edges"><path d="M 63.7708510958 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.735334382 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.655751165 133.516409613 L 198.399505896 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.655751165 133.516409613 L 198.399505896 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.735334382 144.024614419 L 192.655751165 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.952971956 121.694679206 L 191.735334382 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.530143028 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991647887 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.53150773 63.4617109039 L 198.399505896 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.53150773 63.4617109039 L 198.399505896 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991647887 73.9699157102 L 187.53150773 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 86.2294879842 L 186.991647887 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.530143028 99.3647439921 L 186.531439495 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.952971956 121.694679206 L 167.530143028 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.7708510958 145.119219086 L 138.952971956 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.39950589599627, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.53150773042594, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.99164788669651, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.53143949532057, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.65575116516962, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.53014302831767, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.73533438241773, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(138.95297195614614, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(63.770851095787805, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8ba3f771f593446693ebd0b3ded36b5d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0ec8313ba4554ac2bccce516abecc0dd"><g class="toyplot-Edges"><path d="M 67.4790687109 145.119219086 L 198.399505896 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.222093258 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.222093258 144.024614419 L 192.381396163 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.209558401 121.694679206 L 192.222093258 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.317943861 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.168651114 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.504957246 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.628927741 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.628927741 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.504957246 73.9699157102 L 188.628927741 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.168651114 86.2294879842 L 187.504957246 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.317943861 99.3647439921 L 187.168651114 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.209558401 121.694679206 L 170.317943861 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.4790687109 145.119219086 L 138.209558401 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(188.62892774063013, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.50495724630812, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.16865111414876, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.38139616261856, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.3179438606912, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.22209325791155, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(138.20955840084656, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(67.479068710913197, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t796c213027204aa4b487313f0e56f178"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td44e3dfa1bfe4fc4a6f9a00ca9b5b285"><g class="toyplot-Edges"><path d="M 63.2929423817 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.753034705 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.797285512 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.753034705 144.024614419 L 191.797285512 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.934930458 121.694679206 L 191.753034705 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.140940633 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.673042077 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.496107085 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.496107085 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 73.9699157102 L 187.496107085 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.673042077 86.2294879842 L 187.106699985 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.140940633 99.3647439921 L 186.673042077 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.934930458 121.694679206 L 170.140940633 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.2929423817 145.119219086 L 133.934930458 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.49610708493549, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.10669998454048, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.67304207728239, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.79728551202604, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.14094063323893, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.753034705163, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(133.93493045787386, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(63.292942381666649, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5fd361fa0fd44baf9daba8e035bef117"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6d5bc9734116420ea2a24af96ca2c1ae"><g class="toyplot-Edges"><path d="M 67.0454108037 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.062790353 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.098190999 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.098190999 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.062790353 144.024614419 L 192.098190999 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.935066928 121.694679206 L 192.062790353 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.070207577 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.301403535 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.566976611 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.566976611 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 73.9699157102 L 188.566976611 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.301403535 86.2294879842 L 187.637709667 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.070207577 99.3647439921 L 187.301403535 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.935066928 121.694679206 L 171.070207577 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.0454108037 145.119219086 L 135.935066928 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.56697661102186, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.63770966689734, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.301403534738, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.09819099869495, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(171.07020757736342, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.06279035320449, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(135.93506692808469, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(67.045410803655116, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb8790f6f146a461abc55dcfc485d750d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t439f2bcc94394a519448e59e32f81044"><g class="toyplot-Edges"><path d="M 62.2574735011 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.301676475 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.602650197 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.602650197 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.301676475 144.024614419 L 192.602650197 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.775695788 121.694679206 L 191.301676475 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.211605454 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.044748855 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.628859506 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.628859506 73.9699157102 L 187.708510958 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.044748855 86.2294879842 L 187.628859506 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.211605454 99.3647439921 L 187.044748855 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 134.775695788 121.694679206 L 168.211605454 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.2574735011 145.119219086 L 134.775695788 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.70851095787827, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.62885950552473, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.04474885493218, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.60265019693398, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(168.21160545400897, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.30167647515967, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(134.77569578827223, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(62.257473501070791, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8c3cb9721a4843b7a7410d7ab2b138a2"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf9715152d5a0444e8de038be53b30ea2"><g class="toyplot-Edges"><path d="M 62.9743365723 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.49644826 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.885855361 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.885855361 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.49644826 144.024614419 L 192.885855361 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.891020827 121.694679206 L 192.49644826 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.239452405 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.549208053 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.611159183 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.611159183 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.549208053 73.9699157102 L 187.611159183 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.239452405 86.2294879842 L 187.549208053 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 99.3647439921 L 187.239452405 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.891020827 121.694679206 L 167.007983507 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.9743365723 145.119219086 L 138.891020827 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.61115918277949, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.54920805317118, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.2394524051297, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.88585536085762, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.00798350733342, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.49644826046253, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(138.89102082653784, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(62.974336572252533, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t71d8b7af65564031a90153eba3cb93a0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td00a16351e0d41c892f8b4ba633d7e7e"><g class="toyplot-Edges"><path d="M 64.9656228811 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.735402618 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.974356975 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.974356975 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.735402618 144.024614419 L 192.974356975 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.059242128 121.694679206 L 192.735402618 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.353208036 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.301403535 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.513807408 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.566908376 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.566908376 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.513807408 73.9699157102 L 187.566908376 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.301403535 86.2294879842 L 187.513807408 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.353208036 99.3647439921 L 187.301403535 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.059242128 121.694679206 L 168.353208036 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.9656228811 145.119219086 L 140.059242128 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.5669083759164, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.51380740768073, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.301403534738, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.97435697458374, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.35320803597079, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.73540261752314, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(140.05924212772294, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(64.965622881090752, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t955c18b254c24976be4b81fb1c52eb15"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tafd9afd27d044a3dae003e078346ecbd"><g class="toyplot-Edges"><path d="M 54.7525366571 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.319376798 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.487598099 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.487598099 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.319376798 144.024614419 L 192.487598099 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.094711008 121.694679206 L 191.319376798 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.459137032 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.593390625 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.788094175 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.044748855 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.044748855 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.788094175 73.9699157102 L 187.044748855 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.593390625 86.2294879842 L 186.788094175 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.459137032 99.3647439921 L 186.593390625 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.094711008 121.694679206 L 164.459137032 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 54.7525366571 145.119219086 L 141.094711008 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.04474885493218, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.78809417512639, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.59339062492884, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.48759809908998, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(164.45913703202052, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.31937679790485, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(141.09471100831882, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(54.752536657093863, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8c29a1563ad548caaedac5bf0addfa92"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf87122659e734de8b89dc2cee08a128a"><g class="toyplot-Edges"><path d="M 53.3542111602 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.151155497 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.018539546 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.018539546 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.151155497 144.024614419 L 192.018539546 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.360011144 121.694679206 L 190.151155497 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.353344506 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.310185461 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.416387397 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.602240786 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.602240786 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.416387397 73.9699157102 L 186.602240786 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.310185461 86.2294879842 L 186.416387397 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.353344506 99.3647439921 L 186.310185461 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.360011144 121.694679206 L 170.353344506 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 53.3542111602 145.119219086 L 138.360011144 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874151, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.60224078630142, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.41638739747654, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.31018546100518, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.0185395463414, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(170.35334450618163, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.15115549671978, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(138.36001114418099, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(53.354211160220792, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbe26331393d04d70a6a2f03bf2ced8ea"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t01648676c7d141319d7b2a904efbe850"><g class="toyplot-Edges"><path d="M 52.6727487345 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.584745169 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.195542774 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.195542774 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.584745169 144.024614419 L 192.195542774 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.484118109 121.694679206 L 189.584745169 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.662827214 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.398687075 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.398687075 73.9699157102 L 186.575690302 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 86.2294879842 L 186.398687075 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.662827214 99.3647439921 L 186.363286429 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.484118109 121.694679206 L 166.662827214 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 52.6727487345 145.119219086 L 141.484118109 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.57569030218363, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.39868707473136, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.36328642924087, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.19554277379373, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.66282721380151, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(189.58474516887247, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(141.48411810871386, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(52.672748734529513, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcd2acef7e5f7478ba0684e0d3a99f1d0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc8d19b74838b463483a4aed234cef660"><g class="toyplot-Edges"><path d="M 56.2216634449 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 144.024614419 L 191.885787126 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.634229677 121.694679206 L 190.664464856 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.326589317 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.203983525 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.265934654 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.265934654 73.9699157102 L 187.115550146 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.203983525 86.2294879842 L 186.265934654 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.326589317 99.3647439921 L 186.203983525 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.634229677 121.694679206 L 167.326589317 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 56.2216634449 145.119219086 L 136.634229677 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.11555014591309, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.26593465414214, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.20398352453381, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.88578712575219, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(167.32658931674754, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.66446485633142, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(136.63422967652122, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(56.221663444947829, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2fe968a2e7ad4eb08a128f98242012bd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb2af82f543d6449facb9549ae93a6e5a"><g class="toyplot-Edges"><path d="M 55.1596440802 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.69101534 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.903555684 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.903555684 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.69101534 144.024614419 L 192.903555684 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.077078921 121.694679206 L 190.69101534 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.813552898 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.84997707 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.911928199 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.380986752 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.380986752 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.911928199 73.9699157102 L 186.380986752 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.84997707 86.2294879842 L 185.911928199 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.813552898 99.3647439921 L 185.84997707 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.077078921 121.694679206 L 170.813552898 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.1596440802 145.119219086 L 142.077078921 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.38098675198614, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.91192819923754, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.84997706962926, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.90355568360283, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(170.8135528975576, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.6910153404493, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(142.07707892067901, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(55.159644080234131, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcffbb5b5129a4c66af2804946a6052d3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t62b5318b7a484dac8709b5876014156e"><g class="toyplot-Edges"><path d="M 59.1245163752 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.832617922 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.266344065 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.266344065 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.832617922 144.024614419 L 192.266344065 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.368724835 121.694679206 L 190.832617922 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.503729014 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.690674165 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.752625295 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.699592561 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.699592561 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.752625295 73.9699157102 L 186.699592561 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.690674165 86.2294879842 L 185.752625295 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.503729014 99.3647439921 L 185.690674165 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.368724835 121.694679206 L 169.503729014 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.1245163752 145.119219086 L 136.368724835 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.69959256140024, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.7526252945305, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(185.6906741649222, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.26634406477461, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.50372901441068, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(190.83261792241109, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(136.36872483534279, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(59.124516375165335, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcb1d5bbcb9cb41cca1497e4ded47f9fb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t62c35790b2d244ac911b770f4d183b10"><g class="toyplot-Edges"><path d="M 66.1869451505 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.496243555 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.611568593 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.611568593 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.496243555 144.024614419 L 193.611568593 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.731922627 121.694679206 L 189.496243555 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.344084934 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.43408772 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.78816241 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.78816241 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.43408772 73.9699157102 L 187.78816241 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 86.2294879842 L 186.43408772 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.344084934 99.3647439921 L 186.363286429 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.731922627 121.694679206 L 164.344084934 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.1869451505 145.119219086 L 141.731922627 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.78816241023179, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.43408772022178, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.36328642924087, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.61156859341199, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(164.34408493417655, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(189.49624355514635, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.73192262714707, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(66.186945150511534, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tddb97c6129704f0b8f74a560d796fae6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3a45904f146947d49456cd8a116442a8"><g class="toyplot-Edges"><path d="M 69.3199022764 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.213174861 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.903623919 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.903623919 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.213174861 144.024614419 L 193.903623919 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.368929541 121.694679206 L 191.213174861 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.680595772 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.88544595 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.522657569 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.522657569 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 73.9699157102 L 187.522657569 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.88544595 86.2294879842 L 186.973947564 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.680595772 99.3647439921 L 186.88544595 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.368929541 121.694679206 L 167.680595772 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.3199022764 145.119219086 L 139.368929541 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.52265756905334, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.97394756395127, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.88544595022512, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.90362391870826, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(167.68059577165212, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.21317486143349, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(139.36892954065902, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(69.319902276416983, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1d03be90297849aa9ea4060436b56c7e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0ea80b97d869433da35dec785e3fea67"><g class="toyplot-Edges"><path d="M 65.7267367591 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.956520182 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.10717763 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 194.10717763 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.956520182 144.024614419 L 194.10717763 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.917912486 121.694679206 L 190.956520182 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.096485121 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.257152728 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.389905148 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.832413217 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.832413217 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.389905148 73.9699157102 L 187.832413217 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.257152728 86.2294879842 L 187.389905148 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.096485121 99.3647439921 L 187.257152728 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.917912486 121.694679206 L 167.096485121 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.7267367591 145.119219086 L 143.917912486 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.83241321709485, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.38990514846412, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.25715272787491, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(194.10717763027836, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.09648512105957, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.9565201816277, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(143.91791248618279, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(65.726736759135576, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t276e34b7fd324f45a4c150757153a1b3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7bef2b3d2ff145f98e7ad5c1e02f3389"><g class="toyplot-Edges"><path d="M 69.2668013082 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.230943419 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.00975762 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.00975762 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.230943419 144.024614419 L 193.00975762 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.377506762 121.694679206 L 192.230943419 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.238155938 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.416455633 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.682028709 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.682028709 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 73.9699157102 L 188.682028709 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.416455633 86.2294879842 L 187.478406762 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.238155938 99.3647439921 L 187.416455633 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.377506762 121.694679206 L 168.238155938 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.2668013082 145.119219086 L 135.377506762 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(188.68202870886583, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.4784067621903, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.41645563258197, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.00975762007423, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(168.23815593812679, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.23094341928413, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(135.37750676160999, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(69.266801308181286, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2cfbe142b2d54b058eaad6bc567da6b4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tecf286138ead4872bb26b01bf03d780d"><g class="toyplot-Edges"><path d="M 68.0720295229 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.04509003 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.629200681 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.629200681 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.04509003 144.024614419 L 192.629200681 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.377574997 121.694679206 L 192.04509003 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.945895908 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.602309021 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.124468542 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.124468542 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 73.9699157102 L 188.124468542 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.602309021 86.2294879842 L 187.637709667 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.945895908 99.3647439921 L 187.602309021 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.377574997 121.694679206 L 164.945895908 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.0720295229 145.119219086 L 136.377574997 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(188.12446854239113, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.63770966689734, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.60230902140688, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.62920068105177, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(164.94589590751431, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.04509003045925, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(136.3775749967154, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(68.072029522878353, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcf63e4f3a5c54b1ebf417f2baedde936"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t44354730ba594011a323f66a7ac258d9"><g class="toyplot-Edges"><path d="M 63.3814439954 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.372477766 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.992057297 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.992057297 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.372477766 144.024614419 L 192.992057297 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.280291457 119.505469871 L 191.372477766 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.716064652 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.04481709 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.04481709 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 77.4726506456 L 188.04481709 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.186351437 91.4835903874 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.186351437 91.4835903874 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 77.4726506456 L 187.186351437 91.4835903874" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.716064652 94.9863253228 L 187.150950791 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.280291457 119.505469871 L 168.716064652 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.3814439954 144.024614419 L 137.280291457 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.18635143689403, 91.483590387374448)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(188.04481709003758, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.15095079140355, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.99205729732896, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(168.71606465224798, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.37247776614055, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(137.28029145672207, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(63.381443995392786, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t22340a93072941c2b7f19aaf9a52362d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5f929cc45e4f403c9a50850d14229bf3"><g class="toyplot-Edges"><path d="M 60.7971968746 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.832617922 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.832617922 144.024614419 L 191.549480994 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.182871447 120.818995472 L 190.832617922 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.760383694 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.894296112 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.53150773 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.53150773 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 80.9753855811 L 187.53150773 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.894296112 82.7267530488 L 186.965097403 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.760383694 97.6133765244 L 186.894296112 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.182871447 120.818995472 L 169.760383694 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.7971968746 144.681377219 L 136.182871447 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.53150773042594, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.96509740257864, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.89429611159773, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.54948099359288, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.7603836942165, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.83261792241109, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(136.18287144651788, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(60.797196874589432, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="ta73a1d4b70bd44059f1991634238a928"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t63a992cda7ff4086a302584eb7bce4df"><g class="toyplot-Edges"><path d="M 72.4528594023 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.36369584 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.36369584 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.930037933 144.024614419 L 192.36369584 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.245300222 121.694679206 L 191.930037933 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.50379725 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.009416445 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.062517413 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.575826772 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.575826772 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.062517413 73.9699157102 L 188.575826772 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.009416445 86.2294879842 L 188.062517413 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.50379725 99.3647439921 L 188.009416445 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 143.245300222 121.694679206 L 170.50379725 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.4528594023 145.119219086 L 143.245300222 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.57582677239444, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.0625174127828, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.00941644454713, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.36369583987334, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(170.50379724951608, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.93003793261522, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(143.24530022186408, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(72.452859402322431, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tebc26a2486ae46e492d4d7b11b01b643"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4e0027a7ae8c407090864abdd28bea54"><g class="toyplot-Edges"><path d="M 67.3994172586 145.119219086 L 198.399505896 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.5937318 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.5937318 144.024614419 L 191.885787126 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.439253186 121.694679206 L 191.5937318 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.618712877 99.3647439921 L 198.399505896 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.097849823 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.177501276 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.177501276 73.9699157102 L 187.797012572 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.097849823 86.2294879842 L 187.177501276 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.618712877 99.3647439921 L 187.097849823 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 132.439253186 121.694679206 L 168.618712877 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.3994172586 145.119219086 L 132.439253186 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.39950589599627, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.7970125716044, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.17750127552139, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.09784982316788, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.88578712575219, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(168.61871287714922, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.59373180045594, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(132.43925318590203, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(67.399417258559694, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t90cfbcb0b68742ee95af5a8eaeb16769"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t76944f0c82e246c38a85d51eebcb07c2"><g class="toyplot-Edges"><path d="M 68.0543292001 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.699933737 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.699933737 144.024614419 L 192.319445033 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.988372602 121.694679206 L 191.699933737 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.786865943 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.540357892 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584608699 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.894364347 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.894364347 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584608699 73.9699157102 L 187.894364347 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.540357892 86.2294879842 L 187.584608699 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.786865943 99.3647439921 L 187.540357892 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.988372602 121.694679206 L 168.786865943 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.0543292001 145.119219086 L 138.988372602 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.89436434670313, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.58460869866167, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.54035789179858, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.31944503301028, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.78686594322892, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.69993373692731, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.98837260163663, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(68.054329200133139, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t839ad5844c5e4362932691f1e8f8b684"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td22f5e24915b441db0294ff0d09ea3ff"><g class="toyplot-Edges"><path d="M 62.9123854426 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.753034705 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.753034705 144.024614419 L 192.257493903 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.572210312 121.694679206 L 191.753034705 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.645263361 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.159800953 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.195201598 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.522657569 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.522657569 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.195201598 73.9699157102 L 187.522657569 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.159800953 86.2294879842 L 187.195201598 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.645263361 99.3647439921 L 187.159800953 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.572210312 121.694679206 L 168.645263361 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.9123854426 145.119219086 L 135.572210312 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.52265756905334, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.19520159826664, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.15980095277618, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.25749390340198, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.64526336126707, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.753034705163, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(135.57221031180751, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(62.912385442644229, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf070bb0dc3ee47629dc3e48876da95fc"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1bbe7db75f0641429dd60f3b61ab96e1"><g class="toyplot-Edges"><path d="M 66.080743214 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.567181316 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.30174471 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.30174471 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.567181316 144.024614419 L 192.30174471 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.421962274 121.694679206 L 191.567181316 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.406240769 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.425305794 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.487256924 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.761611926 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.761611926 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.487256924 73.9699157102 L 187.761611926 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.425305794 86.2294879842 L 187.487256924 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.406240769 99.3647439921 L 187.425305794 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.421962274 121.694679206 L 167.406240769 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.080743214 145.119219086 L 138.421962274 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.76161192611394, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.48725692356288, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.42530579395458, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.30174471026507, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.40624076910106, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.56718131633806, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(138.42196227378929, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(66.080743214040154, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t92ffebb830f240e5ac8809e5f17cd904"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcc28bf5c8d3e4220bf3770f4287fddea"><g class="toyplot-Edges"><path d="M 69.2756514696 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.770735028 144.024614419 L 198.399505896 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.646901004 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.646901004 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.770735028 144.024614419 L 192.646901004 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.413248583 121.694679206 L 191.770735028 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.601149025 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.903214508 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.080217736 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.080217736 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 73.9699157102 L 188.080217736 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.903214508 86.2294879842 L 187.991716122 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.601149025 99.3647439921 L 187.903214508 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.413248583 121.694679206 L 170.601149025 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.2756514696 145.119219086 L 140.413248583 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599627, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(188.08021773552804, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.99171612180191, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.90321450807576, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.64690100379704, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.60114902461484, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.77073502790819, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(140.41324858262752, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(69.275651469553907, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tc5a26c59935e40508637867b81f4a01c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta325104375df49ee895f56c8b22d29db"><g class="toyplot-Edges"><path d="M 67.7976745203 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.646832769 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.806203909 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.646832769 144.024614419 L 192.806203909 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.430675965 121.694679206 L 191.646832769 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.317943861 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.805862733 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.894364347 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.98286596 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.98286596 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.894364347 73.9699157102 L 187.98286596 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.805862733 86.2294879842 L 187.894364347 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.317943861 99.3647439921 L 187.805862733 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.430675965 121.694679206 L 170.317943861 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.7976745203 145.119219086 L 136.430675965 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.98286596042931, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.89436434670313, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.80586273297698, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.80620390850407, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.3179438606912, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.64683276869158, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(136.43067596495109, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.797674520327334, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb37bb5071c01401bb68563249ade4a32"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3127b418fd234c24b9d1bae35eabed28"><g class="toyplot-Edges"><path d="M 69.3907035674 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.089340837 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.089340837 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 144.024614419 L 192.089340837 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.014991321 121.694679206 L 191.168924055 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.459273502 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.956315476 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.142168865 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.142168865 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 73.9699157102 L 188.142168865 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.956315476 86.2294879842 L 187.991716122 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.459273502 99.3647439921 L 187.956315476 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.014991321 121.694679206 L 166.459273502 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.3907035674 145.119219086 L 140.014991321 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(188.14216886513634, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.99171612180191, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.95631547631143, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.08934083732231, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.45927350223135, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.16892405457043, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(140.01499132085988, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(69.390703567397907, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t56b3dffb21b7458ba6c76b6ad82cb14a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdc16f47aba8e4460b96ed75cc6a4d295"><g class="toyplot-Edges"><path d="M 73.1166215053 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.186692612 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.354845679 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.354845679 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.186692612 144.024614419 L 192.354845679 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.200708239 121.694679206 L 192.186692612 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.910631732 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.416523868 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.505025481 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.628927741 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.628927741 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.505025481 73.9699157102 L 188.628927741 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.416523868 86.2294879842 L 188.505025481 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.910631732 99.3647439921 L 188.416523868 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.200708239 121.694679206 L 166.910631732 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 73.1166215053 145.119219086 L 138.200708239 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.62892774063013, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.50502548141353, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(188.4165238676874, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.35484567850077, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(166.91063173223469, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.1866926124211, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(138.20070823947395, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(73.116621505268512, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6120544df51745058be76b82a5fa8648"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="te0a0242a9e9540bdbe239c6396d7ab79"><g class="toyplot-Edges"><path d="M 65.1072254631 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.186692612 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.186692612 144.024614419 L 192.567249551 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.262727604 121.694679206 L 192.186692612 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.857735469 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.115618381 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.266071124 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.266071124 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.115618381 73.9699157102 L 188.266071124 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.991716122 86.2294879842 L 188.115618381 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.857735469 99.3647439921 L 187.991716122 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.262727604 121.694679206 L 169.857735469 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.1072254631 145.119219086 L 139.262727604 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(188.26607112435295, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(188.11561838101852, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.99171612180191, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.5672495514435, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(169.85773546931523, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.1866926124211, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.26272760418766, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(65.107225463052586, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t06968000138d4afca7fecd4fb2de5842"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf8cefdfdcc4d4cafb5a245f5ae16e7cd"><g class="toyplot-Edges"><path d="M 65.4081309497 145.119219086 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.284044388 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.284044388 144.024614419 L 192.319445033 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.944258265 121.694679206 L 192.284044388 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.062517413 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.168719349 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.363422899 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.363422899 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.168719349 73.9699157102 L 188.363422899 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.062517413 86.2294879842 L 188.168719349 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.034670462 99.3647439921 L 188.062517413 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.944258265 121.694679206 L 169.034670462 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.4081309497 145.119219086 L 140.944258265 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.36342289945173, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.16871934925419, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.06251741278282, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.31944503301028, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(169.0346704616621, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.28404438751983, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(140.94425826498437, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(65.408130949721482, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t60c0425888ea4ebcbea1535a1827d26d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tb434bca66be94b7da4a9004d8da6ddb5"><g class="toyplot-Edges"><path d="M 63.9567044846 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.381327928 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.531848906 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.531848906 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.381327928 144.024614419 L 192.531848906 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.537219077 121.694679206 L 191.381327928 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.813348192 99.3647439921 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.761611926 86.2294879842 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.841263378 73.9699157102 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.071367574 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.071367574 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.841263378 73.9699157102 L 188.071367574 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.761611926 86.2294879842 L 187.841263378 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.813348192 99.3647439921 L 187.761611926 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.537219077 121.694679206 L 167.813348192 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.9567044846 145.119219086 L 141.537219077 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(188.07136757415543, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.84126337846749, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.76161192611394, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.53184890595304, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.81334819224131, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.38132792751318, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(141.53721907694953, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(63.956704484612729, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t648e7597287645f38fd6ce8dac4d45be"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc858c27c1c48450fa4ffff852639533b"><g class="toyplot-Edges"><path d="M 56.7792236114 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.735266147 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.735266147 144.024614419 L 192.257493903 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.723072466 121.694679206 L 190.735266147 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.565611909 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.841263378 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.920914831 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.920914831 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.841263378 73.9699157102 L 187.920914831 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 86.2294879842 L 187.841263378 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.565611909 99.3647439921 L 187.797012572 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.723072466 121.694679206 L 168.565611909 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 56.7792236114 145.119219086 L 141.723072466 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.920914830821, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.84126337846749, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.7970125716044, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.25749390340201, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(168.56561190891355, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.73526614731233, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(141.72307246577444, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(56.77922361142253, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0bff3e3ee0ba421b88eaee3aad09b0f1"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t21d3d7c9eaee450aa5b2f2bdf370ad67"><g class="toyplot-Edges"><path d="M 57.2748326483 144.900298153 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.726552456 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.726552456 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.080490676 144.024614419 L 192.726552456 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.439935537 121.256837339 L 192.080490676 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.264569952 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.690810635 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 70.4671807747 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.78816241 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.78816241 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.708510958 70.4671807747 L 187.78816241 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.690810635 84.4781205165 L 187.708510958 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.264569952 98.4890602582 L 187.690810635 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.439935537 121.256837339 L 166.264569952 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 57.2748326483 144.900298153 L 142.439935537 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.78816241023176, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.70851095787825, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.690810635133, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.72655245615056, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.26456995203387, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.0804906759497, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(142.4399355369562, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(57.274832648288942, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t18930dd9ff5d48a49d0c3f6fe109c416"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t007d48f4108d4e449d4c52627382f44c"><g class="toyplot-Edges"><path d="M 52.327592441 144.900298153 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.310526637 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.257493903 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.310526637 144.024614419 L 192.257493903 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.882443606 121.256837339 L 191.310526637 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.47717853 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.549208053 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.558058215 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.646559828 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.646559828 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.558058215 70.4671807747 L 187.646559828 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.549208053 84.4781205165 L 187.558058215 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.47717853 98.4890602582 L 187.549208053 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.882443606 121.256837339 L 169.47717853 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 52.327592441 144.900298153 L 142.882443606 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.64655982826994, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.55805821454379, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.54920805317118, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.25749390340198, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(169.4771785302928, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.31052663653224, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(142.8824436055869, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(52.327592440997549, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0f5a94b1eba4424985558f170ac99b81"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf9e1ae29431e4875beb56c927825b0f5"><g class="toyplot-Edges"><path d="M 58.2483503993 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.452197454 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.452197454 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.363627605 144.024614419 L 192.452197454 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.856166062 119.505469871 L 191.363627605 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.999133346 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.805862733 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.805862733 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 77.4726506456 L 187.805862733 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.85011354 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.85011354 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.797012572 77.4726506456 L 187.85011354 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.999133346 94.9863253228 L 187.797012572 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 146.856166062 119.505469871 L 166.999133346 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.2483503993 144.024614419 L 146.856166062 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874151, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.85011353984007, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.80586273297698, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.7970125716044, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.4521974535995, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.99913334596081, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.36362760476791, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(146.85616606189072, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(58.248350399276504, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf6834e713268415c9b603c3028d35818"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t9a06eb2b460c4f7d90a3d3c5aa5862ae"><g class="toyplot-Edges"><path d="M 55.9473084424 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.151223732 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.514080348 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.514080348 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.151223732 144.024614419 L 191.514080348 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.351092748 119.505469871 L 191.151223732 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.397458843 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991647887 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.991647887 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 77.4726506456 L 186.991647887 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.345654342 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.345654342 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 77.4726506456 L 187.345654342 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.397458843 94.9863253228 L 186.973947564 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.351092748 119.505469871 L 168.397458843 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.9473084424 144.024614419 L 137.351092748 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.34565434160106, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.99164788669648, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.97394756395124, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.51408034810237, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(168.39745884283386, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.15122373182518, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.35109274770295, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(55.947308442396789, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t64856d244192488eab5f0634b0908c2d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4bc3127ebd4c4ef5bbab4cdb6a529255"><g class="toyplot-Edges"><path d="M 58.7528095975 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.053871957 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.637982607 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.637982607 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.053871957 144.024614419 L 191.637982607 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.581333414 119.505469871 L 191.053871957 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.6985008 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.770393852 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.770393852 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.75269353 77.4726506456 L 186.770393852 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.823494821 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.823494821 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.75269353 77.4726506456 L 186.823494821 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.6985008 94.9863253228 L 186.75269353 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.581333414 119.505469871 L 170.6985008 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.7528095975 144.024614419 L 139.581333414 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.82349482061684, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.77039385238115, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.75269352963591, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.637982607319, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(170.69850079971363, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.05387195672645, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.58133341360178, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(58.75280959751553, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td388bc09a07b4e4b8115701d3f973116"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t287d4dc17f0e46ad83fee19119228f3d"><g class="toyplot-Edges"><path d="M 67.5233195178 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.788435351 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.390178089 144.024614419 L 191.788435351 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.174157755 119.505469871 L 191.390178089 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.158504486 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.726211281 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.743911603 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.10676822 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.10676822 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.743911603 84.4781205165 L 188.10676822 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.726211281 77.4726506456 L 187.743911603 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.158504486 94.9863253228 L 187.726211281 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.174157755 119.505469871 L 168.158504486 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.5233195178 144.024614419 L 138.174157755 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(188.10676821964589, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.7439116033687, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.72621128062346, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.78843535065346, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.15850448577331, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.39017808888582, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.17415775535608, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(67.523319517776272, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9959504b478f4118b7e9e924668ee39a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t8e2321710f744ea78c72c48f86273646"><g class="toyplot-Edges"><path d="M 65.8771895025 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.469829541 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.222093258 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.222093258 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.469829541 144.024614419 L 192.222093258 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.156593903 119.505469871 L 191.469829541 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.344357875 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.071367574 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.10676822 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.425374029 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.425374029 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.10676822 84.4781205165 L 188.425374029 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 188.071367574 77.4726506456 L 188.10676822 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.344357875 94.9863253228 L 188.071367574 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.156593903 119.505469871 L 168.344357875 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.8771895025 144.024614419 L 140.156593903 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(188.42537402906004, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(188.10676821964589, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(188.07136757415543, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.22209325791155, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.34435787459819, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.46982954123933, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.1565939028217, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(65.877189502470031, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcdfbaa44467941a683aa4b80024e4634"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7e967af47dfa42c68ae1eb2c983e952f"><g class="toyplot-Edges"><path d="M 59.2484186344 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.823767761 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.814985835 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.814985835 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.823767761 144.024614419 L 191.814985835 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.537219077 119.505469871 L 190.823767761 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.344289639 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.221752082 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.221752082 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.938546918 77.4726506456 L 187.221752082 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.938546918 77.4726506456 L 187.115550146 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.344289639 94.9863253228 L 186.938546918 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.537219077 119.505469871 L 167.344289639 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.2484186344 144.024614419 L 141.537219077 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736888, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.11555014591309, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.22175208238446, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.93854691846079, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.81498583477122, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.34428963949279, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.82376776103848, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(141.5372190769495, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(59.248418634381906, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1186f85dc63b4c8b98f407d82de88fdf"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tadda380bbeb749db82a83d04e2a94959"><g class="toyplot-Edges"><path d="M 56.77037345 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.912269375 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.416796808 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.416796808 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.912269375 144.024614419 L 192.416796808 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.546069238 119.505469871 L 190.912269375 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.63627673 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.584540464 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.584540464 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.504889011 77.4726506456 L 186.584540464 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.504889011 77.4726506456 L 186.575690302 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.63627673 94.9863253228 L 186.504889011 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.546069238 119.505469871 L 166.63627673 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 56.77037345 144.024614419 L 141.546069238 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.57569030218366, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.58454046355627, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.50488901120272, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.41679680810904, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(166.63627672968366, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.91226937476463, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(141.54606923832219, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(56.770373450049945, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t251fd0dd6ca942eea4853f32872bb566"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6e4d6a1423974bffaeead1c227607846"><g class="toyplot-Edges"><path d="M 60.664444454 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.257357433 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.823835996 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.823835996 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.257357433 144.024614419 L 191.823835996 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.71429054 119.505469871 L 190.257357433 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.503592544 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.566840141 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.566840141 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.504889011 77.4726506456 L 186.566840141 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.504889011 77.4726506456 L 186.557989979 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.503592544 94.9863253228 L 186.504889011 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.71429054 119.505469871 L 167.503592544 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.664444454 144.024614419 L 142.71429054 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.55798997943839, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.566840140811, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.50488901120272, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.82383599614386, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(167.50359254419982, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(190.25735743319117, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(142.71429053950723, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(60.664444454000204, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf23fe3b0ee6e49b78c250687f302877d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t09346452d99244569171453bbfc5247e"><g class="toyplot-Edges"><path d="M 55.6818036012 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.310458401 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.452197454 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.452197454 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.310458401 144.024614419 L 192.452197454 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.917503076 119.505469871 L 190.310458401 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.769302091 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.230534009 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.230534009 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.186283202 77.4726506456 L 186.230534009 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.345586106 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.345586106 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.186283202 77.4726506456 L 186.345586106 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.769302091 94.9863253228 L 186.186283202 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.917503076 119.505469871 L 170.769302091 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.6818036012 144.024614419 L 137.917503076 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.34558610649566, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.23053400865166, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.1862832017886, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.4521974535995, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(170.76930209069451, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.31045840142684, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.91750307555029, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(55.68180360121837, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t1d9e118e3b1c46faa0b545267fb3016d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t5a41c939bd08443390a4195cbfa993d2"><g class="toyplot-Edges"><path d="M 58.4519041108 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.053871957 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.407946647 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.407946647 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.053871957 144.024614419 L 192.407946647 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.121056787 119.505469871 L 191.053871957 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.096485121 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.203983525 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.203983525 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.142032395 77.4726506456 L 186.203983525 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.142032395 77.4726506456 L 186.557989979 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.096485121 94.9863253228 L 186.142032395 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.121056787 119.505469871 L 167.096485121 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.4519041108 144.024614419 L 138.121056787 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736896, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736896, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736896, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.55798997943839, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.20398352453381, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.14203239492556, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.40794664673643, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(167.09648512105957, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.05387195672645, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(138.12105678712041, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(58.451904110846641, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tfd06e6c82d2a4ab49bd0347fcdcc6273"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t75547786acee42dea78cd0e22a5a825b"><g class="toyplot-Edges"><path d="M 70.2934200274 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.540767302 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.540767302 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.761884867 144.024614419 L 193.540767302 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.36879307 119.505469871 L 191.761884867 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.698296094 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.009348209 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.009348209 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 77.4726506456 L 187.009348209 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 77.4726506456 L 187.106699985 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.698296094 94.9863253228 L 186.965097403 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.36879307 119.505469871 L 167.698296094 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.2934200274 144.024614419 L 137.36879307 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.10669998454048, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.0093482094417, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.96509740257864, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.54076730243105, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.69829609439734, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.76188486653561, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(137.36879307044819, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(70.293420027404551, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2a70439b97a9481694397302ca67b95d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t1fe7846dea8e44daa138126700ee4db7"><g class="toyplot-Edges"><path d="M 71.9395500427 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.49644826 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.248711977 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.49644826 144.024614419 L 193.248711977 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.935476339 119.505469871 L 192.49644826 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 77.4726506456 L 187.363354664 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.381054987 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 77.4726506456 L 187.381054987 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 94.9863253228 L 187.319103857 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.935476339 119.505469871 L 167.007983507 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.9395500427 144.024614419 L 141.935476339 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.38105498709152, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.36335466434628, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.31910385748324, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.2487119771348, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(167.00798350733342, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.49644826046253, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(141.93547633871717, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(71.939550042710806, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t564c9009dee14635aa6cf7486a72806e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2fa642dfa86e47c4837acca9e9306ff6"><g class="toyplot-Edges"><path d="M 66.4701503144 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.682165179 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.682165179 144.024614419 L 192.567249551 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.457499389 119.505469871 L 190.682165179 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.848612368 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.478338527 77.4726506456 L 186.531439495 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.478338527 77.4726506456 L 186.717292884 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.848612368 94.9863253228 L 186.478338527 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.457499389 119.505469871 L 165.848612368 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.4701503144 144.024614419 L 140.457499389 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.71729288414545, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.53143949532057, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.47833852708484, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.5672495514435, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(165.84861236752096, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(190.68216517907666, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(140.45749938949058, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(66.470150314435173, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t0c465b2e5ac14cc5978fa3cb25cbdee7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4306883873da4c1e86c3d6839e218bac"><g class="toyplot-Edges"><path d="M 63.7443006117 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.673383253 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.726552456 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.726552456 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.673383253 144.024614419 L 192.726552456 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.36879307 119.505469871 L 191.673383253 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.362058197 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.407537236 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.407537236 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.319035622 77.4726506456 L 186.407537236 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.372136591 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.372136591 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.319035622 77.4726506456 L 186.372136591 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.362058197 94.9863253228 L 186.319035622 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.36879307 119.505469871 L 168.362058197 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.7443006117 144.024614419 L 137.36879307 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.37213659061351, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.40753723610396, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.31903562237781, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.72655245615059, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(168.36205819734343, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(191.67338325280949, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(137.36879307044822, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(63.744300611669992, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t8b4141fa5443491a92fd1bf5ba3fba73"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcb0c54a37a354854b05812cfb66a974f"><g class="toyplot-Edges"><path d="M 64.3284112623 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.328226959 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.07170875 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.07170875 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.328226959 144.024614419 L 193.07170875 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.351365688 119.505469871 L 191.328226959 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.158572721 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.903146273 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.903146273 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.779244014 77.4726506456 L 186.903146273 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.779244014 77.4726506456 L 186.814644659 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.158572721 94.9863253228 L 186.779244014 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.351365688 119.505469871 L 169.158572721 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.3284112623 144.024614419 L 141.351365688 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.81464465924421, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.90314627297036, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.77924401375378, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.0717087496825, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(169.15857272087871, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.32822695927749, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(141.35136568812464, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(64.32841126226252, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t803e614433ee43a3a047b3977624e266"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3c60ff7dc789401298181a5bd378165e"><g class="toyplot-Edges"><path d="M 67.3728667744 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.540699067 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.213311332 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.213311332 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.540699067 144.024614419 L 193.213311332 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.820219536 119.505469871 L 192.540699067 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.185259675 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.911996434 77.4726506456 L 186.973947564 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.973947564 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.911996434 77.4726506456 L 186.973947564 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 171.185259675 94.9863253228 L 186.911996434 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.820219536 119.505469871 L 171.185259675 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.3728667744 144.024614419 L 138.820219536 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.97394756395127, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.97394756395127, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(186.911996434343, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.21331133164435, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(171.18525967520739, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.54069906732565, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(138.82021953555693, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.372866774441832, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t391bc23f6633434f9dcfb7fe7d02f2f9"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t94860032b6a2472b8aacb20c444d66ed"><g class="toyplot-Edges"><path d="M 72.3820581113 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.930106168 133.516409613 L 198.399505896 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.930106168 133.516409613 L 198.399505896 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 144.024614419 L 192.930106168 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.669698557 119.505469871 L 192.142441806 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.981637729 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.540357892 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.540357892 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.416455633 77.4726506456 L 187.540357892 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584608699 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.584608699 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.416455633 77.4726506456 L 187.584608699 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.981637729 94.9863253228 L 187.416455633 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.669698557 119.505469871 L 169.981637729 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.3820581113 144.024614419 L 137.669698557 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.39950589599627, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.39950589599627, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.58460869866167, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.54035789179858, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.41645563258197, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.93010616772068, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.98163772853184, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.14244180555801, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(137.6696985571171, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(72.382058111341522, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t44486734c6e94e05a0659889e6091a92"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf948eb1899d446a99c53c1252acba549"><g class="toyplot-Edges"><path d="M 66.4347496689 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.974356975 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.974356975 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.142441806 144.024614419 L 192.974356975 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.359874674 119.505469871 L 192.142441806 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.875162852 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.018198371 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.018198371 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 77.4726506456 L 187.018198371 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.637709667 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 77.4726506456 L 187.637709667 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.875162852 94.9863253228 L 187.000498048 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.359874674 119.505469871 L 165.875162852 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.4347496689 144.024614419 L 136.359874674 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.63770966689734, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.01819837081433, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.00049804806909, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.97435697458377, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(165.87516285163881, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.14244180555801, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(136.35987467397018, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(66.434749668944733, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t72731c384a294f3285b7ce950e77f332"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tea0d1a28b7614ae5a44afc9d4f66a0d1"><g class="toyplot-Edges"><path d="M 65.6205348227 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.230875184 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.230875184 144.024614419 L 192.071640515 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.156457433 119.505469871 L 191.230875184 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.043588858 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.938546918 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.938546918 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 77.4726506456 L 186.938546918 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.327954019 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.327954019 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 77.4726506456 L 187.327954019 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.043588858 94.9863253228 L 186.920846596 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.156457433 119.505469871 L 170.043588858 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.6205348227 144.024614419 L 138.156457433 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.32795401885585, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.93854691846082, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.92084659571557, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.07164051457707, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(170.04358885814014, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.23087518417876, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(138.15645743261089, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(65.620534822664212, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3623611e95804eec9109e759c94b7a30"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t82a3adbe0bba4ffd9e3f6930dd4e939c"><g class="toyplot-Edges"><path d="M 65.4966325634 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.726484221 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.876936964 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.876936964 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.726484221 144.024614419 L 191.876936964 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.076464805 119.505469871 L 191.726484221 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.264979363 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.681892239 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.699592561 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.796944336 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.796944336 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.699592561 84.4781205165 L 186.796944336 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.681892239 77.4726506456 L 186.699592561 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.264979363 94.9863253228 L 186.681892239 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.076464805 119.505469871 L 172.264979363 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.4966325634 144.024614419 L 133.076464805 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.79694433649897, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.69959256140024, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.681892238655, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.87693696437958, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(172.26497936266631, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.72648422104513, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(133.07646480473028, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(65.496632563447605, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t660613f675eb4cdebda3fca505b23cbd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc65376ebdf694092b352e0489a0a6bc6"><g class="toyplot-Edges"><path d="M 58.3103015289 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.646832769 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.381396163 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.646832769 144.024614419 L 192.381396163 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.068024054 119.505469871 L 191.646832769 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.30923017 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.973879329 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.973879329 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.956179006 77.4726506456 L 185.973879329 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.026980297 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.026980297 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.956179006 77.4726506456 L 186.026980297 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 172.30923017 94.9863253228 L 185.956179006 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.068024054 119.505469871 L 172.30923017 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 58.3103015289 144.024614419 L 139.068024054 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736888, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.02698029708154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.97387932884587, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(185.9561790061006, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.38139616261856, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(172.3092301695294, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.64683276869158, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(139.06802405399014, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(58.3103015288848, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tbd94cee749614d4c861386a7a0f20040"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t165d596e08d943068ae54599265c7388"><g class="toyplot-Edges"><path d="M 55.41629876 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.36355937 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.708852133 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.708852133 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.36355937 144.024614419 L 192.708852133 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.52830068 119.505469871 L 190.36355937 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.609794481 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.327817549 77.4726506456 L 185.345517871 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.345517871 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.327817549 77.4726506456 L 185.345517871 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.609794481 94.9863253228 L 185.327817549 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.52830068 119.505469871 L 167.609794481 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.41629876 144.024614419 L 140.52830068 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736896, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.34551787139026, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.34551787139026, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(185.32781754864504, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.70885213340534, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(167.60979448067121, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.36355936966257, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(140.52830068047152, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(55.416298760039957, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5e782fe7d39f4e78aa2b0f2dc434250c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t82aa086f1ee24aa5ba1fd0a86710cd4b"><g class="toyplot-Edges"><path d="M 53.0356053508 143.805693485 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.655751165 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.655751165 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 144.024614419 L 192.655751165 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.625652456 119.067628004 L 190.664464856 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.149790795 94.110641589 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.770257382 75.7212831779 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.770257382 80.9753855811 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.787957705 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.787957705 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.770257382 80.9753855811 L 184.787957705 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.770257382 75.7212831779 L 184.770257382 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.149790795 94.110641589 L 184.770257382 75.7212831779" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.625652456 119.067628004 L 170.149790795 94.110641589" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 53.0356053508 143.805693485 L 140.625652456 119.067628004" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874151, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.78795770491553, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.77025738217031, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(184.77025738217031, 75.721283177905292)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.65575116516962, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(170.14979079461153, 94.11064158895266)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(190.66446485633142, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(140.62565245557025, 119.06762800394549)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(53.035605350806691, 143.80569348547345)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t635624f7fcf241309bf393f3164e8589"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf27b3f160a334c78bb65e08a961e5f03"><g class="toyplot-Edges"><path d="M 62.5937796332 144.024614419 L 198.399505896 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.283976152 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.292894549 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.292894549 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.283976152 144.024614419 L 192.292894549 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.430948905 119.505469871 L 191.283976152 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.318148566 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.026912062 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.026912062 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.044612385 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.044612385 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.026912062 70.4671807747 L 185.044612385 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.026912062 77.4726506456 L 185.026912062 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 173.318148566 94.9863253228 L 185.026912062 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.430948905 119.505469871 L 173.318148566 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.5937796332 144.024614419 L 140.430948905 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.04461238472138, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.02691206197613, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(185.02691206197613, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.29289454889246, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(173.31814856600741, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.2839761524144, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(140.43094890537276, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(62.593779633230113, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t7280ac2ae5d74c2a9072fdc7b7b9fdeb"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td50191b41f1d464097eb2e701b3ef743"><g class="toyplot-Edges"><path d="M 63.3814439954 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.602513727 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.5937318 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.5937318 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.602513727 144.024614419 L 191.5937318 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.811369374 119.505469871 L 190.602513727 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.654181758 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.434019485 91.4835903874 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.434019485 91.4835903874 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.425169324 77.4726506456 L 185.434019485 91.4835903874" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.442869646 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.442869646 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.425169324 77.4726506456 L 185.442869646 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.654181758 94.9863253228 L 185.425169324 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.811369374 119.505469871 L 169.654181758 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.3814439954 144.024614419 L 138.811369374 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.44286964648899, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.43401948511638, 91.483590387374448)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(185.42516932374377, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.59373180045594, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.65418175774511, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(190.60251372672309, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(138.81136937418432, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(63.381443995392786, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td5c056b3e9e64e3181a3cb716e4cb2d3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfbc3704493bf4608bbb505e712c65cf3"><g class="toyplot-Edges"><path d="M 55.8942074742 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.239588875 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.168924055 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 189.239588875 144.024614419 L 191.168924055 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.014377205 119.505469871 L 189.239588875 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.459341737 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.726006575 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.743706898 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.779107544 84.4781205165 L 198.399505896 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.779107544 84.4781205165 L 198.399505896 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.743706898 70.4671807747 L 184.779107544 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 184.726006575 77.4726506456 L 184.743706898 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.459341737 94.9863253228 L 184.726006575 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 131.014377205 119.505469871 L 167.459341737 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 55.8942074742 144.024614419 L 131.014377205 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599633, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599633, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.77910754354292, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.74370689805247, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(184.72600657530725, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.16892405457043, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(167.45934173733679, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(189.23958887534053, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(131.01437720491117, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(55.894207474161114, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td26b99093aa441dcbf85bc2c0677823a"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t749c520c00744c9ba0b802ec3e1ffef5"><g class="toyplot-Edges"><path d="M 62.5229783422 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.328226959 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.328226959 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.664464856 144.024614419 L 191.328226959 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.510668593 119.505469871 L 190.664464856 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.618849347 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.965029167 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.009279974 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.018130136 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.018130136 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.009279974 70.4671807747 L 186.018130136 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 185.965029167 77.4726506456 L 186.009279974 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.618849347 94.9863253228 L 185.965029167 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.510668593 119.505469871 L 170.618849347 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.5229783422 144.024614419 L 141.510668593 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.01813013570896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.00927997433632, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(185.96502916747323, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.32822695927749, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(170.61884934736008, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(190.66446485633142, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(141.51066859283171, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(62.52297834224921, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="teb97e723ef45413780ef3a62a90c5f5e"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcbbb56fb09664441b501901b6623381f"><g class="toyplot-Edges"><path d="M 61.2131544591 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.788367116 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.514148583 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.514148583 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.788367116 144.024614419 L 192.514148583 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.156525668 119.505469871 L 190.788367116 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.636344965 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.080081265 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.159732718 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.221683847 84.4781205165 L 198.399505896 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.221683847 84.4781205165 L 198.399505896 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.159732718 70.4671807747 L 186.221683847 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.080081265 77.4726506456 L 186.159732718 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.636344965 94.9863253228 L 186.080081265 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.156525668 119.505469871 L 167.636344965 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.2131544591 144.024614419 L 139.156525668 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599633, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599633, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.22168384727905, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.15973271767075, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.08008126531723, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.5141485832078, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(167.63634496478909, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.78836711554803, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(139.15652566771632, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(61.213154459102299, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t581e9526bdc843f09f9ce7521957e92c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td192cef6524e41d3a9a67d6b56f8ff6e"><g class="toyplot-Edges"><path d="M 62.5937796332 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.868155038 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.868155038 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.549480994 144.024614419 L 192.868155038 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.56322368 120.818995472 L 191.549480994 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.875299322 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.487188688 82.7267530488 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.540289657 80.9753855811 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.646491593 63.4617109039 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.646491593 63.4617109039 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.540289657 80.9753855811 L 186.646491593 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.487188688 82.7267530488 L 186.540289657 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.875299322 97.6133765244 L 186.487188688 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.56322368 120.818995472 L 167.875299322 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 62.5937796332 144.681377219 L 133.56322368 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.64649159316454, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.54028965669318, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.48718868845748, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.86815503811241, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.87529932184967, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.54948099359288, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(133.56322368022407, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(62.593779633230128, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="taa11cddbd3d34f00a277af269d184228"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3e3a86cc1ebe46b9b697b35fc67f3453"><g class="toyplot-Edges"><path d="M 61.8326657552 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.089340837 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.584949874 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.584949874 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.089340837 144.024614419 L 192.584949874 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.510532123 119.943311738 L 192.089340837 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.255651556 95.8620090567 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.425237559 79.2240181133 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.460638204 73.9699157102 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.460638204 73.9699157102 L 186.531439495 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.425237559 79.2240181133 L 186.460638204 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.255651556 95.8620090567 L 186.425237559 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.510532123 119.943311738 L 165.255651556 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 61.8326657552 144.243535352 L 139.510532123 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.53143949532057, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.46063820433966, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.4252375588492, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.58494987418874, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(165.25565155555583, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.08934083732231, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(139.51053212262084, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(61.832665755185296, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te60c9585b58a45f083c134ff82cfe2ce"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tad7a8ee14c254317b6e74a06eacfbf99"><g class="toyplot-Edges"><path d="M 59.9918321897 144.243535352 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 144.024614419 L 198.399505896 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.30174471 133.516409613 L 198.399505896 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.30174471 133.516409613 L 198.399505896 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 144.024614419 L 192.30174471 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.103629405 119.943311738 L 192.071640515 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.317739155 95.8620090567 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.858895466 79.2240181133 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.867745627 73.9699157102 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.062449178 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.062449178 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.867745627 73.9699157102 L 187.062449178 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.858895466 79.2240181133 L 186.867745627 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.317739155 95.8620090567 L 186.858895466 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.103629405 119.943311738 L 167.317739155 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 59.9918321897 144.243535352 L 142.103629405 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.39950589599633, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736896, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.06244917767742, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.86774562747991, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.8588954661073, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.3017447102651, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(167.31773915537497, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.07164051457713, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(142.10362940479686, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(59.991832189681546, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tf6664fe58dc749f1bb7edec07aec1302"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t778a26095fae4bb2afff8642e4aa1970"><g class="toyplot-Edges"><path d="M 66.5232512827 144.243535352 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.611500358 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.611500358 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.071640515 144.024614419 L 192.611500358 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.183007917 119.943311738 L 192.071640515 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.609999186 95.8620090567 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.177501276 79.2240181133 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.212901921 73.9699157102 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.248302567 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.248302567 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.212901921 73.9699157102 L 187.248302567 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.177501276 79.2240181133 L 187.212901921 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 170.609999186 95.8620090567 L 187.177501276 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.183007917 119.943311738 L 170.609999186 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.5232512827 144.243535352 L 138.183007917 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.2483025665023, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.21290192101185, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.17750127552139, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.61150035830656, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(170.60999918598748, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(192.07164051457713, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(138.18300791672871, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(66.52325128267087, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t55f772cc18a042698d93bb1687353e92"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td67e2da296024139ba7a1f7c5c953bcf"><g class="toyplot-Edges"><path d="M 65.7355869205 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.133523409 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.505298422 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.133523409 144.024614419 L 192.505298422 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.200571769 119.943311738 L 191.133523409 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.264569952 95.8620090567 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 79.2240181133 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.832344982 73.9699157102 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.858895466 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.858895466 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.832344982 73.9699157102 L 186.858895466 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 79.2240181133 L 186.832344982 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.264569952 95.8620090567 L 186.726143046 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.200571769 119.943311738 L 166.264569952 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.7355869205 144.243535352 L 136.200571769 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.85889546610727, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.83234498198945, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.72614304551806, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.50529842183516, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(166.26456995203387, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.13352340908003, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(136.20057176926312, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(65.735586920508197, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5644ea6d75ad479d9b9764e6a67cbeef"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t85f8b3c907ce4c1298af4f4fd119411d"><g class="toyplot-Edges"><path d="M 69.5765569562 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.894637287 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.337145356 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.337145356 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.894637287 144.024614419 L 192.337145356 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.997222763 119.943311738 L 191.894637287 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.485960457 95.8620090567 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 79.2240181133 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 73.9699157102 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 77.4726506456 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.150950791 77.4726506456 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.106699985 73.9699157102 L 187.150950791 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 79.2240181133 L 187.106699985 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.485960457 95.8620090567 L 187.053599016 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.997222763 119.943311738 L 168.485960457 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.5765569562 144.243535352 L 138.997222763 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.15095079140355, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.10669998454048, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.05359901630482, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.33714535575552, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(168.48596045656004, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.89463728712479, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(138.99722276300923, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(69.576556956222802, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcae4a22903f14a0a93a7b70909847fa7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdb0a9d60e44444f2893464bcf22b2df8"><g class="toyplot-Edges"><path d="M 63.4787957705 144.243535352 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.505230187 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.213243097 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.213243097 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.505230187 144.024614419 L 192.213243097 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.908379974 119.943311738 L 191.505230187 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.698159624 95.8620090567 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.673042077 79.2240181133 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 73.9699157102 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 77.4726506456 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 77.4726506456 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 73.9699157102 L 186.743843368 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.673042077 79.2240181133 L 186.717292884 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.698159624 95.8620090567 L 186.673042077 79.2240181133" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.908379974 119.943311738 L 165.698159624 95.8620090567" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.4787957705 144.243535352 L 133.908379974 119.943311738" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.7438433682633, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.71729288414545, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.67304207728239, 79.224018113342893)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.21324309653892, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(165.69815962418653, 95.86200905667144)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.50523018672979, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(133.90837997375604, 119.94331173780488)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(63.478795770491558, 144.24353535240314)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t87b93eccfe834c238a3b8eed91d1eac3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t0b6f2eb6d46542a6b19f2ea86f6bfabf"><g class="toyplot-Edges"><path d="M 63.8770530323 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.974220504 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.000839224 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.000839224 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.974220504 144.024614419 L 192.000839224 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.652066469 120.818995472 L 190.974220504 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.742615136 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 82.7267530488 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 80.9753855811 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 63.4617109039 L 198.399505896 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 63.4617109039 L 198.399505896 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.814644659 80.9753855811 L 186.814644659 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.726143046 82.7267530488 L 186.814644659 80.9753855811" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.742615136 97.6133765244 L 186.726143046 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.652066469 120.818995472 L 168.742615136 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 63.8770530323 144.681377219 L 138.652066469 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.39950589599627, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.81464465924421, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.81464465924421, 80.975385581061687)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(186.72614304551806, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.00083922359619, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(168.74261513636583, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(190.97422050437291, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(138.65206646947726, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(63.877053032259198, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t5d136ebc04944e76836a9997691bb566"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="ta4b273537a45401782160eb78ac3a931"><g class="toyplot-Edges"><path d="M 71.6120940719 145.119219086 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.593800036 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.593800036 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.319445033 144.024614419 L 192.593800036 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.837783388 121.694679206 L 192.319445033 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.946100613 99.3647439921 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 86.2294879842 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 73.9699157102 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.389905148 63.4617109039 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.389905148 63.4617109039 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 73.9699157102 L 187.389905148 63.4617109039" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 86.2294879842 L 187.363354664 73.9699157102" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.946100613 99.3647439921 L 187.319103857 86.2294879842" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.837783388 121.694679206 L 167.946100613 99.3647439921" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.6120940719 145.119219086 L 136.837783388 121.694679206" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.38990514846412, 63.46171090387373)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.36335466434628, 73.969915710186498)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.31910385748324, 86.229487984218068)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.59380003556137, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(167.94610061283052, 99.364743992109027)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.31944503301028, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(136.83778338809134, 121.69467920552366)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(71.612094071924076, 145.11921908626255)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td365d9257c424a8fa177e4121ba2a239"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tdb770ef250534fc999d035a32f87e625"><g class="toyplot-Edges"><path d="M 72.3378073045 144.900298153 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.75310294 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.133659879 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.133659879 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.75310294 144.024614419 L 193.133659879 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.245163752 121.256837339 L 192.75310294 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.786524768 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.566908376 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.646559828 70.4671807747 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.65540999 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.65540999 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.646559828 70.4671807747 L 187.65540999 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.566908376 84.4781205165 L 187.646559828 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 163.786524768 98.4890602582 L 187.566908376 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.245163752 121.256837339 L 163.786524768 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.3378073045 144.900298153 L 141.245163752 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.65540998964255, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.64655982826994, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.5669083759164, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.1336598792908, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(163.78652476770185, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(192.75310294026838, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(141.24516375165325, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(72.337807304478446, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t6ef52225f3b34336a492db83e822a8b6"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7a13bc1cd6b5430fb92229d535d3864e"><g class="toyplot-Edges"><path d="M 64.275310294 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.009689385 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.009689385 144.024614419 L 192.62035052 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.288868678 120.818995472 L 192.009689385 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.981637729 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.49603885 82.7267530488 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 66.9644458393 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.708442723 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.708442723 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.575690302 66.9644458393 L 186.708442723 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.49603885 82.7267530488 L 186.575690302 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.981637729 97.6133765244 L 186.49603885 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 133.288868678 120.818995472 L 169.981637729 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.275310294 144.681377219 L 133.288868678 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.70844272277284, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.57569030218363, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(186.49603884983009, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.62035051967919, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(169.98163772853184, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(192.00968938496879, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(133.28886867767301, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(64.275310294026838, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t3a37b8893b3f416695fba95ff2e2afb7"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td8153e59fae541628bbc841be3805548"><g class="toyplot-Edges"><path d="M 74.5237971635 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.062858588 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.346063752 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.346063752 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.062858588 144.024614419 L 193.346063752 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.439867302 120.818995472 L 193.062858588 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.866380925 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.628859506 82.7267530488 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.673110312 66.9644458393 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.743911603 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.743911603 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.673110312 66.9644458393 L 187.743911603 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.628859506 82.7267530488 L 187.673110312 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.866380925 97.6133765244 L 187.628859506 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.439867302 120.818995472 L 166.866380925 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 74.5237971635 144.681377219 L 141.439867302 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.7439116033687, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.67311031238779, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.62885950552473, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.34606375223353, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(166.8663809253716, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(193.06285858830989, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(141.43986730185077, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(74.523797163514175, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tad851c075a49460cb121b9e8edc9cc12"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="td7314f54221e4805a49e0fa6c485323c"><g class="toyplot-Edges"><path d="M 72.3555076272 144.681377219 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.540699067 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.2664123 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.2664123 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.540699067 144.024614419 L 193.2664123 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.422166979 120.818995472 L 192.540699067 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 97.6133765244 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.195201598 82.7267530488 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.274853051 66.9644458393 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.319103857 77.4726506456 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.274853051 66.9644458393 L 187.319103857 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.195201598 82.7267530488 L 187.274853051 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.007983507 97.6133765244 L 187.195201598 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.422166979 120.818995472 L 167.007983507 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 72.3555076272 144.681377219 L 141.422166979 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.31910385748324, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.27485305062015, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.19520159826664, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(193.26641229988002, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(167.00798350733342, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(192.54069906732565, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(141.42216697910555, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(72.355507627223687, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t357b220bc6724fa68a75c6b2dc75ca85"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tf72938c64ece4af195cb693b5d56ebfa"><g class="toyplot-Edges"><path d="M 71.2138368102 144.681377219 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 144.024614419 L 198.399505896 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 133.516409613 L 198.399505896 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.567249551 133.516409613 L 198.399505896 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 144.024614419 L 192.567249551 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.129838713 120.818995472 L 191.65568293 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.388472211 97.6133765244 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 82.7267530488 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 66.9644458393 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 77.4726506456 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.965097403 66.9644458393 L 187.000498048 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 82.7267530488 L 186.965097403 66.9644458393" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.388472211 97.6133765244 L 186.920846596 82.7267530488" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.129838713 120.818995472 L 166.388472211 97.6133765244" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 71.2138368102 144.681377219 L 137.129838713 120.818995472" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.39950589599627, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.00049804806909, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.96509740257864, 66.964445839311324)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(186.92084659571557, 82.726753048780466)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(192.5672495514435, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(166.38847221125044, 97.613376524390233)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.65568293006422, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(137.12983871338761, 120.81899547166427)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(71.213836810156437, 144.68137721933283)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="td7c69a36c09c450d953f1beccefd1b04"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tef89253ee18d4fe29fa6d9937b710bfe"><g class="toyplot-Edges"><path d="M 69.2314006627 144.900298153 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.319513268 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.319513268 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.62035052 144.024614419 L 193.319513268 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.758063701 121.256837339 L 192.62035052 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.512442706 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.097849823 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.133250469 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.168651114 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.168651114 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.133250469 70.4671807747 L 187.168651114 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.097849823 84.4781205165 L 187.133250469 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.512442706 98.4890602582 L 187.097849823 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.758063701 121.256837339 L 167.512442706 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.2314006627 144.900298153 L 135.758063701 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.16865111414876, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.1332504686583, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(187.09784982316788, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(193.31951326811571, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.51244270557245, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(192.62035051967914, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(135.75806370063242, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(69.231400662690831, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tb90a33912d474edeb4f884822aec0cf8"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t85059f304438404e9eefcc02e4f0d44f"><g class="toyplot-Edges"><path d="M 68.6561401735 144.900298153 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.938956329 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.231011654 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.231011654 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.938956329 144.024614419 L 193.231011654 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.422030509 121.256837339 L 192.938956329 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.12296737 98.4890602582 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.504957246 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.602309021 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.602309021 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.504957246 70.4671807747 L 187.602309021 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.478406762 84.4781205165 L 187.504957246 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.12296737 98.4890602582 L 187.478406762 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.422030509 121.256837339 L 166.12296737 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 68.6561401735 144.900298153 L 139.422030509 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.60230902140688, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.50495724630812, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.4784067621903, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(193.23101165438959, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(166.12296737007202, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(192.93895632909329, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(139.42203050889472, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(68.656140173470916, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t9945c31828f24c0eaf95f28977518110"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tfbc3d4ce94064ca8b9033c2eb033e40e"><g class="toyplot-Edges"><path d="M 64.036355937 144.900298153 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.407946647 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.045158266 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 192.407946647 144.024614419 L 193.045158266 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.103288229 121.256837339 L 192.407946647 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.370703653 98.4890602582 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.903146273 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 70.4671807747 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.292553373 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.292553373 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.920846596 70.4671807747 L 187.292553373 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.903146273 84.4781205165 L 186.920846596 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 165.370703653 98.4890602582 L 186.903146273 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 137.103288229 121.256837339 L 165.370703653 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 64.036355937 144.900298153 L 137.103288229 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(187.29255337336537, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.92084659571557, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.90314627297036, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(193.04515826556468, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(165.3707036533998, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(192.40794664673643, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(137.10328822926976, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(64.03635593696626, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t10bca789e3fa46bea51a8fb823903ed3"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t00dbc656165b4110b07f214ae68a390e"><g class="toyplot-Edges"><path d="M 70.4084721252 144.900298153 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.151360202 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.20446117 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.20446117 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.151360202 144.024614419 L 193.20446117 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.855415476 121.256837339 L 193.151360202 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.618576407 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.345654342 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 70.4671807747 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.496107085 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.496107085 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.363354664 70.4671807747 L 187.496107085 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.345654342 84.4781205165 L 187.363354664 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 166.618576407 98.4890602582 L 187.345654342 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 135.855415476 121.256837339 L 166.618576407 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.4084721252 144.900298153 L 135.855415476 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.49610708493549, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.36335466434628, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(187.34565434160106, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.20446117027171, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(166.61857640693842, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(193.15136020203605, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(135.85541547573118, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(70.408472125248551, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te2e95a24dd0b46cea7918b8e2920c25c"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t672f0624b4984450981f6c1e2a538ab6"><g class="toyplot-Edges"><path d="M 70.0810161545 144.900298153 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.779585189 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.39916472 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 193.39916472 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.779585189 144.024614419 L 193.39916472 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.616529354 121.256837339 L 191.779585189 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.220182675 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.266002889 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.283703212 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.699660797 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.699660797 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.283703212 70.4671807747 L 187.699660797 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.266002889 84.4781205165 L 187.283703212 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.220182675 98.4890602582 L 187.266002889 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 136.616529354 121.256837339 L 164.220182675 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 70.0810161545 144.900298153 L 136.616529354 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.69966079650561, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.28370321199273, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(187.26600288924755, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(193.39916472046926, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(164.22018267495994, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(191.77958518928082, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(136.616529353776, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(40%,76.1%,64.7%);fill-opacity:1.0;opacity:1.0;stroke:rgb(40%,76.1%,64.7%);stroke-opacity:1.0" transform="translate(70.081016154461821, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2ec2fdbb2cc04162a7b31b9c750c1fa0"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tc6b4026e1eb04e4cac4a5262f1f43d74"><g class="toyplot-Edges"><path d="M 67.4967690337 144.900298153 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.487529864 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.903487448 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.903487448 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.487529864 144.024614419 L 191.903487448 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.900143928 121.256837339 L 191.487529864 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.680595772 98.4890602582 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.027048532 70.4671807747 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.115550146 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.027048532 70.4671807747 L 187.115550146 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.000498048 84.4781205165 L 187.027048532 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.680595772 98.4890602582 L 187.000498048 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 142.900143928 121.256837339 L 167.680595772 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 67.4967690337 144.900298153 L 142.900143928 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.11555014591309, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.02704853218694, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(187.00049804806909, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.90348744849743, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(167.68059577165212, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(191.48752986398455, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(142.90014392833211, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(98.8%,55.3%,38.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(98.8%,55.3%,38.4%);stroke-opacity:1.0" transform="translate(67.496769033658438, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te7db4c34603d4dc7bdceb0d149150dd4"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t6c619dd049514df5999cb96042086c15"><g class="toyplot-Edges"><path d="M 66.8772577376 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.443279057 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.567181316 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.567181316 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.443279057 144.024614419 L 191.567181316 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.457499389 119.505469871 L 191.443279057 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.123172075 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 77.4726506456 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.0801495 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.0801495 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 84.4781205165 L 187.0801495 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.717292884 77.4726506456 L 186.717292884 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.123172075 94.9863253228 L 186.717292884 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 140.457499389 119.505469871 L 169.123172075 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 66.8772577376 144.024614419 L 140.457499389 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(187.08014950042264, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.71729288414545, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(186.71729288414545, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.56718131633806, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(169.12317207538825, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(191.44327905712146, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(140.45749938949058, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(55.3%,62.7%,79.6%);fill-opacity:1.0;opacity:1.0;stroke:rgb(55.3%,62.7%,79.6%);stroke-opacity:1.0" transform="translate(66.877257737575434, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="t2aeaa4453ee04109a69113bee4e38d5d"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t3eb033070c644c23b84661dbd4a8ebf4"><g class="toyplot-Edges"><path d="M 65.8683393411 144.900298153 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.682233414 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.85038648 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.85038648 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.682233414 144.024614419 L 191.85038648 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.873525209 121.256837339 L 191.682233414 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.114321914 98.4890602582 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.230602244 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.230602244 70.4671807747 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.372204826 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.372204826 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.230602244 70.4671807747 L 187.372204826 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.230602244 84.4781205165 L 187.230602244 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.114321914 98.4890602582 L 187.230602244 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.873525209 121.256837339 L 169.114321914 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.8683393411 144.900298153 L 141.873525209 121.256837339" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.37220482571891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.23060224375709, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(187.23060224375709, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.85038648026173, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(169.11432191401562, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(191.68223341418206, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(141.87352520910886, 121.25683733859398)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(90.6%,54.1%,76.5%);fill-opacity:1.0;opacity:1.0;stroke:rgb(90.6%,54.1%,76.5%);stroke-opacity:1.0" transform="translate(65.868339341097396, 144.90029815279772)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tea95279be3b2404ea41b87b7573b122f"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t2d1b36b6a0304bf78dc454b056d9520c"><g class="toyplot-Edges"><path d="M 57.4606860371 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.133523409 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.239725346 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.239725346 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.133523409 144.024614419 L 191.239725346 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.457431154 119.505469871 L 191.133523409 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.937250451 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.248234331 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.257084493 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.363286429 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.257084493 84.4781205165 L 186.363286429 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.248234331 77.4726506456 L 186.257084493 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 167.937250451 94.9863253228 L 186.248234331 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 139.457431154 119.505469871 L 167.937250451 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 57.4606860371 144.024614419 L 139.457431154 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736896, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.36328642924087, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.25708449276954, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(186.24823433139693, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.23972534555136, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(167.93725045145794, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(191.13352340907997, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(139.45743115438518, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(65.1%,84.7%,32.9%);fill-opacity:1.0;opacity:1.0;stroke:rgb(65.1%,84.7%,32.9%);stroke-opacity:1.0" transform="translate(57.460686037113838, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="te0828619ba1440b7ae61d660b51f1740"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t4a2baea1965f44c3bbdfa5c599bdd096"><g class="toyplot-Edges"><path d="M 69.6296579245 144.024614419 L 198.408356057 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.885787126 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.65568293 144.024614419 L 191.885787126 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.404466656 119.505469871 L 191.65568293 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.609589775 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.239452405 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.239452405 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 77.4726506456 L 187.239452405 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 84.4781205165 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 84.4781205165 L 198.408356057 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 187.053599016 77.4726506456 L 187.053599016 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 164.609589775 94.9863253228 L 187.053599016 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 141.404466656 119.505469871 L 164.609589775 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 69.6296579245 144.024614419 L 141.404466656 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(198.40835605736891, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.05359901630482, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.2394524051297, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(187.05359901630482, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.88578712575219, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(164.60958977535498, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(191.65568293006422, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(141.40446665636031, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(100%,85.1%,18.4%);fill-opacity:1.0;opacity:1.0;stroke:rgb(100%,85.1%,18.4%);stroke-opacity:1.0" transform="translate(69.629657924458485, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tce6e3d05b2ab4db4a6734d0de935b5fd"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="t7d479429d72e45779246d60386632539"><g class="toyplot-Edges"><path d="M 60.0006823511 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.354777443 144.024614419 L 198.417206219 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.983138901 133.516409613 L 198.408356057 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.983138901 133.516409613 L 198.408356057 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 191.354777443 144.024614419 L 191.983138901 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.714017599 119.505469871 L 191.354777443 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.468260134 94.9863253228 L 198.417206219 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 77.4726506456 L 198.408356057 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 70.4671807747 L 198.417206219 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.743843368 70.4671807747 L 198.417206219 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.557989979 84.4781205165 L 186.743843368 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.531439495 77.4726506456 L 186.557989979 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 168.468260134 94.9863253228 L 186.531439495 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 138.714017599 119.505469871 L 168.468260134 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 60.0006823511 144.024614419 L 138.714017599 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.40835605736891, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.7438433682633, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.55798997943839, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(186.53143949532057, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.98313890085097, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(168.46826013381479, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(191.35477744339536, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(138.71401759908557, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(89.8%,76.9%,58%);fill-opacity:1.0;opacity:1.0;stroke:rgb(89.8%,76.9%,58%);stroke-opacity:1.0" transform="translate(60.000682351054131, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tcad8c7cb05004227a65dae1b6f879183"><g class="toyplot-Series"></g></g><g class="toyplot-mark-Graph" id="tcf75a30f4b5942c7a889389aa185ba99"><g class="toyplot-Edges"><path d="M 65.841788857 144.024614419 L 198.417206219 168.543758967" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.036103399 144.024614419 L 198.408356057 154.532819225" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.23965711 133.516409613 L 198.417206219 140.521879484" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.23965711 133.516409613 L 198.417206219 126.510939742" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 190.036103399 144.024614419 L 190.23965711 133.516409613" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.156866843 119.505469871 L 190.036103399 144.024614419" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.60108079 94.9863253228 L 198.408356057 112.5" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.88544595 70.4671807747 L 198.408356057 56.456241033" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.88544595 70.4671807747 L 198.408356057 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.584540464 77.4726506456 L 186.88544595 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.664191916 84.4781205165 L 198.417206219 70.4671807747" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.664191916 84.4781205165 L 198.417206219 98.4890602582" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 186.584540464 77.4726506456 L 186.664191916 84.4781205165" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 169.60108079 94.9863253228 L 186.584540464 77.4726506456" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 144.156866843 119.505469871 L 169.60108079 94.9863253228" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><path d="M 65.841788857 144.024614419 L 144.156866843 119.505469871" style="fill:none;opacity:0.2;stroke:rgb(16.1%,15.3%,14.1%);stroke-linecap:round;stroke-opacity:1.0;stroke-width:2"></path><g class="toyplot-HeadMarkers"></g><g class="toyplot-MiddleMarkers"></g><g class="toyplot-TailMarkers"></g></g><g class="toyplot-Vertices"><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 98.489060258249651)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 56.456241032998548)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 112.5)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 126.51093974175035)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 140.5218794835007)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.40835605736891, 154.53281922525107)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(198.41720621874154, 168.54375896700148)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.66419191590978, 84.478120516499274)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.88544595022512, 70.467180774748925)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(186.58454046355624, 77.4726506456241)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.23965711044593, 133.51640961262552)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(169.60108078950941, 94.98632532281205)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(190.03610339887581, 144.02461441893831)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(144.15686684324336, 119.50546987087519)"><circle r="0.0"></circle></g><g class="toyplot-Datum" style="fill:rgb(70.2%,70.2%,70.2%);fill-opacity:1.0;opacity:1.0;stroke:rgb(70.2%,70.2%,70.2%);stroke-opacity:1.0" transform="translate(65.841788856979562, 144.02461441893831)"><circle r="0.0"></circle></g></g></g><g class="toyplot-mark-Text" id="tad3b6e726fac4580a0716f8c99440ea4"><g class="toyplot-Series"><g class="toyplot-Datum" transform="translate(198.41720621874154,98.489060258249651)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">lip</text></g><g class="toyplot-Datum" transform="translate(198.41720621874154,70.467180774748925)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">rex</text></g><g class="toyplot-Datum" transform="translate(198.40835605736891,84.478120516499274)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">rck</text></g><g class="toyplot-Datum" transform="translate(198.40835605736891,56.456241032998548)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">tha</text></g><g class="toyplot-Datum" transform="translate(198.40835605736891,112.5)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">cup</text></g><g class="toyplot-Datum" transform="translate(198.41720621874154,126.51093974175035)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">sup</text></g><g class="toyplot-Datum" transform="translate(198.41720621874154,140.5218794835007)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">cya</text></g><g class="toyplot-Datum" transform="translate(198.40835605736891,154.53281922525107)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">cys</text></g><g class="toyplot-Datum" transform="translate(198.41720621874154,168.54375896700148)"><text style="fill:rgb(16.1%,15.3%,14.1%);fill-opacity:1.0;font-family:helvetica;font-size:12.0px;font-weight:normal;opacity:1.0;stroke:none;vertical-align:baseline;white-space:pre" x="12.0" y="3.066">prz</text></g></g></g></g></g></svg><div class="toyplot-behavior"><script>(function()
{
var modules={};
modules["toyplot/tables"] = (function()
    {
        var tables = [];

        var module = {};

        module.set = function(owner, key, names, columns)
        {
            tables.push({owner: owner, key: key, names: names, columns: columns});
        }

        module.get = function(owner, key)
        {
            for(var i = 0; i != tables.length; ++i)
            {
                var table = tables[i];
                if(table.owner != owner)
                    continue;
                if(table.key != key)
                    continue;
                return {names: table.names, columns: table.columns};
            }
        }

        module.get_csv = function(owner, key)
        {
            var table = module.get(owner, key);
            if(table != undefined)
            {
                var csv = "";
                csv += table.names.join(",") + "\n";
                for(var i = 0; i != table.columns[0].length; ++i)
                {
                  for(var j = 0; j != table.columns.length; ++j)
                  {
                    if(j)
                      csv += ",";
                    csv += table.columns[j][i];
                  }
                  csv += "\n";
                }
                return csv;
            }
        }

        return module;
    })();
modules["toyplot/root/id"] = "t5aba26c279e840d5b7744f5b016c8add";
modules["toyplot/root"] = (function(root_id)
    {
        return document.querySelector("#" + root_id);
    })(modules["toyplot/root/id"]);
modules["toyplot/canvas/id"] = "t493499ef62de4bc5bb57012ed1d381bc";
modules["toyplot/canvas"] = (function(canvas_id)
    {
        return document.querySelector("#" + canvas_id);
    })(modules["toyplot/canvas/id"]);
modules["toyplot/menus/context"] = (function(root, canvas)
    {
        var wrapper = document.createElement("div");
        wrapper.innerHTML = "<ul class='toyplot-context-menu' style='background:#eee; border:1px solid #b8b8b8; border-radius:5px; box-shadow: 0px 0px 8px rgba(0%,0%,0%,0.25); margin:0; padding:3px 0; position:fixed; visibility:hidden;'></ul>"
        var menu = wrapper.firstChild;

        root.appendChild(menu);

        var items = [];

        var ignore_mouseup = null;
        function open_menu(e)
        {
            var show_menu = false;
            for(var index=0; index != items.length; ++index)
            {
                var item = items[index];
                if(item.show(e))
                {
                    item.item.style.display = "block";
                    show_menu = true;
                }
                else
                {
                    item.item.style.display = "none";
                }
            }

            if(show_menu)
            {
                ignore_mouseup = true;
                menu.style.left = (e.clientX + 1) + "px";
                menu.style.top = (e.clientY - 5) + "px";
                menu.style.visibility = "visible";
                e.stopPropagation();
                e.preventDefault();
            }
        }

        function close_menu()
        {
            menu.style.visibility = "hidden";
        }

        function contextmenu(e)
        {
            open_menu(e);
        }

        function mousemove(e)
        {
            ignore_mouseup = false;
        }

        function mouseup(e)
        {
            if(ignore_mouseup)
            {
                ignore_mouseup = false;
                return;
            }
            close_menu();
        }

        function keydown(e)
        {
            if(e.key == "Escape" || e.key == "Esc" || e.keyCode == 27)
            {
                close_menu();
            }
        }

        canvas.addEventListener("contextmenu", contextmenu);
        canvas.addEventListener("mousemove", mousemove);
        document.addEventListener("mouseup", mouseup);
        document.addEventListener("keydown", keydown);

        var module = {};
        module.add_item = function(label, show, activate)
        {
            var wrapper = document.createElement("div");
            wrapper.innerHTML = "<li class='toyplot-context-menu-item' style='background:#eee; color:#333; padding:2px 20px; list-style:none; margin:0; text-align:left;'>" + label + "</li>"
            var item = wrapper.firstChild;

            items.push({item: item, show: show});

            function mouseover()
            {
                this.style.background = "steelblue";
                this.style.color = "white";
            }

            function mouseout()
            {
                this.style.background = "#eee";
                this.style.color = "#333";
            }

            function choose_item(e)
            {
                close_menu();
                activate();

                e.stopPropagation();
                e.preventDefault();
            }

            item.addEventListener("mouseover", mouseover);
            item.addEventListener("mouseout", mouseout);
            item.addEventListener("mouseup", choose_item);
            item.addEventListener("contextmenu", choose_item);

            menu.appendChild(item);
        };
        return module;
    })(modules["toyplot/root"],modules["toyplot/canvas"]);
modules["toyplot/io"] = (function()
    {
        var module = {};
        module.save_file = function(mime_type, charset, data, filename)
        {
            var uri = "data:" + mime_type + ";charset=" + charset + "," + data;
            uri = encodeURI(uri);

            var link = document.createElement("a");
            if(typeof link.download != "undefined")
            {
              link.href = uri;
              link.style = "visibility:hidden";
              link.download = filename;

              document.body.appendChild(link);
              link.click();
              document.body.removeChild(link);
            }
            else
            {
              window.open(uri);
            }
        };
        return module;
    })();
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t52aa31c1e5b44694a1a55de2e38438b0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -0.0018270000000000005, -0.0019690000000000003, -0.0045850000000000005, -0.0011720000000000003, -0.00459, -0.0034000000000000002, -0.005255, -0.005531], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t52aa31c1e5b44694a1a55de2e38438b0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6fefcfad67fe47f29cd47a00cf23b82c","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -0.001736000000000001, -0.0017870000000000008, -0.004414000000000001, -0.0008810000000000007, -0.004425000000000001, -0.003944000000000001, -0.005030000000000001, -0.005326000000000001], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6fefcfad67fe47f29cd47a00cf23b82c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t989ab78f06b742c6b5bf755c732df236","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -0.0019330000000000007, -0.0019470000000000008, -0.0048400000000000006, -0.0009990000000000008, -0.004847000000000001, -0.0037750000000000006, -0.005496000000000001, -0.005815000000000001], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t989ab78f06b742c6b5bf755c732df236","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf0a8d18d957b45038d95e70f366539fb","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000018675e-06, -1.0000000000018675e-06, -1.0000000000018675e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, -0.0019459999999999998, -0.0019770000000000005, -0.0048660000000000005, -0.0007350000000000004, -0.004889, -0.0035020000000000003, -0.005553000000000001, -0.005909], [8.0, 7.0, 6.0, 4.0, 5.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf0a8d18d957b45038d95e70f366539fb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf2187f860df4440bab92b6e570060b08","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -0.0019050000000000004, -0.001922, -0.004764000000000001, -0.0006500000000000004, -0.004808000000000001, -0.003723, -0.0054930000000000005, -0.005838], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf2187f860df4440bab92b6e570060b08","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb450ce834a544ec3b32ab5604a2fb535","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0020310000000000007, -0.002052000000000001, -0.005093, -0.000648000000000001, -0.005111, -0.003673, -0.0058130000000000005, -0.00619], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb450ce834a544ec3b32ab5604a2fb535","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9e5daa44288749cfb2ca50f0eb29ea8f","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -0.0020870000000000003, -0.0021400000000000004, -0.005289000000000001, -0.0007390000000000009, -0.005323000000000001, -0.003439000000000001, -0.006121000000000001, -0.006417000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9e5daa44288749cfb2ca50f0eb29ea8f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4399cf4722cd40f0854feacb2a98f78a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -1.999999999999398e-06, -1.999999999999398e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.0019839999999999997, -0.0020109999999999998, -0.005032999999999999, -0.0007349999999999995, -0.005044, -0.0029929999999999996, -0.0058649999999999996, -0.006167], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4399cf4722cd40f0854feacb2a98f78a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t57ebccbfe0e4491c869d8d40d7fd0384","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.0019460000000000007, -0.001960000000000001, -0.004880000000000001, -0.0006500000000000004, -0.004896, -0.0026230000000000003, -0.0057540000000000004, -0.0060420000000000005], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t57ebccbfe0e4491c869d8d40d7fd0384","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2679d76b34ed443da830d4630a919aad","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -1.0000000000001327e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0018019999999999998, -0.0018129999999999995, -0.004495, -0.0007159999999999996, -0.004519, -0.0025659999999999997, -0.005403, -0.005637], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2679d76b34ed443da830d4630a919aad","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c04ee1d2eac4d19ac3025f884a7b4c0","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -0.0019910000000000006, -0.0019960000000000004, -0.004894000000000001, -0.0006820000000000003, -0.004966, -0.00237, -0.005945000000000001, -0.006224], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c04ee1d2eac4d19ac3025f884a7b4c0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdf2f39ecb15a4bfba0595d3e7a710bb6","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0019379999999999996, -0.0019429999999999994, -0.0046949999999999995, -0.0006680000000000002, -0.004777, -0.002445, -0.0057859999999999995, -0.006063], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdf2f39ecb15a4bfba0595d3e7a710bb6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t33fcb132a61b43bfa163fcd55dd3269a","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.0000000000001327e-06, -2.0000000000002655e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -0.0020620000000000005, -0.002066, -0.004966, -0.0008599999999999997, -0.005038000000000001, -0.00262, -0.006137, -0.006439], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t33fcb132a61b43bfa163fcd55dd3269a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t41fc181587734eed99e73da108cede90","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -8.673617379884035e-19, -1.0000000000001327e-06, -8.673617379884035e-19, -0.0020170000000000006, -0.0020250000000000008, -0.004854000000000001, -0.0007910000000000009, -0.004936000000000001, -0.0034160000000000006, -0.0060030000000000005, -0.006351000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t41fc181587734eed99e73da108cede90","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t21fbb93fda994175b089a87fb19df6e7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.001962, -0.0019660000000000007, -0.004712000000000001, -0.0006880000000000011, -0.004778000000000001, -0.002998000000000001, -0.005912000000000001, -0.006182000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t21fbb93fda994175b089a87fb19df6e7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd921c04c783475398a0c7dfa155f6ed","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.673617379884035e-19, 0.0, -0.002097, -0.00211, -0.005038000000000001, -0.0007520000000000001, -0.005098, -0.0036090000000000002, -0.006315, -0.006616], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdd921c04c783475398a0c7dfa155f6ed","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t42c4e169a7354be09437f44a81ed21b7","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002012999999999999, -0.0020619999999999996, -0.004912, -0.0006549999999999993, -0.004971, -0.003351, -0.006196999999999999, -0.006493], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t42c4e169a7354be09437f44a81ed21b7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tca1d2b27413c4b5aaede2bc3cabf3b90","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, -1.0000000000001327e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0019439999999999995, -0.001959, -0.004644, -0.0005419999999999991, -0.004716, -0.0038969999999999994, -0.0059229999999999994, -0.006225], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tca1d2b27413c4b5aaede2bc3cabf3b90","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf7118d8149644b8f97574a40126d9965","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -1.0000000000001327e-06, -0.001967, -0.0019959999999999995, -0.004706, -0.0004989999999999994, -0.004772, -0.003789, -0.0059559999999999995, -0.006312], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf7118d8149644b8f97574a40126d9965","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tffc653747caf4eda91cd80f502deb3fe","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -8.673617379884035e-19, -8.673617379884035e-19, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.0000000000018675e-06, -0.0018950000000000009, -0.001980000000000001, -0.0046250000000000015, -0.0006020000000000018, -0.004713000000000002, -0.0035920000000000014, -0.005963000000000001, -0.0062850000000000015], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tffc653747caf4eda91cd80f502deb3fe","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc2569b6c0f8f4d6fbdb08c3b208b2e59","vertex_data","graph vertex data",["x", "y"],[[-1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, 0.0, 0.0, -1.0000000000001327e-06, 0.0, -0.0020090000000000004, -0.0020740000000000003, -0.004669, -0.0004889999999999999, -0.0047810000000000005, -0.003595, -0.006106, -0.006479], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc2569b6c0f8f4d6fbdb08c3b208b2e59","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2cb7038c66c3404eb7af9b529bd44d8a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -2.0000000000002655e-06, -0.002084, -0.002175, -0.004483, -0.0005830000000000002, -0.00474, -0.0032220000000000005, -0.006312, -0.006726], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2cb7038c66c3404eb7af9b529bd44d8a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td5867096d3b54acfb96892d6d6e37cef","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -8.673617379884035e-19, -8.673617379884035e-19, -0.0021290000000000007, -0.002145000000000001, -0.003944000000000001, -0.0005840000000000012, -0.004149000000000001, -0.0034910000000000006, -0.006504000000000001, -0.006965000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td5867096d3b54acfb96892d6d6e37cef","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t86e3604794a642a38d488d4299d02bea","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -8.673617379884035e-19, -1.734723475976807e-18, -0.002268000000000001, -0.0022790000000000015, -0.0037930000000000017, -0.0006070000000000016, -0.0040240000000000015, -0.004061000000000002, -0.006844000000000001, -0.0073170000000000015], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t86e3604794a642a38d488d4299d02bea","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6de88a4bf7f24f529211fdc279571bf2","vertex_data","graph vertex data",["x", "y"],[[-8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, -8.673617379884035e-19, 0.0, 0.0, 0.0, -8.673617379884035e-19, -0.0022860000000000016, -0.002294000000000001, -0.0036150000000000015, -0.0005840000000000012, -0.0037060000000000014, -0.003983000000000001, -0.006927000000000001, -0.007400000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6de88a4bf7f24f529211fdc279571bf2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcf81e12199684abda75fb0bb52b3fca4","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -1.0000000000001327e-06, -0.002321, -0.0023239999999999997, -0.0035789999999999997, -0.0006300000000000004, -0.003699, -0.003509, -0.007066, -0.007587], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcf81e12199684abda75fb0bb52b3fca4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9daffcd106ff410391aeed898c33f3ef","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.0023999999999999994, -0.0024029999999999998, -0.0036559999999999995, -0.0006559999999999995, -0.003798, -0.0035179999999999994, -0.007316, -0.007861], [7.0, 6.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9daffcd106ff410391aeed898c33f3ef","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb07ea5f9c05f4ef385bda6d76844c01e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0023809999999999994, -0.002385, -0.003568, -0.0007100000000000006, -0.0036879999999999994, -0.0036689999999999995, -0.007337, -0.007909], [7.0, 6.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb07ea5f9c05f4ef385bda6d76844c01e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8849c004139c43139dbe1591cc50bfc0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002353, -0.0023569999999999997, -0.0034399999999999995, -0.0006579999999999997, -0.0035700000000000003, -0.0038979999999999996, -0.007467, -0.007894], [7.0, 8.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8849c004139c43139dbe1591cc50bfc0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1f5787067c704b40ba01f99b0523904d","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.734723475976807e-18, -0.002367000000000002, -0.0023710000000000016, -0.003190000000000001, -0.0007090000000000022, -0.0034220000000000014, -0.003914000000000002, -0.0073500000000000015, -0.007925000000000001], [7.0, 8.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1f5787067c704b40ba01f99b0523904d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdce309a51b0446889cf2b1b98eae05d5","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0023439999999999997, -0.0024269999999999995, -0.0028909999999999995, -0.0006220000000000002, -0.003439, -0.004514, -0.007324, -0.008038], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdce309a51b0446889cf2b1b98eae05d5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c36bbcc713d4de3ac2e49eb63925c5a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0023699999999999997, -0.0023819999999999996, -0.0026889999999999996, -0.0008159999999999999, -0.003117, -0.0036950000000000004, -0.007487, -0.008326], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5c36bbcc713d4de3ac2e49eb63925c5a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t506fe1fe8c6c4728bbb5efe5537a333d","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002366, -0.002372, -0.002436, -0.0007160000000000005, -0.002824, -0.003562000000000001, -0.0073820000000000005, -0.008368], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t506fe1fe8c6c4728bbb5efe5537a333d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t22ef0063c2cc4dbe802da172eb7ca58c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.002502999999999999, -0.002568, -0.002666, -0.0009349999999999983, -0.0027739999999999996, -0.003704, -0.007598, -0.008853], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t22ef0063c2cc4dbe802da172eb7ca58c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t168f8a0dc03e41c697bf5bac67b83c90","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0025330000000000005, -0.0026440000000000005, -0.002725, -0.0007800000000000012, -0.0029969999999999997, -0.003573, -0.0072440000000000004, -0.009247], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t168f8a0dc03e41c697bf5bac67b83c90","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t92bbfb6b32ed413a902f154d5b1e6ec5","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -0.002404999999999999, -0.0025429999999999993, -0.00258, -0.0007399999999999993, -0.003072, -0.0032759999999999994, -0.006657, -0.008721], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t92bbfb6b32ed413a902f154d5b1e6ec5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc0259d6a4f7242ff9a13d5afa69d8e12","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.002644999999999999, -0.002689999999999999, -0.002728999999999999, -0.0007480000000000004, -0.002927999999999999, -0.003240999999999999, -0.007470999999999999, -0.00929], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc0259d6a4f7242ff9a13d5afa69d8e12","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taa53c18d71b54367b593d3c21c750cce","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.002686000000000001, -0.002714000000000001, -0.002759000000000001, -0.0007640000000000008, -0.0030830000000000007, -0.0035020000000000008, -0.007099000000000001, -0.009756], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"taa53c18d71b54367b593d3c21c750cce","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t43e8d8e428564310b55526226e95cf6a","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0025249999999999995, -0.002548999999999999, -0.002576, -0.000699, -0.0030489999999999996, -0.0025509999999999994, -0.006591, -0.009757], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t43e8d8e428564310b55526226e95cf6a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t08865226b9584bdaaff11ab901823cf4","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.002293999999999999, -0.0023510000000000007, -0.0023560000000000005, -0.0006540000000000001, -0.0028129999999999995, -0.0017579999999999991, -0.007228, -0.009576], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t08865226b9584bdaaff11ab901823cf4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tca0312ece1434e4dbddf24b09976db1d","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -1.9999999999985307e-06, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, -9.999999999992654e-07, -1.9999999999985307e-06, -0.0023139999999999983, -0.002325999999999998, -0.0023469999999999984, -0.000677999999999998, -0.0027249999999999983, -0.002062999999999999, -0.0072489999999999985, -0.009659999999999998], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tca0312ece1434e4dbddf24b09976db1d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb1fc1dc028e4437fac1d2ae840fdce2b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.002328, -0.0023700000000000006, -0.0024010000000000004, -0.0006390000000000007, -0.0028470000000000006, -0.0017810000000000013, -0.007385000000000001, -0.009688], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb1fc1dc028e4437fac1d2ae840fdce2b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9c7a7c3fe7e441bf99129436d1505908","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.002301000000000001, -0.0023090000000000003, -0.002347, -0.0006270000000000008, -0.0028600000000000006, -0.0018130000000000004, -0.007308, -0.009648], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9c7a7c3fe7e441bf99129436d1505908","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t987b5f95aa414e4b9c502812795a5286","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002092, -0.0021020000000000006, -0.002138000000000001, -0.0006010000000000008, -0.0026380000000000006, -0.001609000000000001, -0.006849000000000001, -0.009430000000000001], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t987b5f95aa414e4b9c502812795a5286","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfbea634a29f1436d93b47782901ba95b","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, 0.0, -0.0021799999999999996, -0.002180999999999999, -0.0022049999999999986, -0.0007359999999999988, -0.0030219999999999986, -0.0018279999999999998, -0.007179, -0.009954], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfbea634a29f1436d93b47782901ba95b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te5c2875e4e9547dca208997be3b47dc0","vertex_data","graph vertex data",["x", "y"],[[-2.000000000002e-06, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.0022520000000000005, -0.0022520000000000005, -0.0022650000000000014, -0.0007489999999999997, -0.0027930000000000003, -0.0016770000000000014, -0.007384000000000001, -0.010807], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te5c2875e4e9547dca208997be3b47dc0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t13697a115db842b88787b59887be3774","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.734723475976807e-18, 0.0, -0.002242000000000001, -0.002242000000000001, -0.002254000000000001, -0.0006620000000000011, -0.002659, -0.0016510000000000014, -0.007379, -0.010859], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t13697a115db842b88787b59887be3774","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t22730598bf3d4f46a26066f7337bf4b0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.002261000000000001, -0.0022640000000000004, -0.0022850000000000006, -0.0008510000000000011, -0.002567, -0.0018060000000000003, -0.007513000000000001, -0.011067], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t22730598bf3d4f46a26066f7337bf4b0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teddad98b97c34cc28c0b10b5248ca99c","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -0.0022099999999999984, -0.0022169999999999985, -0.002227, -0.0008979999999999995, -0.0027019999999999995, -0.0016169999999999986, -0.007110999999999998, -0.011362999999999998], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"teddad98b97c34cc28c0b10b5248ca99c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t38bd2ab0605146ce89ac860eb92a659e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.002116, -0.0021379999999999993, -0.0021469999999999996, -0.0007939999999999996, -0.0030080000000000003, -0.0016699999999999996, -0.007069, -0.011594], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t38bd2ab0605146ce89ac860eb92a659e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tec17f82c662f45edb0c9aae6e72cfefe","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0019900000000000004, -0.0020020000000000003, -0.0020100000000000014, -0.0007140000000000011, -0.0035960000000000002, -0.0015350000000000016, -0.006670000000000001, -0.011511], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tec17f82c662f45edb0c9aae6e72cfefe","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6710a25e5ae947c48f3b6486d693757f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0018410000000000024, -0.0018450000000000012, -0.0018540000000000015, -0.0007660000000000011, -0.0029830000000000013, -0.0009300000000000003, -0.006720000000000001, -0.011435], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6710a25e5ae947c48f3b6486d693757f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t440be00d7ad54e80a90b1304fbb5d8a9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0018449999999999994, -0.0018519999999999995, -0.001856, -0.0006080000000000009, -0.002863000000000001, -0.0012099999999999993, -0.006675, -0.011792], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t440be00d7ad54e80a90b1304fbb5d8a9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t62dfe980cbca45ed9ed8538539c9adf6","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0019019999999999992, -0.001934, -0.0019369999999999995, -0.0006370000000000004, -0.0032169999999999994, -0.0014509999999999992, -0.006569, -0.012366], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t62dfe980cbca45ed9ed8538539c9adf6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3c5c7f58c1634d368b3e51b5dd3ae9ca","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001745, -0.0017590000000000001, -0.0017600000000000011, -0.000596000000000001, -0.003262000000000001, -0.001262000000000001, -0.0066240000000000005, -0.011511], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3c5c7f58c1634d368b3e51b5dd3ae9ca","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t65d08aff28284857999824c89b700daa","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, 0.0, -0.001831000000000001, -0.0018499999999999992, -0.0018510000000000002, -0.0006589999999999999, -0.003051, -0.0015099999999999992, -0.006648, -0.012324], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t65d08aff28284857999824c89b700daa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tecebaed64d38483ca09eee3254d18cd4","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0019950000000000002, -0.001975000000000001, -0.0020020000000000003, -0.0007769999999999999, -0.003013, -0.001398, -0.007052, -0.013516], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tecebaed64d38483ca09eee3254d18cd4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8e5426d586b847d588e477cb54e27009","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -0.0019030000000000002, -0.0018539999999999997, -0.0019140000000000008, -0.0007329999999999993, -0.003027, -0.0012490000000000001, -0.006875, -0.013479], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8e5426d586b847d588e477cb54e27009","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tac719de240784b4f967bbf72a6cdc442","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, -0.0019330000000000007, -0.0019280000000000026, -0.0019380000000000022, -0.0006620000000000011, -0.0033050000000000024, -0.0011450000000000002, -0.007373000000000001, -0.01352], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tac719de240784b4f967bbf72a6cdc442","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a0b2ec66b1b4903aec613ab62b315ea","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0019019999999999992, -0.0019039999999999994, -0.001908, -0.0006300000000000004, -0.003266, -0.0015530000000000006, -0.006709, -0.013347], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6a0b2ec66b1b4903aec613ab62b315ea","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t84e2187f6e68463ca75769704f9f9870","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0019570000000000004, -0.00196, -0.0019629999999999995, -0.000621, -0.003266, -0.0012759999999999994, -0.006873, -0.013998], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t84e2187f6e68463ca75769704f9f9870","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb7cf8188cdb34079b96f8efecdca53f5","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.001850000000000001, -0.001857000000000001, -0.0018589999999999995, -0.000536, -0.0037549999999999997, -0.0012050000000000012, -0.006111, -0.014096000000000001], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb7cf8188cdb34079b96f8efecdca53f5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3ee6b2fd665d41dbbec46d6d253fcbfc","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.0017990000000000003, -0.0018090000000000016, -0.0018110000000000001, -0.0005320000000000012, -0.003564000000000001, -0.0009460000000000007, -0.006868000000000001, -0.014266000000000001], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3ee6b2fd665d41dbbec46d6d253fcbfc","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t71c993dba6fe48d692b600c3b82e6e80","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.001854999999999999, -0.0018609999999999998, -0.001864000000000001, -0.000593999999999999, -0.0033550000000000003, -0.0011590000000000003, -0.006827, -0.014178], [8.0, 5.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t71c993dba6fe48d692b600c3b82e6e80","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7181849e5aa2461e89afa16b1b21fe7e","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.0017560000000000006, -0.0017840000000000009, -0.0017850000000000019, -0.0005980000000000013, -0.003124, -0.0010280000000000011, -0.0066430000000000005, -0.013586], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7181849e5aa2461e89afa16b1b21fe7e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4e5c42b795654338857bb79ed19ff431","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -0.0018239999999999992, -0.0017870000000000004, -0.0018260000000000012, -0.0006180000000000005, -0.003143, -0.0012469999999999998, -0.006543, -0.013731], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4e5c42b795654338857bb79ed19ff431","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82fcd47712204648ad7504c871db2679","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0018550000000000007, -0.0018709999999999994, -0.001876000000000001, -0.0005820000000000009, -0.0033550000000000003, -0.001079, -0.006914, -0.014031], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82fcd47712204648ad7504c871db2679","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t24890861000d458e8def31fa614cf915","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -0.001849, -0.0018729999999999997, -0.0018740000000000007, -0.000595, -0.003254, -0.001098, -0.006392, -0.013748], [8.0, 5.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t24890861000d458e8def31fa614cf915","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5f07d728d3534427997a6132b1239b38","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0019179999999999996, -0.0019229999999999994, -0.001927, -0.0005730000000000006, -0.003235, -0.0012469999999999998, -0.006435, -0.014202], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5f07d728d3534427997a6132b1239b38","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t437cea7291c942c994362cbfeb724fb4","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0018159999999999982, -0.0018320000000000003, -0.0018339999999999988, -0.0006040000000000004, -0.002848, -0.001044999999999999, -0.0063349999999999995, -0.014067], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t437cea7291c942c994362cbfeb724fb4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95f54d698faf45d6af0fc14cd317076d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, -1.000000000001e-06, -0.0018939999999999999, -0.0018970000000000011, -0.001901, -0.0006340000000000009, -0.0030679999999999995, -0.0009230000000000002, -0.00698, -0.015027], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95f54d698faf45d6af0fc14cd317076d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t732d935cff1d4737b613097dbee96b4b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -0.001875, -0.0018790000000000005, -0.001882, -0.0006240000000000013, -0.0029370000000000004, -0.0009549999999999993, -0.0067740000000000005, -0.014861000000000001], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t732d935cff1d4737b613097dbee96b4b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdba7fc56b3c34abcad40aad2ea2544a2","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001903000000000002, -0.0019130000000000015, -0.0019130000000000015, -0.0006920000000000016, -0.0032780000000000014, -0.001236000000000001, -0.006484000000000002, -0.015696], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdba7fc56b3c34abcad40aad2ea2544a2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7e8fcef8fae6413e857054e39199bede","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0018459999999999987, -0.0018609999999999998, -0.0018620000000000008, -0.0006069999999999999, -0.00332, -0.0012809999999999992, -0.007052, -0.014659], [7.0, 5.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 6.0, 7.0, 2.5, 5.5, 1.75, 3.625, 1.8125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7e8fcef8fae6413e857054e39199bede","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t705d9545d860439c9d8de7d3255650d0","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0016750000000000011, -0.001680000000000001, -0.0016840000000000015, -0.0005540000000000024, -0.003046, -0.001015000000000002, -0.006831000000000001, -0.014086000000000001], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t705d9545d860439c9d8de7d3255650d0","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdc15e8585c2e49f388d4bc266c0e91b8","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.001628000000000001, -0.0016320000000000015, -0.0016370000000000013, -0.0005920000000000022, -0.003334, -0.000903000000000001, -0.007163000000000001, -0.013746000000000001], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdc15e8585c2e49f388d4bc266c0e91b8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf3272f54be694e5ca00b78e81d98f579","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001595000000000001, -0.0015980000000000005, -0.001602000000000001, -0.0006340000000000009, -0.0037080000000000012, -0.000811000000000001, -0.006883, -0.013854], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf3272f54be694e5ca00b78e81d98f579","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tafa2034f6ec94846bdef595e7da1d185","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -2.0000000000002655e-06, -2.0000000000002655e-06, -9.999999999992654e-07, -1.000000000001e-06, -0.00166, -0.001661000000000001, -0.001667, -0.0007350000000000013, -0.0035989999999999998, -0.0008509999999999993, -0.006354, -0.014378], [5.0, 7.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tafa2034f6ec94846bdef595e7da1d185","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf3e180ccf5fe44979338e51b57d85356","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999975306e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0017459999999999976, -0.0017469999999999986, -0.0017789999999999993, -0.0005669999999999981, -0.0030479999999999986, -0.000954, -0.006655999999999999, -0.015118], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf3e180ccf5fe44979338e51b57d85356","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf11c0abcb98549e3be28a2ef35629499","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.469446951953614e-18, -0.0017960000000000025, -0.0018030000000000025, -0.0018120000000000011, -0.000623000000000002, -0.0035210000000000016, -0.0010510000000000016, -0.006543000000000002, -0.015828000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf11c0abcb98549e3be28a2ef35629499","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t554f48df981443c18fe31b64f68c3c44","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0016290000000000002, -0.0016400000000000008, -0.001646, -0.0005789999999999997, -0.003335000000000001, -0.0009000000000000015, -0.006845, -0.014963], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t554f48df981443c18fe31b64f68c3c44","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf4bcdff385314cc7bf1dcb8d44bedaea","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0016900000000000005, -0.0017010000000000011, -0.0017110000000000007, -0.0007130000000000018, -0.0035659999999999997, -0.001040000000000001, -0.006325000000000001, -0.015667], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf4bcdff385314cc7bf1dcb8d44bedaea","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfd27016321114f8f86c16b8c3b87fd88","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -1.000000000001e-06, -0.0016480000000000002, -0.0016579999999999998, -0.0016629999999999995, -0.0006859999999999991, -0.003162999999999999, -0.000900999999999999, -0.006626999999999999, -0.015961], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfd27016321114f8f86c16b8c3b87fd88","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8bc28881f28242298008b715d011da5a","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -0.0017870000000000021, -0.0017890000000000024, -0.001805000000000001, -0.0009350000000000018, -0.0035130000000000022, -0.0011510000000000027, -0.006569000000000002, -0.016681], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8bc28881f28242298008b715d011da5a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t25d7adc901954c04a9797fef3998210b","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0017239999999999998, -0.0017789999999999993, -0.0017879999999999997, -0.0007769999999999999, -0.002999999999999999, -0.0010959999999999998, -0.006362, -0.01677], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t25d7adc901954c04a9797fef3998210b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t35adad9f02234314aa8ad303337624aa","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0016749999999999994, -0.0017300000000000006, -0.0017409999999999995, -0.0007609999999999995, -0.003307000000000001, -0.0009440000000000004, -0.006763, -0.01616], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t35adad9f02234314aa8ad303337624aa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2f16cf3419a24ef48fad7776f62bd4db","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0016039999999999995, -0.0016939999999999993, -0.0017029999999999997, -0.0007029999999999988, -0.0030159999999999996, -0.0008489999999999991, -0.0070539999999999995, -0.015427], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2f16cf3419a24ef48fad7776f62bd4db","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t564cc720543e4875ac1db2f37fe47836","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -0.001549, -0.0016879999999999985, -0.0016949999999999986, -0.0007989999999999994, -0.0030619999999999988, -0.0008780000000000003, -0.0064139999999999996, -0.015545], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t564cc720543e4875ac1db2f37fe47836","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t94b9abf90c48495bac152600c5de43d7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0015350000000000016, -0.0016160000000000011, -0.0016510000000000014, -0.0007940000000000013, -0.003328000000000001, -0.0008990000000000005, -0.006825000000000001, -0.015266000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t94b9abf90c48495bac152600c5de43d7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t583f49e67a3446efa6696f4bc3bea945","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0013490000000000012, -0.0015340000000000006, -0.0015610000000000016, -0.0007760000000000006, -0.002961, -0.0009530000000000007, -0.007135000000000001, -0.014642], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t583f49e67a3446efa6696f4bc3bea945","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb97c29ddede0462abdd9c56915ecdf0e","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0014950000000000015, -0.0015550000000000008, -0.0015810000000000008, -0.0008439999999999993, -0.0027360000000000006, -0.000869, -0.007105, -0.015142000000000001], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb97c29ddede0462abdd9c56915ecdf0e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9aec7bde68a7422ead7171c0b10d73dd","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -0.0014770000000000009, -0.0015610000000000016, -0.0015780000000000013, -0.0008360000000000017, -0.0032710000000000013, -0.0008880000000000016, -0.006884000000000001, -0.015186000000000002], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9aec7bde68a7422ead7171c0b10d73dd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9f8e577d7d1c4740996d25d9ba538e73","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.001543000000000001, -0.0013360000000000021, -0.001551000000000002, -0.0007490000000000014, -0.0035590000000000014, -0.0009430000000000011, -0.006924000000000001, -0.015273000000000002], [5.0, 6.0, 8.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 5.5, 7.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9f8e577d7d1c4740996d25d9ba538e73","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t09e4766b5b4c442f83d0b89ae06c388b","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0011540000000000005, -0.0014180000000000009, -0.0014220000000000014, -0.000725, -0.002850000000000002, -0.0008330000000000004, -0.007109000000000001, -0.014724000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t09e4766b5b4c442f83d0b89ae06c388b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t15dedcb4b2d34ea5821e66905488d6b5","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0010389999999999983, -0.001398, -0.0014029999999999997, -0.0006679999999999985, -0.003382999999999999, -0.0008059999999999994, -0.0067399999999999995, -0.014745999999999999], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t15dedcb4b2d34ea5821e66905488d6b5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t97d112388bd44cfbb9e78f6ec13a37ba","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013419999999999994, -0.0014199999999999994, -0.0014260000000000002, -0.0006819999999999986, -0.0030149999999999986, -0.0008039999999999992, -0.006900999999999999, -0.014782], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t97d112388bd44cfbb9e78f6ec13a37ba","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta99a52eb92bf4a8681eeec78dc0388f6","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001469999999999999, -0.0015060000000000004, -0.0015169999999999993, -0.0008249999999999993, -0.0030159999999999996, -0.000952999999999999, -0.007122, -0.01551], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta99a52eb92bf4a8681eeec78dc0388f6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1c95a80e3222467984db5647792c7571","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013380000000000006, -0.001387000000000001, -0.0013960000000000014, -0.0007160000000000014, -0.003701000000000001, -0.0008500000000000001, -0.006514000000000001, -0.014828000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1c95a80e3222467984db5647792c7571","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t84d394e45e5f449cacdceacd82a0e170","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -0.0014160000000000006, -0.0014540000000000004, -0.0014729999999999986, -0.0007930000000000003, -0.003415999999999999, -0.000900999999999999, -0.006867, -0.01508], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t84d394e45e5f449cacdceacd82a0e170","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta0cda425581d44a4a80c81c65a4be650","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0013039999999999996, -0.0013699999999999997, -0.001398, -0.0008129999999999995, -0.003778, -0.0008349999999999989, -0.006696, -0.014379], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta0cda425581d44a4a80c81c65a4be650","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1e585d7200f44fef9afde593fd568708","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0013670000000000002, -0.0014099999999999998, -0.0014420000000000006, -0.0007970000000000008, -0.0033620000000000004, -0.0008310000000000001, -0.006605, -0.01409], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1e585d7200f44fef9afde593fd568708","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e175e2764474743b6038741cf6e3fe3","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.001509, -0.0015239999999999993, -0.0015489999999999983, -0.0008269999999999996, -0.0036249999999999998, -0.0008400000000000005, -0.007097999999999999, -0.014743], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e175e2764474743b6038741cf6e3fe3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td9ddec6e10c54e2a800af794c92be927","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.001412, -0.0014820000000000007, -0.0014990000000000003, -0.0007900000000000008, -0.003346, -0.0008330000000000004, -0.0065710000000000005, -0.014953000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td9ddec6e10c54e2a800af794c92be927","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td2a135a33ee14b67a205d4631e3b872b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013750000000000012, -0.0014760000000000016, -0.0015019999999999999, -0.0007230000000000014, -0.00332, -0.0007970000000000008, -0.007287000000000001, -0.015005000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td2a135a33ee14b67a205d4631e3b872b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8aa4230eb4f64c66bb45337dcb57f6c4","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012729999999999998, -0.0014219999999999997, -0.0014409999999999978, -0.0007489999999999997, -0.003331999999999998, -0.0008209999999999988, -0.007252999999999999, -0.015142], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8aa4230eb4f64c66bb45337dcb57f6c4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1c990d7818c9436aa86e5b49af23ef75","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0013520000000000008, -0.0014670000000000013, -0.001510000000000001, -0.0007520000000000009, -0.0031520000000000003, -0.0008220000000000015, -0.007092000000000001, -0.015228], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1c990d7818c9436aa86e5b49af23ef75","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf052cd2bdb58401ba8486a919dcdf18d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.0013810000000000003, -0.0014760000000000016, -0.0015189999999999995, -0.0007480000000000021, -0.0032980000000000006, -0.0008190000000000003, -0.006410000000000001, -0.015304000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf052cd2bdb58401ba8486a919dcdf18d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8ecc70ddae454c4f9089997ecadf25bb","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0014069999999999985, -0.0014839999999999992, -0.0015969999999999995, -0.000782999999999999, -0.0036889999999999996, -0.0008629999999999992, -0.006872, -0.015403], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8ecc70ddae454c4f9089997ecadf25bb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95d44d0defbe42e1a4d98833f8c62e5c","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013039999999999996, -0.0013209999999999993, -0.0013629999999999996, -0.0007470000000000011, -0.0035759999999999993, -0.0007790000000000002, -0.006213, -0.014543], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t95d44d0defbe42e1a4d98833f8c62e5c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t48fcae728fdc41f89e51e60ad4e85beb","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, 0.0, 0.0, -9.999999999992654e-07, -1.000000000001e-06, -0.0012530000000000006, -0.001288000000000001, -0.0013299999999999996, -0.000733000000000001, -0.0033229999999999996, -0.0007430000000000006, -0.006449, -0.014359], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t48fcae728fdc41f89e51e60ad4e85beb","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdf37e856a6d741289c642e06048e7dc2","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013190000000000007, -0.0013630000000000014, -0.0014180000000000009, -0.0007820000000000014, -0.0033840000000000016, -0.0008190000000000003, -0.006771000000000001, -0.015272], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdf37e856a6d741289c642e06048e7dc2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8320b58e20104a4f9a63c386bf68c03f","vertex_data","graph vertex data",["x", "y"],[[-2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.001230000000000002, -0.0012910000000000005, -0.0013430000000000004, -0.0006510000000000023, -0.00349, -0.0007550000000000022, -0.006719000000000001, -0.015214000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8320b58e20104a4f9a63c386bf68c03f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ec8313ba4554ac2bccce516abecc0dd","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -0.0011059999999999993, -0.0012329999999999997, -0.0012709999999999996, -0.0006820000000000003, -0.003174999999999999, -0.000700000000000001, -0.006803, -0.014795], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ec8313ba4554ac2bccce516abecc0dd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td44e3dfa1bfe4fc4a6f9a00ca9b5b285","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012340000000000007, -0.0012780000000000014, -0.0013270000000000018, -0.0007480000000000021, -0.003195, -0.0007530000000000002, -0.007286000000000001, -0.015268], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td44e3dfa1bfe4fc4a6f9a00ca9b5b285","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6d5bc9734116420ea2a24af96ca2c1ae","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0011129999999999994, -0.0012180000000000003, -0.0012560000000000002, -0.0007139999999999994, -0.003089999999999999, -0.0007179999999999999, -0.0070599999999999994, -0.014844], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6d5bc9734116420ea2a24af96ca2c1ae","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t439f2bcc94394a519448e59e32f81044","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012099999999999993, -0.0012189999999999996, -0.0012849999999999997, -0.0006569999999999996, -0.0034129999999999994, -0.0008039999999999992, -0.0071909999999999995, -0.015385], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t439f2bcc94394a519448e59e32f81044","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf9715152d5a0444e8de038be53b30ea2","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0012210000000000016, -0.0012280000000000017, -0.0012630000000000002, -0.0006250000000000006, -0.003549, -0.0006690000000000012, -0.006726000000000001, -0.015304000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf9715152d5a0444e8de038be53b30ea2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td00a16351e0d41c892f8b4ba633d7e7e","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.0012259999999999997, -0.0012320000000000005, -0.0012560000000000002, -0.000615000000000001, -0.0033970000000000007, -0.0006420000000000019, -0.006594000000000001, -0.015079], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td00a16351e0d41c892f8b4ba633d7e7e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tafd9afd27d044a3dae003e078346ecbd","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012849999999999997, -0.0013139999999999992, -0.0013360000000000004, -0.0006700000000000005, -0.003837, -0.0008020000000000006, -0.006477, -0.016233], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tafd9afd27d044a3dae003e078346ecbd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf87122659e734de8b89dc2cee08a128a","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -3.469446951953614e-18, -0.0013350000000000029, -0.001356000000000003, -0.0013680000000000012, -0.0007230000000000014, -0.003171000000000002, -0.0009340000000000008, -0.006786000000000002, -0.016391000000000003], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf87122659e734de8b89dc2cee08a128a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t01648676c7d141319d7b2a904efbe850","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, -0.001337999999999999, -0.0013579999999999998, -0.0013619999999999986, -0.0007029999999999988, -0.003587999999999999, -0.0009979999999999989, -0.0064329999999999995, -0.016468], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t01648676c7d141319d7b2a904efbe850","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc8d19b74838b463483a4aed234cef660","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012770000000000004, -0.001373000000000001, -0.001380000000000001, -0.0007380000000000008, -0.0035130000000000005, -0.0008760000000000018, -0.006981000000000001, -0.016067], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc8d19b74838b463483a4aed234cef660","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb2af82f543d6449facb9549ae93a6e5a","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.00136, -0.001413000000000001, -0.0014200000000000011, -0.0006230000000000003, -0.0031190000000000002, -0.0008730000000000005, -0.006366, -0.016187], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb2af82f543d6449facb9549ae93a6e5a","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t62b5318b7a484dac8709b5876014156e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013240000000000005, -0.001431, -0.001438, -0.0006950000000000012, -0.003266999999999999, -0.0008570000000000001, -0.007011, -0.015739], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t62b5318b7a484dac8709b5876014156e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t62c35790b2d244ac911b770f4d183b10","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.001200999999999999, -0.0013539999999999993, -0.0013619999999999986, -0.0005429999999999983, -0.0038499999999999993, -0.0010079999999999985, -0.006404999999999999, -0.014941], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t62c35790b2d244ac911b770f4d183b10","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3a45904f146947d49456cd8a116442a8","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012310000000000012, -0.0012930000000000007, -0.0013030000000000003, -0.00051, -0.0034730000000000004, -0.0008140000000000005, -0.006672000000000001, -0.014587000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3a45904f146947d49456cd8a116442a8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ea80b97d869433da35dec785e3fea67","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0011960000000000009, -0.0012460000000000006, -0.001261, -0.0004869999999999996, -0.0035390000000000005, -0.000843, -0.006158, -0.014993000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0ea80b97d869433da35dec785e3fea67","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7bef2b3d2ff145f98e7ad5c1e02f3389","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -0.0011000000000000003, -0.001236000000000001, -0.001243000000000001, -0.0006110000000000004, -0.0034100000000000016, -0.0006990000000000017, -0.007123000000000002, -0.014593000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7bef2b3d2ff145f98e7ad5c1e02f3389","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tecf286138ead4872bb26b01bf03d780d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -0.0011630000000000008, -0.0012180000000000003, -0.0012220000000000009, -0.0006540000000000018, -0.0037820000000000006, -0.0007200000000000019, -0.0070100000000000015, -0.014728000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tecf286138ead4872bb26b01bf03d780d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t44354730ba594011a323f66a7ac258d9","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.001269000000000001, -0.0011720000000000012, -0.0012729999999999998, -0.0006130000000000007, -0.0033560000000000013, -0.0007960000000000016, -0.006908000000000001, -0.015258], [5.0, 6.0, 8.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 5.5, 7.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t44354730ba594011a323f66a7ac258d9","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5f929cc45e4f403c9a50850d14229bf3","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012300000000000002, -0.001294, -0.0013019999999999993, -0.0007760000000000006, -0.0032379999999999996, -0.0008570000000000001, -0.007032, -0.01555], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5f929cc45e4f403c9a50850d14229bf3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t63a992cda7ff4086a302584eb7bce4df","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.0000000000027348e-06, -1.0000000000027348e-06, -1.734723475976807e-18, 0.0, -0.0011120000000000019, -0.0011700000000000026, -0.0011760000000000017, -0.0006840000000000023, -0.0031540000000000023, -0.0007330000000000027, -0.006234000000000002, -0.014233], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t63a992cda7ff4086a302584eb7bce4df","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4e0027a7ae8c407090864abdd28bea54","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -2.0000000000002655e-06, -0.0011999999999999997, -0.0012700000000000003, -0.0012790000000000006, -0.0007380000000000008, -0.003367, -0.0007709999999999991, -0.007455, -0.014804], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4e0027a7ae8c407090864abdd28bea54","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t76944f0c82e246c38a85d51eebcb07c2","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011890000000000008, -0.0012240000000000011, -0.001229000000000001, -0.0006890000000000004, -0.0033480000000000003, -0.0007589999999999993, -0.0067150000000000005, -0.01473], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t76944f0c82e246c38a85d51eebcb07c2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td22f5e24915b441db0294ff0d09ea3ff","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0012310000000000012, -0.0012680000000000018, -0.0012720000000000023, -0.0006960000000000022, -0.0033640000000000024, -0.0007530000000000002, -0.007101000000000001, -0.015311000000000002], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td22f5e24915b441db0294ff0d09ea3ff","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1bbe7db75f0641429dd60f3b61ab96e1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012040000000000002, -0.001235, -0.001242, -0.0006910000000000006, -0.003504, -0.0007740000000000004, -0.006779, -0.014953000000000001], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1bbe7db75f0641429dd60f3b61ab96e1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcc28bf5c8d3e4220bf3770f4287fddea","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.000000000002e-06, -1.000000000001e-06, -0.0011680000000000006, -0.0011780000000000002, -0.0011880000000000016, -0.0006519999999999998, -0.003143, -0.0007510000000000017, -0.006554000000000001, -0.014592], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcc28bf5c8d3e4220bf3770f4287fddea","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta325104375df49ee895f56c8b22d29db","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011789999999999995, -0.0011890000000000008, -0.0011990000000000004, -0.0006340000000000009, -0.003174999999999999, -0.0007650000000000001, -0.007004, -0.014759], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta325104375df49ee895f56c8b22d29db","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3127b418fd234c24b9d1bae35eabed28","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0011610000000000006, -0.0011780000000000002, -0.0011820000000000008, -0.0007150000000000004, -0.0036110000000000014, -0.0008190000000000003, -0.006599000000000001, -0.014579], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3127b418fd234c24b9d1bae35eabed28","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdc16f47aba8e4460b96ed75cc6a4d295","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0011059999999999993, -0.0011199999999999995, -0.001129999999999999, -0.0006849999999999998, -0.0035600000000000007, -0.0007039999999999998, -0.006804, -0.014158], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdc16f47aba8e4460b96ed75cc6a4d295","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te0a0242a9e9540bdbe239c6396d7ab79","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0011470000000000004, -0.001164, -0.0011780000000000002, -0.0006610000000000019, -0.0032270000000000007, -0.0007039999999999998, -0.006684000000000001, -0.015063], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"te0a0242a9e9540bdbe239c6396d7ab79","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf8cefdfdcc4d4cafb5a245f5ae16e7cd","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0011359999999999999, -0.0011579999999999993, -0.0011699999999999992, -0.0006890000000000004, -0.00332, -0.0006930000000000009, -0.006494, -0.015028999999999999], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf8cefdfdcc4d4cafb5a245f5ae16e7cd","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb434bca66be94b7da4a9004d8da6ddb5","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, 0.0, -0.0011690000000000016, -0.0011949999999999999, -0.0012040000000000002, -0.0006650000000000007, -0.003458000000000001, -0.0007950000000000006, -0.006427, -0.015193], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tb434bca66be94b7da4a9004d8da6ddb5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc858c27c1c48450fa4ffff852639533b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0011859999999999996, -0.0011949999999999999, -0.0011999999999999997, -0.0006959999999999987, -0.003373000000000001, -0.0008680000000000007, -0.006406, -0.016004], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc858c27c1c48450fa4ffff852639533b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t21d3d7c9eaee450aa5b2f2bdf370ad67","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012010000000000007, -0.001210000000000001, -0.0012120000000000013, -0.0006430000000000012, -0.003633000000000001, -0.0007160000000000014, -0.006325000000000001, -0.015948], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t21d3d7c9eaee450aa5b2f2bdf370ad67","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t007d48f4108d4e449d4c52627382f44c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.001217000000000001, -0.0012270000000000007, -0.0012280000000000017, -0.0006960000000000022, -0.003270000000000002, -0.0008030000000000016, -0.006275000000000001, -0.016507], [8.0, 6.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t007d48f4108d4e449d4c52627382f44c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf9e1ae29431e4875beb56c927825b0f5","vertex_data","graph vertex data",["x", "y"],[[-3.469446951953614e-18, -3.469446951953614e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, 0.0, -0.0011940000000000006, -0.0011990000000000021, -0.0012000000000000014, -0.000674000000000001, -0.003550000000000001, -0.0007970000000000026, -0.005826000000000001, -0.015838], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf9e1ae29431e4875beb56c927825b0f5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9a06eb2b460c4f7d90a3d3c5aa5862ae","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.0012510000000000021, -0.0012910000000000022, -0.0012930000000000025, -0.0007800000000000012, -0.0033920000000000027, -0.0008210000000000023, -0.006900000000000002, -0.016098], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t9a06eb2b460c4f7d90a3d3c5aa5862ae","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4bc3127ebd4c4ef5bbab4cdb6a529255","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999975306e-07, 0.0, -0.0013099999999999987, -0.0013159999999999995, -0.0013179999999999997, -0.0007659999999999993, -0.0031319999999999994, -0.0008319999999999994, -0.006647999999999999, -0.015781], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4bc3127ebd4c4ef5bbab4cdb6a529255","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t287d4dc17f0e46ad83fee19119228f3d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.734723475976807e-18, -0.001165000000000001, -0.0012060000000000005, -0.0012080000000000007, -0.0007489999999999997, -0.003419, -0.0007939999999999996, -0.0068070000000000006, -0.014790000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t287d4dc17f0e46ad83fee19119228f3d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8e2321710f744ea78c72c48f86273646","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0011289999999999998, -0.0011649999999999994, -0.001169, -0.0006999999999999992, -0.003398, -0.000785000000000001, -0.006583, -0.014976], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t8e2321710f744ea78c72c48f86273646","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7e967af47dfa42c68ae1eb2c983e952f","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -1.0000000000044695e-06, -0.001277000000000002, -0.0012650000000000022, -0.001297000000000003, -0.0007460000000000019, -0.003511000000000002, -0.0008580000000000011, -0.006427000000000002, -0.015725000000000003], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7e967af47dfa42c68ae1eb2c983e952f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tadda380bbeb749db82a83d04e2a94959","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, -9.999999999975306e-07, -0.0013379999999999972, -0.001336999999999998, -0.0013459999999999982, -0.000677999999999998, -0.003590999999999997, -0.0008479999999999981, -0.006425999999999998, -0.016005], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tadda380bbeb749db82a83d04e2a94959","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e4d6a1423974bffaeead1c227607846","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, 0.0, -0.001340000000000001, -0.0013390000000000016, -0.0013460000000000017, -0.0007450000000000009, -0.0034930000000000013, -0.0009220000000000009, -0.006294000000000001, -0.015565], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6e4d6a1423974bffaeead1c227607846","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t09346452d99244569171453bbfc5247e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013640000000000006, -0.0013769999999999998, -0.0013819999999999995, -0.000674000000000001, -0.003124, -0.0009160000000000001, -0.006836, -0.016128], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t09346452d99244569171453bbfc5247e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5a41c939bd08443390a4195cbfa993d2","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, -0.0013399999999999992, -0.0013799999999999993, -0.0013869999999999993, -0.000678999999999999, -0.0035390000000000005, -0.0008319999999999994, -0.006813, -0.015815], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t5a41c939bd08443390a4195cbfa993d2","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t75547786acee42dea78cd0e22a5a825b","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012780000000000014, -0.001289000000000002, -0.001294, -0.0005509999999999994, -0.003471, -0.0007519999999999992, -0.0068980000000000005, -0.014477], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t75547786acee42dea78cd0e22a5a825b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1fe7846dea8e44daa138126700ee4db7","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012469999999999998, -0.0012490000000000001, -0.001254, -0.0005839999999999995, -0.003549, -0.0006690000000000012, -0.0063820000000000005, -0.014291], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t1fe7846dea8e44daa138126700ee4db7","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2fa642dfa86e47c4837acca9e9306ff6","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013220000000000003, -0.0013430000000000004, -0.0013490000000000012, -0.0006610000000000001, -0.003680000000000001, -0.0008740000000000015, -0.006549000000000001, -0.014909], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2fa642dfa86e47c4837acca9e9306ff6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4306883873da4c1e86c3d6839e218bac","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0013609999999999994, -0.0013569999999999988, -0.0013670000000000002, -0.0006429999999999995, -0.0033959999999999997, -0.0007620000000000005, -0.006898, -0.015217], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4306883873da4c1e86c3d6839e218bac","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcb0c54a37a354854b05812cfb66a974f","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0013109999999999997, -0.001301, -0.0013150000000000002, -0.0006040000000000004, -0.003306, -0.0008009999999999996, -0.006448000000000001, -0.015151000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcb0c54a37a354854b05812cfb66a974f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3c60ff7dc789401298181a5bd378165e","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0012930000000000007, -0.0012930000000000007, -0.0013000000000000008, -0.0005880000000000017, -0.003077, -0.0006640000000000014, -0.006734, -0.014807], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3c60ff7dc789401298181a5bd378165e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t94860032b6a2472b8aacb20c444d66ed","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, -2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0012239999999999994, -0.001229000000000001, -0.001243000000000001, -0.0006200000000000008, -0.0032130000000000006, -0.0007090000000000013, -0.006864, -0.014241], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t94860032b6a2472b8aacb20c444d66ed","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf948eb1899d446a99c53c1252acba549","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.0012180000000000003, -0.0012879999999999992, -0.0012899999999999995, -0.0006149999999999992, -0.0036769999999999997, -0.0007089999999999996, -0.007011999999999999, -0.014913], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf948eb1899d446a99c53c1252acba549","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tea0d1a28b7614ae5a44afc9d4f66a0d1","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.734723475976807e-18, -0.0012530000000000006, -0.0012970000000000013, -0.0012990000000000015, -0.0007170000000000024, -0.0032060000000000005, -0.0008120000000000002, -0.006809000000000001, -0.015005000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tea0d1a28b7614ae5a44afc9d4f66a0d1","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82a3adbe0bba4ffd9e3f6930dd4e939c","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -0.0013130000000000017, -0.0013240000000000005, -0.0013260000000000008, -0.0007390000000000001, -0.002955000000000001, -0.0007559999999999997, -0.007383000000000001, -0.015019000000000001], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82a3adbe0bba4ffd9e3f6930dd4e939c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc65376ebdf694092b352e0489a0a6bc6","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.0000000000044695e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.001400000000000002, -0.001406000000000001, -0.001408000000000003, -0.000682000000000002, -0.0029500000000000012, -0.0007650000000000018, -0.006706000000000002, -0.015831], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc65376ebdf694092b352e0489a0a6bc6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t165d596e08d943068ae54599265c7388","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, -9.999999999975306e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999975306e-07, -0.0014769999999999991, -0.0014769999999999991, -0.0014789999999999977, -0.0006449999999999997, -0.003480999999999998, -0.0009099999999999976, -0.006540999999999998, -0.016158], [8.0, 6.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t165d596e08d943068ae54599265c7388","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82aa086f1ee24aa5ba1fd0a86710cd4b","vertex_data","graph vertex data",["x", "y"],[[-3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -3.469446951953614e-18, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0015400000000000014, -0.0015420000000000017, -0.0015420000000000017, -0.0006510000000000023, -0.0031940000000000007, -0.0008760000000000018, -0.006530000000000001, -0.016427], [5.0, 8.0, 6.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.25, 6.625, 2.5, 5.3125, 1.75, 3.53125, 1.765625]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t82aa086f1ee24aa5ba1fd0a86710cd4b","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf27b3f160a334c78bb65e08a961e5f03","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -9.999999999992654e-07, -2.000000000002e-06, -0.0015110000000000002, -0.0015130000000000005, -0.0015130000000000005, -0.0006919999999999999, -0.002836, -0.0008059999999999994, -0.0065520000000000005, -0.015347000000000001], [5.0, 7.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf27b3f160a334c78bb65e08a961e5f03","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td50191b41f1d464097eb2e701b3ef743","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, 0.0, 0.0, 0.0, -1.000000000001e-06, -0.001466000000000002, -0.0014670000000000013, -0.0014680000000000006, -0.0007710000000000009, -0.003250000000000001, -0.0008830000000000018, -0.006735000000000001, -0.015258], [7.0, 8.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 5.5, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td50191b41f1d464097eb2e701b3ef743","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfbc3704493bf4608bbb505e712c65cf3","vertex_data","graph vertex data",["x", "y"],[[-1.9999999999985307e-06, -1.9999999999985307e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.001540999999999999, -0.0015449999999999995, -0.0015469999999999998, -0.0008190000000000003, -0.0034979999999999994, -0.0010369999999999997, -0.0076159999999999995, -0.016104], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfbc3704493bf4608bbb505e712c65cf3","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t749c520c00744c9ba0b802ec3e1ffef5","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0014009999999999995, -0.0014020000000000005, -0.0014070000000000003, -0.0008009999999999996, -0.0031409999999999997, -0.000876, -0.00643, -0.015355], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t749c520c00744c9ba0b802ec3e1ffef5","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcbbb56fb09664441b501901b6623381f","vertex_data","graph vertex data",["x", "y"],[[-1.9999999999985307e-06, -1.9999999999985307e-06, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -0.001377999999999999, -0.001384999999999999, -0.0013939999999999994, -0.0006669999999999992, -0.0034779999999999985, -0.0008619999999999982, -0.006695999999999999, -0.015503], [7.0, 5.0, 8.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcbbb56fb09664441b501901b6623381f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td192cef6524e41d3a9a67d6b56f8ff6e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013299999999999996, -0.0013419999999999994, -0.0013480000000000002, -0.0006269999999999991, -0.003450999999999999, -0.0007759999999999989, -0.0073279999999999994, -0.015347], [7.0, 8.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td192cef6524e41d3a9a67d6b56f8ff6e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3e3a86cc1ebe46b9b697b35fc67f3453","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013430000000000004, -0.0013509999999999998, -0.0013550000000000003, -0.0006590000000000016, -0.0037470000000000003, -0.0007150000000000004, -0.0066560000000000005, -0.015433], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3e3a86cc1ebe46b9b697b35fc67f3453","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tad7a8ee14c254317b6e74a06eacfbf99","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -1.9999999999985307e-06, -1.9999999999985307e-06, -1.9999999999985307e-06, -9.999999999975306e-07, -0.0012829999999999994, -0.0013049999999999989, -0.0013059999999999981, -0.0006909999999999989, -0.0035139999999999998, -0.0007169999999999989, -0.006362999999999999, -0.015641], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tad7a8ee14c254317b6e74a06eacfbf99","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t778a26095fae4bb2afff8642e4aa1970","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -9.999999999992654e-07, -0.0012619999999999992, -0.0012659999999999998, -0.0012700000000000003, -0.0006560000000000003, -0.003141999999999999, -0.0007169999999999989, -0.0068059999999999996, -0.014903], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t778a26095fae4bb2afff8642e4aa1970","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td67e2da296024139ba7a1f7c5c953bcf","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -0.0013059999999999999, -0.0013089999999999994, -0.001321000000000001, -0.0006680000000000002, -0.003632999999999999, -0.0008229999999999991, -0.00703, -0.014992], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td67e2da296024139ba7a1f7c5c953bcf","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t85f8b3c907ce4c1298af4f4fd119411d","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0012729999999999998, -0.0012779999999999996, -0.0012839999999999987, -0.0006870000000000001, -0.0033819999999999996, -0.0007369999999999998, -0.0067139999999999995, -0.014558], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t85f8b3c907ce4c1298af4f4fd119411d","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdb0a9d60e44444f2893464bcf22b2df8","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0013190000000000007, -0.0013220000000000003, -0.001327, -0.0007010000000000002, -0.0036970000000000006, -0.0007810000000000004, -0.007289, -0.015247], [8.0, 5.0, 7.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 6.75, 6.375, 2.5, 5.1875, 1.75, 3.46875, 1.734375]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdb0a9d60e44444f2893464bcf22b2df8","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0b6f2eb6d46542a6b19f2ea86f6bfabf","vertex_data","graph vertex data",["x", "y"],[[-2.0000000000002655e-06, -2.0000000000002655e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013109999999999997, -0.0013109999999999997, -0.001321000000000001, -0.000725, -0.003353, -0.0008410000000000015, -0.006753, -0.015202], [8.0, 7.0, 5.0, 6.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t0b6f2eb6d46542a6b19f2ea86f6bfabf","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta4b273537a45401782160eb78ac3a931","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.0012460000000000006, -0.0012490000000000001, -0.0012540000000000016, -0.0006580000000000006, -0.0034430000000000016, -0.0006890000000000004, -0.006958000000000001, -0.014328], [8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.5, 6.75, 5.875, 2.5, 4.9375, 1.75, 3.34375, 1.671875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"ta4b273537a45401782160eb78ac3a931","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdb770ef250534fc999d035a32f87e625","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.001216, -0.001217000000000001, -0.0012259999999999997, -0.0005970000000000003, -0.003913, -0.0006399999999999999, -0.00646, -0.014246], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tdb770ef250534fc999d035a32f87e625","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7a13bc1cd6b5430fb92229d535d3864e","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, -0.0013229999999999995, -0.001337999999999999, -0.001347000000000001, -0.0006549999999999993, -0.0032130000000000006, -0.000723999999999999, -0.007359, -0.015157], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7a13bc1cd6b5430fb92229d535d3864e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td8153e59fae541628bbc841be3805548","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.734723475976807e-18, -1.000000000001e-06, -0.0012060000000000005, -0.0012140000000000015, -0.0012190000000000013, -0.0005730000000000006, -0.0035650000000000005, -0.0006050000000000014, -0.006438000000000001, -0.013999000000000001], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td8153e59fae541628bbc841be3805548","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td7314f54221e4805a49e0fa6c485323c","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, -0.001254, -0.0012589999999999997, -0.001268, -0.0005819999999999992, -0.003549, -0.0006639999999999997, -0.0064399999999999995, -0.014244], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"td7314f54221e4805a49e0fa6c485323c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf72938c64ece4af195cb693b5d56ebfa","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -2.000000000002e-06, -2.000000000002e-06, -2.000000000002e-06, -1.000000000001e-06, -0.0012900000000000012, -0.001294, -0.0012990000000000015, -0.0006610000000000019, -0.0036190000000000007, -0.0007640000000000008, -0.006925000000000001, -0.014373], [6.0, 7.0, 8.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.5, 7.25, 6.125, 2.5, 5.0625, 1.75, 3.40625, 1.703125]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tf72938c64ece4af195cb693b5d56ebfa","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tef89253ee18d4fe29fa6d9937b710bfe","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -1.734723475976807e-18, 0.0, 0.0, 0.0, 0.0, -0.0012709999999999996, -0.001275, -0.0012790000000000006, -0.0005760000000000001, -0.0034920000000000003, -0.0006550000000000011, -0.00708, -0.014597], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tef89253ee18d4fe29fa6d9937b710bfe","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t85059f304438404e9eefcc02e4f0d44f","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012219999999999991, -0.0012329999999999997, -0.0012359999999999993, -0.0005859999999999997, -0.0036489999999999995, -0.0006189999999999998, -0.006666, -0.014662], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t85059f304438404e9eefcc02e4f0d44f","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfbc3d4ce94064ca8b9033c2eb033e40e","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0012570000000000012, -0.0012990000000000015, -0.001301, -0.0006069999999999999, -0.003734000000000001, -0.000678999999999999, -0.006928, -0.015184], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tfbc3d4ce94064ca8b9033c2eb033e40e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t00dbc656165b4110b07f214ae68a390e","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -9.999999999992654e-07, -0.0012340000000000007, -0.0012490000000000001, -0.0012510000000000004, -0.000589000000000001, -0.0035930000000000007, -0.000595, -0.007069, -0.014464], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t00dbc656165b4110b07f214ae68a390e","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t672f0624b4984450981f6c1e2a538ab6","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -9.999999999992654e-07, -0.0012110000000000003, -0.0012580000000000004, -0.0012600000000000007, -0.0005669999999999998, -0.0038639999999999994, -0.0007500000000000007, -0.006983, -0.014501], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t672f0624b4984450981f6c1e2a538ab6","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc6b4026e1eb04e4cac4a5262f1f43d74","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.000000000001e-06, -1.000000000001e-06, -0.0012770000000000004, -0.001287, -0.0012900000000000012, -0.0007360000000000005, -0.0034730000000000004, -0.0007830000000000007, -0.006273000000000001, -0.014793], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tc6b4026e1eb04e4cac4a5262f1f43d74","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6c619dd049514df5999cb96042086c15","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0012810000000000009, -0.0013220000000000003, -0.0013220000000000003, -0.0007740000000000004, -0.0033100000000000004, -0.0007880000000000005, -0.006549000000000001, -0.014863000000000001], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t6c619dd049514df5999cb96042086c15","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3eb033070c644c23b84661dbd4a8ebf4","vertex_data","graph vertex data",["x", "y"],[[-1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, 0.0, 0.0, -0.0012480000000000008, -0.0012640000000000012, -0.0012640000000000012, -0.0007419999999999996, -0.0033110000000000014, -0.0007610000000000013, -0.006389000000000001, -0.014977], [6.0, 8.0, 7.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 7.0, 6.0, 2.5, 5.0, 1.75, 3.375, 1.6875]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t3eb033070c644c23b84661dbd4a8ebf4","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2d1b36b6a0304bf78dc454b056d9520c","vertex_data","graph vertex data",["x", "y"],[[-9.999999999975306e-07, -9.999999999975306e-07, 0.0, -9.999999999975306e-07, -9.999999999975306e-07, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, -0.0013619999999999986, -0.0013740000000000002, -0.0013749999999999995, -0.0008109999999999992, -0.003443999999999999, -0.0008230000000000008, -0.0066619999999999995, -0.015927], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t2d1b36b6a0304bf78dc454b056d9520c","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4a2baea1965f44c3bbdfa5c599bdd096","vertex_data","graph vertex data",["x", "y"],[[-9.999999999992654e-07, -9.999999999992654e-07, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.999999999992654e-07, -0.0012840000000000004, -0.0012630000000000002, -0.0012840000000000004, -0.0007379999999999991, -0.0038200000000000005, -0.0007640000000000008, -0.006442, -0.014551999999999999], [5.0, 7.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t4a2baea1965f44c3bbdfa5c599bdd096","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7d479429d72e45779246d60386632539","vertex_data","graph vertex data",["x", "y"],[[0.0, 0.0, 0.0, -1.000000000001e-06, 0.0, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -0.0013190000000000007, -0.001340000000000001, -0.0013430000000000004, -0.0007270000000000002, -0.003384, -0.0007980000000000001, -0.006746, -0.01564], [6.0, 8.0, 5.0, 7.0, 4.0, 3.0, 2.0, 1.0, 0.0, 7.0, 6.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"t7d479429d72e45779246d60386632539","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 11, 10, 9, 9, 10, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 1, 0, 9, 10, 11, 13, 15]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcf75a30f4b5942c7a889389aa185ba99","vertex_data","graph vertex data",["x", "y"],[[-1.734723475976807e-18, -1.734723475976807e-18, -1.000000000001e-06, -1.000000000001e-06, -1.000000000001e-06, 0.0, 0.0, -1.000000000001e-06, 0.0, -0.001328000000000001, -0.001303000000000002, -0.0013370000000000014, -0.0009240000000000012, -0.003256000000000002, -0.0009469999999999999, -0.006131000000000001, -0.01498], [5.0, 7.0, 6.0, 8.0, 4.0, 3.0, 2.0, 1.0, 0.0, 6.0, 7.0, 6.5, 2.5, 5.25, 1.75, 3.5, 1.75]],"toyplot");
(function(tables, context_menu, io, owner_id, key, label, names, columns, filename)
        {
            tables.set(owner_id, key, names, columns);

            var owner = document.querySelector("#" + owner_id);
            function show_item(e)
            {
                return owner.contains(e.target);
            }

            function choose_item()
            {
                io.save_file("text/csv", "utf-8", tables.get_csv(owner_id, key), filename + ".csv");
            }

            context_menu.add_item("Save " + label + " as CSV", show_item, choose_item);
        })(modules["toyplot/tables"],modules["toyplot/menus/context"],modules["toyplot/io"],"tcf75a30f4b5942c7a889389aa185ba99","edge_data","graph edge data",["source", "target"],[[16, 14, 12, 12, 14, 15, 13, 10, 10, 11, 9, 9, 11, 13, 15, 16], [8, 7, 6, 5, 12, 14, 4, 3, 2, 10, 1, 0, 9, 11, 13, 15]],"toyplot");
})();</script></div></div>



```python
## returns a consensus tree
consensus = trees.get_consensus_tree()
```


```python
## returns the newick string, file, or url (the source of the multitrees object)
## you can get the actual newick string from the .treelist
trees.newick
```




    'http://eaton-lab.org/pdsb/full-r0.mcmc.txt'




```python
## a list of Toytree objects in this multitree object
## I show just the first 10 here.
trees.treelist[:10]
```




    [<toytree.tree.Toytree at 0x7f0407297210>,
     <toytree.tree.Toytree at 0x7f0407297390>,
     <toytree.tree.Toytree at 0x7f0407297810>,
     <toytree.tree.Toytree at 0x7f0407297c90>,
     <toytree.tree.Toytree at 0x7f0407312150>,
     <toytree.tree.Toytree at 0x7f0410627910>,
     <toytree.tree.Toytree at 0x7f040728edd0>,
     <toytree.tree.Toytree at 0x7f0407312a90>,
     <toytree.tree.Toytree at 0x7f0407312f10>,
     <toytree.tree.Toytree at 0x7f04073323d0>]




```python
## a conveniently accessible list of pretty colors
trees.colors
```




    ['rgba(40.0%,76.1%,64.7%,1.000)',
     'rgba(98.8%,55.3%,38.4%,1.000)',
     'rgba(55.3%,62.7%,79.6%,1.000)',
     'rgba(90.6%,54.1%,76.5%,1.000)',
     'rgba(65.1%,84.7%,32.9%,1.000)',
     'rgba(100.0%,85.1%,18.4%,1.000)',
     'rgba(89.8%,76.9%,58.0%,1.000)',
     'rgba(70.2%,70.2%,70.2%,1.000)']


